export declare namespace Schemas {
    /** Bulk issue property update request details. */
    interface BulkIssuePropertyUpdateRequest {
        /** The value of the property. The value must be a [valid](https://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters. */
        value?: string;
        /** EXPERIMENTAL. The Jira expression to calculate the value of the property. The value of the expression must be an object that can be converted to JSON, such as a number, boolean, string, list, or map. The context variables available to the expression are `issue` and `user`. Issues for which the expression returns a value whose JSON representation is longer than 32768 characters are ignored. */
        expression?: string;
        /** The bulk operation filter. */
        filter?: Schemas.IssueFilterForBulkPropertySet;
    }
    /** Bulk operation filter details. */
    interface IssueFilterForBulkPropertySet {
        /** List of issues to perform the bulk operation on. */
        entityIds?: number[];
        /** The value of properties to perform the bulk operation on. */
        currentValue?: string;
        /** Whether the bulk operation occurs only when the property is present on or absent from an issue. */
        hasProperty?: boolean;
    }
    /** Error messages from an operation. */
    interface ErrorCollection {
        /** The list of error messages produced by this operation. For example, "input parameter 'key' must be provided" */
        errorMessages?: string[];
        /** The list of errors by parameter returned by the operation. For example,"projectKey": "Project keys must start with an uppercase letter, followed by one or more uppercase alphanumeric characters." */
        errors?: {
            [key: string]: string;
        };
        status?: number;
    }
    /** Bulk operation filter details. */
    interface IssueFilterForBulkPropertyDelete {
        /** List of issues to perform the bulk delete operation on. */
        entityIds?: number[];
        /** The value of properties to perform the bulk operation on. */
        currentValue?: string;
    }
    /** Lists of issues and entity properties. See [Entity properties](https://developer.atlassian.com/cloud/jira/platform/jira-entity-properties/) for more information. */
    interface IssueEntityProperties {
        /** A list of entity property IDs. */
        entitiesIds?: number[];
        /** A list of entity property keys and values. */
        properties?: {
            [key: string]: Schemas.JsonNode;
        };
    }
    interface JsonNode {
        floatingPointNumber?: boolean;
        elements?: {};
        pojo?: boolean;
        number?: boolean;
        integralNumber?: boolean;
        int?: boolean;
        long?: boolean;
        double?: boolean;
        bigDecimal?: boolean;
        bigInteger?: boolean;
        textual?: boolean;
        boolean?: boolean;
        binary?: boolean;
        containerNode?: boolean;
        missingNode?: boolean;
        object?: boolean;
        valueNode?: boolean;
        numberValue?: number;
        numberType?: "INT" | "LONG" | "BIG_INTEGER" | "FLOAT" | "DOUBLE" | "BIG_DECIMAL";
        intValue?: number;
        longValue?: number;
        bigIntegerValue?: number;
        doubleValue?: number;
        decimalValue?: number;
        booleanValue?: boolean;
        binaryValue?: (Blob)[];
        valueAsInt?: number;
        valueAsLong?: number;
        valueAsDouble?: number;
        valueAsBoolean?: boolean;
        fieldNames?: {};
        textValue?: string;
        valueAsText?: string;
        array?: boolean;
        fields?: {};
        null?: boolean;
    }
    /** An issue ID with entity property values. See [Entity properties](https://developer.atlassian.com/cloud/jira/platform/jira-entity-properties/) for more information. */
    interface IssueEntityPropertiesForMultiUpdate {
        /** The ID of the issue. */
        issueID?: number;
        /** Entity properties to set on the issue. The maximum length of an issue property value is 32768 characters. */
        properties?: {
            [key: string]: Schemas.JsonNode;
        };
    }
    /** A list of issues and their respective properties to set or update. See [Entity properties](https://developer.atlassian.com/cloud/jira/platform/jira-entity-properties/) for more information. */
    interface MultiIssueEntityProperties {
        /** A list of issue IDs and their respective properties. */
        issues?: Schemas.IssueEntityPropertiesForMultiUpdate[];
    }
    interface IdBean {
        /** The ID of the permission scheme to associate with the project. Use the [Get all permission schemes](#api-rest-api-3-permissionscheme-get) resource to get a list of permission scheme IDs. */
        id: number;
    }
    interface AvatarUrlsBean {
        /** The URL of the item's 16x16 pixel avatar. */
        "16x16"?: string;
        /** The URL of the item's 24x24 pixel avatar. */
        "24x24"?: string;
        /** The URL of the item's 32x32 pixel avatar. */
        "32x32"?: string;
        /** The URL of the item's 48x48 pixel avatar. */
        "48x48"?: string;
    }
    /** Details about a permission granted to a user or group. */
    interface PermissionGrant {
        /** The ID of the permission granted details. */
        id?: number;
        /** The URL of the permission granted details. */
        self?: string;
        /** The user or group being granted the permission. It consists of a `type` and a type-dependent `parameter`. See [Holder object](../api-group-permission-schemes/#holder-object) in *Get all permission schemes* for more information. */
        holder?: Schemas.PermissionHolder;
        /** The permission to grant. This permission can be one of the built-in permissions or a custom permission added by an app. See [Built-in permissions](../api-group-permission-schemes/#built-in-permissions) in *Get all permission schemes* for more information about the built-in permissions. See the [project permission](https://developer.atlassian.com/cloud/jira/platform/modules/project-permission/) and [global permission](https://developer.atlassian.com/cloud/jira/platform/modules/global-permission/) module documentation for more information about custom permissions. */
        permission?: string;
    }
    /** Details of a user, group, field, or project role that holds a permission. See [Holder object](../api-group-permission-schemes/#holder-object) in *Get all permission schemes* for more information. */
    interface PermissionHolder {
        /** The type of permission holder. */
        type: string;
        /** The identifier of permission holder. */
        parameter?: string;
        /** Expand options that include additional permission holder details in the response. */
        expand?: string;
    }
    /** Details of a permission scheme. */
    interface PermissionScheme {
        [key: string]: {};
    }
    /** Details about a project. */
    interface ProjectDetails {
        /** The URL of the project details. */
        self?: string;
        /** The ID of the project. */
        id?: string;
        /** The key of the project. */
        key?: string;
        /** The name of the project. */
        name?: string;
        /** The [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes) of the project. */
        projectTypeKey?: "software" | "service_desk" | "business";
        /** Whether or not the project is simplified. */
        simplified?: boolean;
        /** The URLs of the project's avatars. */
        avatarUrls?: Schemas.AvatarUrlsBean;
        /** The category the project belongs to. */
        projectCategory?: Schemas.UpdatedProjectCategory;
    }
    /** The projects the item is associated with. Indicated for items associated with [next-gen projects](https://confluence.atlassian.com/x/loMyO). */
    interface Scope {
        [key: string]: {};
    }
    /** A project category. */
    interface UpdatedProjectCategory {
        /** The URL of the project category. */
        self?: string;
        /** The ID of the project category. */
        id?: string;
        /** The name of the project category. */
        description?: string;
        /** The description of the project category. */
        name?: string;
    }
    /** Details about permissions. */
    interface Permissions {
        /** List of permissions. */
        permissions?: {
            [key: string]: Schemas.UserPermission;
        };
    }
    /** Details of a permission and its availability to a user. */
    interface UserPermission {
        [key: string]: {};
    }
    /** Details of global permissions to look up and project permissions with associated projects and issues to look up. */
    interface BulkPermissionsRequestBean {
        /** Project permissions with associated projects and issues to look up. */
        projectPermissions?: Schemas.BulkProjectPermissions[];
        /** Global permissions to look up. */
        globalPermissions?: string[];
        /** The account ID of a user. */
        accountId?: string;
    }
    /** Details of project permissions and associated issues and projects to look up. */
    interface BulkProjectPermissions {
        /** List of issue IDs. */
        issues?: number[];
        /** List of project IDs. */
        projects?: number[];
        /** List of project permissions. */
        permissions: string[];
    }
    /** Details of global and project permissions granted to the user. */
    interface BulkPermissionGrants {
        /** List of project permissions and the projects and issues those permissions provide access to. */
        projectPermissions: Schemas.BulkProjectPermissionGrants[];
        /** List of permissions granted to the user. */
        globalPermissions: string[];
    }
    /** List of project permissions and the projects and issues those permissions grant access to. */
    interface BulkProjectPermissionGrants {
        /** A project permission, */
        permission: string;
        /** IDs of the issues the user has the permission for. */
        issues: number[];
        /** IDs of the projects the user has the permission for. */
        projects: number[];
    }
    interface PermissionsKeysBean {
        /** A list of permission keys. */
        permissions: string[];
    }
    /** A list of projects in which a user is granted permissions. */
    interface PermittedProjects {
        /** A list of projects. */
        projects?: Schemas.ProjectIdentifierBean[];
    }
    /** The identifiers for a project. */
    interface ProjectIdentifierBean {
        /** The ID of the project. */
        id?: number;
        /** The key of the project. */
        key?: string;
    }
    /** A project's sender email address. */
    interface ProjectEmailAddress {
        /** The email address. */
        emailAddress?: string;
        /** When using a custom domain, the status of the email address. */
        emailAddressStatus?: string[];
    }
    /** Details about a project type. */
    interface ProjectType {
        /** The key of the project type. */
        key?: string;
        /** The formatted key of the project type. */
        formattedKey?: string;
        /** The key of the project type's description. */
        descriptionI18nKey?: string;
        /** The icon of the project type. */
        icon?: string;
        /** The color of the project type. */
        color?: string;
    }
    /** Details about a group. */
    interface GroupDetails {
        /** The name of the group. */
        name?: string;
        /** The ID of the group, if available, which uniquely identifies the group across all Atlassian products. For example, *952d12c3-5b5b-4d04-bb32-44d383afc4b2*. */
        groupId?: string | null;
    }
    /** A page of items. */
    interface PageBeanGroupDetails {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.GroupDetails[];
    }
    /** List of issue level security items in a project. */
    interface ProjectIssueSecurityLevels {
        /** Issue level security items list. */
        levels: Schemas.SecurityLevel[];
    }
    /** Details of an issue level security item. */
    interface SecurityLevel {
        /** The URL of the issue level security item. */
        self?: string;
        /** The ID of the issue level security item. */
        id?: string;
        /** The description of the issue level security item. */
        description?: string;
        /** The name of the issue level security item. */
        name?: string;
    }
    /** Details about a notification associated with an event. */
    interface EventNotification {
        /** Expand options that include additional event notification details in the response. */
        expand?: string;
        /** The ID of the notification. */
        id?: number;
        /** Identifies the recipients of the notification. */
        notificationType?: "CurrentAssignee" | "Reporter" | "CurrentUser" | "ProjectLead" | "ComponentLead" | "User" | "Group" | "ProjectRole" | "EmailAddress" | "AllWatchers" | "UserCustomField" | "GroupCustomField";
        /**
         * The value of the `notificationType`:
         *
         *  *  `User` The `parameter` is the user account ID.
         *  *  `Group` The `parameter` is the group name.
         *  *  `ProjectRole` The `parameter` is the project role ID.
         *  *  `UserCustomField` The `parameter` is the ID of the custom field.
         *  *  `GroupCustomField` The `parameter` is the ID of the custom field.
         */
        parameter?: string;
        /** The specified group. */
        group?: Schemas.GroupName;
        /** The custom user or group field. */
        field?: Schemas.FieldDetails;
        /** The email address. */
        emailAddress?: string;
        /** The specified project role. */
        projectRole?: Schemas.ProjectRole;
        /** The specified user. */
        user?: Schemas.UserDetails;
    }
    /** Details about a field. */
    interface FieldDetails {
        /** The ID of the field. */
        id?: string;
        /** The key of the field. */
        key?: string;
        /** The name of the field. */
        name?: string;
        /** Whether the field is a custom field. */
        custom?: boolean;
        /** Whether the content of the field can be used to order lists. */
        orderable?: boolean;
        /** Whether the field can be used as a column on the issue navigator. */
        navigable?: boolean;
        /** Whether the content of the field can be searched. */
        searchable?: boolean;
        /** The names that can be used to reference the field in an advanced search. For more information, see [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ). */
        clauseNames?: string[];
        /** The scope of the field. */
        scope?: Schemas.Scope;
        /** The data schema for the field. */
        schema?: Schemas.JsonTypeBean;
    }
    /** Details about a group name. */
    interface GroupName {
        /** The name of group. */
        name?: string;
        /** The URL for these group details. */
        self?: string;
    }
    /** The schema of a field. */
    interface JsonTypeBean {
        /** The data type of the field. */
        type: string;
        /** When the data type is an array, the name of the field items within the array. */
        items?: string;
        /** If the field is a system field, the name of the field. */
        system?: string;
        /** If the field is a custom field, the URI of the field. */
        custom?: string;
        /** If the field is a custom field, the custom ID of the field. */
        customId?: number;
        /** If the field is a custom field, the configuration of the field. */
        configuration?: {
            [key: string]: any;
        };
    }
    /** Details about a notification event. */
    interface NotificationEvent {
        /** The ID of the event. The event can be a [Jira system event](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-eventsEvents) or a [custom event](https://confluence.atlassian.com/x/AIlKLg). */
        id?: number;
        /** The name of the event. */
        name?: string;
        /** The description of the event. */
        description?: string;
        /** The template of the event. Only custom events configured by Jira administrators have template. */
        templateEvent?: Schemas.NotificationEvent;
    }
    /** Details about a notification scheme. */
    interface NotificationScheme {
        /** Expand options that include additional notification scheme details in the response. */
        expand?: string;
        /** The ID of the notification scheme. */
        id?: number;
        self?: string;
        /** The name of the notification scheme. */
        name?: string;
        /** The description of the notification scheme. */
        description?: string;
        /** The notification events and associated recipients. */
        notificationSchemeEvents?: Schemas.NotificationSchemeEvent[];
        /** The scope of the notification scheme. */
        scope?: Schemas.Scope;
    }
    /** Details about a notification scheme event. */
    interface NotificationSchemeEvent {
        event?: Schemas.NotificationEvent;
        notifications?: Schemas.EventNotification[];
    }
    /** Details about the roles in a project. */
    interface ProjectRole {
        /** The URL the project role details. */
        self?: string;
        /** The name of the project role. */
        name?: string;
        /** The ID of the project role. */
        id?: number;
        /** The description of the project role. */
        description?: string;
        /** The list of users who act in this role. */
        actors?: Schemas.RoleActor[];
        /** The scope of the role. Indicated for roles associated with [next-gen projects](https://confluence.atlassian.com/x/loMyO). */
        scope?: Schemas.Scope;
        /** The translated name of the project role. */
        translatedName?: string;
        /** Whether the calling user is part of this role. */
        currentUserRole?: boolean;
        /** Whether this role is the admin role for the project. */
        admin?: boolean;
        /** Whether the roles are configurable for this project. */
        roleConfigurable?: boolean;
        /** Whether this role is the default role for the project */
        default?: boolean;
    }
    /** Details of the group associated with the role. */
    interface ProjectRoleGroup {
        /** The display name of the group. */
        displayName?: string;
        /** The name of the group */
        name?: string;
    }
    /** Details of the user associated with the role. */
    interface ProjectRoleUser {
        /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Returns *unknown* if the record is deleted and corrupted, for example, as the result of a server import. */
        accountId?: string;
    }
    /** Details about a user assigned to a project role. */
    interface RoleActor {
        /** The ID of the role actor. */
        id?: number;
        /** The display name of the role actor. For users, depending on the user’s privacy setting, this may return an alternative value for the user's name. */
        displayName?: string;
        /** The type of role actor. */
        type?: "atlassian-group-role-actor" | "atlassian-user-role-actor";
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        name?: string;
        /** The avatar of the role actor. */
        avatarUrl?: string;
        actorUser?: Schemas.ProjectRoleUser;
        actorGroup?: Schemas.ProjectRoleGroup;
    }
    /**
     * User details permitted by the user's Atlassian Account privacy settings. However, be aware of these exceptions:
     *
     *  *  User record deleted from Atlassian: This occurs as the result of a right to be forgotten request. In this case, `displayName` provides an indication and other parameters have default values or are blank (for example, email is blank).
     *  *  User record corrupted: This occurs as a results of events such as a server import and can only happen to deleted users. In this case, `accountId` returns *unknown* and all other parameters have fallback values.
     *  *  User record unavailable: This usually occurs due to an internal service outage. In this case, all parameters have fallback values.
     */
    interface UserDetails {
        /** The URL of the user. */
        self?: string;
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        name?: string;
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        key?: string;
        /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
        accountId?: string;
        /** The email address of the user. Depending on the user’s privacy settings, this may be returned as null. */
        emailAddress?: string;
        /** The avatars of the user. */
        avatarUrls?: Schemas.AvatarUrlsBean;
        /** The display name of the user. Depending on the user’s privacy settings, this may return an alternative value. */
        displayName?: string;
        /** Whether the user is active. */
        active?: boolean;
        /** The time zone specified in the user's profile. Depending on the user’s privacy settings, this may be returned as null. */
        timeZone?: string;
        /** The type of account represented by this user. This will be one of 'atlassian' (normal users), 'app' (application user) or 'customer' (Jira Service Desk customer user) */
        accountType?: string;
    }
    /** A page of items. */
    interface PageBeanNotificationScheme {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.NotificationScheme[];
    }
    /** Jira instance health check results. Deprecated and no longer returned. */
    interface HealthCheckResult {
        /** The name of the Jira health check item. */
        name?: string;
        /** The description of the Jira health check item. */
        description?: string;
        /** Whether the Jira health check item passed or failed. */
        passed?: boolean;
    }
    /** Details about the Jira instance. */
    interface ServerInformation {
        /** The base URL of the Jira instance. */
        baseUrl?: string;
        /** The version of Jira. */
        version?: string;
        /** The major, minor, and revision version numbers of the Jira version. */
        versionNumbers?: number[];
        /** The type of server deployment. This is always returned as *Cloud*. */
        deploymentType?: string;
        /** The build number of the Jira version. */
        buildNumber?: number;
        /** The timestamp when the Jira version was built. */
        buildDate?: string;
        /** The time in Jira when this request was responded to. */
        serverTime?: string;
        /** The unique identifier of the Jira version. */
        scmInfo?: string;
        /** The name of the Jira instance. */
        serverTitle?: string;
        /** Jira instance health check results. Deprecated and no longer returned. */
        healthChecks?: Schemas.HealthCheckResult[];
    }
    /** Details of an issue type. */
    interface IssueTypeInfo {
        /** The ID of the issue type. */
        id?: number;
        /** The name of the issue type. */
        name?: string;
        /** The avatar of the issue type. */
        avatarId?: number;
    }
    /** The hierarchy of issue types within a project. */
    interface ProjectIssueTypeHierarchy {
        /** The ID of the project. */
        projectId?: number;
        /** Details of an issue type hierarchy level. */
        hierarchy?: Schemas.ProjectIssueTypesHierarchyLevel[];
    }
    /** Details of an issue type hierarchy level. */
    interface ProjectIssueTypesHierarchyLevel {
        /** The ID of the issue type hierarchy level. This property is deprecated, see [Change notice: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        entityId?: string;
        /** The level of the issue type hierarchy level. */
        level?: number;
        /** The name of the issue type hierarchy level. */
        name?: string;
        /** The list of issue types in the hierarchy level. */
        issueTypes?: Schemas.IssueTypeInfo[];
    }
    /** Details about a task. */
    interface TaskProgressBeanObject {
        /** The URL of the task. */
        self: string;
        /** The ID of the task. */
        id: string;
        /** The description of the task. */
        description?: string;
        /** The status of the task. */
        status: "ENQUEUED" | "RUNNING" | "COMPLETE" | "FAILED" | "CANCEL_REQUESTED" | "CANCELLED" | "DEAD";
        /** Information about the progress of the task. */
        message?: string;
        /** The result of the task execution. */
        result?: any;
        /** The ID of the user who submitted the task. */
        submittedBy: number;
        /** The progress of the task, as a percentage complete. */
        progress: number;
        /** The execution time of the task, in milliseconds. */
        elapsedRuntime: number;
        /** A timestamp recording when the task was submitted. */
        submitted: number;
        /** A timestamp recording when the task was started. */
        started?: number;
        /** A timestamp recording when the task was finished. */
        finished?: number;
        /** A timestamp recording when the task progress was last updated. */
        lastUpdate: number;
    }
    /** A list of JQL queries to parse. */
    interface JqlQueriesToParse {
        /** A list of queries to parse. */
        queries: string[];
    }
    /** A JQL query clause that consists of nested clauses. For example, `(labels in (urgent, blocker) OR lastCommentedBy = currentUser()). Note that, where nesting is not defined, the parser nests JQL clauses based on the operator precedence. For example, "A OR B AND C" is parsed as "(A OR B) AND C". See Setting the precedence of operators for more information about precedence in JQL queries.` */
    interface CompoundClause {
        /** The list of nested clauses. */
        clauses: Schemas.JqlQueryClause[];
        /** The operator between the clauses. */
        operator: "and" | "or" | "not";
    }
    /** A clause that asserts whether a field was changed. For example, `status CHANGED AFTER startOfMonth(-1M)`.See [CHANGED](https://confluence.atlassian.com/x/dgiiLQ#Advancedsearching-operatorsreference-CHANGEDCHANGED) for more information about the CHANGED operator. */
    interface FieldChangedClause {
        field: Schemas.JqlQueryField;
        /** The operator applied to the field. */
        operator: "changed";
        /** The list of time predicates. */
        predicates: Schemas.JqlQueryClauseTimePredicate[];
    }
    /** A clause that asserts the current value of a field. For example, `summary ~ test`. */
    interface FieldValueClause {
        field: Schemas.JqlQueryField;
        /** The operator between the field and operand. */
        operator: "=" | "!=" | ">" | "<" | ">=" | "<=" | "in" | "not in" | "~" | "~=" | "is" | "is not";
        operand: Schemas.JqlQueryClauseOperand;
    }
    /** A clause that asserts a previous value of a field. For example, `status WAS "Resolved" BY currentUser() BEFORE "2019/02/02"`. See [WAS](https://confluence.atlassian.com/x/dgiiLQ#Advancedsearching-operatorsreference-WASWAS) for more information about the WAS operator. */
    interface FieldWasClause {
        field: Schemas.JqlQueryField;
        /** The operator between the field and operand. */
        operator: "was" | "was in" | "was not in" | "was not";
        operand: Schemas.JqlQueryClauseOperand;
        /** The list of time predicates. */
        predicates: Schemas.JqlQueryClauseTimePredicate[];
    }
    /** An operand that is a function. See [Advanced searching - functions reference](https://confluence.atlassian.com/x/dwiiLQ) for more information about JQL functions. */
    interface FunctionOperand {
        /** The name of the function. */
        function: string;
        /** The list of function arguments. */
        arguments: string[];
    }
    /** A parsed JQL query. */
    interface JqlQuery {
        where?: Schemas.JqlQueryClause;
        orderBy?: Schemas.JqlQueryOrderByClause;
    }
    type JqlQueryClause = never;
    type JqlQueryClauseOperand = never;
    /** A time predicate for a temporal JQL clause. */
    interface JqlQueryClauseTimePredicate {
        /** The operator between the field and the operand. */
        operator: "before" | "after" | "from" | "to" | "on" | "during" | "by";
        operand: Schemas.JqlQueryClauseOperand;
    }
    /** A field used in a JQL query. See [Advanced searching - fields reference](https://confluence.atlassian.com/x/dAiiLQ) for more information about fields in JQL queries. */
    interface JqlQueryField {
        /** The name of the field. */
        name: string;
        /** When the field refers to a value in an entity property, details of the entity property value. */
        property?: Schemas.JqlQueryFieldEntityProperty[];
    }
    /** Details of an entity property. */
    interface JqlQueryFieldEntityProperty {
        /** The object on which the property is set. */
        entity: string;
        /** The key of the property. */
        key: string;
        /** The path in the property value to query. */
        path: string;
        /** The type of the property value extraction. Not available if the extraction for the property is not registered on the instance with the [Entity property](https://developer.atlassian.com/cloud/jira/platform/modules/entity-property/) module. */
        type?: "number" | "string" | "text" | "date" | "user";
    }
    /** Details of the order-by JQL clause. */
    interface JqlQueryOrderByClause {
        /** The list of order-by clause fields and their ordering directives. */
        fields: Schemas.JqlQueryOrderByClauseElement[];
    }
    /** An element of the order-by JQL clause. */
    interface JqlQueryOrderByClauseElement {
        field: Schemas.JqlQueryField;
        /** The direction in which to order the results. */
        direction?: "asc" | "desc";
    }
    type JqlQueryUnitaryOperand = never;
    /** An operand that is a JQL keyword. See [Advanced searching - keywords reference](https://confluence.atlassian.com/jiracorecloud/advanced-searching-keywords-reference-765593717.html#Advancedsearching-keywordsreference-EMPTYEMPTY) for more information about operand keywords. */
    interface KeywordOperand {
        /** The keyword that is the operand value. */
        keyword: "empty";
    }
    /** An operand that is a list of values. */
    interface ListOperand {
        /** The list of operand values. */
        values: Schemas.JqlQueryUnitaryOperand[];
    }
    /** A list of parsed JQL queries. */
    interface ParsedJqlQueries {
        /** A list of parsed JQL queries. */
        queries: Schemas.ParsedJqlQuery[];
    }
    /** Details of a parsed JQL query. */
    interface ParsedJqlQuery {
        /** The JQL query that was parsed and validated. */
        query: string;
        /** The syntax tree of the query. Empty if the query was invalid. */
        structure?: Schemas.JqlQuery;
        /** The list of syntax or validation errors. */
        errors?: string[];
    }
    /** An operand that is a user-provided value. */
    interface ValueOperand {
        /** The operand value. */
        value: string;
    }
    /** List of issues and JQL queries. */
    interface IssuesAndJQLQueries {
        /** A list of JQL queries. */
        jqls: string[];
        /** A list of issue IDs. */
        issueIds: number[];
    }
    /** A list of matched issues or errors for each JQL query, in the order the JQL queries were passed. */
    interface IssueMatches {
        matches: Schemas.IssueMatchesForJQL[];
    }
    /** A list of the issues matched to a JQL query or details of errors encountered during matching. */
    interface IssueMatchesForJQL {
        /** A list of issue IDs. */
        matchedIssues: number[];
        /** A list of errors. */
        errors: string[];
    }
    /** Details of an issue navigator column item. */
    interface ColumnItem {
        /** The issue navigator column label. */
        label?: string;
        /** The issue navigator column value. */
        value?: string;
    }
    /** Details about a license for the Jira instance. */
    interface License {
        /** The applications under this license. */
        applications: Schemas.LicensedApplication[];
    }
    /** Details about a licensed Jira application. */
    interface LicensedApplication {
        /** The ID of the application. */
        id: string;
        /** The licensing plan. */
        plan: "UNLICENSED" | "FREE" | "PAID";
    }
    /** Details about an issue event. */
    interface IssueEvent {
        /** The ID of the event. */
        id?: number;
        /** The name of the event. */
        name?: string;
    }
    /** Details about the configuration of Jira. */
    interface Configuration {
        /** Whether the ability for users to vote on issues is enabled. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details. */
        votingEnabled?: boolean;
        /** Whether the ability for users to watch issues is enabled. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details. */
        watchingEnabled?: boolean;
        /** Whether the ability to create unassigned issues is enabled. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details. */
        unassignedIssuesAllowed?: boolean;
        /** Whether the ability to create subtasks for issues is enabled. */
        subTasksEnabled?: boolean;
        /** Whether the ability to link issues is enabled. */
        issueLinkingEnabled?: boolean;
        /** Whether the ability to track time is enabled. This property is deprecated. */
        timeTrackingEnabled?: boolean;
        /** Whether the ability to add attachments to issues is enabled. */
        attachmentsEnabled?: boolean;
        /** The configuration of time tracking. */
        timeTrackingConfiguration?: Schemas.TimeTrackingConfiguration;
    }
    /** Details of the time tracking configuration. */
    interface TimeTrackingConfiguration {
        /** The number of hours in a working day. */
        workingHoursPerDay: number;
        /** The number of days in a working week. */
        workingDaysPerWeek: number;
        /** The format that will appear on an issue's *Time Spent* field. */
        timeFormat: "pretty" | "days" | "hours";
        /** The default unit of time applied to logged time. */
        defaultUnit: "minute" | "hour" | "day" | "week";
    }
    /** Details of an application property. */
    interface ApplicationProperty {
        /** The ID of the application property. The ID and key are the same. */
        id?: string;
        /** The key of the application property. The ID and key are the same. */
        key?: string;
        /** The new value. */
        value?: string;
        /** The name of the application property. */
        name?: string;
        /** The description of the application property. */
        desc?: string;
        /** The data type of the application property. */
        type?: string;
        /** The default value of the application property. */
        defaultValue?: string;
        example?: string;
        /** The allowed values, if applicable. */
        allowedValues?: string[];
    }
    interface SimpleApplicationPropertyBean {
        /** The ID of the application property. */
        id?: string;
        /** The new value. */
        value?: string;
    }
    /** List of all permission schemes. */
    interface PermissionSchemes {
        /** Permission schemes list. */
        permissionSchemes?: Schemas.PermissionScheme[];
    }
    /** List of permission grants. */
    interface PermissionGrants {
        /** Permission grants list. */
        permissions?: Schemas.PermissionGrant[];
        /** Expand options that include additional permission grant details in the response. */
        expand?: string;
    }
    /** Details of an application role. */
    interface ApplicationRole {
        /** The key of the application role. */
        key?: string;
        /** The groups associated with the application role. */
        groups?: string[];
        /** The display name of the application role. */
        name?: string;
        /** The groups that are granted default access for this application role. */
        defaultGroups?: string[];
        /** Determines whether this application role should be selected by default on user creation. */
        selectedByDefault?: boolean;
        /** Deprecated. */
        defined?: boolean;
        /** The maximum count of users on your license. */
        numberOfSeats?: number;
        /** The count of users remaining on your license. */
        remainingSeats?: number;
        /** The number of users counting against your license. */
        userCount?: number;
        /** The [type of users](https://confluence.atlassian.com/x/lRW3Ng) being counted against your license. */
        userCountDescription?: string;
        hasUnlimitedSeats?: boolean;
        /** Indicates if the application role belongs to Jira platform (`jira-core`). */
        platform?: boolean;
    }
    /** Details about a workflow. */
    interface DeprecatedWorkflow {
        /** The name of the workflow. */
        name?: string;
        /** The description of the workflow. */
        description?: string;
        /** The datetime the workflow was last modified. */
        lastModifiedDate?: string;
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        lastModifiedUser?: string;
        /** The account ID of the user that last modified the workflow. */
        lastModifiedUserAccountId?: string;
        /** The number of steps included in the workflow. */
        steps?: number;
        /** The scope where this workflow applies */
        scope?: Schemas.Scope;
        default?: boolean;
    }
    /** A workflow transition condition. */
    interface CreateWorkflowCondition {
        /** The compound condition operator. */
        operator?: "AND" | "OR";
        /** The list of workflow conditions. */
        conditions?: Schemas.CreateWorkflowCondition[];
        /** The type of the transition rule. */
        type?: string;
        /** EXPERIMENTAL. The configuration of the transition rule. */
        configuration?: {
            [key: string]: any;
        };
    }
    /** The details of a workflow. */
    interface CreateWorkflowDetails {
        /** The name of the workflow. The name must be unique. The maximum length is 255 characters. Characters can be separated by a whitespace but the name cannot start or end with a whitespace. */
        name: string;
        /** The description of the workflow. The maximum length is 1000 characters. */
        description?: string;
        /**
         * The transitions of the workflow. For the request to be valid, these transitions must:
         *
         *  *  include one *initial* transition.
         *  *  not use the same name for a *global* and *directed* transition.
         *  *  have a unique name for each *global* transition.
         *  *  have a unique 'to' status for each *global* transition.
         *  *  have unique names for each transition from a status.
         *  *  not have a 'from' status on *initial* and *global* transitions.
         *  *  have a 'from' status on *directed* transitions.
         *
         * All the transition statuses must be included in `statuses`.
         */
        transitions: Schemas.CreateWorkflowTransitionDetails[];
        /** The statuses of the workflow. Any status that does not include a transition is added to the workflow without a transition. */
        statuses: Schemas.CreateWorkflowStatusDetails[];
    }
    /** The details of a transition status. */
    interface CreateWorkflowStatusDetails {
        /** The ID of the status. */
        id: string;
        /** The properties of the status. */
        properties?: {
            [key: string]: string;
        };
    }
    /** The details of a workflow transition. */
    interface CreateWorkflowTransitionDetails {
        /** The name of the transition. The maximum length is 60 characters. */
        name: string;
        /** The description of the transition. The maximum length is 1000 characters. */
        description?: string;
        /** The statuses the transition can start from. */
        from?: string[];
        /** The status the transition goes to. */
        to: string;
        /** The type of the transition. */
        type: "global" | "initial" | "directed";
        /** The rules of the transition. */
        rules?: Schemas.CreateWorkflowTransitionRulesDetails;
        /** The screen of the transition. */
        screen?: Schemas.CreateWorkflowTransitionScreenDetails;
        /** The properties of the transition. */
        properties?: {
            [key: string]: string;
        };
    }
    /** A workflow transition rule. */
    interface CreateWorkflowTransitionRule {
        /** The type of the transition rule. */
        type: string;
        /** EXPERIMENTAL. The configuration of the transition rule. */
        configuration?: {
            [key: string]: any;
        };
    }
    /** The details of a workflow transition rules. */
    interface CreateWorkflowTransitionRulesDetails {
        /** The workflow conditions. */
        conditions?: Schemas.CreateWorkflowCondition;
        /** The workflow validators. */
        validators?: Schemas.CreateWorkflowTransitionRule[];
        /** The workflow post functions. */
        postFunctions?: Schemas.CreateWorkflowTransitionRule[];
    }
    /** The details of a transition screen. */
    interface CreateWorkflowTransitionScreenDetails {
        /** The ID of the screen. */
        id: string;
    }
    /** The classic workflow identifiers. */
    interface WorkflowIDs {
        /** The name of the workflow. */
        name: string;
        /** The entity ID of the workflow. */
        entityId?: string;
    }
    /** Details about the server Jira is running on. */
    interface WorkflowTransitionProperty {
        [key: string]: {};
    }
    /** A page of items. */
    interface PageBeanWorkflow {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Workflow[];
    }
    /** Properties that identify a published workflow. */
    interface PublishedWorkflowId {
        /** The name of the workflow. */
        name: string;
        /** The entity ID of the workflow. */
        entityId?: string;
    }
    /** Details of a workflow transition. */
    interface Transition {
        /** The ID of the transition. */
        id: string;
        /** The name of the transition. */
        name: string;
        /** The description of the transition. */
        description: string;
        /** The statuses the transition can start from. */
        from: string[];
        /** The status the transition goes to. */
        to: string;
        /** The type of the transition. */
        type: "global" | "initial" | "directed";
        screen?: Schemas.TransitionScreenDetails;
        rules?: Schemas.WorkflowRules;
        /** The properties of the transition. */
        properties?: {
            [key: string]: any;
        };
    }
    /** The details of a transition screen. */
    interface TransitionScreenDetails {
        /** The ID of the screen. */
        id: string;
        /** The name of the screen. */
        name?: string;
    }
    /** Details about a workflow. */
    interface Workflow {
        id: Schemas.PublishedWorkflowId;
        /** The description of the workflow. */
        description: string;
        /** The transitions of the workflow. */
        transitions?: Schemas.Transition[];
        /** The statuses of the workflow. */
        statuses?: Schemas.WorkflowStatus[];
        /** Whether this is the default workflow. */
        isDefault?: boolean;
        /** The workflow schemes the workflow is assigned to. */
        schemes?: Schemas.WorkflowSchemeIdName[];
        /** The projects the workflow is assigned to, through workflow schemes. */
        projects?: Schemas.ProjectDetails[];
        /** Whether the workflow has a draft version. */
        hasDraftWorkflow?: boolean;
        operations?: Schemas.WorkflowOperations;
        /** The creation date of the workflow. */
        created?: string;
        /** The last edited date of the workflow. */
        updated?: string;
    }
    /** A compound workflow transition rule condition. This object returns `nodeType` as `compound`. */
    interface WorkflowCompoundCondition {
        /** The compound condition operator. */
        operator: "AND" | "OR";
        /** The list of workflow conditions. */
        conditions: Schemas.WorkflowCondition[];
        nodeType: string;
    }
    type WorkflowCondition = Schemas.WorkflowSimpleCondition | Schemas.WorkflowCompoundCondition;
    /** Operations allowed on a workflow */
    interface WorkflowOperations {
        /** Whether the workflow can be updated. */
        canEdit: boolean;
        /** Whether the workflow can be deleted. */
        canDelete: boolean;
    }
    /** A collection of transition rules. */
    interface WorkflowRules {
        /** The workflow conditions. ([Deprecated](https://community.developer.atlassian.com/t/deprecation-of-conditions-body-param/48884)) */
        conditions?: Schemas.WorkflowTransitionRule[];
        conditionsTree?: Schemas.WorkflowCondition;
        /** The workflow validators. */
        validators?: Schemas.WorkflowTransitionRule[];
        /** The workflow post functions. */
        postFunctions?: Schemas.WorkflowTransitionRule[];
    }
    /** The ID and the name of the workflow scheme. */
    interface WorkflowSchemeIdName {
        /** The ID of the workflow scheme. */
        id: string;
        /** The name of the workflow scheme. */
        name: string;
    }
    /** A workflow transition rule condition. This object returns `nodeType` as `simple`. */
    interface WorkflowSimpleCondition {
        /** The type of the transition rule. */
        type: string;
        /** EXPERIMENTAL. The configuration of the transition rule. */
        configuration?: {};
        nodeType: string;
    }
    /** Details of a workflow status. */
    interface WorkflowStatus {
        /** The ID of the issue status. */
        id: string;
        /** The name of the status in the workflow. */
        name: string;
        /** Additional properties that modify the behavior of issues in this status. Supports the properties `jira.issue.editable` and `issueEditable` (deprecated) that indicate whether issues are editable. */
        properties?: {
            [key: string]: any;
        };
    }
    /** A workflow transition rule. */
    interface WorkflowTransitionRule {
        /** The type of the transition rule. */
        type: string;
        /** EXPERIMENTAL. The configuration of the transition rule. */
        configuration?: any;
    }
    /** A workflow transition rule. */
    interface ConnectWorkflowTransitionRule {
        /** The ID of the transition rule. */
        id: string;
        /** The key of the rule, as defined in the Connect app descriptor. */
        key: string;
        configuration: Schemas.RuleConfiguration;
        transition?: Schemas.WorkflowTransition;
    }
    /** A page of items. */
    interface PageBeanWorkflowTransitionRules {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.WorkflowTransitionRules[];
    }
    /** A rule configuration. */
    interface RuleConfiguration {
        /** Configuration of the rule, as it is stored by the Connect app on the rule configuration page. */
        value: string;
        /** EXPERIMENTAL: Whether the rule is disabled. */
        disabled?: boolean;
        /** EXPERIMENTAL: A tag used to filter rules in [Get workflow transition rule configurations](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-rules/#api-rest-api-3-workflow-rule-config-get). */
        tag?: string;
    }
    /** Properties that identify a workflow. */
    interface WorkflowId {
        /** The name of the workflow. */
        name: string;
        /** Whether the workflow is in the draft state. */
        draft: boolean;
    }
    /** A workflow transition. */
    interface WorkflowTransition {
        /** The transition ID. */
        id: number;
        /** The transition name. */
        name: string;
    }
    /** A workflow with transition rules. */
    interface WorkflowTransitionRules {
        workflowId: Schemas.WorkflowId;
        /** The list of post functions within the workflow. */
        postFunctions: Schemas.ConnectWorkflowTransitionRule[];
        /** The list of conditions within the workflow. */
        conditions: Schemas.ConnectWorkflowTransitionRule[];
        /** The list of validators within the workflow. */
        validators: Schemas.ConnectWorkflowTransitionRule[];
    }
    /** Details about a workflow configuration update request. */
    interface WorkflowTransitionRulesUpdate {
        /** The list of workflows with transition rules to update. */
        workflows: Schemas.WorkflowTransitionRules[];
    }
    /** Details of any errors encountered while updating workflow transition rules for a workflow. */
    interface WorkflowTransitionRulesUpdateErrorDetails {
        workflowId: Schemas.WorkflowId;
        /** A list of transition rule update errors, indexed by the transition rule ID. Any transition rule that appears here wasn't updated. */
        ruleUpdateErrors: {
            [key: string]: string[];
        };
        /** The list of errors that specify why the workflow update failed. The workflow was not updated if the list contains any entries. */
        updateErrors: string[];
    }
    /** Details of any errors encountered while updating workflow transition rules. */
    interface WorkflowTransitionRulesUpdateErrors {
        /** A list of workflows. */
        updateResults: Schemas.WorkflowTransitionRulesUpdateErrorDetails[];
    }
    /** Details about a workflow configuration update request. */
    interface WorkflowTransitionRulesDetails {
        workflowId: Schemas.WorkflowId;
        /** The list of connect workflow rule IDs. */
        workflowRuleIds: string[];
    }
    /** Details of workflows and their transition rules to delete. */
    interface WorkflowsWithTransitionRulesDetails {
        /** The list of workflows with transition rules to delete. */
        workflows: Schemas.WorkflowTransitionRulesDetails[];
    }
    /** Details about the time tracking provider. */
    interface TimeTrackingProvider {
        /** The key for the time tracking provider. For example, *JIRA*. */
        key: string;
        /** The name of the time tracking provider. For example, *JIRA provided time tracking*. */
        name?: string;
        /** The URL of the configuration page for the time tracking provider app. For example, \*\\/example/config/url*. This property is only returned if the `adminPageKey` property is set in the module descriptor of the time tracking provider app. */
        url?: string;
    }
    /** Details of an item associated with the changed record. */
    interface AssociatedItemBean {
        /** The ID of the associated record. */
        id?: string;
        /** The name of the associated record. */
        name?: string;
        /** The type of the associated record. */
        typeName?: string;
        /** The ID of the associated parent record. */
        parentId?: string;
        /** The name of the associated parent record. */
        parentName?: string;
    }
    /** An audit record. */
    interface AuditRecordBean {
        /** The ID of the audit record. */
        id?: number;
        /** The summary of the audit record. */
        summary?: string;
        /** The URL of the computer where the creation of the audit record was initiated. */
        remoteAddress?: string;
        /** Deprecated, use `authorAccountId` instead. The key of the user who created the audit record. */
        authorKey?: string;
        /** The date and time on which the audit record was created. */
        created?: string;
        /** The category of the audit record. For a list of these categories, see the help article [Auditing in Jira applications](https://confluence.atlassian.com/x/noXKM). */
        category?: string;
        /** The event the audit record originated from. */
        eventSource?: string;
        /** The description of the audit record. */
        description?: string;
        objectItem?: Schemas.AssociatedItemBean;
        /** The list of values changed in the record event. */
        changedValues?: Schemas.ChangedValueBean[];
        /** The list of items associated with the changed record. */
        associatedItems?: Schemas.AssociatedItemBean[];
    }
    /** Container for a list of audit records. */
    interface AuditRecords {
        /** The number of audit items skipped before the first item in this list. */
        offset?: number;
        /** The requested or default limit on the number of audit items to be returned. */
        limit?: number;
        /** The total number of audit items returned. */
        total?: number;
        /** The list of audit items. */
        records?: Schemas.AuditRecordBean[];
    }
    /** Details of names changed in the record event. */
    interface ChangedValueBean {
        /** The name of the field changed. */
        fieldName?: string;
        /** The value of the field before the change. */
        changedFrom?: string;
        /** The value of the field after the change. */
        changedTo?: string;
    }
    /** Details about an issue type. */
    interface IssueTypeDetails {
        /** The URL of these issue type details. */
        self?: string;
        /** The ID of the issue type. */
        id?: string;
        /** The description of the issue type. */
        description?: string;
        /** The URL of the issue type's avatar. */
        iconUrl?: string;
        /** The name of the issue type. */
        name?: string;
        /** Whether this issue type is used to create subtasks. */
        subtask?: boolean;
        /** The ID of the issue type's avatar. */
        avatarId?: number;
        /** Unique ID for next-gen projects. */
        entityId?: string;
        /** Hierarchy level of the issue type. */
        hierarchyLevel?: number;
        /** Details of the next-gen projects the issue type is available in. */
        scope?: Schemas.Scope;
    }
    interface ListWrapperCallbackApplicationRole {
    }
    interface ListWrapperCallbackGroupName {
    }
    /** A page of items. */
    interface PageBeanWorkflowScheme {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.WorkflowScheme[];
    }
    interface SimpleListWrapperApplicationRole {
        size?: number;
        items?: Schemas.ApplicationRole[];
        pagingCallback?: Schemas.ListWrapperCallbackApplicationRole;
        callback?: Schemas.ListWrapperCallbackApplicationRole;
        "max-results"?: number;
    }
    interface SimpleListWrapperGroupName {
        size?: number;
        items?: Schemas.GroupName[];
        pagingCallback?: Schemas.ListWrapperCallbackGroupName;
        callback?: Schemas.ListWrapperCallbackGroupName;
        "max-results"?: number;
    }
    /**
     * A user with details as permitted by the user's Atlassian Account privacy settings. However, be aware of these exceptions:
     *
     *  *  User record deleted from Atlassian: This occurs as the result of a right to be forgotten request. In this case, `displayName` provides an indication and other parameters have default values or are blank (for example, email is blank).
     *  *  User record corrupted: This occurs as a results of events such as a server import and can only happen to deleted users. In this case, `accountId` returns *unknown* and all other parameters have fallback values.
     *  *  User record unavailable: This usually occurs due to an internal service outage. In this case, all parameters have fallback values.
     */
    interface User {
        /** The URL of the user. */
        self?: string;
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        key?: string;
        /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Required in requests. */
        accountId?: string;
        /**
         * The user account type. Can take the following values:
         *
         *  *  `atlassian` regular Atlassian user account
         *  *  `app` system account used for Connect applications and OAuth to represent external systems
         *  *  `customer` Jira Service Desk account representing an external service desk
         */
        accountType?: "atlassian" | "app" | "customer" | "unknown";
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        name?: string;
        /** The email address of the user. Depending on the user’s privacy setting, this may be returned as null. */
        emailAddress?: string;
        /** The avatars of the user. */
        avatarUrls?: Schemas.AvatarUrlsBean;
        /** The display name of the user. Depending on the user’s privacy setting, this may return an alternative value. */
        displayName?: string;
        /** Whether the user is active. */
        active?: boolean;
        /** The time zone specified in the user's profile. Depending on the user’s privacy setting, this may be returned as null. */
        timeZone?: string;
        /** The locale of the user. Depending on the user’s privacy setting, this may be returned as null. */
        locale?: string;
        /** The groups that the user belongs to. */
        groups?: Schemas.SimpleListWrapperGroupName;
        /** The application roles the user is assigned to. */
        applicationRoles?: Schemas.SimpleListWrapperApplicationRole;
        /** Expand options that include additional user details in the response. */
        expand?: string;
    }
    /** Details about a workflow scheme. */
    interface WorkflowScheme {
        /** The ID of the workflow scheme. */
        id?: number;
        /** The name of the workflow scheme. The name must be unique. The maximum length is 255 characters. Required when creating a workflow scheme. */
        name?: string;
        /** The description of the workflow scheme. */
        description?: string;
        /** The name of the default workflow for the workflow scheme. The default workflow has *All Unassigned Issue Types* assigned to it in Jira. If `defaultWorkflow` is not specified when creating a workflow scheme, it is set to *Jira Workflow (jira)*. */
        defaultWorkflow?: string;
        /** The issue type to workflow mappings, where each mapping is an issue type ID and workflow name pair. Note that an issue type can only be mapped to one workflow in a workflow scheme. */
        issueTypeMappings?: {
            [key: string]: string;
        };
        /** For draft workflow schemes, this property is the name of the default workflow for the original workflow scheme. The default workflow has *All Unassigned Issue Types* assigned to it in Jira. */
        originalDefaultWorkflow?: string;
        /** For draft workflow schemes, this property is the issue type to workflow mappings for the original workflow scheme, where each mapping is an issue type ID and workflow name pair. Note that an issue type can only be mapped to one workflow in a workflow scheme. */
        originalIssueTypeMappings?: {
            [key: string]: string;
        };
        /** Whether the workflow scheme is a draft or not. */
        draft?: boolean;
        /** The user that last modified the draft workflow scheme. A modification is a change to the issue type-project mappings only. This property does not apply to non-draft workflows. */
        lastModifiedUser?: Schemas.User;
        /** The date-time that the draft workflow scheme was last modified. A modification is a change to the issue type-project mappings only. This property does not apply to non-draft workflows. */
        lastModified?: string;
        self?: string;
        /**
         * Whether to create or update a draft workflow scheme when updating an active workflow scheme. An active workflow scheme is a workflow scheme that is used by at least one project. The following examples show how this property works:
         *
         *  *  Update an active workflow scheme with `updateDraftIfNeeded` set to `true`: If a draft workflow scheme exists, it is updated. Otherwise, a draft workflow scheme is created.
         *  *  Update an active workflow scheme with `updateDraftIfNeeded` set to `false`: An error is returned, as active workflow schemes cannot be updated.
         *  *  Update an inactive workflow scheme with `updateDraftIfNeeded` set to `true`: The workflow scheme is updated, as inactive workflow schemes do not require drafts to update.
         *
         * Defaults to `false`.
         */
        updateDraftIfNeeded?: boolean;
        /** The issue types available in Jira. */
        issueTypes?: {
            [key: string]: Schemas.IssueTypeDetails;
        };
    }
    /** Details about the mapping between issue types and a workflow. */
    interface IssueTypesWorkflowMapping {
        /** The name of the workflow. Optional if updating the workflow-issue types mapping. */
        workflow?: string;
        /** The list of issue type IDs. */
        issueTypes?: string[];
        /** Whether the workflow is the default workflow for the workflow scheme. */
        defaultMapping?: boolean;
        /** Whether a draft workflow scheme is created or updated when updating an active workflow scheme. The draft is updated with the new workflow-issue types mapping. Defaults to `false`. */
        updateDraftIfNeeded?: boolean;
    }
    /** Details about the mapping between an issue type and a workflow. */
    interface IssueTypeWorkflowMapping {
        /** The ID of the issue type. Not required if updating the issue type-workflow mapping. */
        issueType?: string;
        /** The name of the workflow. */
        workflow?: string;
        /** Set to true to create or update the draft of a workflow scheme and update the mapping in the draft, when the workflow scheme cannot be edited. Defaults to `false`. Only applicable when updating the workflow-issue types mapping. */
        updateDraftIfNeeded?: boolean;
    }
    /** Details about the default workflow. */
    interface DefaultWorkflow {
        /** The name of the workflow to set as the default workflow. */
        workflow: string;
        /** Whether a draft workflow scheme is created or updated when updating an active workflow scheme. The draft is updated with the new default workflow. Defaults to `false`. */
        updateDraftIfNeeded?: boolean;
    }
    /** Details about the status mappings for publishing a draft workflow scheme. */
    interface PublishDraftWorkflowScheme {
        /** Mappings of statuses to new statuses for issue types. */
        statusMappings?: Schemas.StatusMapping[];
    }
    /** Details about the mapping from a status to a new status for an issue type. */
    interface StatusMapping {
        /** The ID of the issue type. */
        issueTypeId: string;
        /** The ID of the status. */
        statusId: string;
        /** The ID of the new status. */
        newStatusId: string;
    }
    /** A container for a list of workflow schemes together with the projects they are associated with. */
    interface ContainerOfWorkflowSchemeAssociations {
        /** A list of workflow schemes together with projects they are associated with. */
        values: Schemas.WorkflowSchemeAssociations[];
    }
    /** A workflow scheme along with a list of projects that use it. */
    interface WorkflowSchemeAssociations {
        /** The list of projects that use the workflow scheme. */
        projectIds: string[];
        /** The workflow scheme. */
        workflowScheme: Schemas.WorkflowScheme;
    }
    /** An associated workflow scheme and project. */
    interface WorkflowSchemeProjectAssociation {
        /** The ID of the workflow scheme. If the workflow scheme ID is `null`, the operation assigns the default workflow scheme. */
        workflowSchemeId?: string;
        /** The ID of the project. */
        projectId: string;
    }
    /** Details of a locale. */
    interface Locale {
        /** The locale code. The Java the locale format is used: a two character language code (ISO 639), an underscore, and two letter country code (ISO 3166). For example, en\_US represents a locale of English (United States). Required on create. */
        locale?: string;
    }
    /** A page of items. */
    interface PageBeanUserKey {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.UserKey[];
    }
    /** List of user account IDs. */
    interface UserKey {
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        key?: string;
        /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Returns *unknown* if the record is deleted and corrupted, for example, as the result of a server import. */
        accountId?: string;
    }
    /** A page of items. */
    interface PageBeanUser {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.User[];
    }
    /** A change item. */
    interface ChangeDetails {
        /** The name of the field changed. */
        field?: string;
        /** The type of the field changed. */
        fieldtype?: string;
        /** The ID of the field changed. */
        fieldId?: string;
        /** The details of the original value. */
        from?: string;
        /** The details of the original value as a string. */
        fromString?: string;
        /** The details of the new value. */
        to?: string;
        /** The details of the new value as a string. */
        toString?: string;
    }
    /** A changelog. */
    interface Changelog {
        /** The ID of the changelog. */
        id?: string;
        /** The user who made the change. */
        author?: Schemas.UserDetails;
        /** The date on which the change took place. */
        created?: string;
        /** The list of items changed. */
        items?: Schemas.ChangeDetails[];
        /** The history metadata associated with the changed. */
        historyMetadata?: Schemas.HistoryMetadata;
    }
    /** The metadata describing an issue field. */
    interface FieldMetadata {
        /** Whether the field is required. */
        required: boolean;
        /** The data type of the field. */
        schema: Schemas.JsonTypeBean;
        /** The name of the field. */
        name: string;
        /** The key of the field. */
        key: string;
        /** The URL that can be used to automatically complete the field. */
        autoCompleteUrl?: string;
        /** Whether the field has a default value. */
        hasDefaultValue?: boolean;
        /** The list of operations that can be performed on the field. */
        operations: string[];
        /** The list of values allowed in the field. */
        allowedValues?: any[];
        /** The default value of the field. */
        defaultValue?: any;
    }
    /** Details of issue history metadata. */
    interface HistoryMetadata {
        [key: string]: {};
    }
    /** Details of user or system associated with a issue history metadata item. */
    interface HistoryMetadataParticipant {
        [key: string]: {};
    }
    interface IncludedFields {
        excluded?: string[];
        included?: string[];
        actuallyIncluded?: string[];
    }
    /** Details about an issue. */
    interface IssueBean {
        /** Expand options that include additional issue details in the response. */
        expand?: string;
        /** The ID of the issue. */
        id?: string;
        /** The URL of the issue details. */
        self?: string;
        /** The key of the issue. */
        key?: string;
        /** The rendered value of each field present on the issue. */
        renderedFields?: {
            [key: string]: any;
        };
        /** Details of the issue properties identified in the request. */
        properties?: {
            [key: string]: any;
        };
        /** The ID and name of each field present on the issue. */
        names?: {
            [key: string]: string;
        };
        /** The schema describing each field present on the issue. */
        schema?: {
            [key: string]: Schemas.JsonTypeBean;
        };
        /** The transitions that can be performed on the issue. */
        transitions?: Schemas.IssueTransition[];
        /** The operations that can be performed on the issue. */
        operations?: Schemas.Operations;
        /** The metadata for the fields on the issue that can be amended. */
        editmeta?: Schemas.IssueUpdateMetadata;
        /** Details of changelogs associated with the issue. */
        changelog?: Schemas.PageOfChangelogs;
        /** The versions of each field on the issue. */
        versionedRepresentations?: {
            [key: string]: {
                [key: string]: any;
            };
        };
        fieldsToInclude?: Schemas.IncludedFields;
        fields?: {
            [key: string]: {};
        };
    }
    /** Details of an issue transition. */
    interface IssueTransition {
        [key: string]: {};
    }
    /** A list of editable field details. */
    interface IssueUpdateMetadata {
        /** A list of editable field details. */
        fields?: {
            [key: string]: Schemas.FieldMetadata;
        };
    }
    /** Details a link group, which defines issue operations. */
    interface LinkGroup {
        id?: string;
        styleClass?: string;
        header?: Schemas.SimpleLink;
        weight?: number;
        links?: Schemas.SimpleLink[];
        groups?: Schemas.LinkGroup[];
    }
    /** Details of the operations that can be performed on the issue. */
    interface Operations {
        [key: string]: {};
    }
    /** A page of changelogs. */
    interface PageOfChangelogs {
        /** The index of the first item returned on the page. */
        startAt?: number;
        /** The maximum number of results that could be on the page. */
        maxResults?: number;
        /** The number of results on the page. */
        total?: number;
        /** The list of changelogs. */
        histories?: Schemas.Changelog[];
    }
    /** The result of a JQL search. */
    interface SearchResults {
        /** Expand options that include additional search result details in the response. */
        expand?: string;
        /** The index of the first item returned on the page. */
        startAt?: number;
        /** The maximum number of results that could be on the page. */
        maxResults?: number;
        /** The number of results on the page. */
        total?: number;
        /** The list of issues found by the search. */
        issues?: Schemas.IssueBean[];
        /** Any warnings related to the JQL query. */
        warningMessages?: string[];
        /** The ID and name of each field in the search results. */
        names?: {
            [key: string]: string;
        };
        /** The schema describing the field types in the search results. */
        schema?: {
            [key: string]: Schemas.JsonTypeBean;
        };
    }
    /** Details about the operations available in this version. */
    interface SimpleLink {
        id?: string;
        styleClass?: string;
        iconClass?: string;
        label?: string;
        title?: string;
        href?: string;
        weight?: number;
    }
    /** A status category. */
    interface StatusCategory {
        [key: string]: {};
    }
    /** A status. */
    interface StatusDetails {
        [key: string]: {};
    }
    interface SearchRequestBean {
        /** A [JQL](https://confluence.atlassian.com/x/egORLQ) expression. */
        jql?: string;
        /** The index of the first item to return in the page of results (page offset). The base index is `0`. */
        startAt?: number;
        /** The maximum number of items to return per page. */
        maxResults?: number;
        /**
         * A list of fields to return for each issue, use it to retrieve a subset of fields. This parameter accepts a comma-separated list. Expand options include:
         *
         *  *  `*all` Returns all fields.
         *  *  `*navigable` Returns navigable fields.
         *  *  Any issue field, prefixed with a minus to exclude.
         *
         * The default is `*navigable`.
         *
         * Examples:
         *
         *  *  `summary,comment` Returns the summary and comments fields only.
         *  *  `-description` Returns all navigable (default) fields except description.
         *  *  `*all,-comment` Returns all fields except comments.
         *
         * Multiple `fields` parameters can be included in a request.
         *
         * Note: All navigable fields are returned by default. This differs from [GET issue](#api-rest-api-3-issue-issueIdOrKey-get) where the default is all fields.
         */
        fields?: string[];
        /**
         * Determines how to validate the JQL query and treat the validation results. Supported values:
         *
         *  *  `strict` Returns a 400 response code if any errors are found, along with a list of all errors (and warnings).
         *  *  `warn` Returns all errors as warnings.
         *  *  `none` No validation is performed.
         *  *  `true` *Deprecated* A legacy synonym for `strict`.
         *  *  `false` *Deprecated* A legacy synonym for `warn`.
         *
         * The default is `strict`.
         *
         * Note: If the JQL is not correctly formed a 400 response code is returned, regardless of the `validateQuery` value.
         */
        validateQuery?: "strict" | "warn" | "none" | "true" | "false";
        /**
         * Use [expand](em>#expansion) to include additional information about issues in the response. Note that, unlike the majority of instances where `expand` is specified, `expand` is defined as a list of values. The expand options are:
         *
         *  *  `renderedFields` Returns field values rendered in HTML format.
         *  *  `names` Returns the display name of each field.
         *  *  `schema` Returns the schema describing a field type.
         *  *  `transitions` Returns all possible transitions for the issue.
         *  *  `operations` Returns all possible operations for the issue.
         *  *  `editmeta` Returns information about how each field can be edited.
         *  *  `changelog` Returns a list of recent updates to an issue, sorted by date, starting from the most recent.
         *  *  `versionedRepresentations` Instead of `fields`, returns `versionedRepresentations` a JSON array containing each version of a field's value, with the highest numbered item representing the most recent version.
         */
        expand?: string[];
        /** A list of up to 5 issue properties to include in the results. This parameter accepts a comma-separated list. */
        properties?: string[];
        /** Reference fields by their key (rather than ID). The default is `false`. */
        fieldsByKeys?: boolean;
    }
    /** Details of a field that can be used in advanced searches. */
    interface FieldReferenceData {
        /** The field identifier. */
        value?: string;
        /**
         * The display name contains the following:
         *
         *  *  for system fields, the field name. For example, `Summary`.
         *  *  for collapsed custom fields, the field name followed by a hyphen and then the field name and field type. For example, `Component - Component[Dropdown]`.
         *  *  for other custom fields, the field name followed by a hyphen and then the custom field ID. For example, `Component - cf[10061]`.
         */
        displayName?: string;
        /** Whether the field can be used in a query's `ORDER BY` clause. */
        orderable?: "true" | "false";
        /** Whether the content of this field can be searched. */
        searchable?: "true" | "false";
        /** Whether the field provide auto-complete suggestions. */
        auto?: "true" | "false";
        /** If the item is a custom field, the ID of the custom field. */
        cfid?: string;
        /** The valid search operators for the field. */
        operators?: string[];
        /** The data types of items in the field. */
        types?: string[];
    }
    /** Details of functions that can be used in advanced searches. */
    interface FunctionReferenceData {
        /** The function identifier. */
        value?: string;
        /** The display name of the function. */
        displayName?: string;
        /** Whether the function can take a list of arguments. */
        isList?: "true" | "false";
        /** The data types returned by the function. */
        types?: string[];
    }
    /** Lists of JQL reference data. */
    interface JQLReferenceData {
        /** List of fields usable in JQL queries. */
        visibleFieldNames?: Schemas.FieldReferenceData[];
        /** List of functions usable in JQL queries. */
        visibleFunctionNames?: Schemas.FunctionReferenceData[];
        /** List of JQL query reserved words. */
        jqlReservedWords?: string[];
    }
    /** Details of how to filter and list search auto complete information. */
    interface SearchAutoCompleteFilter {
        /** List of project IDs used to filter the visible field details returned. */
        projectIds?: number[];
        /** Include collapsed fields for fields that have non-unique names. */
        includeCollapsedFields?: boolean;
    }
    /** A field auto-complete suggestion. */
    interface AutoCompleteSuggestion {
        /** The value of a suggested item. */
        value?: string;
        /** The display name of a suggested item. If `fieldValue` or `predicateValue` are provided, the matching text is highlighted with the HTML bold tag. */
        displayName?: string;
    }
    /** The results from a JQL query. */
    interface AutoCompleteSuggestions {
        /** The list of suggested item. */
        results?: Schemas.AutoCompleteSuggestion[];
    }
    /** The JQL queries to be converted. */
    interface JQLPersonalDataMigrationRequest {
        /** A list of queries with user identifiers. Maximum of 100 queries. */
        queryStrings?: string[];
    }
    /** The converted JQL queries. */
    interface ConvertedJQLQueries {
        /** The list of converted query strings with account IDs in place of user identifiers. */
        queryStrings?: string[];
        /** List of queries containing user information that could not be mapped to an existing user */
        queriesWithUnknownUsers?: Schemas.JQLQueryWithUnknownUsers[];
    }
    /** JQL queries that contained users that could not be found */
    interface JQLQueryWithUnknownUsers {
        /** The original query, for reference */
        originalQuery?: string;
        /** The converted query, with accountIDs instead of user identifiers, or 'unknown' for users that could not be found */
        convertedQuery?: string;
    }
    /** Details about a filter. */
    interface Filter {
        /** The URL of the filter. */
        self?: string;
        /** The unique identifier for the filter. */
        id?: string;
        /** The name of the filter. Must be unique. */
        name: string;
        /** A description of the filter. */
        description?: string;
        /** The user who owns the filter. This is defaulted to the creator of the filter, however Jira administrators can change the owner of a shared filter in the admin settings. */
        owner?: Schemas.User;
        /** The JQL query for the filter. For example, *project = SSP AND issuetype = Bug*. */
        jql?: string;
        /** A URL to view the filter results in Jira, using the ID of the filter. For example, *https://your-domain.atlassian.net/issues/?filter=10100*. */
        viewUrl?: string;
        /** A URL to view the filter results in Jira, using the [Search for issues using JQL](#api-rest-api-3-filter-search-get) operation with the filter's JQL string to return the filter results. For example, *https://your-domain.atlassian.net/rest/api/3/search?jql=project+%3D+SSP+AND+issuetype+%3D+Bug*. */
        searchUrl?: string;
        /** Whether the filter is selected as a favorite. */
        favourite?: boolean;
        /** The count of how many users have selected this filter as a favorite, including the filter owner. */
        favouritedCount?: number;
        /** The groups and projects that the filter is shared with. */
        sharePermissions?: Schemas.SharePermission[];
        /** The groups and projects that can edit the filter. */
        editPermissions?: Schemas.SharePermission[];
        /** A paginated list of the users that the filter is shared with. This includes users that are members of the groups or can browse the projects that the filter is shared with. */
        sharedUsers?: Schemas.UserList;
        /** A paginated list of the users that are subscribed to the filter. */
        subscriptions?: Schemas.FilterSubscriptionsList;
    }
    /** Details of a user or group subscribing to a filter. */
    interface FilterSubscription {
        /** The ID of the filter subscription. */
        id?: number;
        /** The user subscribing to filter. */
        user?: Schemas.User;
        /** The group subscribing to filter. */
        group?: Schemas.GroupName;
    }
    /** A paginated list of subscriptions to a filter. */
    interface FilterSubscriptionsList {
        /** The number of items on the page. */
        size?: number;
        /** The list of items. */
        items?: Schemas.FilterSubscription[];
        /** The maximum number of results that could be on the page. */
        "max-results"?: number;
        /** The index of the first item returned on the page. */
        "start-index"?: number;
        /** The index of the last item returned on the page. */
        "end-index"?: number;
    }
    /** The project issue type hierarchy. */
    interface Hierarchy {
        /** The ID of the base level. This property is deprecated, see [Change notice: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        baseLevelId?: number;
        /** Details about the hierarchy level. */
        levels?: Schemas.HierarchyLevel[];
    }
    interface HierarchyLevel {
        /** The ID of the hierarchy level. This property is deprecated, see [Change notice: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        id?: number;
        /** The name of this hierarchy level. */
        name?: string;
        /** The ID of the level above this one in the hierarchy. This property is deprecated, see [Change notice: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        aboveLevelId?: number;
        /** The ID of the level below this one in the hierarchy. This property is deprecated, see [Change notice: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        belowLevelId?: number;
        /** The ID of the project configuration. This property is deprecated, see [Change oticen: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        projectConfigurationId?: number;
        /** The level of this item in the hierarchy. */
        level?: number;
        /** The issue types available in this hierarchy level. */
        issueTypeIds?: number[];
        /** The external UUID of the hierarchy level. This property is deprecated, see [Change notice: Removing hierarchy level IDs from next-gen APIs](https://developer.atlassian.com/cloud/jira/platform/change-notice-removing-hierarchy-level-ids-from-next-gen-apis/). */
        externalUuid?: string;
        globalHierarchyLevel?: "SUBTASK" | "BASE" | "EPIC";
    }
    /** Details about a project. */
    interface Project {
        /** Expand options that include additional project details in the response. */
        expand?: string;
        /** The URL of the project details. */
        self?: string;
        /** The ID of the project. */
        id?: string;
        /** The key of the project. */
        key?: string;
        /** A brief description of the project. */
        description?: string;
        /** The username of the project lead. */
        lead?: Schemas.User;
        /** List of the components contained in the project. */
        components?: Schemas.ProjectComponent[];
        /** List of the issue types available in the project. */
        issueTypes?: Schemas.IssueTypeDetails[];
        /** A link to information about this project, such as project documentation. */
        url?: string;
        /** An email address associated with the project. */
        email?: string;
        /** The default assignee when creating issues for this project. */
        assigneeType?: "PROJECT_LEAD" | "UNASSIGNED";
        /** The versions defined in the project. For more information, see [Create version](#api-rest-api-3-version-post). */
        versions?: Schemas.Version[];
        /** The name of the project. */
        name?: string;
        /** The name and self URL for each role defined in the project. For more information, see [Create project role](#api-rest-api-3-role-post). */
        roles?: {
            [key: string]: string;
        };
        /** The URLs of the project's avatars. */
        avatarUrls?: Schemas.AvatarUrlsBean;
        /** The category the project belongs to. */
        projectCategory?: Schemas.ProjectCategory;
        /** The [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes) of the project. */
        projectTypeKey?: "software" | "service_desk" | "business";
        /** Whether the project is simplified. */
        simplified?: boolean;
        /** The type of the project. */
        style?: "classic" | "next-gen";
        /** Whether the project is selected as a favorite. */
        favourite?: boolean;
        /** Whether the project is private. */
        isPrivate?: boolean;
        /** The issue type hierarchy for the project. */
        issueTypeHierarchy?: Schemas.Hierarchy;
        /** User permissions on the project */
        permissions?: Schemas.ProjectPermissions;
        /** Map of project properties */
        properties?: {
            [key: string]: any;
        };
        /** Unique ID for next-gen projects. */
        uuid?: string;
        /** Insights about the project. */
        insight?: Schemas.ProjectInsight;
        /** Whether the project is marked as deleted. */
        deleted?: boolean;
        /** The date when the project is deleted permanently. */
        retentionTillDate?: string;
        /** The date when the project was marked as deleted. */
        deletedDate?: string;
        /** The user who marked the project as deleted. */
        deletedBy?: Schemas.User;
        /** Whether the project is archived. */
        archived?: boolean;
        /** The date when the project was archived. */
        archivedDate?: string;
        /** The user who archived the project. */
        archivedBy?: Schemas.User;
        /** The project landing page info. */
        landingPageInfo?: Schemas.ProjectLandingPageInfo;
    }
    /** A project category. */
    interface ProjectCategory {
        /** The URL of the project category. */
        self?: string;
        /** The ID of the project category. */
        id?: string;
        /** The name of the project category. Required on create, optional on update. */
        name?: string;
        /** The description of the project category. */
        description?: string;
    }
    /** Details about a project component. */
    interface ProjectComponent {
        /** The URL of the component. */
        self?: string;
        /** The unique identifier for the component. */
        id?: string;
        /** The unique name for the component in the project. Required when creating a component. Optional when updating a component. The maximum length is 255 characters. */
        name?: string;
        /** The description for the component. Optional when creating or updating a component. */
        description?: string;
        /** The user details for the component's lead user. */
        lead?: Schemas.User;
        /** This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        leadUserName?: string;
        /** The accountId of the component's lead user. The accountId uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
        leadAccountId?: string;
        /**
         * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Can take the following values:
         *
         *  *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
         *  *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
         *  *  `UNASSIGNED` an assignee is not set for issues created with this component.
         *  *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
         *
         * Default value: `PROJECT_DEFAULT`.
         * Optional when creating or updating a component.
         */
        assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
        /** The details of the user associated with `assigneeType`, if any. See `realAssignee` for details of the user assigned to issues created with this component. */
        assignee?: Schemas.User;
        /**
         * The type of the assignee that is assigned to issues created with this component, when an assignee cannot be set from the `assigneeType`. For example, `assigneeType` is set to `COMPONENT_LEAD` but no component lead is set. This property is set to one of the following values:
         *
         *  *  `PROJECT_LEAD` when `assigneeType` is `PROJECT_LEAD` and the project lead has permission to be assigned issues in the project that the component is in.
         *  *  `COMPONENT_LEAD` when `assignee`Type is `COMPONENT_LEAD` and the component lead has permission to be assigned issues in the project that the component is in.
         *  *  `UNASSIGNED` when `assigneeType` is `UNASSIGNED` and Jira is configured to allow unassigned issues.
         *  *  `PROJECT_DEFAULT` when none of the preceding cases are true.
         */
        realAssigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
        /** The user assigned to issues created with this component, when `assigneeType` does not identify a valid assignee. */
        realAssignee?: Schemas.User;
        /** Whether a user is associated with `assigneeType`. For example, if the `assigneeType` is set to `COMPONENT_LEAD` but the component lead is not set, then `false` is returned. */
        isAssigneeTypeValid?: boolean;
        /** The key of the project the component is assigned to. Required when creating a component. Can't be updated. */
        project?: string;
        /** The ID of the project the component is assigned to. */
        projectId?: number;
    }
    /** Additional details about a project. */
    interface ProjectInsight {
        /** Total issue count. */
        totalIssueCount?: number;
        /** The last issue update time. */
        lastIssueUpdateTime?: string;
    }
    interface ProjectLandingPageInfo {
        url?: string;
        projectKey?: string;
        projectType?: string;
        boardId?: number;
        simplified?: boolean;
    }
    /** Permissions which a user has on a project. */
    interface ProjectPermissions {
        /** Whether the logged user can edit the project. */
        canEdit?: boolean;
    }
    /** Details of a share permission for the filter. */
    interface SharePermission {
        /** The unique identifier of the share permission. */
        id?: number;
        /**
         * The type of share permission:
         *
         *  *  `user` Shared with a user.
         *  *  `group` Shared with a group. If set in a request, then specify `sharePermission.group` as well.
         *  *  `project` Shared with a project. If set in a request, then specify `sharePermission.project` as well.
         *  *  `projectRole` Share with a project role in a project. This value is not returned in responses. It is used in requests, where it needs to be specify with `projectId` and `projectRoleId`.
         *  *  `global` Shared globally. If set in a request, no other `sharePermission` properties need to be specified.
         *  *  `loggedin` Shared with all logged-in users. Note: This value is set in a request by specifying `authenticated` as the `type`.
         *  *  `project-unknown` Shared with a project that the user does not have access to. Cannot be set in a request.
         */
        type: "user" | "group" | "project" | "projectRole" | "global" | "loggedin" | "authenticated" | "project-unknown";
        /**
         * The project that the filter is shared with. This is similar to the project object returned by [Get project](#api-rest-api-3-project-projectIdOrKey-get) but it contains a subset of the properties, which are: `self`, `id`, `key`, `assigneeType`, `name`, `roles`, `avatarUrls`, `projectType`, `simplified`.
         * For a request, specify the `id` for the project.
         */
        project?: Schemas.Project;
        /**
         * The project role that the filter is shared with.
         * For a request, specify the `id` for the role. You must also specify the `project` object and `id` for the project that the role is in.
         */
        role?: Schemas.ProjectRole;
        /** The group that the filter is shared with. For a request, specify the `name` property for the group. */
        group?: Schemas.GroupName;
        /** The user account ID that the filter is shared with. For a request, specify the `accountId` property for the user. */
        user?: Schemas.UserBean;
    }
    interface UserBean {
        /**
         * This property is deprecated in favor of `accountId` because of privacy changes. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
         * The key of the user.
         */
        key?: string;
        /** The URL of the user. */
        self?: string;
        /**
         * This property is deprecated in favor of `accountId` because of privacy changes. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
         * The username of the user.
         */
        name?: string;
        /** The display name of the user. Depending on the user’s privacy setting, this may return an alternative value. */
        displayName?: string;
        /** Whether the user is active. */
        active?: boolean;
        /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
        accountId?: string;
        /** The avatars of the user. */
        avatarUrls?: Schemas.UserBeanAvatarUrls;
    }
    interface UserBeanAvatarUrls {
        /** The URL of the user's 16x16 pixel avatar. */
        "16x16"?: string;
        /** The URL of the user's 32x32 pixel avatar. */
        "32x32"?: string;
        /** The URL of the user's 48x48 pixel avatar. */
        "48x48"?: string;
        /** The URL of the user's 24x24 pixel avatar. */
        "24x24"?: string;
    }
    /** A paginated list of users sharing the filter. This includes users that are members of the groups or can browse the projects that the filter is shared with. */
    interface UserList {
        /** The number of items on the page. */
        size?: number;
        /** The list of items. */
        items?: Schemas.User[];
        /** The maximum number of results that could be on the page. */
        "max-results"?: number;
        /** The index of the first item returned on the page. */
        "start-index"?: number;
        /** The index of the last item returned on the page. */
        "end-index"?: number;
    }
    /** Details about a project version. */
    interface Version {
        /**
         * Use [expand](em>#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
         *
         *  *  `operations` Returns the list of operations available for this version.
         *  *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property contains a count of issues with a status other than *to do*, *in progress*, and *done*.
         *
         * Optional for create and update.
         */
        expand?: string;
        /** The URL of the version. */
        self?: string;
        /** The ID of the version. */
        id?: string;
        /** The description of the version. Optional when creating or updating a version. */
        description?: string;
        /** The unique name of the version. Required when creating a version. Optional when updating a version. The maximum length is 255 characters. */
        name?: string;
        /** Indicates that the version is archived. Optional when creating or updating a version. */
        archived?: boolean;
        /** Indicates that the version is released. If the version is released a request to release again is ignored. Not applicable when creating a version. Optional when updating a version. */
        released?: boolean;
        /** The start date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version. */
        startDate?: string;
        /** The release date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version. */
        releaseDate?: string;
        /** Indicates that the version is overdue. */
        overdue?: boolean;
        /** The date on which work on this version is expected to start, expressed in the instance's *Day/Month/Year Format* date format. */
        userStartDate?: string;
        /** The date on which work on this version is expected to finish, expressed in the instance's *Day/Month/Year Format* date format. */
        userReleaseDate?: string;
        /** Deprecated. Use `projectId`. */
        project?: string;
        /** The ID of the project to which this version is attached. Required when creating a version. Not applicable when updating a version. */
        projectId?: number;
        /** The URL of the self link to the version to which all unfixed issues are moved when a version is released. Not applicable when creating a version. Optional when updating a version. */
        moveUnfixedIssuesTo?: string;
        /** If the expand option `operations` is used, returns the list of operations available for this version. */
        operations?: Schemas.SimpleLink[];
        /** If the expand option `issuesstatus` is used, returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property contains a count of issues with a status other than *to do*, *in progress*, and *done*. */
        issuesStatusForFixVersion?: Schemas.VersionIssuesStatus;
    }
    /** Counts of the number of issues in various statuses. */
    interface VersionIssuesStatus {
        [key: string]: {};
    }
    /** Details of a filter. */
    interface FilterDetails {
        /** Expand options that include additional filter details in the response. */
        expand?: string;
        /** The URL of the filter. */
        self?: string;
        /** The unique identifier for the filter. */
        id?: string;
        /** The name of the filter. */
        name: string;
        /** The description of the filter. */
        description?: string;
        /** The user who owns the filter. Defaults to the creator of the filter, however, Jira administrators can change the owner of a shared filter in the admin settings. */
        owner?: Schemas.User;
        /** The JQL query for the filter. For example, *project = SSP AND issuetype = Bug*. */
        jql?: string;
        /** A URL to view the filter results in Jira, using the ID of the filter. For example, *https://your-domain.atlassian.net/issues/?filter=10100*. */
        viewUrl?: string;
        /** A URL to view the filter results in Jira, using the [Search for issues using JQL](#api-rest-api-3-filter-search-get) operation with the filter's JQL string to return the filter results. For example, *https://your-domain.atlassian.net/rest/api/3/search?jql=project+%3D+SSP+AND+issuetype+%3D+Bug*. */
        searchUrl?: string;
        /** Whether the filter is selected as a favorite by any users, not including the filter owner. */
        favourite?: boolean;
        /** The count of how many users have selected this filter as a favorite, including the filter owner. */
        favouritedCount?: number;
        /** The groups and projects that the filter is shared with. This can be specified when updating a filter, but not when creating a filter. */
        sharePermissions?: Schemas.SharePermission[];
        /** The groups and projects that can edit the filter. This can be specified when updating a filter, but not when creating a filter. */
        editPermissions?: Schemas.SharePermission[];
        /** The users that are subscribed to the filter. */
        subscriptions?: Schemas.FilterSubscription[];
    }
    /** A page of items. */
    interface PageBeanFilterDetails {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.FilterDetails[];
    }
    /** Details of the scope of the default sharing for new filters and dashboards. */
    interface DefaultShareScope {
        /**
         * The scope of the default sharing for new filters and dashboards:
         *
         *  *  `AUTHENTICATED` Shared with all logged-in users.
         *  *  `GLOBAL` Shared with all logged-in users. This shows as `AUTHENTICATED` in the response.
         *  *  `PRIVATE` Not shared with any users.
         */
        scope: "GLOBAL" | "AUTHENTICATED" | "PRIVATE";
    }
    interface SharePermissionInputBean {
        /**
         * The type of the share permission.Specify the type as follows:
         *
         *  *  `user` Share with a user.
         *  *  `group` Share with a group. Specify `groupname` as well.
         *  *  `project` Share with a project. Specify `projectId` as well.
         *  *  `projectRole` Share with a project role in a project. Specify `projectId` and `projectRoleId` as well.
         *  *  `global` Share globally, including anonymous users. If set, this type overrides all existing share permissions and must be deleted before any non-global share permissions is set.
         *  *  `authenticated` Share with all logged-in users. This shows as `loggedin` in the response. If set, this type overrides all existing share permissions and must be deleted before any non-global share permissions is set.
         */
        type: "user" | "project" | "group" | "projectRole" | "global" | "authenticated";
        /** The ID of the project to share the filter with. Set `type` to `project`. */
        projectId?: string;
        /** The name of the group to share the filter with. Set `type` to `group`. */
        groupname?: string;
        /** The ID of the project role to share the filter with. Set `type` to `projectRole` and the `projectId` for the project that the role is in. */
        projectRoleId?: string;
        /** The user account ID that the filter is shared with. For a request, specify the `accountId` property for the user. */
        accountId?: string;
        /** The rights for the share permission. */
        rights?: number;
    }
    /** Details of a dashboard. */
    interface Dashboard {
        description?: string;
        /** The ID of the dashboard. */
        id?: string;
        /** Whether the dashboard is selected as a favorite by the user. */
        isFavourite?: boolean;
        /** The name of the dashboard. */
        name?: string;
        /** The owner of the dashboard. */
        owner?: Schemas.UserBean;
        /** The number of users who have this dashboard as a favorite. */
        popularity?: number;
        /** The rank of this dashboard. */
        rank?: number;
        /** The URL of these dashboard details. */
        self?: string;
        /** The details of any view share permissions for the dashboard. */
        sharePermissions?: Schemas.SharePermission[];
        /** The details of any edit share permissions for the dashboard. */
        editPermissions?: Schemas.SharePermission[];
        /** The URL of the dashboard. */
        view?: string;
        /** Whether the current user has permission to edit the dashboard. */
        isWritable?: boolean;
    }
    /** A page containing dashboard details. */
    interface PageOfDashboards {
        /** The index of the first item returned on the page. */
        startAt?: number;
        /** The maximum number of results that could be on the page. */
        maxResults?: number;
        /** The number of results on the page. */
        total?: number;
        /** The URL of the previous page of results, if any. */
        prev?: string;
        /** The URL of the next page of results, if any. */
        next?: string;
        /** List of dashboards. */
        dashboards?: Schemas.Dashboard[];
    }
    /** A page of items. */
    interface PageBeanDashboard {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Dashboard[];
    }
    /** Details of a dashboard. */
    interface DashboardDetails {
        /** The name of the dashboard. */
        name: string;
        /** The description of the dashboard. */
        description?: string;
        /** The share permissions for the dashboard. */
        sharePermissions: Schemas.SharePermission[];
        /** The edit permissions for the dashboard. */
        editPermissions: Schemas.SharePermission[];
    }
    /** Property key details. */
    interface PropertyKey {
        /** The URL of the property. */
        self?: string;
        /** The key of the property. */
        key?: string;
    }
    /** List of property keys. */
    interface PropertyKeys {
        /** Property key details. */
        keys?: Schemas.PropertyKey[];
    }
    /** An entity property, for more information see [Entity properties](https://developer.atlassian.com/cloud/jira/platform/jira-entity-properties/). */
    interface EntityProperty {
        /** The key of the property. Required on create and update. */
        key?: string;
        /** The value of the property. Required on create and update. */
        value?: any;
    }
    interface UserMigrationBean {
        key?: string;
        username?: string;
        accountId?: string;
    }
    interface UnrestrictedUserEmail {
        /** The accountId of the user */
        accountId?: string;
        /** The email of the user */
        email?: string;
    }
    /** A page of items. */
    interface PageBeanString {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: string[];
    }
    /** Details about the replacement for a deleted version. */
    interface CustomFieldReplacement {
        /** The ID of the custom field in which to replace the version number. */
        customFieldId?: number;
        /** The version number to use as a replacement for the deleted version. */
        moveTo?: number;
    }
    interface DeleteAndReplaceVersionBean {
        /** The ID of the version to update `fixVersion` to when the field contains the deleted version. */
        moveFixIssuesTo?: number;
        /** The ID of the version to update `affectedVersion` to when the field contains the deleted version. */
        moveAffectedIssuesTo?: number;
        /** An array of custom field IDs (`customFieldId`) and version IDs (`moveTo`) to update when the fields contain the deleted version. */
        customFieldReplacementList?: Schemas.CustomFieldReplacement[];
    }
    /** Various counts of issues within a version. */
    interface VersionIssueCounts {
        /** The URL of these count details. */
        self?: string;
        /** Count of issues where the `fixVersion` is set to the version. */
        issuesFixedCount?: number;
        /** Count of issues where the `affectedVersion` is set to the version. */
        issuesAffectedCount?: number;
        /** Count of issues where a version custom field is set to the version. */
        issueCountWithCustomFieldsShowingVersion?: number;
        /** List of custom fields using the version. */
        customFieldUsage?: Schemas.VersionUsageInCustomField[];
    }
    /** List of custom fields using the version. */
    interface VersionUsageInCustomField {
        /** The name of the custom field. */
        fieldName?: string;
        /** The ID of the custom field. */
        customFieldId?: number;
        /** Count of the issues where the custom field contains the version. */
        issueCountWithVersionInCustomField?: number;
    }
    /** Count of a version's unresolved issues. */
    interface VersionUnresolvedIssuesCount {
        /** The URL of these count details. */
        self?: string;
        /** Count of unresolved issues. */
        issuesUnresolvedCount?: number;
        /** Count of issues. */
        issuesCount?: number;
    }
    interface VersionMoveBean {
        /** The URL (self link) of the version after which to place the moved version. Cannot be used with `position`. */
        after?: string;
        /** An absolute position in which to place the moved version. Cannot be used with `after`. */
        position?: "Earlier" | "Later" | "First" | "Last";
    }
    /** The list of users found in a search, including header text (Showing X of Y matching users) and total of matched users. */
    interface FoundUsers {
        users?: Schemas.UserPickerUser[];
        /** The total number of users found in the search. */
        total?: number;
        /** Header text indicating the number of users in the response and the total number of users found in the search. */
        header?: string;
    }
    /** A user found in a search. */
    interface UserPickerUser {
        /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
        accountId?: string;
        /** This property is no longer available . See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        name?: string;
        /** This property is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
        key?: string;
        /** The display name, email address, and key of the user with the matched query string highlighted with the HTML bold tag. */
        html?: string;
        /** The display name of the user. Depending on the user’s privacy setting, this may be returned as null. */
        displayName?: string;
        /** The avatar URL of the user. */
        avatarUrl?: string;
    }
    /** The user details. */
    interface NewUserDetails {
        [key: string]: {};
    }
    /** Details of an avatar. */
    interface Avatar {
        /** The ID of the avatar. */
        id: string;
        /** The owner of the avatar. For a system avatar the owner is null (and nothing is returned). For non-system avatars this is the appropriate identifier, such as the ID for a project or the account ID for a user. */
        owner?: string;
        /** Whether the avatar is a system avatar. */
        isSystemAvatar?: boolean;
        /** Whether the avatar is used in Jira. For example, shown as a project's avatar. */
        isSelected?: boolean;
        /** Whether the avatar can be deleted. */
        isDeletable?: boolean;
        /** The file name of the avatar icon. Returned for system avatars. */
        fileName?: string;
        /** The list of avatar icon URLs. */
        urls?: {
            [key: string]: string;
        };
    }
    /** Details about system and custom avatars. */
    interface Avatars {
        /** System avatars list. */
        system?: Schemas.Avatar[];
        /** Custom avatars list. */
        custom?: Schemas.Avatar[];
    }
    /** A screen tab. */
    interface ScreenableTab {
        /** The ID of the screen tab. */
        id?: number;
        /** The name of the screen tab. The maximum length is 255 characters. */
        name: string;
    }
    /** A page of items. */
    interface PageBeanScreen {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Screen[];
    }
    /** A screen. */
    interface Screen {
        /** The ID of the screen. */
        id?: number;
        /** The name of the screen. */
        name?: string;
        /** The description of the screen. */
        description?: string;
        /** The scope of the screen. */
        scope?: Schemas.Scope;
    }
    /** A screen tab field. */
    interface ScreenableField {
        /** The ID of the screen tab field. */
        id?: string;
        /** The name of the screen tab field. Required on create and update. The maximum length is 255 characters. */
        name?: string;
    }
    interface MoveFieldBean {
        /** The ID of the screen tab field after which to place the moved screen tab field. Required if `position` isn't provided. */
        after?: string;
        /** The named position to which the screen tab field should be moved. Required if `after` isn't provided. */
        position?: "Earlier" | "Later" | "First" | "Last";
    }
    interface AddFieldBean {
        /** The ID of the field to add. */
        fieldId: string;
    }
    /** Details of a screen. */
    interface ScreenDetails {
        /** The name of the screen. The name must be unique. The maximum length is 255 characters. */
        name: string;
        /** The description of the screen. The maximum length is 255 characters. */
        description?: string;
    }
    /** Details of a screen. */
    interface UpdateScreenDetails {
        /** The name of the screen. The name must be unique. The maximum length is 255 characters. */
        name?: string;
        /** The description of the screen. The maximum length is 255 characters. */
        description?: string;
    }
    /** Details of an issue resolution. */
    interface Resolution {
        /** The URL of the issue resolution. */
        self?: string;
        /** The ID of the issue resolution. */
        id?: string;
        /** The description of the issue resolution. */
        description?: string;
        /** The name of the issue resolution. */
        name?: string;
    }
    /** Details about the project. */
    interface CreateProjectDetails {
        /** Project keys must be unique and start with an uppercase letter followed by one or more uppercase alphanumeric characters. The maximum length is 10 characters. */
        key: string;
        /** The name of the project. */
        name: string;
        /** A brief description of the project. */
        description?: string;
        /** This parameter is deprecated because of privacy changes. Use `leadAccountId` instead. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. The user name of the project lead. Either `lead` or `leadAccountId` must be set when creating a project. Cannot be provided with `leadAccountId`. */
        lead?: string;
        /** The account ID of the project lead. Either `lead` or `leadAccountId` must be set when creating a project. Cannot be provided with `lead`. */
        leadAccountId?: string;
        /** A link to information about this project, such as project documentation */
        url?: string;
        /** The default assignee when creating issues for this project. */
        assigneeType?: "PROJECT_LEAD" | "UNASSIGNED";
        /** An integer value for the project's avatar. */
        avatarId?: number;
        /** The ID of the issue security scheme for the project, which enables you to control who can and cannot view issues. Use the [Get issue security schemes](#api-rest-api-3-issuesecurityschemes-get) resource to get all issue security scheme IDs. */
        issueSecurityScheme?: number;
        /** The ID of the permission scheme for the project. Use the [Get all permission schemes](#api-rest-api-3-permissionscheme-get) resource to see a list of all permission scheme IDs. */
        permissionScheme?: number;
        /** The ID of the notification scheme for the project. Use the [Get notification schemes](#api-rest-api-3-notificationscheme-get) resource to get a list of notification scheme IDs. */
        notificationScheme?: number;
        /** The ID of the project's category. A complete list of category IDs is found using the [Get all project categories](#api-rest-api-3-projectCategory-get) operation. */
        categoryId?: number;
        /** The [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes), which defines the application-specific feature set. If you don't specify the project template you have to specify the project type. */
        projectTypeKey?: "software" | "service_desk" | "business";
        /** A predefined configuration for a project. The type of the `projectTemplateKey` must match with the type of the `projectTypeKey`. */
        projectTemplateKey?: "com.pyxis.greenhopper.jira:gh-simplified-agility-kanban" | "com.pyxis.greenhopper.jira:gh-simplified-agility-scrum" | "com.pyxis.greenhopper.jira:gh-simplified-basic" | "com.pyxis.greenhopper.jira:gh-simplified-kanban-classic" | "com.pyxis.greenhopper.jira:gh-simplified-scrum-classic" | "com.atlassian.servicedesk:simplified-it-service-management" | "com.atlassian.servicedesk:simplified-general-service-desk" | "com.atlassian.servicedesk:simplified-internal-service-desk" | "com.atlassian.servicedesk:simplified-external-service-desk" | "com.atlassian.servicedesk:simplified-hr-service-desk" | "com.atlassian.servicedesk:simplified-facilities-service-desk" | "com.atlassian.servicedesk:simplified-legal-service-desk" | "com.atlassian.jira-core-project-templates:jira-core-simplified-content-management" | "com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval" | "com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking" | "com.atlassian.jira-core-project-templates:jira-core-simplified-process-control" | "com.atlassian.jira-core-project-templates:jira-core-simplified-procurement" | "com.atlassian.jira-core-project-templates:jira-core-simplified-project-management" | "com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment" | "com.atlassian.jira-core-project-templates:jira-core-simplified-task-";
        /** The ID of the workflow scheme for the project. Use the [Get all workflow schemes](#api-rest-api-3-workflowscheme-get) operation to get a list of workflow scheme IDs. If you specify the workflow scheme you cannot specify the project template key. */
        workflowScheme?: number;
        /** The ID of the issue type screen scheme for the project. Use the [Get all issue type screen schemes](#api-rest-api-3-issuetypescreenscheme-get) operation to get a list of issue type screen scheme IDs. If you specify the issue type screen scheme you cannot specify the project template key. */
        issueTypeScreenScheme?: number;
        /** The ID of the issue type scheme for the project. Use the [Get all issue type schemes](#api-rest-api-3-issuetypescheme-get) operation to get a list of issue type scheme IDs. If you specify the issue type scheme you cannot specify the project template key. */
        issueTypeScheme?: number;
        /** The ID of the field configuration scheme for the project. Use the [Get all field configuration schemes](#api-rest-api-3-fieldconfigurationscheme-get) operation to get a list of field configuration scheme IDs. If you specify the field configuration scheme you cannot specify the project template key. */
        fieldConfigurationScheme?: number;
    }
    /** Identifiers for a project. */
    interface ProjectIdentifiers {
        /** The URL of the created project. */
        self: string;
        /** The ID of the created project. */
        id: number;
        /** The key of the created project. */
        key: string;
    }
    /** Details about the project. */
    interface UpdateProjectDetails {
        /** Project keys must be unique and start with an uppercase letter followed by one or more uppercase alphanumeric characters. The maximum length is 10 characters. */
        key?: string;
        /** The name of the project. */
        name?: string;
        /** A brief description of the project. */
        description?: string;
        /** This parameter is deprecated because of privacy changes. Use `leadAccountId` instead. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. The user name of the project lead. Cannot be provided with `leadAccountId`. */
        lead?: string;
        /** The account ID of the project lead. Cannot be provided with `lead`. */
        leadAccountId?: string;
        /** A link to information about this project, such as project documentation */
        url?: string;
        /** The default assignee when creating issues for this project. */
        assigneeType?: "PROJECT_LEAD" | "UNASSIGNED";
        /** An integer value for the project's avatar. */
        avatarId?: number;
        /** The ID of the issue security scheme for the project, which enables you to control who can and cannot view issues. Use the [Get issue security schemes](#api-rest-api-3-issuesecurityschemes-get) resource to get all issue security scheme IDs. */
        issueSecurityScheme?: number;
        /** The ID of the permission scheme for the project. Use the [Get all permission schemes](#api-rest-api-3-permissionscheme-get) resource to see a list of all permission scheme IDs. */
        permissionScheme?: number;
        /** The ID of the notification scheme for the project. Use the [Get notification schemes](#api-rest-api-3-notificationscheme-get) resource to get a list of notification scheme IDs. */
        notificationScheme?: number;
        /** The ID of the project's category. A complete list of category IDs is found using the [Get all project categories](#api-rest-api-3-projectCategory-get) operation. To remove the project category from the project, set the value to `-1.` */
        categoryId?: number;
    }
    /** A page of items. */
    interface PageBeanVersion {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Version[];
    }
    /** Details about a component with a count of the issues it contains. */
    interface ComponentWithIssueCount {
        /** Count of issues for the component. */
        issueCount?: number;
        /** The user assigned to issues created with this component, when `assigneeType` does not identify a valid assignee. */
        realAssignee?: Schemas.User;
        /** Whether a user is associated with `assigneeType`. For example, if the `assigneeType` is set to `COMPONENT_LEAD` but the component lead is not set, then `false` is returned. */
        isAssigneeTypeValid?: boolean;
        /**
         * The type of the assignee that is assigned to issues created with this component, when an assignee cannot be set from the `assigneeType`. For example, `assigneeType` is set to `COMPONENT_LEAD` but no component lead is set. This property is set to one of the following values:
         *
         *  *  `PROJECT_LEAD` when `assigneeType` is `PROJECT_LEAD` and the project lead has permission to be assigned issues in the project that the component is in.
         *  *  `COMPONENT_LEAD` when `assignee`Type is `COMPONENT_LEAD` and the component lead has permission to be assigned issues in the project that the component is in.
         *  *  `UNASSIGNED` when `assigneeType` is `UNASSIGNED` and Jira is configured to allow unassigned issues.
         *  *  `PROJECT_DEFAULT` when none of the preceding cases are true.
         */
        realAssigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
        /** The key of the project to which the component is assigned. */
        project?: string;
        /** Not used. */
        projectId?: number;
        /** The details of the user associated with `assigneeType`, if any. See `realAssignee` for details of the user assigned to issues created with this component. */
        assignee?: Schemas.User;
        /** The user details for the component's lead user. */
        lead?: Schemas.User;
        /**
         * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Takes the following values:
         *
         *  *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
         *  *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
         *  *  `UNASSIGNED` an assignee is not set for issues created with this component.
         *  *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
         */
        assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
        /** The description for the component. */
        description?: string;
        /** The URL for this count of the issues contained in the component. */
        self?: string;
        /** The name for the component. */
        name?: string;
        /** The unique identifier for the component. */
        id?: string;
    }
    /** A page of items. */
    interface PageBeanComponentWithIssueCount {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.ComponentWithIssueCount[];
    }
    interface StringList {
    }
    /** A page of items. */
    interface PageBeanProject {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Project[];
    }
    /** List of project avatars. */
    interface ProjectAvatars {
        /** List of avatars included with Jira. These avatars cannot be deleted. */
        system?: Schemas.Avatar[];
        /** List of avatars added to Jira. These avatars may be deleted. */
        custom?: Schemas.Avatar[];
    }
    /** Status details for an issue type. */
    interface IssueTypeWithStatus {
        /** The URL of the issue type's status details. */
        self: string;
        /** The ID of the issue type. */
        id: string;
        /** The name of the issue type. */
        name: string;
        /** Whether this issue type represents subtasks. */
        subtask: boolean;
        /** List of status details for the issue type. */
        statuses: Schemas.StatusDetails[];
    }
    /** Details about a security scheme. */
    interface SecurityScheme {
        /** The URL of the issue security scheme. */
        self?: string;
        /** The ID of the issue security scheme. */
        id?: number;
        /** The name of the issue security scheme. */
        name?: string;
        /** The description of the issue security scheme. */
        description?: string;
        /** The ID of the default security level. */
        defaultSecurityLevelId?: number;
        levels?: Schemas.SecurityLevel[];
    }
    /** The list of features on a project. */
    interface ContainerForProjectFeatures {
        /** The project features. */
        features?: Schemas.ProjectFeature[];
    }
    /** Details of a project feature. */
    interface ProjectFeature {
        /** The ID of the project. */
        projectId?: number;
        /** The state of the feature. When updating the state of a feature, only ENABLED and DISABLED are supported. Responses can contain all values */
        state?: "ENABLED" | "DISABLED" | "COMING_SOON";
        /** Whether the state of the feature can be updated. */
        toggleLocked?: boolean;
        /** The key of the feature. */
        feature?: string;
        /** List of keys of the features required to enable the feature. */
        prerequisites?: string[];
        /** Localized display name for the feature. */
        localisedName?: string;
        /** Localized display description for the feature. */
        localisedDescription?: string;
        /** URI for the image representing the feature. */
        imageUri?: string;
    }
    /** Details of the feature state. */
    interface ProjectFeatureState {
        /** The feature state. */
        state?: "ENABLED" | "DISABLED" | "COMING_SOON";
    }
    /** An issue priority. */
    interface Priority {
        [key: string]: {};
    }
    /** A comment. */
    interface Comment {
        [key: string]: {};
    }
    /** Key fields from the linked issue. */
    interface Fields {
        /** The summary description of the linked issue. */
        summary?: string;
        /** The status of the linked issue. */
        status?: Schemas.StatusDetails;
        /** The priority of the linked issue. */
        priority?: Schemas.Priority;
        /** The assignee of the linked issue. */
        assignee?: Schemas.UserDetails;
        /** The time tracking of the linked issue. */
        timetracking?: Schemas.TimeTrackingDetails;
        /** The type of the linked issue. */
        issuetype?: Schemas.IssueTypeDetails;
        /** The type of the linked issue. */
        issueType?: Schemas.IssueTypeDetails;
    }
    /**
     * This object is used as follows:
     *
     *  *  In the [ issueLink](#api-rest-api-3-issueLink-post) resource it defines and reports on the type of link between the issues. Find a list of issue link types with [Get issue link types](#api-rest-api-3-issueLinkType-get).
     *  *  In the [ issueLinkType](#api-rest-api-3-issueLinkType-post) resource it defines and reports on issue link types.
     */
    interface IssueLinkType {
        /**
         * The ID of the issue link type and is used as follows:
         *
         *  *  In the [ issueLink](#api-rest-api-3-issueLink-post) resource it is the type of issue link. Required on create when `name` isn't provided. Otherwise, read only.
         *  *  In the [ issueLinkType](#api-rest-api-3-issueLinkType-post) resource it is read only.
         */
        id?: string;
        /**
         * The name of the issue link type and is used as follows:
         *
         *  *  In the [ issueLink](#api-rest-api-3-issueLink-post) resource it is the type of issue link. Required on create when `id` isn't provided. Otherwise, read only.
         *  *  In the [ issueLinkType](#api-rest-api-3-issueLinkType-post) resource it is required on create and optional on update. Otherwise, read only.
         */
        name?: string;
        /**
         * The description of the issue link type inward link and is used as follows:
         *
         *  *  In the [ issueLink](#api-rest-api-3-issueLink-post) resource it is read only.
         *  *  In the [ issueLinkType](#api-rest-api-3-issueLinkType-post) resource it is required on create and optional on update. Otherwise, read only.
         */
        inward?: string;
        /**
         * The description of the issue link type outward link and is used as follows:
         *
         *  *  In the [ issueLink](#api-rest-api-3-issueLink-post) resource it is read only.
         *  *  In the [ issueLinkType](#api-rest-api-3-issueLinkType-post) resource it is required on create and optional on update. Otherwise, read only.
         */
        outward?: string;
        /** The URL of the issue link type. Read only. */
        self?: string;
    }
    interface LinkIssueRequestJsonBean {
        type: Schemas.IssueLinkType;
        inwardIssue: Schemas.LinkedIssue;
        outwardIssue: Schemas.LinkedIssue;
        comment?: Schemas.Comment;
    }
    /** The ID or key of a linked issue. */
    interface LinkedIssue {
        /** The ID of an issue. Required if `key` isn't provided. */
        id?: string;
        /** The key of an issue. Required if `id` isn't provided. */
        key?: string;
        /** The URL of the issue. */
        self?: string;
        /** The fields associated with the issue. */
        fields?: Schemas.Fields;
    }
    interface RichText {
        valueSet?: boolean;
        finalised?: boolean;
        emptyAdf?: boolean;
    }
    /** Time tracking details. */
    interface TimeTrackingDetails {
        /** The original estimate of time needed for this issue in readable format. */
        originalEstimate?: string;
        /** The remaining estimate of time needed for this issue in readable format. */
        remainingEstimate?: string;
        /** Time worked on this issue in readable format. */
        timeSpent?: string;
        /** The original estimate of time needed for this issue in seconds. */
        originalEstimateSeconds?: number;
        /** The remaining estimate of time needed for this issue in seconds. */
        remainingEstimateSeconds?: number;
        /** Time worked on this issue in seconds. */
        timeSpentSeconds?: number;
    }
    /** The group or role to which this item is visible. */
    interface Visibility {
        [key: string]: {};
    }
    /** Details of a link between issues. */
    interface IssueLink {
        /** The ID of the issue link. */
        id?: string;
        /** The URL of the issue link. */
        self?: string;
        /** The type of link between the issues. */
        type: Schemas.IssueLinkType;
        /** The issue the link joins to. */
        inwardIssue: Schemas.LinkedIssue;
        /** The issue the link originates from. */
        outwardIssue: Schemas.LinkedIssue;
    }
    /** Paginated list of worklog details */
    interface PageOfWorklogs {
        [key: string]: {};
    }
    /** Details of a worklog. */
    interface Worklog {
        [key: string]: {};
    }
    interface IssueTypeCreateBean {
        /** The unique name for the issue type. The maximum length is 60 characters. */
        name: string;
        /** The description of the issue type. */
        description?: string;
        /**
         * Deprecated. Use `hierarchyLevel` instead.
         *
         * Whether the issue type is `subtype` or `standard`. Defaults to `standard`.
         */
        type?: "subtask" | "standard";
        /**
         * The hierarchy level of the issue type. Use:
         *
         *  *  `-1` for Subtask.
         *  *  `0` for Base.
         *
         * Defaults to `0`.
         */
        hierarchyLevel?: number;
    }
    interface IssueTypeUpdateBean {
        /** The unique name for the issue type. The maximum length is 60 characters. */
        name?: string;
        /** The description of the issue type. */
        description?: string;
        /** The ID of an issue type avatar. */
        avatarId?: number;
    }
    /** List of security schemes. */
    interface SecuritySchemes {
        /** List of security schemes. */
        issueSecuritySchemes?: Schemas.SecurityScheme[];
    }
    /** Issue security level member. */
    interface IssueSecurityLevelMember {
        /** The ID of the issue security level member. */
        id: number;
        /** The ID of the issue security level. */
        issueSecurityLevelId: number;
        /** The user or group being granted the permission. It consists of a `type` and a type-dependent `parameter`. See [Holder object](../api-group-permission-schemes/#holder-object) in *Get all permission schemes* for more information. */
        holder: Schemas.PermissionHolder;
    }
    /** A page of items. */
    interface PageBeanIssueSecurityLevelMember {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueSecurityLevelMember[];
    }
    /** List of issue transitions. */
    interface Transitions {
        /** Expand options that include additional transitions details in the response. */
        expand?: string;
        /** List of issue transitions. */
        transitions?: Schemas.IssueTransition[];
    }
    /** A list of issues suggested for use in auto-completion. */
    interface IssuePickerSuggestions {
        /** A list of issues for an issue type suggested for use in auto-completion. */
        sections?: Schemas.IssuePickerSuggestionsIssueType[];
    }
    /** A type of issue suggested for use in auto-completion. */
    interface IssuePickerSuggestionsIssueType {
        /** The label of the type of issues suggested for use in auto-completion. */
        label?: string;
        /** If issue suggestions are found, returns a message indicating the number of issues suggestions found and returned. */
        sub?: string;
        /** The ID of the type of issues suggested for use in auto-completion. */
        id?: string;
        /** If no issue suggestions are found, returns a message indicating no suggestions were found, */
        msg?: string;
        /** A list of issues suggested for use in auto-completion. */
        issues?: Schemas.SuggestedIssue[];
    }
    /** An issue suggested for use in the issue picker auto-completion. */
    interface SuggestedIssue {
        /** The ID of the issue. */
        id?: number;
        /** The key of the issue. */
        key?: string;
        /** The key of the issue in HTML format. */
        keyHtml?: string;
        /** The URL of the issue type's avatar. */
        img?: string;
        /** The phrase containing the query string in HTML format, with the string highlighted with HTML bold tags. */
        summary?: string;
        /** The phrase containing the query string, as plain text. */
        summaryText?: string;
    }
    /** Details of an operation to perform on a field. */
    interface FieldUpdateOperation {
        /** The value to add to the field. */
        add?: any;
        /** The value to set in the field. */
        set?: any;
        /** The value to removed from the field. */
        remove?: any;
        /** The value to edit in the field. */
        edit?: any;
    }
    /** Details of an issue update request. */
    interface IssueUpdateDetails {
        [key: string]: {};
    }
    /** The details of votes on an issue. */
    interface Votes {
        /** The URL of these issue vote details. */
        self?: string;
        /** The number of votes on the issue. */
        votes?: number;
        /** Whether the user making this request has voted on the issue. */
        hasVoted?: boolean;
        /** List of the users who have voted on this issue. An empty list is returned when the calling user doesn't have the *View voters and watchers* project permission. */
        voters?: Schemas.User[];
    }
    /** A list of issue IDs. */
    interface IssueList {
        /** The list of issue IDs. */
        issueIds: string[];
    }
    /** A container for the watch status of a list of issues. */
    interface BulkIssueIsWatching {
        /** The map of issue ID to boolean watch status. */
        issuesIsWatching?: {
            [key: string]: boolean;
        };
    }
    /** The details of watchers on an issue. */
    interface Watchers {
        /** The URL of these issue watcher details. */
        self?: string;
        /** Whether the calling user is watching this issue. */
        isWatching?: boolean;
        /** The number of users watching this issue. */
        watchCount?: number;
        /** Details of the users watching this issue. */
        watchers?: Schemas.UserDetails[];
    }
    /** Details about a created issue or subtask. */
    interface CreatedIssue {
        /** The ID of the created issue or subtask. */
        id?: string;
        /** The key of the created issue or subtask. */
        key?: string;
        /** The URL of the created issue or subtask. */
        self?: string;
        /** The response code and messages related to any requested transition. */
        transition?: Schemas.NestedResponse;
    }
    interface NestedResponse {
        status?: number;
        errorCollection?: Schemas.ErrorCollection;
    }
    interface IssuesUpdateBean {
        [key: string]: {};
    }
    interface BulkOperationErrorResult {
        status?: number;
        elementErrors?: Schemas.ErrorCollection;
        failedElementNumber?: number;
    }
    /** Details about the issues created and the errors for requests that failed. */
    interface CreatedIssues {
        /** Details of the issues created. */
        issues?: Schemas.CreatedIssue[];
        /** Error details for failed issue creation requests. */
        errors?: Schemas.BulkOperationErrorResult[];
    }
    /** The wrapper for the issue creation metadata for a list of projects. */
    interface IssueCreateMetadata {
        /** Expand options that include additional project details in the response. */
        expand?: string;
        /** List of projects and their issue creation metadata. */
        projects?: Schemas.ProjectIssueCreateMetadata[];
    }
    /** Details of the issue creation metadata for an issue type. */
    interface IssueTypeIssueCreateMetadata {
        /** The URL of these issue type details. */
        self?: string;
        /** The ID of the issue type. */
        id?: string;
        /** The description of the issue type. */
        description?: string;
        /** The URL of the issue type's avatar. */
        iconUrl?: string;
        /** The name of the issue type. */
        name?: string;
        /** Whether this issue type is used to create subtasks. */
        subtask?: boolean;
        /** The ID of the issue type's avatar. */
        avatarId?: number;
        /** Unique ID for next-gen projects. */
        entityId?: string;
        /** Hierarchy level of the issue type. */
        hierarchyLevel?: number;
        /** Details of the next-gen projects the issue type is available in. */
        scope?: Schemas.Scope;
        /** Expand options that include additional issue type metadata details in the response. */
        expand?: string;
        /** List of the fields available when creating an issue for the issue type. */
        fields?: {
            [key: string]: Schemas.FieldMetadata;
        };
    }
    /** Details of the issue creation metadata for a project. */
    interface ProjectIssueCreateMetadata {
        /** Expand options that include additional project issue create metadata details in the response. */
        expand?: string;
        /** The URL of the project. */
        self?: string;
        /** The ID of the project. */
        id?: string;
        /** The key of the project. */
        key?: string;
        /** The name of the project. */
        name?: string;
        /** List of the project's avatars, returning the avatar size and associated URL. */
        avatarUrls?: Schemas.AvatarUrlsBean;
        /** List of the issue types supported by the project. */
        issuetypes?: Schemas.IssueTypeIssueCreateMetadata[];
    }
    /** The application the linked item is in. */
    interface Application {
        [key: string]: {};
    }
    /** An icon. */
    interface IconBean {
        /** The URL of a 16x16 pixel icon. */
        url16x16?: string;
        /** The title of the icon, for use as a tooltip on the icon. */
        title?: string;
        /** The URL of the tooltip, used only for a status icon. */
        link?: string;
    }
    /** Details of an issue remote link. */
    interface RemoteIssueLink {
        /** The ID of the link. */
        id?: number;
        /** The URL of the link. */
        self?: string;
        /** The global ID of the link, such as the ID of the item on the remote system. */
        globalId?: string;
        /** Details of the remote application the linked item is in. */
        application?: Schemas.Application;
        /** Description of the relationship between the issue and the linked item. */
        relationship?: string;
        /** Details of the item linked to. */
        object?: Schemas.RemoteObject;
    }
    /** The linked item. */
    interface RemoteObject {
        [key: string]: {};
    }
    /** The status of the item. */
    interface Status {
        [key: string]: {};
    }
    /**
     * An icon. If no icon is defined:
     *
     *  *  for a status icon, no status icon displays in Jira.
     *  *  for the remote object icon, the default link icon displays in Jira.
     */
    interface Icon {
        [key: string]: {};
    }
    /** Details of a remote issue link. */
    interface RemoteIssueLinkRequest {
        [key: string]: {};
    }
    /** Details of the identifiers for a created or updated remote issue link. */
    interface RemoteIssueLinkIdentifies {
        /** The ID of the remote issue link, such as the ID of the item on the remote system. */
        id?: number;
        /** The URL of the remote issue link. */
        self?: string;
    }
    /** Details about a notification. */
    interface Notification {
        [key: string]: {};
    }
    /** Details of the users and groups to receive the notification. */
    interface NotificationRecipients {
        [key: string]: {};
    }
    /** Details of the group membership or permissions needed to receive the notification. */
    interface NotificationRecipientsRestrictions {
        /** List of group memberships required to receive the notification. */
        groups?: Schemas.GroupName[];
        /** List of permissions required to receive the notification. */
        permissions?: Schemas.RestrictedPermission[];
    }
    /** Details of the permission. */
    interface RestrictedPermission {
        [key: string]: {};
    }
    /** A list of issue link type beans. */
    interface IssueLinkTypes {
        /** The issue link type bean. */
        issueLinkTypes?: Schemas.IssueLinkType[];
    }
    /** A page of comments. */
    interface PageOfComments {
        [key: string]: {};
    }
    interface PaginatedResponseComment {
        total?: number;
        maxResults?: number;
        startAt?: number;
        results?: Schemas.Comment[];
    }
    interface IssueCommentListRequestBean {
        /** The list of comment IDs. A maximum of 1000 IDs can be specified. */
        ids: number[];
    }
    /** A page of items. */
    interface PageBeanComment {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Comment[];
    }
    /** A page of items. */
    interface PageBeanChangelog {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Changelog[];
    }
    /** A list of changelog IDs. */
    interface IssueChangelogIds {
        /** The list of changelog IDs. */
        changelogIds: number[];
    }
    /** Details about an attachment. */
    interface Attachment {
        [key: string]: {};
    }
    interface Group {
        /** The name of group. */
        name?: string;
        /** The URL for these group details. */
        self?: string;
        /** A paginated list of the users that are members of the group. A maximum of 50 users is returned in the list, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 50 users, use`?expand=users[51:100]`. */
        users?: Schemas.PagedListUserDetailsApplicationUser;
        /** Expand options that include additional group details in the response. */
        expand?: string;
    }
    /** A paged list. To access additional details append `[start-index:end-index]` to the expand request. For example, `?expand=sharedUsers[10:40]` returns a list starting at item 10 and finishing at item 40. */
    interface PagedListUserDetailsApplicationUser {
        /** The number of items on the page. */
        size?: number;
        /** The list of items. */
        items?: Schemas.UserDetails[];
        /** The maximum number of results that could be on the page. */
        "max-results"?: number;
        /** The index of the first item returned on the page. */
        "start-index"?: number;
        /** The index of the last item returned on the page. */
        "end-index"?: number;
    }
    /** A page of items. */
    interface PageBeanUserDetails {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.UserDetails[];
    }
    interface AddGroupBean {
        [key: string]: {};
    }
    interface UpdateUserToGroupBean {
        [key: string]: {};
    }
    /** A group found in a search. */
    interface FoundGroup {
        /** The name of the group. */
        name?: string;
        /** The group name with the matched query string highlighted with the HTML bold tag. */
        html?: string;
        labels?: Schemas.GroupLabel[];
        /** The ID of the group, if available, which uniquely identifies the group across all Atlassian products. For example, *952d12c3-5b5b-4d04-bb32-44d383afc4b2*. */
        groupId?: string | null;
    }
    /** The list of groups found in a search, including header text (Showing X of Y matching groups) and total of matched groups. */
    interface FoundGroups {
        /** Header text indicating the number of groups in the response and the total number of groups found in the search. */
        header?: string;
        /** The total number of groups found in the search. */
        total?: number;
        groups?: Schemas.FoundGroup[];
    }
    /** A group label. */
    interface GroupLabel {
        /** The group label name. */
        text?: string;
        /** The title of the group label. */
        title?: string;
        /** The type of the group label. */
        type?: "ADMIN" | "SINGLE" | "MULTIPLE";
    }
    /** List of users and groups found in a search. */
    interface FoundUsersAndGroups {
        users?: Schemas.FoundUsers;
        groups?: Schemas.FoundGroups;
    }
    interface CustomFieldDefinitionJsonBean {
        /** The name of the custom field, which is displayed in Jira. This is not the unique identifier. */
        name: string;
        /** The description of the custom field, which is displayed in Jira. */
        description?: string;
        /**
         * The type of the custom field. These built-in custom field types are available:
         *
         *  *  `cascadingselect`: Enables values to be selected from two levels of select lists (value: `com.atlassian.jira.plugin.system.customfieldtypes:cascadingselect`)
         *  *  `datepicker`: Stores a date using a picker control (value: `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`)
         *  *  `datetime`: Stores a date with a time component (value: `com.atlassian.jira.plugin.system.customfieldtypes:datetime`)
         *  *  `float`: Stores and validates a numeric (floating point) input (value: `com.atlassian.jira.plugin.system.customfieldtypes:float`)
         *  *  `grouppicker`: Stores a user group using a picker control (value: `com.atlassian.jira.plugin.system.customfieldtypes:grouppicker`)
         *  *  `importid`: A read-only field that stores the ID the issue had in the system it was imported from (value: `com.atlassian.jira.plugin.system.customfieldtypes:importid`)
         *  *  `labels`: Stores labels (value: `com.atlassian.jira.plugin.system.customfieldtypes:labels`)
         *  *  `multicheckboxes`: Stores multiple values using checkboxes (value: ``)
         *  *  `multigrouppicker`: Stores multiple user groups using a picker control (value: ``)
         *  *  `multiselect`: Stores multiple values using a select list (value: `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`)
         *  *  `multiuserpicker`: Stores multiple users using a picker control (value: `com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker`)
         *  *  `multiversion`: Stores multiple versions from the versions available in a project using a picker control (value: `com.atlassian.jira.plugin.system.customfieldtypes:multiversion`)
         *  *  `project`: Stores a project from a list of projects that the user is permitted to view (value: `com.atlassian.jira.plugin.system.customfieldtypes:project`)
         *  *  `radiobuttons`: Stores a value using radio buttons (value: `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`)
         *  *  `readonlyfield`: Stores a read-only text value, which can only be populated via the API (value: `com.atlassian.jira.plugin.system.customfieldtypes:readonlyfield`)
         *  *  `select`: Stores a value from a configurable list of options (value: `com.atlassian.jira.plugin.system.customfieldtypes:select`)
         *  *  `textarea`: Stores a long text string using a multiline text area (value: `com.atlassian.jira.plugin.system.customfieldtypes:textarea`)
         *  *  `textfield`: Stores a text string using a single-line text box (value: `com.atlassian.jira.plugin.system.customfieldtypes:textfield`)
         *  *  `url`: Stores a URL (value: `com.atlassian.jira.plugin.system.customfieldtypes:url`)
         *  *  `userpicker`: Stores a user using a picker control (value: `com.atlassian.jira.plugin.system.customfieldtypes:userpicker`)
         *  *  `version`: Stores a version using a picker control (value: `com.atlassian.jira.plugin.system.customfieldtypes:version`)
         *
         * To create a field based on a [Forge custom field type](https://developer.atlassian.com/platform/forge/manifest-reference/modules/#jira-custom-field-type--beta-), use the ID of the Forge custom field type as the value. For example, `ari:cloud:ecosystem::extension/e62f20a2-4b61-4dbe-bfb9-9a88b5e3ac84/548c5df1-24aa-4f7c-bbbb-3038d947cb05/static/my-cf-type-key`.
         */
        type: string;
        /**
         * The searcher defines the way the field is searched in Jira. For example, *com.atlassian.jira.plugin.system.customfieldtypes:grouppickersearcher*.
         * The search UI (basic search and JQL search) will display different operations and values for the field, based on the field searcher. You must specify a searcher that is valid for the field type, as listed below (abbreviated values shown):
         *
         *  *  `cascadingselect`: `cascadingselectsearcher`
         *  *  `datepicker`: `daterange`
         *  *  `datetime`: `datetimerange`
         *  *  `float`: `exactnumber` or `numberrange`
         *  *  `grouppicker`: `grouppickersearcher`
         *  *  `importid`: `exactnumber` or `numberrange`
         *  *  `labels`: `labelsearcher`
         *  *  `multicheckboxes`: `multiselectsearcher`
         *  *  `multigrouppicker`: `multiselectsearcher`
         *  *  `multiselect`: `multiselectsearcher`
         *  *  `multiuserpicker`: `userpickergroupsearcher`
         *  *  `multiversion`: `versionsearcher`
         *  *  `project`: `projectsearcher`
         *  *  `radiobuttons`: `multiselectsearcher`
         *  *  `readonlyfield`: `textsearcher`
         *  *  `select`: `multiselectsearcher`
         *  *  `textarea`: `textsearcher`
         *  *  `textfield`: `textsearcher`
         *  *  `url`: `exacttextsearcher`
         *  *  `userpicker`: `userpickergroupsearcher`
         *  *  `version`: `versionsearcher`
         *
         * If no searcher is provided, the field isn't searchable. However, [Forge custom fields](https://developer.atlassian.com/platform/forge/manifest-reference/modules/#jira-custom-field-type--beta-) have a searcher set automatically, so are always searchable.
         */
        searcherKey?: "com.atlassian.jira.plugin.system.customfieldtypes:cascadingselectsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:daterange" | "com.atlassian.jira.plugin.system.customfieldtypes:datetimerange" | "com.atlassian.jira.plugin.system.customfieldtypes:exactnumber" | "com.atlassian.jira.plugin.system.customfieldtypes:exacttextsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:grouppickersearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:labelsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:multiselectsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:numberrange" | "com.atlassian.jira.plugin.system.customfieldtypes:projectsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:textsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:userpickergroupsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:versionsearcher";
    }
    /** Details of a custom field. */
    interface UpdateCustomFieldDetails {
        /** The name of the custom field. It doesn't have to be unique. The maximum length is 255 characters. */
        name?: string;
        /** The description of the custom field. The maximum length is 40000 characters. */
        description?: string;
        /**
         * The searcher that defines the way the field is searched in Jira. It can be set to `null`, otherwise you must specify the valid searcher for the field type, as listed below (abbreviated values shown):
         *
         *  *  `cascadingselect`: `cascadingselectsearcher`
         *  *  `datepicker`: `daterange`
         *  *  `datetime`: `datetimerange`
         *  *  `float`: `exactnumber` or `numberrange`
         *  *  `grouppicker`: `grouppickersearcher`
         *  *  `importid`: `exactnumber` or `numberrange`
         *  *  `labels`: `labelsearcher`
         *  *  `multicheckboxes`: `multiselectsearcher`
         *  *  `multigrouppicker`: `multiselectsearcher`
         *  *  `multiselect`: `multiselectsearcher`
         *  *  `multiuserpicker`: `userpickergroupsearcher`
         *  *  `multiversion`: `versionsearcher`
         *  *  `project`: `projectsearcher`
         *  *  `radiobuttons`: `multiselectsearcher`
         *  *  `readonlyfield`: `textsearcher`
         *  *  `select`: `multiselectsearcher`
         *  *  `textarea`: `textsearcher`
         *  *  `textfield`: `textsearcher`
         *  *  `url`: `exacttextsearcher`
         *  *  `userpicker`: `userpickergroupsearcher`
         *  *  `version`: `versionsearcher`
         */
        searcherKey?: "com.atlassian.jira.plugin.system.customfieldtypes:cascadingselectsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:daterange" | "com.atlassian.jira.plugin.system.customfieldtypes:datetimerange" | "com.atlassian.jira.plugin.system.customfieldtypes:exactnumber" | "com.atlassian.jira.plugin.system.customfieldtypes:exacttextsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:grouppickersearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:labelsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:multiselectsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:numberrange" | "com.atlassian.jira.plugin.system.customfieldtypes:projectsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:textsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:userpickergroupsearcher" | "com.atlassian.jira.plugin.system.customfieldtypes:versionsearcher";
    }
    /** A page of items. */
    interface PageBeanScreenWithTab {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.ScreenWithTab[];
    }
    /** A screen with tab details. */
    interface ScreenWithTab {
        /** The ID of the screen. */
        id?: number;
        /** The name of the screen. */
        name?: string;
        /** The description of the screen. */
        description?: string;
        /** The scope of the screen. */
        scope?: Schemas.Scope;
        /** The tab for the screen. */
        tab?: Schemas.ScreenableTab;
    }
    /** A context. */
    interface Context {
        /** The ID of the context. */
        id?: number;
        /** The name of the context. */
        name?: string;
        /** The scope of the context. */
        scope?: Schemas.Scope;
    }
    /** A page of items. */
    interface PageBeanContext {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Context[];
    }
    /** Details of the custom field options for a context. */
    interface CustomFieldContextOption {
        /** The ID of the custom field option. */
        id: string;
        /** The value of the custom field option. */
        value: string;
        /** For cascading options, the ID of the custom field option containing the cascading option. */
        optionId?: string;
        /** Whether the option is disabled. */
        disabled: boolean;
    }
    /** A page of items. */
    interface PageBeanCustomFieldContextOption {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.CustomFieldContextOption[];
    }
    /** Details of the options to create for a custom field. */
    interface BulkCustomFieldOptionCreateRequest {
        /** Details of options to create. */
        options?: Schemas.CustomFieldOptionCreate[];
    }
    /** Details of a custom field option to create. */
    interface CustomFieldOptionCreate {
        /** The value of the custom field option. */
        value: string;
        /** For cascading options, the ID of the custom field object containing the cascading option. */
        optionId?: string;
        /** Whether the option is disabled. */
        disabled?: boolean;
    }
    /** A list of custom field options for a context. */
    interface CustomFieldCreatedContextOptionsList {
        /** The created custom field options. */
        options?: Schemas.CustomFieldContextOption[];
    }
    /** An ordered list of custom field option IDs and information on where to move them. */
    interface OrderOfCustomFieldOptions {
        /** A list of IDs of custom field options to move. The order of the custom field option IDs in the list is the order they are given after the move. The list must contain custom field options or cascading options, but not both. */
        customFieldOptionIds: string[];
        /** The ID of the custom field option or cascading option to place the moved options after. Required if `position` isn't provided. */
        after?: string;
        /** The position the custom field options should be moved to. Required if `after` isn't provided. */
        position?: "First" | "Last";
    }
    /** Details of the options to update for a custom field. */
    interface BulkCustomFieldOptionUpdateRequest {
        /** Details of the options to update. */
        options?: Schemas.CustomFieldOptionUpdate[];
    }
    /** Details of a custom field option for a context. */
    interface CustomFieldOptionUpdate {
        /** The ID of the custom field option. */
        id: string;
        /** The value of the custom field option. */
        value?: string;
        /** Whether the option is disabled. */
        disabled?: boolean;
    }
    /** A list of custom field options for a context. */
    interface CustomFieldUpdatedContextOptionsList {
        /** The updated custom field options. */
        options?: Schemas.CustomFieldOptionUpdate[];
    }
    /** Count of issues assigned to a component. */
    interface ComponentIssuesCount {
        /** The URL for this count of issues for a component. */
        self?: string;
        /** The count of issues assigned to a component. */
        issueCount?: number;
    }
    /** List of system avatars. */
    interface SystemAvatars {
        /** A list of avatar details. */
        system?: Schemas.Avatar[];
    }
    /** Details of an issue type scheme. */
    interface IssueTypeScheme {
        /** The ID of the issue type scheme. */
        id: string;
        /** The name of the issue type scheme. */
        name: string;
        /** The description of the issue type scheme. */
        description?: string;
        /** The ID of the default issue type of the issue type scheme. */
        defaultIssueTypeId?: string;
        /** Whether the issue type scheme is the default. */
        isDefault?: boolean;
    }
    /** A page of items. */
    interface PageBeanIssueTypeScheme {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeScheme[];
    }
    /** Issue type scheme with a list of the projects that use it. */
    interface IssueTypeSchemeProjects {
        /** Details of an issue type scheme. */
        issueTypeScheme: Schemas.IssueTypeScheme;
        /** The IDs of the projects using the issue type scheme. */
        projectIds: string[];
    }
    /** A page of items. */
    interface PageBeanIssueTypeSchemeProjects {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeSchemeProjects[];
    }
    /** Issue type scheme item. */
    interface IssueTypeSchemeMapping {
        /** The ID of the issue type scheme. */
        issueTypeSchemeId: string;
        /** The ID of the issue type. */
        issueTypeId: string;
    }
    /** A page of items. */
    interface PageBeanIssueTypeSchemeMapping {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeSchemeMapping[];
    }
    /** Details of the association between an issue type scheme and project. */
    interface IssueTypeSchemeProjectAssociation {
        /** The ID of the issue type scheme. */
        issueTypeSchemeId: string;
        /** The ID of the project. */
        projectId: string;
    }
    /** Details of an issue type scheme and its associated issue types. */
    interface IssueTypeSchemeDetails {
        /** The name of the issue type scheme. The name must be unique. The maximum length is 255 characters. */
        name: string;
        /** The description of the issue type scheme. The maximum length is 4000 characters. */
        description?: string;
        /** The ID of the default issue type of the issue type scheme. This ID must be included in `issueTypeIds`. */
        defaultIssueTypeId?: string;
        /** The list of issue types IDs of the issue type scheme. At least one standard issue type ID is required. */
        issueTypeIds: string[];
    }
    /** The ID of an issue type scheme. */
    interface IssueTypeSchemeID {
        /** The ID of the issue type scheme. */
        issueTypeSchemeId: string;
    }
    /** The list of issue type IDs. */
    interface IssueTypeIds {
        /** The list of issue type IDs. */
        issueTypeIds: string[];
    }
    /** Details of the name, description, and default issue type for an issue type scheme. */
    interface IssueTypeSchemeUpdateDetails {
        /** The name of the issue type scheme. The name must be unique. The maximum length is 255 characters. */
        name?: string;
        /** The description of the issue type scheme. The maximum length is 4000 characters. */
        description?: string;
        /** The ID of the default issue type of the issue type scheme. */
        defaultIssueTypeId?: string;
    }
    /** An ordered list of issue type IDs and information about where to move them. */
    interface OrderOfIssueTypes {
        /** A list of the issue type IDs to move. The order of the issue type IDs in the list is the order they are given after the move. */
        issueTypeIds: string[];
        /** The ID of the issue type to place the moved issue types after. Required if `position` isn't provided. */
        after?: string;
        /** The position the issue types should be moved to. Required if `after` isn't provided. */
        position?: "First" | "Last";
    }
    interface CreateUpdateRoleRequestBean {
        /** The name of the project role. Must be unique. Cannot begin or end with whitespace. The maximum length is 255 characters. Required when creating a project role. Optional when partially updating a project role. */
        name?: string;
        /** A description of the project role. Required when fully updating a project role. Optional when creating or partially updating a project role. */
        description?: string;
    }
    interface ActorInputBean {
        /** The account IDs of the users to add as default actors. This parameter accepts a comma-separated list. For example, `"user":["5b10a2844c20165700ede21g", "5b109f2e9729b51b54dc274d"]`. */
        user?: string[];
        /** The name of the group to add as a default actor. This parameter accepts a comma-separated list. For example, `"group":["project-admin", "jira-developers"]`. */
        group?: string[];
    }
    interface ProjectRoleActorsUpdateBean {
        /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
        id?: number;
        /** The actors to add to the project role. Add groups using `atlassian-group-role-actor` and a list of group names. For example, `"atlassian-group-role-actor":["another","administrators"]}`. Add users using `atlassian-user-role-actor` and a list of account IDs. For example, `"atlassian-user-role-actor":["12345678-9abc-def1-2345-6789abcdef12", "abcdef12-3456-789a-bcde-f123456789ab"]`. */
        categorisedActors?: {
            [key: string]: string[];
        };
    }
    interface ActorsMap {
        /** The user account ID of the user to add. */
        user?: string[];
        /** The name of the group to add. */
        group?: string[];
    }
    /** Details about a project role. */
    interface ProjectRoleDetails {
        /** The URL the project role details. */
        self?: string;
        /** The name of the project role. */
        name?: string;
        /** The ID of the project role. */
        id?: number;
        /** The description of the project role. */
        description?: string;
        /** Whether this role is the admin role for the project. */
        admin?: boolean;
        /** The scope of the role. Indicated for roles associated with [next-gen projects](https://confluence.atlassian.com/x/loMyO). */
        scope?: Schemas.Scope;
        /** Whether the roles are configurable for this project. */
        roleConfigurable?: boolean;
        /** The translated name of the project role. */
        translatedName?: string;
        /** Whether this role is the default role for the project. */
        default?: boolean;
    }
    /** The screen scheme for an issue type. */
    interface IssueTypeScreenSchemeItem {
        /** The ID of the issue type screen scheme. */
        issueTypeScreenSchemeId: string;
        /** The ID of the issue type or *default*. Only issue types used in classic projects are accepted. When creating an issue screen scheme, an entry for *default* must be provided and defines the mapping for all issue types without a screen scheme. Otherwise, a *default* entry can't be provided. */
        issueTypeId: string;
        /** The ID of the screen scheme. */
        screenSchemeId: string;
    }
    /** A page of items. */
    interface PageBeanIssueTypeScreenSchemeItem {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeScreenSchemeItem[];
    }
    /** Details of an issue type screen scheme. */
    interface IssueTypeScreenScheme {
        /** The ID of the issue type screen scheme. */
        id: string;
        /** The name of the issue type screen scheme. */
        name: string;
        /** The description of the issue type screen scheme. */
        description?: string;
    }
    /** Issue type screen scheme with a list of the projects that use it. */
    interface IssueTypeScreenSchemesProjects {
        /** Details of an issue type screen scheme. */
        issueTypeScreenScheme: Schemas.IssueTypeScreenScheme;
        /** The IDs of the projects using the issue type screen scheme. */
        projectIds: string[];
    }
    /** A page of items. */
    interface PageBeanIssueTypeScreenSchemesProjects {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeScreenSchemesProjects[];
    }
    /** A page of items. */
    interface PageBeanIssueTypeScreenScheme {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeScreenScheme[];
    }
    /** A page of items. */
    interface PageBeanProjectDetails {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.ProjectDetails[];
    }
    /** Associated issue type screen scheme and project. */
    interface IssueTypeScreenSchemeProjectAssociation {
        /** The ID of the issue type screen scheme. */
        issueTypeScreenSchemeId?: string;
        /** The ID of the project. */
        projectId?: string;
    }
    /** The details of an issue type screen scheme. */
    interface IssueTypeScreenSchemeDetails {
        /** The name of the issue type screen scheme. The name must be unique. The maximum length is 255 characters. */
        name: string;
        /** The description of the issue type screen scheme. The maximum length is 255 characters. */
        description?: string;
        /** The IDs of the screen schemes for the issue type IDs and *default*. A *default* entry is required to create an issue type screen scheme, it defines the mapping for all issue types without a screen scheme. */
        issueTypeMappings: Schemas.IssueTypeScreenSchemeMapping[];
    }
    /** The IDs of the screen schemes for the issue type IDs. */
    interface IssueTypeScreenSchemeMapping {
        /** The ID of the issue type or *default*. Only issue types used in classic projects are accepted. An entry for *default* must be provided and defines the mapping for all issue types without a screen scheme. */
        issueTypeId: string;
        /** The ID of the screen scheme. Only screen schemes used in classic projects are accepted. */
        screenSchemeId: string;
    }
    /** The ID of an issue type screen scheme. */
    interface IssueTypeScreenSchemeId {
        /** The ID of the issue type screen scheme. */
        id: string;
    }
    /** Details of an issue type screen scheme. */
    interface IssueTypeScreenSchemeUpdateDetails {
        /** The name of the issue type screen scheme. The name must be unique. The maximum length is 255 characters. */
        name?: string;
        /** The description of the issue type screen scheme. The maximum length is 255 characters. */
        description?: string;
    }
    /** A list of issue type screen scheme mappings. */
    interface IssueTypeScreenSchemeMappingDetails {
        /** The list of issue type to screen scheme mappings. A *default* entry cannot be specified because a default entry is added when an issue type screen scheme is created. */
        issueTypeMappings: Schemas.IssueTypeScreenSchemeMapping[];
    }
    /** The ID of a screen scheme. */
    interface UpdateDefaultScreenScheme {
        /** The ID of the screen scheme. */
        screenSchemeId: string;
    }
    /** Metadata for an issue attachment. */
    interface AttachmentMetadata {
        /** The ID of the attachment. */
        id?: number;
        /** The URL of the attachment metadata details. */
        self?: string;
        /** The name of the attachment file. */
        filename?: string;
        /** Details of the user who attached the file. */
        author?: Schemas.User;
        /** The datetime the attachment was created. */
        created?: string;
        /** The size of the attachment. */
        size?: number;
        /** The MIME type of the attachment. */
        mimeType?: string;
        /** Additional properties of the attachment. */
        properties?: {
            [key: string]: any;
        };
        /** The URL of the attachment. */
        content?: string;
        /** The URL of a thumbnail representing the attachment. */
        thumbnail?: string;
        /** \[EXPERIMENTAL\] - The file ID of the attachment in the media store. */
        mediaApiFileId?: string;
    }
    /** Details of the instance's attachment settings. */
    interface AttachmentSettings {
        /** Whether the ability to add attachments is enabled. */
        enabled?: boolean;
        /** The maximum size of attachments permitted, in bytes. */
        uploadLimit?: number;
    }
    interface AttachmentArchiveEntry {
        entryIndex?: number;
        abbreviatedName?: string;
        mediaType?: string;
        name?: string;
        size?: number;
    }
    interface AttachmentArchiveImpl {
        /** The list of the items included in the archive. */
        entries?: Schemas.AttachmentArchiveEntry[];
        /** The number of items in the archive. */
        totalEntryCount?: number;
    }
    interface AttachmentArchive {
        moreAvailable?: boolean;
        totalNumberOfEntriesAvailable?: number;
        totalEntryCount?: number;
        entries?: Schemas.AttachmentArchiveEntry[];
    }
    /** Metadata for an item in an attachment archive. */
    interface AttachmentArchiveItemReadable {
        /** The path of the archive item. */
        path?: string;
        /** The position of the item within the archive. */
        index?: number;
        /** The size of the archive item. */
        size?: string;
        /** The MIME type of the archive item. */
        mediaType?: string;
        /** The label for the archive item. */
        label?: string;
    }
    /** Metadata for an archive (for example a zip) and its contents. */
    interface AttachmentArchiveMetadataReadable {
        /** The ID of the attachment. */
        id?: number;
        /** The name of the archive file. */
        name?: string;
        /** The list of the items included in the archive. */
        entries?: Schemas.AttachmentArchiveItemReadable[];
        /** The number of items included in the archive. */
        totalEntryCount?: number;
        /** The MIME type of the attachment. */
        mediaType?: string;
    }
    /** Details of a changed worklog. */
    interface ChangedWorklog {
        /** The ID of the worklog. */
        worklogId?: number;
        /** The datetime of the change. */
        updatedTime?: number;
        /** Details of properties associated with the change. */
        properties?: Schemas.EntityProperty[];
    }
    /** List of changed worklogs. */
    interface ChangedWorklogs {
        /** Changed worklog list. */
        values?: Schemas.ChangedWorklog[];
        /** The datetime of the first worklog item in the list. */
        since?: number;
        /** The datetime of the last worklog item in the list. */
        until?: number;
        /** The URL of this changed worklogs list. */
        self?: string;
        /** The URL of the next list of changed worklogs. */
        nextPage?: string;
        lastPage?: boolean;
    }
    interface WorklogIdsRequestBean {
        /** A list of worklog IDs. */
        ids: number[];
    }
    /** Details of a custom option for a field. */
    interface CustomFieldOption {
        /** The URL of these custom field option details. */
        self?: string;
        /** The value of the custom field option. */
        value?: string;
    }
    /** Details of a context to project association. */
    interface CustomFieldContextProjectMapping {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the project. */
        projectId?: string;
        /** Whether context is global. */
        isGlobalContext?: boolean;
    }
    /** A page of items. */
    interface PageBeanCustomFieldContextProjectMapping {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.CustomFieldContextProjectMapping[];
    }
    /** The details of a custom field context. */
    interface CustomFieldContext {
        /** The ID of the context. */
        id: string;
        /** The name of the context. */
        name: string;
        /** The description of the context. */
        description: string;
        /** Whether the context is global. */
        isGlobalContext: boolean;
        /** Whether the context apply to all issue types. */
        isAnyIssueType: boolean;
    }
    /** A page of items. */
    interface PageBeanCustomFieldContext {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.CustomFieldContext[];
    }
    type CustomFieldContextDefaultValue = Schemas.CustomFieldContextDefaultValueCascadingOption | Schemas.CustomFieldContextDefaultValueMultipleOption | Schemas.CustomFieldContextDefaultValueSingleOption | Schemas.CustomFieldContextSingleUserPickerDefaults | Schemas.CustomFieldContextDefaultValueMultiUserPicker | Schemas.CustomFieldContextDefaultValueSingleGroupPicker | Schemas.CustomFieldContextDefaultValueMultipleGroupPicker | Schemas.CustomFieldContextDefaultValueDate | Schemas.CustomFieldContextDefaultValueDateTime | Schemas.CustomFieldContextDefaultValueURL | Schemas.CustomFieldContextDefaultValueProject | Schemas.CustomFieldContextDefaultValueFloat | Schemas.CustomFieldContextDefaultValueLabels | Schemas.CustomFieldContextDefaultValueTextField | Schemas.CustomFieldContextDefaultValueTextArea | Schemas.CustomFieldContextDefaultValueReadOnly | Schemas.CustomFieldContextDefaultValueSingleVersionPicker | Schemas.CustomFieldContextDefaultValueMultipleVersionPicker;
    /** The default value for a cascading select custom field. */
    interface CustomFieldContextDefaultValueCascadingOption {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the default option. */
        optionId: string;
        /** The ID of the default cascading option. */
        cascadingOptionId?: string;
        type: string;
    }
    /** The default value for a Date custom field. */
    interface CustomFieldContextDefaultValueDate {
        /** The default date in ISO format. Ignored if `useCurrent` is true. */
        date?: string;
        /** Whether to use the current date. */
        useCurrent?: boolean;
        type: string;
    }
    /** The default value for a date time custom field. */
    interface CustomFieldContextDefaultValueDateTime {
        /** The default date-time in ISO format. Ignored if `useCurrent` is true. */
        dateTime?: string;
        /** Whether to use the current date. */
        useCurrent?: boolean;
        type: string;
    }
    /** Default value for a float (number) custom field. */
    interface CustomFieldContextDefaultValueFloat {
        /** The default floating-point number. */
        number: number;
        type: string;
    }
    /** Default value for a labels custom field. */
    interface CustomFieldContextDefaultValueLabels {
        /** The default labels value. */
        labels: string[];
        type: string;
    }
    /** The default value for a User Picker (multiple) custom field. */
    interface CustomFieldContextDefaultValueMultiUserPicker {
        /** The ID of the context. */
        contextId: string;
        /** The IDs of the default users. */
        accountIds: string[];
        type: string;
    }
    /** The default value for a multiple group picker custom field. */
    interface CustomFieldContextDefaultValueMultipleGroupPicker {
        /** The ID of the context. */
        contextId: string;
        /** The IDs of the default groups. */
        groupIds: string[];
        type: string;
    }
    /** The default value for a multi-select custom field. */
    interface CustomFieldContextDefaultValueMultipleOption {
        /** The ID of the context. */
        contextId: string;
        /** The list of IDs of the default options. */
        optionIds: string[];
        type: string;
    }
    /** The default value for a multiple version picker custom field. */
    interface CustomFieldContextDefaultValueMultipleVersionPicker {
        /** The IDs of the default versions. */
        versionIds: string[];
        /** The order the pickable versions are displayed in. If not provided, the released-first order is used. Available version orders are `"releasedFirst"` and `"unreleasedFirst"`. */
        versionOrder?: string;
        type: string;
    }
    /** The default value for a project custom field. */
    interface CustomFieldContextDefaultValueProject {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the default project. */
        projectId: string;
        type: string;
    }
    /** The default text for a read only custom field. */
    interface CustomFieldContextDefaultValueReadOnly {
        /** The default text. The maximum length is 255 characters. */
        text?: string;
        type: string;
    }
    /** The default value for a group picker custom field. */
    interface CustomFieldContextDefaultValueSingleGroupPicker {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the the default group. */
        groupId: string;
        type: string;
    }
    /** The default value for a single select custom field. */
    interface CustomFieldContextDefaultValueSingleOption {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the default option. */
        optionId: string;
        type: string;
    }
    /** The default value for a version picker custom field. */
    interface CustomFieldContextDefaultValueSingleVersionPicker {
        /** The ID of the default version. */
        versionId: string;
        /** The order the pickable versions are displayed in. If not provided, the released-first order is used. Available version orders are `"releasedFirst"` and `"unreleasedFirst"`. */
        versionOrder?: string;
        type: string;
    }
    /** The default text for a text area custom field. */
    interface CustomFieldContextDefaultValueTextArea {
        /** The default text. The maximum length is 32767 characters. */
        text?: string;
        type: string;
    }
    /** The default text for a text custom field. */
    interface CustomFieldContextDefaultValueTextField {
        /** The default text. The maximum length is 254 characters. */
        text?: string;
        type: string;
    }
    /** The default value for a URL custom field. */
    interface CustomFieldContextDefaultValueURL {
        /** The ID of the context. */
        contextId: string;
        /** The default URL. */
        url: string;
        type: string;
    }
    /** Defaults for a User Picker (single) custom field. */
    interface CustomFieldContextSingleUserPickerDefaults {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the default user. */
        accountId: string;
        userFilter: Schemas.UserFilter;
        type: string;
    }
    /** A page of items. */
    interface PageBeanCustomFieldContextDefaultValue {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.CustomFieldContextDefaultValue[];
    }
    /** Filter for a User Picker (single) custom field. */
    interface UserFilter {
        /** Whether the filter is enabled. */
        enabled: boolean;
        /** User groups autocomplete suggestion users must belong to. If not provided, the default values are used. A maximum of 10 groups can be provided. */
        groups?: string[];
        /** Roles that autocomplete suggestion users must belong to. If not provided, the default values are used. A maximum of 10 roles can be provided. */
        roleIds?: number[];
    }
    /** The details of a created custom field context. */
    interface CreateCustomFieldContext {
        /** The ID of the context. */
        id?: string;
        /** The name of the context. */
        name: string;
        /** The description of the context. */
        description?: string;
        /** The list of project IDs associated with the context. If the list is empty, the context is global. */
        projectIds?: string[];
        /** The list of issue types IDs for the context. If the list is empty, the context refers to all issue types. */
        issueTypeIds?: string[];
    }
    /** A list of project IDs. */
    interface ProjectIds {
        /** The IDs of projects. */
        projectIds: string[];
    }
    /** Details of a custom field context. */
    interface CustomFieldContextUpdateDetails {
        /** The name of the custom field context. The name must be unique. The maximum length is 255 characters. */
        name?: string;
        /** The description of the custom field context. The maximum length is 255 characters. */
        description?: string;
    }
    /** The project and issue type mapping. */
    interface ProjectIssueTypeMapping {
        /** The ID of the project. */
        projectId: string;
        /** The ID of the issue type. */
        issueTypeId: string;
    }
    /** The project and issue type mappings. */
    interface ProjectIssueTypeMappings {
        /** The project and issue type mappings. */
        mappings: Schemas.ProjectIssueTypeMapping[];
    }
    /** The project and issue type mapping with a matching custom field context. */
    interface ContextForProjectAndIssueType {
        /** The ID of the project. */
        projectId: string;
        /** The ID of the issue type. */
        issueTypeId: string;
        /** The ID of the custom field context. */
        contextId: string;
    }
    /** A page of items. */
    interface PageBeanContextForProjectAndIssueType {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.ContextForProjectAndIssueType[];
    }
    /** Default values to update. */
    interface CustomFieldContextDefaultValueUpdate {
        defaultValues?: Schemas.CustomFieldContextDefaultValue[];
    }
    /** Mapping of an issue type to a context. */
    interface IssueTypeToContextMapping {
        /** The ID of the context. */
        contextId: string;
        /** The ID of the issue type. */
        issueTypeId?: string;
        /** Whether the context is mapped to any issue type. */
        isAnyIssueType?: boolean;
    }
    /** A page of items. */
    interface PageBeanIssueTypeToContextMapping {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueTypeToContextMapping[];
    }
    /** A list of issue IDs and the value to update a custom field to. */
    interface CustomFieldValueUpdate {
        /** The list of issue IDs. */
        issueIds: number[];
        /**
         * The value for the custom field. The value must be compatible with the [custom field type](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field/#data-types) as follows:
         *
         *  *  `string` the value must be a string.
         *  *  `number` the value must be a number.
         *  *  `datetime` the value must be a string that represents a date in the ISO format, for example `"2021-01-18T12:00:00-03:00"`.
         *  *  `user` the value must be an object that contains the `accountId` field.
         *  *  `group` the value must be an object that contains the group `name` field.
         *
         * A list of appropriate values must be provided if the field is of the `list` [collection type](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field/#collection-types).
         */
        value: any;
    }
    /** Details of updates for a custom field. */
    interface CustomFieldValueUpdateDetails {
        /** The list of custom field update details. */
        updates?: Schemas.CustomFieldValueUpdate[];
    }
    /** A custom field and its new value with a list of issue to update. */
    interface MultipleCustomFieldValuesUpdate {
        /** The ID or key of the custom field. For example, `customfield_10010`. */
        customField: string;
        /** The list of issue IDs. */
        issueIds: number[];
        /**
         * The value for the custom field. The value must be compatible with the [custom field type](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field/#data-types) as follows:
         *
         *  *  `string` the value must be a string.
         *  *  `number` the value must be a number.
         *  *  `datetime` the value must be a string that represents a date in the ISO format, for example `"2021-01-18T12:00:00-03:00"`.
         *  *  `user` the value must be an object that contains the `accountId` field.
         *  *  `group` the value must be an object that contains the group `name` field.
         *
         * A list of appropriate values must be provided if the field is of the `list` [collection type](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field/#collection-types).
         */
        value: any;
    }
    /** List of updates for a custom fields. */
    interface MultipleCustomFieldValuesUpdateDetails {
        updates?: Schemas.MultipleCustomFieldValuesUpdate[];
    }
    /** Details of the contextual configuration for a custom field. */
    interface ContextualConfiguration {
        /** The ID of the configuration. */
        id: string;
        /** Deprecated, do not use. */
        contextId?: number;
        /** The ID of the field context the configuration is associated with. */
        fieldContextId: string;
        /** The field configuration. */
        configuration?: any;
        /** The field value schema. */
        schema?: any;
    }
    /** A page of items. */
    interface PageBeanContextualConfiguration {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.ContextualConfiguration[];
    }
    /** Details of configurations for a custom field. */
    interface CustomFieldConfigurations {
        /** The list of custom field configuration details. */
        configurations: Schemas.ContextualConfiguration[];
    }
    /** A page of items. */
    interface PageBeanScreenScheme {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.ScreenScheme[];
    }
    /** A screen scheme. */
    interface ScreenScheme {
        /** The ID of the screen scheme. */
        id?: number;
        /** The name of the screen scheme. */
        name?: string;
        /** The description of the screen scheme. */
        description?: string;
        /** The IDs of the screens for the screen types of the screen scheme. */
        screens?: Schemas.ScreenTypes;
        /** Details of the issue type screen schemes associated with the screen scheme. */
        issueTypeScreenSchemes?: Schemas.PageBeanIssueTypeScreenScheme;
    }
    /** The IDs of the screens for the screen types of the screen scheme. */
    interface ScreenTypes {
        /** The ID of the edit screen. */
        edit?: number;
        /** The ID of the create screen. */
        create?: number;
        /** The ID of the view screen. */
        view?: number;
        /** The ID of the default screen. Required when creating a screen scheme. */
        default?: number;
    }
    /** Details of a screen scheme. */
    interface ScreenSchemeDetails {
        /** The name of the screen scheme. The name must be unique. The maximum length is 255 characters. */
        name: string;
        /** The description of the screen scheme. The maximum length is 255 characters. */
        description?: string;
        /** The IDs of the screens for the screen types of the screen scheme. Only screens used in classic projects are accepted. */
        screens: Schemas.ScreenTypes;
    }
    /** The ID of a screen scheme. */
    interface ScreenSchemeId {
        /** The ID of the screen scheme. */
        id: number;
    }
    /** Details of a screen scheme. */
    interface UpdateScreenSchemeDetails {
        /** The name of the screen scheme. The name must be unique. The maximum length is 255 characters. */
        name?: string;
        /** The description of the screen scheme. The maximum length is 255 characters. */
        description?: string;
        /** The IDs of the screens for the screen types of the screen scheme. Only screens used in classic projects are accepted. */
        screens?: Schemas.UpdateScreenTypes;
    }
    /** The IDs of the screens for the screen types of the screen scheme. */
    interface UpdateScreenTypes {
        /** The ID of the edit screen. To remove the screen association, pass a null. */
        edit?: string;
        /** The ID of the create screen. To remove the screen association, pass a null. */
        create?: string;
        /** The ID of the view screen. To remove the screen association, pass a null. */
        view?: string;
        /** The ID of the default screen. When specified, must include a screen ID as a default screen is required. */
        default?: string;
    }
    interface GlobalScopeBean {
        /** Defines the behavior of the option in the global context.If notSelectable is set, the option cannot be set as the field's value. This is useful for archiving an option that has previously been selected but shouldn't be used anymore.If defaultValue is set, the option is selected by default. */
        attributes?: ("notSelectable" | "defaultValue")[];
    }
    /** Details of the options for a select list issue field. */
    interface IssueFieldOption {
        /** The unique identifier for the option. This is only unique within the select field's set of options. */
        id: number;
        /** The option's name, which is displayed in Jira. */
        value: string;
        /** The properties of the object, as arbitrary key-value pairs. These properties can be searched using JQL, if the extractions (see [Issue Field Option Property Index](https://developer.atlassian.com/cloud/jira/platform/modules/issue-field-option-property-index/)) are defined in the descriptor for the issue field module. */
        properties?: {
            [key: string]: {};
        };
        config?: Schemas.IssueFieldOptionConfiguration;
    }
    /** Details of the projects the option is available in. */
    interface IssueFieldOptionConfiguration {
        /** Defines the projects that the option is available in. If the scope is not defined, then the option is available in all projects. */
        scope?: Schemas.IssueFieldOptionScopeBean;
        /** DEPRECATED */
        attributes?: ("notSelectable" | "defaultValue")[];
    }
    interface IssueFieldOptionScopeBean {
        /** DEPRECATED */
        projects?: number[];
        /** Defines the projects in which the option is available and the behavior of the option within each project. Specify one object per project. The behavior of the option in a project context overrides the behavior in the global context. */
        projects2?: Schemas.ProjectScopeBean[];
        /** Defines the behavior of the option within the global context. If this property is set, even if set to an empty object, then the option is available in all projects. */
        global?: Schemas.GlobalScopeBean;
    }
    /** A page of items. */
    interface PageBeanIssueFieldOption {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.IssueFieldOption[];
    }
    interface ProjectScopeBean {
        /** The ID of the project that the option's behavior applies to. */
        id?: number;
        /** Defines the behavior of the option in the project.If notSelectable is set, the option cannot be set as the field's value. This is useful for archiving an option that has previously been selected but shouldn't be used anymore.If defaultValue is set, the option is selected by default. */
        attributes?: ("notSelectable" | "defaultValue")[];
    }
    interface IssueFieldOptionCreateBean {
        [key: string]: {};
    }
    interface RemoveOptionFromIssuesResult {
        /** The IDs of the modified issues. */
        modifiedIssues?: number[];
        /** The IDs of the unchanged issues, those issues where errors prevent modification. */
        unmodifiedIssues?: number[];
        /** A collection of errors related to unchanged issues. The collection size is limited, which means not all errors may be returned. */
        errors?: Schemas.SimpleErrorCollection;
    }
    interface SimpleErrorCollection {
        /** The list of errors by parameter returned by the operation. For example,"projectKey": "Project keys must start with an uppercase letter, followed by one or more uppercase alphanumeric characters." */
        errors?: {
            [key: string]: string;
        };
        /** The list of error messages produced by this operation. For example, "input parameter 'key' must be provided" */
        errorMessages?: string[];
        httpStatusCode?: number;
    }
    /** Details about a task. */
    interface TaskProgressBeanRemoveOptionFromIssuesResult {
        /** The URL of the task. */
        self: string;
        /** The ID of the task. */
        id: string;
        /** The description of the task. */
        description?: string;
        /** The status of the task. */
        status: "ENQUEUED" | "RUNNING" | "COMPLETE" | "FAILED" | "CANCEL_REQUESTED" | "CANCELLED" | "DEAD";
        /** Information about the progress of the task. */
        message?: string;
        /** The result of the task execution. */
        result?: Schemas.RemoveOptionFromIssuesResult;
        /** The ID of the user who submitted the task. */
        submittedBy: number;
        /** The progress of the task, as a percentage complete. */
        progress: number;
        /** The execution time of the task, in milliseconds. */
        elapsedRuntime: number;
        /** A timestamp recording when the task was submitted. */
        submitted: number;
        /** A timestamp recording when the task was started. */
        started?: number;
        /** A timestamp recording when the task was finished. */
        finished?: number;
        /** A timestamp recording when the task progress was last updated. */
        lastUpdate: number;
    }
    /** Details of a field. */
    interface Field {
        /** The ID of the field. */
        id: string;
        /** The name of the field. */
        name: string;
        schema: Schemas.JsonTypeBean;
        /** The description of the field. */
        description?: string;
        /** The key of the field. */
        key?: string;
        /** Whether the field is locked. */
        isLocked?: boolean;
        /** Whether the field is shown on screen or not. */
        isUnscreenable?: boolean;
        /** The searcher key of the field. Returned for custom fields. */
        searcherKey?: string;
        /** Number of screens where the field is used. */
        screensCount?: number;
        /** Number of contexts where the field is used. */
        contextsCount?: number;
        lastUsed?: Schemas.FieldLastUsed;
    }
    /** Information about the most recent use of a field. */
    interface FieldLastUsed {
        /**
         * Last used value type:
         *
         *  *  *TRACKED*: field is tracked and a last used date is available.
         *  *  *NOT\_TRACKED*: field is not tracked, last used date is not available.
         *  *  *NO\_INFORMATION*: field is tracked, but no last used date is available.
         */
        type?: "TRACKED" | "NOT_TRACKED" | "NO_INFORMATION";
        /** The date when the value of the field last changed. */
        value?: string;
    }
    /** A page of items. */
    interface PageBeanField {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Field[];
    }
    /** Details of a field configuration scheme. */
    interface FieldConfigurationScheme {
        /** The ID of the field configuration scheme. */
        id: string;
        /** The name of the field configuration scheme. */
        name: string;
        /** The description of the field configuration scheme. */
        description?: string;
    }
    /** A page of items. */
    interface PageBeanFieldConfigurationScheme {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.FieldConfigurationScheme[];
    }
    /** The field configuration for an issue type. */
    interface FieldConfigurationIssueTypeItem {
        /** The ID of the field configuration scheme. */
        fieldConfigurationSchemeId: string;
        /** The ID of the issue type or *default*. When set to *default* this field configuration issue type item applies to all issue types without a field configuration. */
        issueTypeId: string;
        /** The ID of the field configuration. */
        fieldConfigurationId: string;
    }
    /** A page of items. */
    interface PageBeanFieldConfigurationIssueTypeItem {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.FieldConfigurationIssueTypeItem[];
    }
    /** Details of a field configuration to issue type mappings. */
    interface AssociateFieldConfigurationsWithIssueTypesRequest {
        /** Field configuration to issue type mappings. */
        mappings: Schemas.FieldConfigurationToIssueTypeMapping[];
    }
    /** The field configuration to issue type mapping. */
    interface FieldConfigurationToIssueTypeMapping {
        /** The ID of the issue type or *default*. When set to *default* this field configuration issue type item applies to all issue types without a field configuration. An issue type can be included only once in a request. */
        issueTypeId: string;
        /** The ID of the field configuration. */
        fieldConfigurationId: string;
    }
    /** Project list with assigned field configuration schema. */
    interface FieldConfigurationSchemeProjects {
        fieldConfigurationScheme?: Schemas.FieldConfigurationScheme;
        /** The IDs of projects using the field configuration scheme. */
        projectIds: string[];
    }
    /** A page of items. */
    interface PageBeanFieldConfigurationSchemeProjects {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.FieldConfigurationSchemeProjects[];
    }
    /** Associated field configuration scheme and project. */
    interface FieldConfigurationSchemeProjectAssociation {
        /** The ID of the field configuration scheme. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme. */
        fieldConfigurationSchemeId?: string;
        /** The ID of the project. */
        projectId: string;
    }
    /** The details of the field configuration scheme. */
    interface UpdateFieldConfigurationSchemeDetails {
        /** The name of the field configuration scheme. The name must be unique. */
        name: string;
        /** The description of the field configuration scheme. */
        description?: string;
    }
    /** The list of issue type IDs to be removed from the field configuration scheme. */
    interface IssueTypeIdsToRemove {
        /** The list of issue type IDs. Must contain unique values not longer than 255 characters and not be empty. Maximum of 100 IDs. */
        issueTypeIds: string[];
    }
    /** Details of a field configuration. */
    interface FieldConfigurationDetails {
        /** The name of the field configuration. Must be unique. */
        name: string;
        /** The description of the field configuration. */
        description?: string;
    }
    /** A page of items. */
    interface PageBeanFieldConfigurationDetails {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.FieldConfigurationDetails[];
    }
    /** A field within a field configuration. */
    interface FieldConfigurationItem {
        /** The ID of the field within the field configuration. */
        id: string;
        /** The description of the field within the field configuration. */
        description?: string;
        /** Whether the field is hidden in the field configuration. */
        isHidden?: boolean;
        /** Whether the field is required in the field configuration. */
        isRequired?: boolean;
        /** The renderer type for the field within the field configuration. */
        renderer?: string;
    }
    /** A page of items. */
    interface PageBeanFieldConfigurationItem {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.FieldConfigurationItem[];
    }
    /** Details of a field configuration. */
    interface FieldConfiguration {
        /** The ID of the field configuration. */
        id: number;
        /** The name of the field configuration. */
        name: string;
        /** The description of the field configuration. */
        description: string;
        /** Whether the field configuration is the default. */
        isDefault?: boolean;
    }
    /** Details of field configuration items. */
    interface FieldConfigurationItemsDetails {
        /** Details of fields in a field configuration. */
        fieldConfigurationItems: Schemas.FieldConfigurationItem[];
    }
    type CustomContextVariable = Schemas.UserContextVariable | Schemas.IssueContextVariable | Schemas.JsonContextVariable;
    interface IdOrKeyBean {
        /** The ID of the referenced item. */
        id?: number;
        /** The key of the referenced item. */
        key?: string;
    }
    /** An [issue](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#issue) specified by ID or key. All the fields of the issue object are available in the Jira expression. */
    interface IssueContextVariable {
        /** Type of custom context variable. */
        type: string;
        /** The issue ID. */
        id?: number;
        /** The issue key. */
        key?: string;
    }
    /** The JQL specifying the issues available in the evaluated Jira expression under the `issues` context variable. */
    interface JexpIssues {
        /** The JQL query that specifies the set of issues available in the Jira expression. */
        jql?: Schemas.JexpJqlIssues;
    }
    /** The JQL specifying the issues available in the evaluated Jira expression under the `issues` context variable. Not all issues returned by the JQL query are loaded, only those described by the `startAt` and `maxResults` properties. To determine whether it is necessary to iterate to ensure all the issues returned by the JQL query are evaluated, inspect `meta.issues.jql.count` in the response. */
    interface JexpJqlIssues {
        /** The JQL query. */
        query?: string;
        /** The index of the first issue to return from the JQL query. */
        startAt?: number;
        /** The maximum number of issues to return from the JQL query. Inspect `meta.issues.jql.maxResults` in the response to ensure the maximum value has not been exceeded. */
        maxResults?: number;
        /** Determines how to validate the JQL query and treat the validation results. */
        validation?: "strict" | "warn" | "none";
    }
    interface JiraExpressionEvalContextBean {
        /** The issue that is available under the `issue` variable when evaluating the expression. */
        issue?: Schemas.IdOrKeyBean;
        /** The collection of issues that is available under the `issues` variable when evaluating the expression. */
        issues?: Schemas.JexpIssues;
        /** The project that is available under the `project` variable when evaluating the expression. */
        project?: Schemas.IdOrKeyBean;
        /** The ID of the sprint that is available under the `sprint` variable when evaluating the expression. */
        sprint?: number;
        /** The ID of the board that is available under the `board` variable when evaluating the expression. */
        board?: number;
        /** The ID of the service desk that is available under the `serviceDesk` variable when evaluating the expression. */
        serviceDesk?: number;
        /** The ID of the customer request that is available under the `customerRequest` variable when evaluating the expression. This is the same as the ID of the underlying Jira issue, but the customer request context variable will have a different type. */
        customerRequest?: number;
        /**
         * Custom context variables and their types. These variable types are available for use in a custom context:
         *
         *  *  `user`: A [user](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#user) specified as an Atlassian account ID.
         *  *  `issue`: An [issue](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#issue) specified by ID or key. All the fields of the issue object are available in the Jira expression.
         *  *  `json`: A JSON object containing custom content.
         *  *  `list`: A JSON list of `user`, `issue`, or `json` variable types.
         */
        custom?: Schemas.CustomContextVariable[];
    }
    interface JiraExpressionEvalRequestBean {
        /** The Jira expression to evaluate. */
        expression: string;
        /** The context in which the Jira expression is evaluated. */
        context?: Schemas.JiraExpressionEvalContextBean;
    }
    /** A JSON object with custom content. */
    interface JsonContextVariable {
        /** Type of custom context variable. */
        type: string;
        /** A JSON object containing custom content. */
        value?: {};
    }
    /** A [user](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#user) specified as an Atlassian account ID. */
    interface UserContextVariable {
        /** Type of custom context variable. */
        type: string;
        /** The account ID of the user. */
        accountId: string;
    }
    /** The description of the page of issues loaded by the provided JQL query. */
    interface IssuesJqlMetaDataBean {
        /** The index of the first issue. */
        startAt: number;
        /** The maximum number of issues that could be loaded in this evaluation. */
        maxResults: number;
        /** The number of issues that were loaded in this evaluation. */
        count: number;
        /** The total number of issues the JQL returned. */
        totalCount: number;
        /** Any warnings related to the JQL query. Present only if the validation mode was set to `warn`. */
        validationWarnings?: string[];
    }
    /** Meta data describing the `issues` context variable. */
    interface IssuesMetaBean {
        jql?: Schemas.IssuesJqlMetaDataBean;
    }
    interface JiraExpressionEvaluationMetaDataBean {
        /** Contains information about the expression complexity. For example, the number of steps it took to evaluate the expression. */
        complexity?: Schemas.JiraExpressionsComplexityBean;
        /** Contains information about the `issues` variable in the context. For example, is the issues were loaded with JQL, information about the page will be included here. */
        issues?: Schemas.IssuesMetaBean;
    }
    /** The result of evaluating a Jira expression. */
    interface JiraExpressionResult {
        /** The value of the evaluated expression. It may be a primitive JSON value or a Jira REST API object. (Some expressions do not produce any meaningful results—for example, an expression that returns a lambda function—if that's the case a simple string representation is returned. These string representations should not be relied upon and may change without notice.) */
        value: any;
        /** Contains various characteristics of the performed expression evaluation. */
        meta?: Schemas.JiraExpressionEvaluationMetaDataBean;
    }
    interface JiraExpressionsComplexityBean {
        /** The number of steps it took to evaluate the expression, where a step is a high-level operation performed by the expression. A step is an operation such as arithmetic, accessing a property, accessing a context variable, or calling a function. */
        steps: Schemas.JiraExpressionsComplexityValueBean;
        /** The number of expensive operations executed while evaluating the expression. Expensive operations are those that load additional data, such as entity properties, comments, or custom fields. */
        expensiveOperations: Schemas.JiraExpressionsComplexityValueBean;
        /** The number of Jira REST API beans returned in the response. */
        beans: Schemas.JiraExpressionsComplexityValueBean;
        /** The number of primitive values returned in the response. */
        primitiveValues: Schemas.JiraExpressionsComplexityValueBean;
    }
    interface JiraExpressionsComplexityValueBean {
        /** The complexity value of the current expression. */
        value: number;
        /** The maximum allowed complexity. The evaluation will fail if this value is exceeded. */
        limit: number;
    }
    /** Details of Jira expressions for analysis. */
    interface JiraExpressionForAnalysis {
        /** The list of Jira expressions to analyse. */
        expressions: string[];
        /** Context variables and their types. The type checker assumes that [common context variables](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/#context-variables), such as `issue` or `project`, are available in context and sets their type. Use this property to override the default types or provide details of new variables. */
        contextVariables?: {
            [key: string]: string;
        };
    }
    /** Details about the analysed Jira expression. */
    interface JiraExpressionAnalysis {
        /** The analysed expression. */
        expression: string;
        /** A list of validation errors. Not included if the expression is valid. */
        errors?: Schemas.JiraExpressionValidationError[];
        /** Whether the expression is valid and the interpreter will evaluate it. Note that the expression may fail at runtime (for example, if it executes too many expensive operations). */
        valid: boolean;
        /** EXPERIMENTAL. The inferred type of the expression. */
        type?: string;
        complexity?: Schemas.JiraExpressionComplexity;
    }
    /** Details about the complexity of the analysed Jira expression. */
    interface JiraExpressionComplexity {
        /**
         * Information that can be used to determine how many [expensive operations](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/#expensive-operations) the evaluation of the expression will perform. This information may be a formula or number. For example:
         *
         *  *  `issues.map(i => i.comments)` performs as many expensive operations as there are issues on the issues list. So this parameter returns `N`, where `N` is the size of issue list.
         *  *  `new Issue(10010).comments` gets comments for one issue, so its complexity is `2` (`1` to retrieve issue 10010 from the database plus `1` to get its comments).
         */
        expensiveOperations: string;
        /** Variables used in the formula, mapped to the parts of the expression they refer to. */
        variables?: {
            [key: string]: string;
        };
    }
    /**
     * Details about syntax and type errors. The error details apply to the entire expression, unless the object includes:
     *
     *  *  `line` and `column`
     *  *  `expression`
     */
    interface JiraExpressionValidationError {
        /** The text line in which the error occurred. */
        line?: number;
        /** The text column in which the error occurred. */
        column?: number;
        /** The part of the expression in which the error occurred. */
        expression?: string;
        /** Details about the error. */
        message: string;
        /** The error type. */
        type: "syntax" | "type" | "other";
    }
    /** Details about the analysed Jira expression. */
    interface JiraExpressionsAnalysis {
        /** The results of Jira expressions analysis. */
        results: Schemas.JiraExpressionAnalysis[];
    }
    /** Details about a failed webhook. */
    interface FailedWebhook {
        /** The webhook ID, as sent in the `X-Atlassian-Webhook-Identifier` header with the webhook. */
        id: string;
        /** The webhook body. */
        body?: string;
        /** The original webhook destination. */
        url: string;
        /** The time the webhook was added to the list of failed webhooks (that is, the time of the last failed retry). */
        failureTime: number;
    }
    /** A page of failed webhooks. */
    interface FailedWebhooks {
        /** The list of webhooks. */
        values: Schemas.FailedWebhook[];
        /** The maximum number of items on the page. If the list of values is shorter than this number, then there are no more pages. */
        maxResults: number;
        /** The URL to the next page of results. Present only if the request returned at least one result.The next page may be empty at the time of receiving the response, but new failed webhooks may appear in time. You can save the URL to the next page and query for new results periodically (for example, every hour). */
        next?: string;
    }
    /** A list of webhooks. */
    interface WebhookDetails {
        /**
         * The JQL filter that specifies which issues the webhook is sent for. Only a subset of JQL can be used. The supported elements are:
         *
         *  *  Fields: `issueKey`, `project`, `issuetype`, `status`, `assignee`, `reporter`, `issue.property`, and `cf[id]`. For custom fields (`cf[id]`), only the epic label custom field is supported.".
         *  *  Operators: `=`, `!=`, `IN`, and `NOT IN`.
         */
        jqlFilter: string;
        /** A list of field IDs. When the issue changelog contains any of the fields, the webhook `jira:issue_updated` is sent. If this parameter is not present, the app is notified about all field updates. */
        fieldIdsFilter?: string[];
        /** A list of issue property keys. A change of those issue properties triggers the `issue_property_set` or `issue_property_deleted` webhooks. If this parameter is not present, the app is notified about all issue property updates. */
        issuePropertyKeysFilter?: string[];
        /** The Jira events that trigger the webhook. */
        events: ("jira:issue_created" | "jira:issue_updated" | "jira:issue_deleted" | "comment_created" | "comment_updated" | "comment_deleted" | "issue_property_set" | "issue_property_deleted")[];
    }
    /** Details of webhooks to register. */
    interface WebhookRegistrationDetails {
        /** A list of webhooks. */
        webhooks: Schemas.WebhookDetails[];
        /** The URL that specifies where to send the webhooks. This URL must use the same base URL as the Connect app. */
        url: string;
    }
    /** Container for a list of registered webhooks. Webhook details are returned in the same order as the request. */
    interface ContainerForRegisteredWebhooks {
        /** A list of registered webhooks. */
        webhookRegistrationResult?: Schemas.RegisteredWebhook[];
    }
    /** ID of a registered webhook or error messages explaining why a webhook wasn't registered. */
    interface RegisteredWebhook {
        /** The ID of the webhook. Returned if the webhook is created. */
        createdWebhookId?: number;
        /** Error messages specifying why the webhook creation failed. */
        errors?: string[];
    }
    /** A page of items. */
    interface PageBeanWebhook {
        /** The URL of the page. */
        self?: string;
        /** If there is another page of results, the URL of the next page. */
        nextPage?: string;
        /** The maximum number of items that could be returned. */
        maxResults?: number;
        /** The index of the first item returned. */
        startAt?: number;
        /** The number of items returned. */
        total?: number;
        /** Whether this is the last page. */
        isLast?: boolean;
        /** The list of items. */
        values?: Schemas.Webhook[];
    }
    /** A webhook. */
    interface Webhook {
        /** The ID of the webhook. */
        id: number;
        /** The JQL filter that specifies which issues the webhook is sent for. */
        jqlFilter: string;
        /** A list of field IDs. When the issue changelog contains any of the fields, the webhook `jira:issue_updated` is sent. If this parameter is not present, the app is notified about all field updates. */
        fieldIdsFilter?: string[];
        /** A list of issue property keys. A change of those issue properties triggers the `issue_property_set` or `issue_property_deleted` webhooks. If this parameter is not present, the app is notified about all issue property updates. */
        issuePropertyKeysFilter?: string[];
        /** The Jira events that trigger the webhook. */
        events: ("jira:issue_created" | "jira:issue_updated" | "jira:issue_deleted" | "comment_created" | "comment_updated" | "comment_deleted" | "issue_property_set" | "issue_property_deleted")[];
        /** The date after which the webhook will stop being sent. Use the "Extend webhook life" resource to extend it. */
        expirationDate?: number;
    }
    /** Container for a list of webhook IDs. */
    interface ContainerForWebhookIDs {
        /** A list of webhook IDs. */
        webhookIds: number[];
    }
    /** The date the newly refreshed webhooks expire. */
    interface WebhooksExpirationDate {
        /** The new expiration date of all refreshed webhooks: 30 days from now. */
        expirationDate: number;
    }
    interface OperationMessage {
        /** The human-readable message that describes the result. */
        message: string;
        /** The status code of the response. */
        statusCode: number;
    }
    interface ErrorMessage {
        /** The error message. */
        message: string;
    }
    interface ConnectModules {
        /**
         * A list of app modules in the same format as the `modules` property in the
         * [app descriptor](https://developer.atlassian.com/cloud/jira/platform/app-descriptor/).
         */
        modules: Schemas.ConnectModule[];
    }
    /**
     * A [Connect module](https://developer.atlassian.com/cloud/jira/platform/about-jira-modules/) in the same format as in the
     * [app descriptor](https://developer.atlassian.com/cloud/jira/platform/app-descriptor/).
     */
    interface ConnectModule {
    }
    /** Details of the workflow and its transition rules. */
    interface WorkflowRulesSearch {
        /** The workflow ID. */
        workflowEntityId: string;
        /** The list of workflow rule IDs. */
        ruleIds: string[];
        /** Use expand to include additional information in the response. This parameter accepts `transition` which, for each rule, returns information about the transition the rule is assigned to. */
        expand?: string;
    }
    /** Details of workflow transition rules. */
    interface WorkflowRulesSearchDetails {
        /** The workflow ID. */
        workflowEntityId?: string;
        /** List of workflow rule IDs that do not belong to the workflow or can not be found. */
        invalidRules?: string[];
        /** List of valid workflow transition rules. */
        validRules?: Schemas.WorkflowTransitionRules[];
    }
    interface EntityPropertyDetails {
        /** The entity property ID. */
        entityId: number;
        /** The entity property key. */
        key: string;
        /** The new value of the entity property. */
        value: string;
    }
    /** A list of custom field details. */
    interface ConnectCustomFieldValue {
        /** The type of custom field. */
        "_type": "StringIssueField" | "NumberIssueField" | "RichTextIssueField" | "SingleSelectIssueField" | "MultiSelectIssueField" | "TextIssueField";
        /** The issue ID. */
        issueID: number;
        /** The custom field ID. */
        fieldID: number;
        /** The value of string type custom field when `_type` is `StringIssueField`. */
        string?: string;
        /** The value of number type custom field when `_type` is `NumberIssueField`. */
        number?: number;
        /** The value of richText type custom field when `_type` is `RichTextIssueField`. */
        richText?: string;
        /** The value of single select and multiselect custom field type when `_type` is `SingleSelectIssueField` or `MultiSelectIssueField`. */
        optionID?: string;
        /** The value of of text custom field type when `_type` is `TextIssueField`. */
        text?: string;
    }
    /** Details of updates for a custom field. */
    interface ConnectCustomFieldValues {
        /** The list of custom field update details. */
        updateValueList?: Schemas.ConnectCustomFieldValue[];
    }
}
export interface Parameter$updateMultipleCustomFieldValues {
    /** Whether to generate a changelog for this update. */
    generateChangelog?: boolean;
}
export interface RequestBody$updateMultipleCustomFieldValues {
    "application/json": Schemas.MultipleCustomFieldValuesUpdateDetails;
}
export interface Response$updateMultipleCustomFieldValues$Status$204 {
    "application/json": {};
}
export interface Parameter$getCustomFieldConfiguration {
    /** The ID or key of the custom field, for example `customfield_10000`. */
    fieldIdOrKey: string;
    /** The list of configuration IDs. To include multiple configurations, separate IDs with an ampersand: `id=10000&id=10001`. Can't be provided with `fieldContextId`, `issueId`, `projectKeyOrId`, or `issueTypeId`. */
    id?: number[];
    /** DEPRECATED. Do not use. */
    contextId?: number[];
    /** The list of field context IDs. To include multiple field contexts, separate IDs with an ampersand: `fieldContextId=10000&fieldContextId=10001`. Can't be provided with `id`, `issueId`, `projectKeyOrId`, or `issueTypeId`. */
    fieldContextId?: number[];
    /** The ID of the issue to filter results by. If the issue doesn't exist, an empty list is returned. Can't be provided with `contextIds`, `projectKeyOrId`, or `issueTypeId`. */
    issueId?: number;
    /** The ID or key of the project to filter results by. Must be provided with `issueTypeId`. Can't be provided with `contextIds` or `issueId`. */
    projectKeyOrId?: string;
    /** The ID of the issue type to filter results by. Must be provided with `projectKeyOrId`. Can't be provided with `contextIds` or `issueId`. */
    issueTypeId?: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getCustomFieldConfiguration$Status$200 {
    "application/json": Schemas.PageBeanContextualConfiguration;
}
export interface Parameter$updateCustomFieldConfiguration {
    /** The ID or key of the custom field, for example `customfield_10000`. */
    fieldIdOrKey: string;
}
export interface RequestBody$updateCustomFieldConfiguration {
    "application/json": Schemas.CustomFieldConfigurations;
}
export interface Response$updateCustomFieldConfiguration$Status$200 {
    "application/json": {};
}
export interface Parameter$updateCustomFieldValue {
    /** The ID or key of the custom field. For example, `customfield_10010`. */
    fieldIdOrKey: string;
    /** Whether to generate a changelog for this update. */
    generateChangelog?: boolean;
}
export interface RequestBody$updateCustomFieldValue {
    "application/json": Schemas.CustomFieldValueUpdateDetails;
}
export interface Response$updateCustomFieldValue$Status$204 {
    "application/json": {};
}
export interface Parameter$getApplicationProperty {
    /** The key of the application property. */
    key?: string;
    /** The permission level of all items being returned in the list. */
    permissionLevel?: string;
    /** When a `key` isn't provided, this filters the list of results by the application property `key` using a regular expression. For example, using `jira.lf.*` will return all application properties with keys that start with *jira.lf.*. */
    keyFilter?: string;
}
export interface Response$getApplicationProperty$Status$200 {
    "application/json": Schemas.ApplicationProperty[];
}
export interface Response$getAdvancedSettings$Status$200 {
    "application/json": Schemas.ApplicationProperty[];
}
export interface Parameter$setApplicationProperty {
    /** The key of the application property to update. */
    id: string;
}
export interface RequestBody$setApplicationProperty {
    "application/json": Schemas.SimpleApplicationPropertyBean;
}
export interface Response$setApplicationProperty$Status$200 {
    "application/json": Schemas.ApplicationProperty;
}
export interface Response$getAllApplicationRoles$Status$200 {
    "application/json": Schemas.ApplicationRole[];
}
export interface Parameter$getApplicationRole {
    /** The key of the application role. Use the [Get all application roles](#api-rest-api-3-applicationrole-get) operation to get the key for each application role. */
    key: string;
}
export interface Response$getApplicationRole$Status$200 {
    "application/json": Schemas.ApplicationRole;
}
export interface Parameter$getAttachmentContent {
    /** The ID of the attachment. */
    id: string;
    /** Whether a redirect is provided for the attachment download. Clients that do not automatically follow redirects can set this to `false` to avoid making multiple requests to download the attachment. */
    redirect?: boolean;
}
export interface Response$getAttachmentContent$Status$200 {
    "application/json": {};
}
export interface Response$getAttachmentMeta$Status$200 {
    "application/json": Schemas.AttachmentSettings;
}
export interface Parameter$getAttachmentThumbnail {
    /** The ID of the attachment. */
    id: string;
    /** Whether a redirect is provided for the attachment download. Clients that do not automatically follow redirects can set this to `false` to avoid making multiple requests to download the attachment. */
    redirect?: boolean;
    /** Whether a default thumbnail is returned when the requested thumbnail is not found. */
    fallbackToDefault?: boolean;
    /** The maximum width to scale the thumbnail to. */
    width?: number;
    /** The maximum height to scale the thumbnail to. */
    height?: number;
}
export interface Response$getAttachmentThumbnail$Status$200 {
    "application/json": {};
}
export interface Parameter$getAttachment {
    /** The ID of the attachment. */
    id: string;
}
export interface Response$getAttachment$Status$200 {
    "application/json": Schemas.AttachmentMetadata;
}
export interface Parameter$removeAttachment {
    /** The ID of the attachment. */
    id: string;
}
export interface Parameter$expandAttachmentForHumans {
    /** The ID of the attachment. */
    id: string;
}
export interface Response$expandAttachmentForHumans$Status$200 {
    "application/json": Schemas.AttachmentArchiveMetadataReadable;
}
export interface Parameter$expandAttachmentForMachines {
    /** The ID of the attachment. */
    id: string;
}
export interface Response$expandAttachmentForMachines$Status$200 {
    "application/json": Schemas.AttachmentArchiveImpl;
}
export interface Parameter$getAuditRecords {
    /** The number of records to skip before returning the first result. */
    offset?: number;
    /** The maximum number of results to return. */
    limit?: number;
    /** The strings to match with audit field content, space separated. */
    filter?: string;
    /** The date and time on or after which returned audit records must have been created. If `to` is provided `from` must be before `to` or no audit records are returned. */
    from?: string;
    /** The date and time on or before which returned audit results must have been created. If `from` is provided `to` must be after `from` or no audit records are returned. */
    to?: string;
}
export interface Response$getAuditRecords$Status$200 {
    "application/json": Schemas.AuditRecords;
}
export interface Parameter$getAllSystemAvatars {
    /** The avatar type. */
    type: "issuetype" | "project" | "user";
}
export interface Response$getAllSystemAvatars$Status$200 {
    "application/json": Schemas.SystemAvatars;
}
export interface Parameter$getCommentsByIds {
    /**
     * Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `renderedBody` Returns the comment body rendered in HTML.
     *  *  `properties` Returns the comment's properties.
     */
    expand?: string;
}
export interface RequestBody$getCommentsByIds {
    "application/json": Schemas.IssueCommentListRequestBean;
}
export interface Response$getCommentsByIds$Status$200 {
    "application/json": Schemas.PageBeanComment;
}
export interface Parameter$getCommentPropertyKeys {
    /** The ID of the comment. */
    commentId: string;
}
export interface Response$getCommentPropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getCommentProperty {
    /** The ID of the comment. */
    commentId: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface Response$getCommentProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setCommentProperty {
    /** The ID of the comment. */
    commentId: string;
    /** The key of the property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setCommentProperty {
    "application/json": {};
}
export interface Response$setCommentProperty$Status$200 {
    "application/json": {};
}
export interface Response$setCommentProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteCommentProperty {
    /** The ID of the comment. */
    commentId: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface RequestBody$createComponent {
    "application/json": Schemas.ProjectComponent;
}
export interface Response$createComponent$Status$201 {
    "application/json": Schemas.ProjectComponent;
}
export interface Parameter$getComponent {
    /** The ID of the component. */
    id: string;
}
export interface Response$getComponent$Status$200 {
    "application/json": Schemas.ProjectComponent;
}
export interface Parameter$updateComponent {
    /** The ID of the component. */
    id: string;
}
export interface RequestBody$updateComponent {
    "application/json": Schemas.ProjectComponent;
}
export interface Response$updateComponent$Status$200 {
    "application/json": Schemas.ProjectComponent;
}
export interface Parameter$deleteComponent {
    /** The ID of the component. */
    id: string;
    /** The ID of the component to replace the deleted component. If this value is null no replacement is made. */
    moveIssuesTo?: string;
}
export interface Parameter$getComponentRelatedIssues {
    /** The ID of the component. */
    id: string;
}
export interface Response$getComponentRelatedIssues$Status$200 {
    "application/json": Schemas.ComponentIssuesCount;
}
export interface Response$getConfiguration$Status$200 {
    "application/json": Schemas.Configuration;
}
export interface Response$getSelectedTimeTrackingImplementation$Status$200 {
    "application/json": Schemas.TimeTrackingProvider;
}
export interface Response$getSelectedTimeTrackingImplementation$Status$204 {
    "application/json": {};
}
export interface RequestBody$selectTimeTrackingImplementation {
    "application/json": Schemas.TimeTrackingProvider;
}
export interface Response$selectTimeTrackingImplementation$Status$204 {
    "application/json": {};
}
export interface Response$getAvailableTimeTrackingImplementations$Status$200 {
    "application/json": Schemas.TimeTrackingProvider[];
}
export interface Response$getSharedTimeTrackingConfiguration$Status$200 {
    "application/json": Schemas.TimeTrackingConfiguration;
}
export interface RequestBody$setSharedTimeTrackingConfiguration {
    "application/json": Schemas.TimeTrackingConfiguration;
}
export interface Response$setSharedTimeTrackingConfiguration$Status$200 {
    "application/json": Schemas.TimeTrackingConfiguration;
}
export interface Parameter$getCustomFieldOption {
    /** The ID of the custom field option. */
    id: string;
}
export interface Response$getCustomFieldOption$Status$200 {
    "application/json": Schemas.CustomFieldOption;
}
export interface Parameter$getAllDashboards {
    /**
     * The filter applied to the list of dashboards. Valid values are:
     *
     *  *  `favourite` Returns dashboards the user has marked as favorite.
     *  *  `my` Returns dashboards owned by the user.
     */
    filter?: "my" | "favourite";
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getAllDashboards$Status$200 {
    "application/json": Schemas.PageOfDashboards;
}
export interface Response$getAllDashboards$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAllDashboards$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$createDashboard {
    "application/json": Schemas.DashboardDetails;
}
export interface Response$createDashboard$Status$200 {
    "application/json": Schemas.Dashboard;
}
export interface Response$createDashboard$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$createDashboard$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getDashboardsPaginated {
    /** String used to perform a case-insensitive partial match with `name`. */
    dashboardName?: string;
    /** User account ID used to return dashboards with the matching `owner.accountId`. This parameter cannot be used with the `owner` parameter. */
    accountId?: string;
    /** This parameter is deprecated because of privacy changes. Use `accountId` instead. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. User name used to return dashboards with the matching `owner.name`. This parameter cannot be used with the `accountId` parameter. */
    owner?: string;
    /** Group name used to returns dashboards that are shared with a group that matches `sharePermissions.group.name`. */
    groupname?: string;
    /** Project ID used to returns dashboards that are shared with a project that matches `sharePermissions.project.id`. */
    projectId?: number;
    /**
     * [Order](#ordering) the results by a field:
     *
     *  *  `description` Sorts by dashboard description. Note that this sort works independently of whether the expand to display the description field is in use.
     *  *  `favourite_count` Sorts by dashboard popularity.
     *  *  `id` Sorts by dashboard ID.
     *  *  `is_favourite` Sorts by whether the dashboard is marked as a favorite.
     *  *  `name` Sorts by dashboard name.
     *  *  `owner` Sorts by dashboard owner name.
     */
    orderBy?: "description" | "-description" | "+description" | "favorite_count" | "-favorite_count" | "+favorite_count" | "id" | "-id" | "+id" | "is_favorite" | "-is_favorite" | "+is_favorite" | "name" | "-name" | "+name" | "owner" | "-owner" | "+owner";
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * Use [expand](#expansion) to include additional information about dashboard in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `description` Returns the description of the dashboard.
     *  *  `owner` Returns the owner of the dashboard.
     *  *  `viewUrl` Returns the URL that is used to view the dashboard.
     *  *  `favourite` Returns `isFavourite`, an indicator of whether the user has set the dashboard as a favorite.
     *  *  `favouritedCount` Returns `popularity`, a count of how many users have set this dashboard as a favorite.
     *  *  `sharePermissions` Returns details of the share permissions defined for the dashboard.
     *  *  `editPermissions` Returns details of the edit permissions defined for the dashboard.
     *  *  `isWritable` Returns whether the current user has permission to edit the dashboard.
     */
    expand?: string;
}
export interface Response$getDashboardsPaginated$Status$200 {
    "application/json": Schemas.PageBeanDashboard;
}
export interface Response$getDashboardsPaginated$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getDashboardsPaginated$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getDashboardItemPropertyKeys {
    /** The ID of the dashboard. */
    dashboardId: string;
    /** The ID of the dashboard item. */
    itemId: string;
}
export interface Response$getDashboardItemPropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getDashboardItemProperty {
    /** The ID of the dashboard. */
    dashboardId: string;
    /** The ID of the dashboard item. */
    itemId: string;
    /** The key of the dashboard item property. */
    propertyKey: string;
}
export interface Response$getDashboardItemProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setDashboardItemProperty {
    /** The ID of the dashboard. */
    dashboardId: string;
    /** The ID of the dashboard item. */
    itemId: string;
    /** The key of the dashboard item property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setDashboardItemProperty {
    "application/json": {};
}
export interface Response$setDashboardItemProperty$Status$200 {
    "application/json": {};
}
export interface Response$setDashboardItemProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteDashboardItemProperty {
    /** The ID of the dashboard. */
    dashboardId: string;
    /** The ID of the dashboard item. */
    itemId: string;
    /** The key of the dashboard item property. */
    propertyKey: string;
}
export interface Parameter$getDashboard {
    /** The ID of the dashboard. */
    id: string;
}
export interface Response$getDashboard$Status$200 {
    "application/json": Schemas.Dashboard;
}
export interface Response$getDashboard$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getDashboard$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$updateDashboard {
    /** The ID of the dashboard to update. */
    id: string;
}
export interface RequestBody$updateDashboard {
    "application/json": Schemas.DashboardDetails;
}
export interface Response$updateDashboard$Status$200 {
    "application/json": Schemas.Dashboard;
}
export interface Response$updateDashboard$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$updateDashboard$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$updateDashboard$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$deleteDashboard {
    /** The ID of the dashboard. */
    id: string;
}
export interface Response$deleteDashboard$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteDashboard$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$copyDashboard {
    id: string;
}
export interface RequestBody$copyDashboard {
    "application/json": Schemas.DashboardDetails;
}
export interface Response$copyDashboard$Status$200 {
    "application/json": Schemas.Dashboard;
}
export interface Response$copyDashboard$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$copyDashboard$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$copyDashboard$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getEvents$Status$200 {
    "application/json": Schemas.IssueEvent[];
}
export interface Parameter$analyseExpression {
    /**
     * The check to perform:
     *
     *  *  `syntax` Each expression's syntax is checked to ensure the expression can be parsed. Also, syntactic limits are validated. For example, the expression's length.
     *  *  `type` EXPERIMENTAL. Each expression is type checked and the final type of the expression inferred. Any type errors that would result in the expression failure at runtime are reported. For example, accessing properties that don't exist or passing the wrong number of arguments to functions. Also performs the syntax check.
     *  *  `complexity` EXPERIMENTAL. Determines the formulae for how many [expensive operations](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/#expensive-operations) each expression may execute.
     */
    check?: "syntax" | "type" | "complexity";
}
export interface RequestBody$analyseExpression {
    "application/json": Schemas.JiraExpressionForAnalysis;
}
export interface Response$analyseExpression$Status$200 {
    "application/json": Schemas.JiraExpressionsAnalysis;
}
export interface Response$analyseExpression$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$analyseExpression$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$evaluateJiraExpression {
    /** Use [expand](#expansion) to include additional information in the response. This parameter accepts `meta.complexity` that returns information about the expression complexity. For example, the number of expensive operations used by the expression and how close the expression is to reaching the [complexity limit](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/#restrictions). Useful when designing and debugging your expressions. */
    expand?: string;
}
export interface RequestBody$evaluateJiraExpression {
    "application/json": Schemas.JiraExpressionEvalRequestBean;
}
export interface Response$evaluateJiraExpression$Status$200 {
    "application/json": Schemas.JiraExpressionResult;
}
export interface Response$evaluateJiraExpression$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$evaluateJiraExpression$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getFields$Status$200 {
    "application/json": Schemas.FieldDetails[];
}
export interface RequestBody$createCustomField {
    "application/json": Schemas.CustomFieldDefinitionJsonBean;
}
export interface Response$createCustomField$Status$201 {
    "application/json": Schemas.FieldDetails;
}
export interface Parameter$getFieldsPaginated {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The type of fields to search. */
    type?: ("custom" | "system")[];
    /** The IDs of the custom fields to return or, where `query` is specified, filter. */
    id?: string[];
    /** String used to perform a case-insensitive partial match with field names or descriptions. */
    query?: string;
    /**
     * [Order](#ordering) the results by a field:
     *
     *  *  `contextsCount` Sorts by the number of contexts related to a field.
     *  *  `lastUsed` Sorts by the date when the value of the field last changed.
     *  *  `name` Sorts by the field name.
     *  *  `screensCount` Sorts by the number of screens related to a field.
     */
    orderBy?: "contextsCount" | "-contextsCount" | "+contextsCount" | "lastUsed" | "-lastUsed" | "+lastUsed" | "name" | "-name" | "+name" | "screensCount" | "-screensCount" | "+screensCount";
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `key` Returns the key for each field.
     *  *  `lastUsed` Returns the date when the value of the field last changed.
     *  *  `screensCount` Returns the number of screens related to a field.
     *  *  `contextsCount` Returns the number of contexts related to a field.
     *  *  `isLocked` Returns information about whether the field is [locked](https://confluence.atlassian.com/x/ZSN7Og).
     *  *  `searcherKey` Returns the searcher key for each custom field.
     */
    expand?: string;
}
export interface Response$getFieldsPaginated$Status$200 {
    "application/json": Schemas.PageBeanField;
}
export interface Response$getFieldsPaginated$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getFieldsPaginated$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$updateCustomField {
    /** The ID of the custom field. */
    fieldId: string;
}
export interface RequestBody$updateCustomField {
    "application/json": Schemas.UpdateCustomFieldDetails;
}
export interface Response$updateCustomField$Status$204 {
    "application/json": {};
}
export interface Response$updateCustomField$Status$400 {
}
export interface Response$updateCustomField$Status$403 {
}
export interface Response$updateCustomField$Status$404 {
}
export interface Parameter$getContextsForField {
    /** The ID of the custom field. */
    fieldId: string;
    /** Whether to return contexts that apply to all issue types. */
    isAnyIssueType?: boolean;
    /** Whether to return contexts that apply to all projects. */
    isGlobalContext?: boolean;
    /** The list of context IDs. To include multiple contexts, separate IDs with ampersand: `contextId=10000&contextId=10001`. */
    contextId?: number[];
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getContextsForField$Status$200 {
    "application/json": Schemas.PageBeanCustomFieldContext;
}
export interface Response$getContextsForField$Status$403 {
}
export interface Response$getContextsForField$Status$404 {
}
export interface Parameter$createCustomFieldContext {
    /** The ID of the custom field. */
    fieldId: string;
}
export interface RequestBody$createCustomFieldContext {
    "application/json": Schemas.CreateCustomFieldContext;
}
export interface Response$createCustomFieldContext$Status$201 {
    "application/json": Schemas.CreateCustomFieldContext;
}
export interface Response$createCustomFieldContext$Status$409 {
}
export interface Parameter$getDefaultValues {
    /** The ID of the custom field, for example `customfield\_10000`. */
    fieldId: string;
    /** The IDs of the contexts. */
    contextId?: number[];
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getDefaultValues$Status$200 {
    "application/json": Schemas.PageBeanCustomFieldContextDefaultValue;
}
export interface Response$getDefaultValues$Status$403 {
}
export interface Response$getDefaultValues$Status$404 {
}
export interface Parameter$setDefaultValues {
    /** The ID of the custom field. */
    fieldId: string;
}
export interface RequestBody$setDefaultValues {
    "application/json": Schemas.CustomFieldContextDefaultValueUpdate;
}
export interface Response$setDefaultValues$Status$204 {
    "application/json": {};
}
export interface Response$setDefaultValues$Status$400 {
}
export interface Response$setDefaultValues$Status$403 {
}
export interface Response$setDefaultValues$Status$404 {
}
export interface Parameter$getIssueTypeMappingsForContexts {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. To include multiple contexts, provide an ampersand-separated list. For example, `contextId=10001&contextId=10002`. */
    contextId?: number[];
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getIssueTypeMappingsForContexts$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeToContextMapping;
}
export interface Response$getIssueTypeMappingsForContexts$Status$403 {
}
export interface Parameter$getCustomFieldContextsForProjectsAndIssueTypes {
    /** The ID of the custom field. */
    fieldId: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface RequestBody$getCustomFieldContextsForProjectsAndIssueTypes {
    "application/json": Schemas.ProjectIssueTypeMappings;
}
export interface Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$200 {
    "application/json": Schemas.PageBeanContextForProjectAndIssueType;
}
export interface Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$400 {
}
export interface Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$403 {
}
export interface Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$404 {
}
export interface Parameter$getProjectContextMapping {
    /** The ID of the custom field, for example `customfield\_10000`. */
    fieldId: string;
    /** The list of context IDs. To include multiple context, separate IDs with ampersand: `contextId=10000&contextId=10001`. */
    contextId?: number[];
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getProjectContextMapping$Status$200 {
    "application/json": Schemas.PageBeanCustomFieldContextProjectMapping;
}
export interface Response$getProjectContextMapping$Status$403 {
}
export interface Response$getProjectContextMapping$Status$404 {
}
export interface Parameter$updateCustomFieldContext {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$updateCustomFieldContext {
    "application/json": Schemas.CustomFieldContextUpdateDetails;
}
export interface Response$updateCustomFieldContext$Status$204 {
    "application/json": {};
}
export interface Response$updateCustomFieldContext$Status$400 {
}
export interface Response$updateCustomFieldContext$Status$403 {
}
export interface Response$updateCustomFieldContext$Status$404 {
}
export interface Parameter$deleteCustomFieldContext {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface Response$deleteCustomFieldContext$Status$204 {
    "application/json": {};
}
export interface Response$deleteCustomFieldContext$Status$400 {
}
export interface Response$deleteCustomFieldContext$Status$403 {
}
export interface Response$deleteCustomFieldContext$Status$404 {
}
export interface Parameter$addIssueTypesToContext {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$addIssueTypesToContext {
    "application/json": Schemas.IssueTypeIds;
}
export interface Response$addIssueTypesToContext$Status$204 {
    "application/json": {};
}
export interface Response$addIssueTypesToContext$Status$400 {
}
export interface Response$addIssueTypesToContext$Status$403 {
}
export interface Response$addIssueTypesToContext$Status$404 {
}
export interface Response$addIssueTypesToContext$Status$409 {
}
export interface Parameter$removeIssueTypesFromContext {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$removeIssueTypesFromContext {
    "application/json": Schemas.IssueTypeIds;
}
export interface Response$removeIssueTypesFromContext$Status$204 {
    "application/json": {};
}
export interface Response$removeIssueTypesFromContext$Status$400 {
}
export interface Response$removeIssueTypesFromContext$Status$403 {
}
export interface Response$removeIssueTypesFromContext$Status$404 {
}
export interface Parameter$getOptionsForContext {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
    /** The ID of the option. */
    optionId?: number;
    /** Whether only options are returned. */
    onlyOptions?: boolean;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getOptionsForContext$Status$200 {
    "application/json": Schemas.PageBeanCustomFieldContextOption;
}
export interface Response$getOptionsForContext$Status$400 {
}
export interface Response$getOptionsForContext$Status$403 {
}
export interface Response$getOptionsForContext$Status$404 {
}
export interface Parameter$updateCustomFieldOption {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$updateCustomFieldOption {
    "application/json": Schemas.BulkCustomFieldOptionUpdateRequest;
}
export interface Response$updateCustomFieldOption$Status$200 {
    "application/json": Schemas.CustomFieldUpdatedContextOptionsList;
}
export interface Response$updateCustomFieldOption$Status$400 {
}
export interface Response$updateCustomFieldOption$Status$403 {
}
export interface Response$updateCustomFieldOption$Status$404 {
}
export interface Parameter$createCustomFieldOption {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$createCustomFieldOption {
    "application/json": Schemas.BulkCustomFieldOptionCreateRequest;
}
export interface Response$createCustomFieldOption$Status$200 {
    "application/json": Schemas.CustomFieldCreatedContextOptionsList;
}
export interface Response$createCustomFieldOption$Status$400 {
}
export interface Response$createCustomFieldOption$Status$403 {
}
export interface Response$createCustomFieldOption$Status$404 {
}
export interface Parameter$reorderCustomFieldOptions {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$reorderCustomFieldOptions {
    "application/json": Schemas.OrderOfCustomFieldOptions;
}
export interface Response$reorderCustomFieldOptions$Status$204 {
    "application/json": {};
}
export interface Response$reorderCustomFieldOptions$Status$400 {
}
export interface Response$reorderCustomFieldOptions$Status$403 {
}
export interface Response$reorderCustomFieldOptions$Status$404 {
}
export interface Parameter$deleteCustomFieldOption {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context from which an option should be deleted. */
    contextId: number;
    /** The ID of the option to delete. */
    optionId: number;
}
export interface Response$deleteCustomFieldOption$Status$400 {
}
export interface Response$deleteCustomFieldOption$Status$403 {
}
export interface Response$deleteCustomFieldOption$Status$404 {
}
export interface Parameter$assignProjectsToCustomFieldContext {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$assignProjectsToCustomFieldContext {
    "application/json": Schemas.ProjectIds;
}
export interface Response$assignProjectsToCustomFieldContext$Status$204 {
    "application/json": {};
}
export interface Response$assignProjectsToCustomFieldContext$Status$400 {
}
export interface Response$assignProjectsToCustomFieldContext$Status$403 {
}
export interface Response$assignProjectsToCustomFieldContext$Status$404 {
}
export interface Parameter$removeCustomFieldContextFromProjects {
    /** The ID of the custom field. */
    fieldId: string;
    /** The ID of the context. */
    contextId: number;
}
export interface RequestBody$removeCustomFieldContextFromProjects {
    "application/json": Schemas.ProjectIds;
}
export interface Response$removeCustomFieldContextFromProjects$Status$204 {
    "application/json": {};
}
export interface Response$removeCustomFieldContextFromProjects$Status$400 {
}
export interface Response$removeCustomFieldContextFromProjects$Status$403 {
}
export interface Response$removeCustomFieldContextFromProjects$Status$404 {
}
export interface Parameter$getContextsForFieldDeprecated {
    /** The ID of the field to return contexts for. */
    fieldId: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getContextsForFieldDeprecated$Status$200 {
    "application/json": Schemas.PageBeanContext;
}
export interface Parameter$getScreensForField {
    /** The ID of the field to return screens for. */
    fieldId: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** Use [expand](#expansion) to include additional information about screens in the response. This parameter accepts `tab` which returns details about the screen tabs the field is used in. */
    expand?: string;
}
export interface Response$getScreensForField$Status$200 {
    "application/json": Schemas.PageBeanScreenWithTab;
}
export interface Parameter$getAllIssueFieldOptions {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
}
export interface Response$getAllIssueFieldOptions$Status$200 {
    "application/json": Schemas.PageBeanIssueFieldOption;
}
export interface Parameter$createIssueFieldOption {
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
}
export interface RequestBody$createIssueFieldOption {
    "application/json": Schemas.IssueFieldOptionCreateBean;
}
export interface Response$createIssueFieldOption$Status$200 {
    "application/json": Schemas.IssueFieldOption;
}
export interface Parameter$getSelectableIssueFieldOptions {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** Filters the results to options that are only available in the specified project. */
    projectId?: number;
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
}
export interface Response$getSelectableIssueFieldOptions$Status$200 {
    "application/json": Schemas.PageBeanIssueFieldOption;
}
export interface Parameter$getVisibleIssueFieldOptions {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** Filters the results to options that are only available in the specified project. */
    projectId?: number;
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
}
export interface Response$getVisibleIssueFieldOptions$Status$200 {
    "application/json": Schemas.PageBeanIssueFieldOption;
}
export interface Parameter$getIssueFieldOption {
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
    /** The ID of the option to be returned. */
    optionId: number;
}
export interface Response$getIssueFieldOption$Status$200 {
    "application/json": Schemas.IssueFieldOption;
}
export interface Parameter$updateIssueFieldOption {
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
    /** The ID of the option to be updated. */
    optionId: number;
}
export interface RequestBody$updateIssueFieldOption {
    "application/json": Schemas.IssueFieldOption;
}
export interface Response$updateIssueFieldOption$Status$200 {
    "application/json": Schemas.IssueFieldOption;
}
export interface Parameter$deleteIssueFieldOption {
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
    /** The ID of the option to be deleted. */
    optionId: number;
}
export interface Response$deleteIssueFieldOption$Status$204 {
    "application/json": {};
}
export interface Parameter$replaceIssueFieldOption {
    /** The ID of the option that will replace the currently selected option. */
    replaceWith?: number;
    /** A JQL query that specifies the issues to be updated. For example, *project=10000*. */
    jql?: string;
    /** Whether screen security is overridden to enable hidden fields to be edited. Available to Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope. */
    overrideScreenSecurity?: boolean;
    /** Whether screen security is overridden to enable uneditable fields to be edited. Available to Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope. */
    overrideEditableFlag?: boolean;
    /**
     * The field key is specified in the following format: **$(app-key)\_\_$(field-key)**. For example, *example-add-on\_\_example-issue-field*. To determine the `fieldKey` value, do one of the following:
     *
     *  *  open the app's plugin descriptor, then **app-key** is the key at the top and **field-key** is the key in the `jiraIssueFields` module. **app-key** can also be found in the app listing in the Atlassian Universal Plugin Manager.
     *  *  run [Get fields](#api-rest-api-3-field-get) and in the field details the value is returned in `key`. For example, `"key": "teams-add-on__team-issue-field"`
     */
    fieldKey: string;
    /** The ID of the option to be deselected. */
    optionId: number;
}
export interface Response$replaceIssueFieldOption$Status$303 {
    "application/json": Schemas.TaskProgressBeanRemoveOptionFromIssuesResult;
}
export interface Response$replaceIssueFieldOption$Status$403 {
}
export interface Parameter$deleteCustomField {
    /** The ID of a custom field. */
    id: string;
}
export interface Response$deleteCustomField$Status$303 {
    "application/json": {};
}
export interface Response$deleteCustomField$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteCustomField$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteCustomField$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteCustomField$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteCustomField$Status$409 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$restoreCustomField {
    /** The ID of a custom field. */
    id: string;
}
export interface Response$restoreCustomField$Status$200 {
    "application/json": {};
}
export interface Response$restoreCustomField$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$restoreCustomField$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$restoreCustomField$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$restoreCustomField$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$trashCustomField {
    /** The ID of a custom field. */
    id: string;
}
export interface Response$trashCustomField$Status$200 {
    "application/json": {};
}
export interface Response$trashCustomField$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$trashCustomField$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$trashCustomField$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$trashCustomField$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getAllFieldConfigurations {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of field configuration IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
    /** If *true* returns default field configurations only. */
    isDefault?: boolean;
    /** The query string used to match against field configuration names and descriptions. */
    query?: string;
}
export interface Response$getAllFieldConfigurations$Status$200 {
    "application/json": Schemas.PageBeanFieldConfigurationDetails;
}
export interface RequestBody$createFieldConfiguration {
    "application/json": Schemas.FieldConfigurationDetails;
}
export interface Response$createFieldConfiguration$Status$200 {
    "application/json": Schemas.FieldConfiguration;
}
export interface Parameter$updateFieldConfiguration {
    /** The ID of the field configuration. */
    id: number;
}
export interface RequestBody$updateFieldConfiguration {
    "application/json": Schemas.FieldConfigurationDetails;
}
export interface Response$updateFieldConfiguration$Status$204 {
    "application/json": {};
}
export interface Parameter$deleteFieldConfiguration {
    /** The ID of the field configuration. */
    id: number;
}
export interface Response$deleteFieldConfiguration$Status$204 {
    "application/json": {};
}
export interface Parameter$getFieldConfigurationItems {
    /** The ID of the field configuration. */
    id: number;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getFieldConfigurationItems$Status$200 {
    "application/json": Schemas.PageBeanFieldConfigurationItem;
}
export interface Parameter$updateFieldConfigurationItems {
    /** The ID of the field configuration. */
    id: number;
}
export interface RequestBody$updateFieldConfigurationItems {
    "application/json": Schemas.FieldConfigurationItemsDetails;
}
export interface Response$updateFieldConfigurationItems$Status$204 {
    "application/json": {};
}
export interface Parameter$getAllFieldConfigurationSchemes {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of field configuration scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
}
export interface Response$getAllFieldConfigurationSchemes$Status$200 {
    "application/json": Schemas.PageBeanFieldConfigurationScheme;
}
export interface RequestBody$createFieldConfigurationScheme {
    "application/json": Schemas.UpdateFieldConfigurationSchemeDetails;
}
export interface Response$createFieldConfigurationScheme$Status$201 {
    "application/json": Schemas.FieldConfigurationScheme;
}
export interface Response$createFieldConfigurationScheme$Status$400 {
}
export interface Response$createFieldConfigurationScheme$Status$403 {
}
export interface Parameter$getFieldConfigurationSchemeMappings {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of field configuration scheme IDs. To include multiple field configuration schemes separate IDs with ampersand: `fieldConfigurationSchemeId=10000&fieldConfigurationSchemeId=10001`. */
    fieldConfigurationSchemeId?: number[];
}
export interface Response$getFieldConfigurationSchemeMappings$Status$200 {
    "application/json": Schemas.PageBeanFieldConfigurationIssueTypeItem;
}
export interface Parameter$getFieldConfigurationSchemeProjectMapping {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of project IDs. To include multiple projects, separate IDs with ampersand: `projectId=10000&projectId=10001`. */
    projectId: number[];
}
export interface Response$getFieldConfigurationSchemeProjectMapping$Status$200 {
    "application/json": Schemas.PageBeanFieldConfigurationSchemeProjects;
}
export interface RequestBody$assignFieldConfigurationSchemeToProject {
    "application/json": Schemas.FieldConfigurationSchemeProjectAssociation;
}
export interface Response$assignFieldConfigurationSchemeToProject$Status$204 {
    "application/json": {};
}
export interface Response$assignFieldConfigurationSchemeToProject$Status$400 {
}
export interface Response$assignFieldConfigurationSchemeToProject$Status$403 {
}
export interface Response$assignFieldConfigurationSchemeToProject$Status$404 {
}
export interface Parameter$updateFieldConfigurationScheme {
    /** The ID of the field configuration scheme. */
    id: number;
}
export interface RequestBody$updateFieldConfigurationScheme {
    "application/json": Schemas.UpdateFieldConfigurationSchemeDetails;
}
export interface Response$updateFieldConfigurationScheme$Status$204 {
    "application/json": {};
}
export interface Response$updateFieldConfigurationScheme$Status$400 {
}
export interface Response$updateFieldConfigurationScheme$Status$403 {
}
export interface Response$updateFieldConfigurationScheme$Status$404 {
}
export interface Parameter$deleteFieldConfigurationScheme {
    /** The ID of the field configuration scheme. */
    id: number;
}
export interface Response$deleteFieldConfigurationScheme$Status$204 {
    "application/json": {};
}
export interface Parameter$setFieldConfigurationSchemeMapping {
    /** The ID of the field configuration scheme. */
    id: number;
}
export interface RequestBody$setFieldConfigurationSchemeMapping {
    "application/json": Schemas.AssociateFieldConfigurationsWithIssueTypesRequest;
}
export interface Response$setFieldConfigurationSchemeMapping$Status$204 {
    "application/json": {};
}
export interface Parameter$removeIssueTypesFromGlobalFieldConfigurationScheme {
    /** The ID of the field configuration scheme. */
    id: number;
}
export interface RequestBody$removeIssueTypesFromGlobalFieldConfigurationScheme {
    "application/json": Schemas.IssueTypeIdsToRemove;
}
export interface Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$204 {
    "application/json": {};
}
export interface Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getFilters {
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface Response$getFilters$Status$200 {
    "application/json": Schemas.Filter[];
}
export interface Parameter$createFilter {
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface RequestBody$createFilter {
    "application/json": Schemas.Filter;
}
export interface Response$createFilter$Status$200 {
    "application/json": Schemas.Filter;
}
export interface Response$getDefaultShareScope$Status$200 {
    "application/json": Schemas.DefaultShareScope;
}
export interface RequestBody$setDefaultShareScope {
    "application/json": Schemas.DefaultShareScope;
}
export interface Response$setDefaultShareScope$Status$200 {
    "application/json": Schemas.DefaultShareScope;
}
export interface Parameter$getFavouriteFilters {
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface Response$getFavouriteFilters$Status$200 {
    "application/json": Schemas.Filter[];
}
export interface Parameter$getMyFilters {
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
    /** Include the user's favorite filters in the response. */
    includeFavourites?: boolean;
}
export interface Response$getMyFilters$Status$200 {
    "application/json": Schemas.Filter[];
}
export interface Parameter$getFiltersPaginated {
    /** String used to perform a case-insensitive partial match with `name`. */
    filterName?: string;
    /** User account ID used to return filters with the matching `owner.accountId`. This parameter cannot be used with `owner`. */
    accountId?: string;
    /** This parameter is deprecated because of privacy changes. Use `accountId` instead. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. User name used to return filters with the matching `owner.name`. This parameter cannot be used with `accountId`. */
    owner?: string;
    /** Group name used to returns filters that are shared with a group that matches `sharePermissions.group.groupname`. */
    groupname?: string;
    /** Project ID used to returns filters that are shared with a project that matches `sharePermissions.project.id`. */
    projectId?: number;
    /** The list of filter IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
    /**
     * [Order](#ordering) the results by a field:
     *
     *  *  `description` Sorts by filter description. Note that this sorting works independently of whether the expand to display the description field is in use.
     *  *  `favourite_count` Sorts by the count of how many users have this filter as a favorite.
     *  *  `is_favourite` Sorts by whether the filter is marked as a favorite.
     *  *  `id` Sorts by filter ID.
     *  *  `name` Sorts by filter name.
     *  *  `owner` Sorts by the ID of the filter owner.
     *  *  `is_shared` Sorts by whether the filter is shared.
     */
    orderBy?: "description" | "-description" | "+description" | "favourite_count" | "-favourite_count" | "+favourite_count" | "id" | "-id" | "+id" | "is_favourite" | "-is_favourite" | "+is_favourite" | "name" | "-name" | "+name" | "owner" | "-owner" | "+owner" | "is_shared" | "-is_shared" | "+is_shared";
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `description` Returns the description of the filter.
     *  *  `favourite` Returns an indicator of whether the user has set the filter as a favorite.
     *  *  `favouritedCount` Returns a count of how many users have set this filter as a favorite.
     *  *  `jql` Returns the JQL query that the filter uses.
     *  *  `owner` Returns the owner of the filter.
     *  *  `searchUrl` Returns a URL to perform the filter's JQL query.
     *  *  `sharePermissions` Returns the share permissions defined for the filter.
     *  *  `editPermissions` Returns the edit permissions defined for the filter.
     *  *  `isWritable` Returns whether the current user has permission to edit the filter.
     *  *  `subscriptions` Returns the users that are subscribed to the filter.
     *  *  `viewUrl` Returns a URL to view the filter.
     */
    expand?: string;
}
export interface Response$getFiltersPaginated$Status$200 {
    "application/json": Schemas.PageBeanFilterDetails;
}
export interface Response$getFiltersPaginated$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getFilter {
    /** The ID of the filter to return. */
    id: number;
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface Response$getFilter$Status$200 {
    "application/json": Schemas.Filter;
}
export interface Parameter$updateFilter {
    /** The ID of the filter to update. */
    id: number;
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface RequestBody$updateFilter {
    "application/json": Schemas.Filter;
}
export interface Response$updateFilter$Status$200 {
    "application/json": Schemas.Filter;
}
export interface Parameter$deleteFilter {
    /** The ID of the filter to delete. */
    id: number;
}
export interface Parameter$getColumns {
    /** The ID of the filter. */
    id: number;
}
export interface Response$getColumns$Status$200 {
    "application/json": Schemas.ColumnItem[];
}
export interface Parameter$setColumns {
    /** The ID of the filter. */
    id: number;
}
export interface RequestBody$setColumns {
    "*/*": string[];
    "multipart/form-data": string[];
}
export interface Response$setColumns$Status$200 {
    "application/json": {};
}
export interface Parameter$resetColumns {
    /** The ID of the filter. */
    id: number;
}
export interface Parameter$setFavouriteForFilter {
    /** The ID of the filter. */
    id: number;
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface Response$setFavouriteForFilter$Status$200 {
    "application/json": Schemas.Filter;
}
export interface Parameter$deleteFavouriteForFilter {
    /** The ID of the filter. */
    id: number;
    /**
     * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
     *  *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
     */
    expand?: string;
}
export interface Response$deleteFavouriteForFilter$Status$200 {
    "application/json": Schemas.Filter;
}
export interface Parameter$getSharePermissions {
    /** The ID of the filter. */
    id: number;
}
export interface Response$getSharePermissions$Status$200 {
    "application/json": Schemas.SharePermission[];
}
export interface Parameter$addSharePermission {
    /** The ID of the filter. */
    id: number;
}
export interface RequestBody$addSharePermission {
    "application/json": Schemas.SharePermissionInputBean;
}
export interface Response$addSharePermission$Status$201 {
    "application/json": Schemas.SharePermission[];
}
export interface Parameter$getSharePermission {
    /** The ID of the filter. */
    id: number;
    /** The ID of the share permission. */
    permissionId: number;
}
export interface Response$getSharePermission$Status$200 {
    "application/json": Schemas.SharePermission;
}
export interface Parameter$deleteSharePermission {
    /** The ID of the filter. */
    id: number;
    /** The ID of the share permission. */
    permissionId: number;
}
export interface Parameter$getGroup {
    /** The name of the group. */
    groupname: string;
    /** List of fields to expand. */
    expand?: string;
}
export interface Response$getGroup$Status$200 {
    "application/json": Schemas.Group;
}
export interface RequestBody$createGroup {
    "application/json": Schemas.AddGroupBean;
}
export interface Response$createGroup$Status$201 {
    "application/json": Schemas.Group;
}
export interface Parameter$removeGroup {
    /** The name of the group. */
    groupname: string;
    /** The group to transfer restrictions to. Only comments and worklogs are transferred. If restrictions are not transferred, comments and worklogs are inaccessible after the deletion. */
    swapGroup?: string;
}
export interface Parameter$bulkGetGroups {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The ID of a group. To specify multiple IDs, pass multiple `groupId` parameters. For example, `groupId=5b10a2844c20165700ede21g&groupId=5b10ac8d82e05b22cc7d4ef5`. */
    groupId?: string[];
    /** The name of a group. To specify multiple names, pass multiple `groupName` parameters. For example, `groupName=administrators&groupName=jira-software-users`. */
    groupName?: string[];
}
export interface Response$bulkGetGroups$Status$200 {
    "application/json": Schemas.PageBeanGroupDetails;
}
export interface Response$bulkGetGroups$Status$403 {
}
export interface Parameter$getUsersFromGroup {
    /** The name of the group. */
    groupname: string;
    /** Include inactive users. */
    includeInactiveUsers?: boolean;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getUsersFromGroup$Status$200 {
    "application/json": Schemas.PageBeanUserDetails;
}
export interface Parameter$addUserToGroup {
    /** The name of the group (case sensitive). */
    groupname: string;
}
export interface RequestBody$addUserToGroup {
    "application/json": Schemas.UpdateUserToGroupBean;
}
export interface Response$addUserToGroup$Status$201 {
    "application/json": Schemas.Group;
}
export interface Parameter$removeUserFromGroup {
    /** The name of the group. */
    groupname: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId: string;
}
export interface Parameter$findGroups {
    /** This parameter is deprecated, setting it does not affect the results. To find groups containing a particular user, use [Get user groups](#api-rest-api-3-user-groups-get). */
    accountId?: string;
    /** The string to find in group names. */
    query?: string;
    /** A group to exclude from the result. To exclude multiple groups, provide an ampersand-separated list. For example, `exclude=group1&exclude=group2`. */
    exclude?: string[];
    /** The maximum number of groups to return. The maximum number of groups that can be returned is limited by the system property `jira.ajax.autocomplete.limit`. */
    maxResults?: number;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    userName?: string;
}
export interface Response$findGroups$Status$200 {
    "application/json": Schemas.FoundGroups;
}
export interface Parameter$findUsersAndGroups {
    /** The search string. */
    query: string;
    /** The maximum number of items to return in each list. */
    maxResults?: number;
    /** Whether the user avatar should be returned. If an invalid value is provided, the default value is used. */
    showAvatar?: boolean;
    /** The custom field ID of the field this request is for. */
    fieldId?: string;
    /** The ID of a project that returned users and groups must have permission to view. To include multiple projects, provide an ampersand-separated list. For example, `projectId=10000&projectId=10001`. This parameter is only used when `fieldId` is present. */
    projectId?: string[];
    /** The ID of an issue type that returned users and groups must have permission to view. To include multiple issue types, provide an ampersand-separated list. For example, `issueTypeId=10000&issueTypeId=10001`. Special values, such as `-1` (all standard issue types) and `-2` (all subtask issue types), are supported. This parameter is only used when `fieldId` is present. */
    issueTypeId?: string[];
    /** The size of the avatar to return. If an invalid value is provided, the default value is used. */
    avatarSize?: "xsmall" | "xsmall@2x" | "xsmall@3x" | "small" | "small@2x" | "small@3x" | "medium" | "medium@2x" | "medium@3x" | "large" | "large@2x" | "large@3x" | "xlarge" | "xlarge@2x" | "xlarge@3x" | "xxlarge" | "xxlarge@2x" | "xxlarge@3x" | "xxxlarge" | "xxxlarge@2x" | "xxxlarge@3x";
    /** Whether the search for groups should be case insensitive. */
    caseInsensitive?: boolean;
    /** Whether Connect app users and groups should be excluded from the search results. If an invalid value is provided, the default value is used. */
    excludeConnectAddons?: boolean;
}
export interface Response$findUsersAndGroups$Status$200 {
    "application/json": Schemas.FoundUsersAndGroups;
}
export interface Response$getLicense$Status$200 {
    "application/json": Schemas.License;
}
export interface Parameter$createIssue {
    /** Whether the project in which the issue is created is added to the user's **Recently viewed** project list, as shown under **Projects** in Jira. When provided, the issue type and request type are added to the user's history for a project. These values are then used to provide defaults on the issue create screen. */
    updateHistory?: boolean;
}
export interface RequestBody$createIssue {
    "application/json": Schemas.IssueUpdateDetails;
}
export interface Response$createIssue$Status$201 {
    "application/json": Schemas.CreatedIssue;
}
export interface Response$createIssue$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$createIssue$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$createIssue$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$createIssues {
    "application/json": Schemas.IssuesUpdateBean;
}
export interface Response$createIssues$Status$201 {
    "application/json": Schemas.CreatedIssues;
}
export interface Response$createIssues$Status$400 {
    "application/json": Schemas.CreatedIssues;
}
export interface Parameter$getCreateIssueMeta {
    /** List of project IDs. This parameter accepts a comma-separated list. Multiple project IDs can also be provided using an ampersand-separated list. For example, `projectIds=10000,10001&projectIds=10020,10021`. This parameter may be provided with `projectKeys`. */
    projectIds?: string[];
    /** List of project keys. This parameter accepts a comma-separated list. Multiple project keys can also be provided using an ampersand-separated list. For example, `projectKeys=proj1,proj2&projectKeys=proj3`. This parameter may be provided with `projectIds`. */
    projectKeys?: string[];
    /** List of issue type IDs. This parameter accepts a comma-separated list. Multiple issue type IDs can also be provided using an ampersand-separated list. For example, `issuetypeIds=10000,10001&issuetypeIds=10020,10021`. This parameter may be provided with `issuetypeNames`. */
    issuetypeIds?: string[];
    /** List of issue type names. This parameter accepts a comma-separated list. Multiple issue type names can also be provided using an ampersand-separated list. For example, `issuetypeNames=name1,name2&issuetypeNames=name3`. This parameter may be provided with `issuetypeIds`. */
    issuetypeNames?: string[];
    /** Use [expand](#expansion) to include additional information about issue metadata in the response. This parameter accepts `projects.issuetypes.fields`, which returns information about the fields in the issue creation screen for each issue type. Fields hidden from the screen are not returned. Use the information to populate the `fields` and `update` fields in [Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post). */
    expand?: string;
}
export interface Response$getCreateIssueMeta$Status$200 {
    "application/json": Schemas.IssueCreateMetadata;
}
export interface Parameter$getIssuePickerResource {
    /** A string to match against text fields in the issue such as title, description, or comments. */
    query?: string;
    /** A JQL query defining a list of issues to search for the query term. Note that `username` and `userkey` cannot be used as search terms for this parameter, due to privacy reasons. Use `accountId` instead. */
    currentJQL?: string;
    /** The key of an issue to exclude from search results. For example, the issue the user is viewing when they perform this query. */
    currentIssueKey?: string;
    /** The ID of a project that suggested issues must belong to. */
    currentProjectId?: string;
    /** Indicate whether to include subtasks in the suggestions list. */
    showSubTasks?: boolean;
    /** When `currentIssueKey` is a subtask, whether to include the parent issue in the suggestions if it matches the query. */
    showSubTaskParent?: boolean;
}
export interface Response$getIssuePickerResource$Status$200 {
    "application/json": Schemas.IssuePickerSuggestions;
}
export interface RequestBody$bulkSetIssuesPropertiesList {
    "application/json": Schemas.IssueEntityProperties;
}
export interface Response$bulkSetIssuesPropertiesList$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$bulkSetIssuesPropertiesList$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$bulkSetIssuePropertiesByIssue {
    "application/json": Schemas.MultiIssueEntityProperties;
}
export interface Response$bulkSetIssuePropertiesByIssue$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$bulkSetIssuePropertiesByIssue$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$bulkSetIssuePropertiesByIssue$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$bulkSetIssueProperty {
    /** The key of the property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$bulkSetIssueProperty {
    "application/json": Schemas.BulkIssuePropertyUpdateRequest;
}
export interface Response$bulkSetIssueProperty$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$bulkSetIssueProperty$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$bulkDeleteIssueProperty {
    /** The key of the property. */
    propertyKey: string;
}
export interface RequestBody$bulkDeleteIssueProperty {
    "application/json": Schemas.IssueFilterForBulkPropertyDelete;
}
export interface Response$bulkDeleteIssueProperty$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$bulkDeleteIssueProperty$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$getIsWatchingIssueBulk {
    "application/json": Schemas.IssueList;
}
export interface Response$getIsWatchingIssueBulk$Status$200 {
    "application/json": Schemas.BulkIssueIsWatching;
}
export interface Parameter$getIssue {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /**
     * A list of fields to return for the issue. This parameter accepts a comma-separated list. Use it to retrieve a subset of fields. Allowed values:
     *
     *  *  `*all` Returns all fields.
     *  *  `*navigable` Returns navigable fields.
     *  *  Any issue field, prefixed with a minus to exclude.
     *
     * Examples:
     *
     *  *  `summary,comment` Returns only the summary and comments fields.
     *  *  `-description` Returns all (default) fields except description.
     *  *  `*navigable,-comment` Returns all navigable fields except comment.
     *
     * This parameter may be specified multiple times. For example, `fields=field1,field2& fields=field3`.
     *
     * Note: All fields are returned by default. This differs from [Search for issues using JQL (GET)](#api-rest-api-3-search-get) and [Search for issues using JQL (POST)](#api-rest-api-3-search-post) where the default is all navigable fields.
     */
    fields?: string[];
    /** Whether fields in `fields` are referenced by keys rather than IDs. This parameter is useful where fields have been added by a connect app and a field's key may differ from its ID. */
    fieldsByKeys?: boolean;
    /**
     * Use [expand](#expansion) to include additional information about the issues in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `renderedFields` Returns field values rendered in HTML format.
     *  *  `names` Returns the display name of each field.
     *  *  `schema` Returns the schema describing a field type.
     *  *  `transitions` Returns all possible transitions for the issue.
     *  *  `editmeta` Returns information about how each field can be edited.
     *  *  `changelog` Returns a list of recent updates to an issue, sorted by date, starting from the most recent.
     *  *  `versionedRepresentations` Returns a JSON array for each version of a field's value, with the highest number representing the most recent version. Note: When included in the request, the `fields` parameter is ignored.
     */
    expand?: string;
    /**
     * A list of issue properties to return for the issue. This parameter accepts a comma-separated list. Allowed values:
     *
     *  *  `*all` Returns all issue properties.
     *  *  Any issue property key, prefixed with a minus to exclude.
     *
     * Examples:
     *
     *  *  `*all` Returns all properties.
     *  *  `*all,-prop1` Returns all properties except `prop1`.
     *  *  `prop1,prop2` Returns `prop1` and `prop2` properties.
     *
     * This parameter may be specified multiple times. For example, `properties=prop1,prop2& properties=prop3`.
     */
    properties?: string[];
    /** Whether the project in which the issue is created is added to the user's **Recently viewed** project list, as shown under **Projects** in Jira. This also populates the [JQL issues search](#api-rest-api-3-search-get) `lastViewed` field. */
    updateHistory?: boolean;
}
export interface Response$getIssue$Status$200 {
    "application/json": Schemas.IssueBean;
}
export interface Parameter$editIssue {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** Whether a notification email about the issue update is sent to all watchers. To disable the notification, administer Jira or administer project permissions are required. If the user doesn't have the necessary permission the request is ignored. */
    notifyUsers?: boolean;
    /** Whether screen security is overridden to enable hidden fields to be edited. Available to Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope. */
    overrideScreenSecurity?: boolean;
    /** Whether screen security is overridden to enable uneditable fields to be edited. Available to Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope. */
    overrideEditableFlag?: boolean;
}
export interface RequestBody$editIssue {
    "application/json": Schemas.IssueUpdateDetails;
}
export interface Response$editIssue$Status$204 {
    "application/json": {};
}
export interface Parameter$deleteIssue {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** Whether the issue's subtasks are deleted when the issue is deleted. */
    deleteSubtasks?: "true" | "false";
}
export interface Parameter$assignIssue {
    /** The ID or key of the issue to be assigned. */
    issueIdOrKey: string;
}
export interface RequestBody$assignIssue {
    "application/json": Schemas.User;
}
export interface Response$assignIssue$Status$204 {
    "application/json": {};
}
export interface Parameter$addAttachment {
    /** The ID or key of the issue that attachments are added to. */
    issueIdOrKey: string;
}
export interface RequestBody$addAttachment {
    "multipart/form-data": string;
}
export interface Response$addAttachment$Status$200 {
    "application/json": Schemas.Attachment[];
}
export interface Parameter$getChangeLogs {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getChangeLogs$Status$200 {
    "application/json": Schemas.PageBeanChangelog;
}
export interface Parameter$getChangeLogsByIds {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface RequestBody$getChangeLogsByIds {
    "application/json": Schemas.IssueChangelogIds;
}
export interface Response$getChangeLogsByIds$Status$200 {
    "application/json": Schemas.PageOfChangelogs;
}
export interface Parameter$getComments {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** [Order](#ordering) the results by a field. Accepts *created* to sort comments by their created date. */
    orderBy?: "created" | "-created" | "+created";
    /** Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML. */
    expand?: string;
}
export interface Response$getComments$Status$200 {
    "application/json": Schemas.PageOfComments;
}
export interface Parameter$addComment {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML. */
    expand?: string;
}
export interface RequestBody$addComment {
    "application/json": Schemas.Comment;
}
export interface Response$addComment$Status$201 {
    "application/json": Schemas.Comment;
}
export interface Parameter$getComment {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the comment. */
    id: string;
    /** Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML. */
    expand?: string;
}
export interface Response$getComment$Status$200 {
    "application/json": Schemas.Comment;
}
export interface Parameter$updateComment {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the comment. */
    id: string;
    /** Set to false to stop users being notified that a comment is updated */
    notifyUsers?: boolean;
    /** Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML. */
    expand?: string;
}
export interface RequestBody$updateComment {
    "application/json": Schemas.Comment;
}
export interface Response$updateComment$Status$200 {
    "application/json": Schemas.Comment;
}
export interface Parameter$deleteComment {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the comment. */
    id: string;
}
export interface Parameter$getEditIssueMeta {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** Whether hidden fields are returned. Available to Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope. */
    overrideScreenSecurity?: boolean;
    /** Whether non-editable fields are returned. Available to Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope. */
    overrideEditableFlag?: boolean;
}
export interface Response$getEditIssueMeta$Status$200 {
    "application/json": Schemas.IssueUpdateMetadata;
}
export interface Parameter$notify {
    /** ID or key of the issue that the notification is sent for. */
    issueIdOrKey: string;
}
export interface RequestBody$notify {
    "application/json": Schemas.Notification;
}
export interface Response$notify$Status$204 {
    "application/json": {};
}
export interface Parameter$getIssuePropertyKeys {
    /** The key or ID of the issue. */
    issueIdOrKey: string;
}
export interface Response$getIssuePropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getIssueProperty {
    /** The key or ID of the issue. */
    issueIdOrKey: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface Response$getIssueProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setIssueProperty {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The key of the issue property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setIssueProperty {
    "application/json": {};
}
export interface Response$setIssueProperty$Status$200 {
    "application/json": {};
}
export interface Response$setIssueProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteIssueProperty {
    /** The key or ID of the issue. */
    issueIdOrKey: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface Parameter$getRemoteIssueLinks {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The global ID of the remote issue link. */
    globalId?: string;
}
export interface Response$getRemoteIssueLinks$Status$200 {
    "application/json": Schemas.RemoteIssueLink;
}
export interface Parameter$createOrUpdateRemoteIssueLink {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface RequestBody$createOrUpdateRemoteIssueLink {
    "application/json": Schemas.RemoteIssueLinkRequest;
}
export interface Response$createOrUpdateRemoteIssueLink$Status$200 {
    "application/json": Schemas.RemoteIssueLinkIdentifies;
}
export interface Response$createOrUpdateRemoteIssueLink$Status$201 {
    "application/json": Schemas.RemoteIssueLinkIdentifies;
}
export interface Response$createOrUpdateRemoteIssueLink$Status$400 {
}
export interface Parameter$deleteRemoteIssueLinkByGlobalId {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The global ID of a remote issue link. */
    globalId: string;
}
export interface Parameter$getRemoteIssueLinkById {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the remote issue link. */
    linkId: string;
}
export interface Response$getRemoteIssueLinkById$Status$200 {
    "application/json": Schemas.RemoteIssueLink;
}
export interface Parameter$updateRemoteIssueLink {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the remote issue link. */
    linkId: string;
}
export interface RequestBody$updateRemoteIssueLink {
    "application/json": Schemas.RemoteIssueLinkRequest;
}
export interface Response$updateRemoteIssueLink$Status$204 {
    "application/json": {};
}
export interface Response$updateRemoteIssueLink$Status$400 {
}
export interface Parameter$deleteRemoteIssueLinkById {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of a remote issue link. */
    linkId: string;
}
export interface Parameter$getTransitions {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** Use [expand](#expansion) to include additional information about transitions in the response. This parameter accepts `transitions.fields`, which returns information about the fields in the transition screen for each transition. Fields hidden from the screen are not returned. Use this information to populate the `fields` and `update` fields in [Transition issue](#api-rest-api-3-issue-issueIdOrKey-transitions-post). */
    expand?: string;
    /** The ID of the transition. */
    transitionId?: string;
    /** Whether transitions with the condition *Hide From User Condition* are included in the response. */
    skipRemoteOnlyCondition?: boolean;
    /** Whether details of transitions that fail a condition are included in the response */
    includeUnavailableTransitions?: boolean;
    /** Whether the transitions are sorted by ops-bar sequence value first then category order (Todo, In Progress, Done) or only by ops-bar sequence value. */
    sortByOpsBarAndStatus?: boolean;
}
export interface Response$getTransitions$Status$200 {
    "application/json": Schemas.Transitions;
}
export interface Parameter$doTransition {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface RequestBody$doTransition {
    "application/json": Schemas.IssueUpdateDetails;
}
export interface Response$doTransition$Status$204 {
    "application/json": {};
}
export interface Parameter$getVotes {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface Response$getVotes$Status$200 {
    "application/json": Schemas.Votes;
}
export interface Parameter$addVote {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface Response$addVote$Status$204 {
    "application/json": {};
}
export interface Parameter$removeVote {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface Parameter$getIssueWatchers {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface Response$getIssueWatchers$Status$200 {
    "application/json": Schemas.Watchers;
}
export interface Parameter$addWatcher {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
}
export interface RequestBody$addWatcher {
    "application/json": string;
}
export interface Response$addWatcher$Status$204 {
    "application/json": {};
}
export interface Parameter$removeWatcher {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Required. */
    accountId?: string;
}
export interface Parameter$getIssueWorklog {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The worklog start date and time, as a UNIX timestamp in milliseconds, after which worklogs are returned. */
    startedAfter?: number;
    /** The worklog start date and time, as a UNIX timestamp in milliseconds, before which worklogs are returned. */
    startedBefore?: number;
    /** Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts`properties`, which returns worklog properties. */
    expand?: string;
}
export interface Response$getIssueWorklog$Status$200 {
    "application/json": Schemas.PageOfWorklogs;
}
export interface Parameter$addWorklog {
    /** The ID or key the issue. */
    issueIdOrKey: string;
    /** Whether users watching the issue are notified by email. */
    notifyUsers?: boolean;
    /**
     * Defines how to update the issue's time estimate, the options are:
     *
     *  *  `new` Sets the estimate to a specific value, defined in `newEstimate`.
     *  *  `leave` Leaves the estimate unchanged.
     *  *  `manual` Reduces the estimate by amount specified in `reduceBy`.
     *  *  `auto` Reduces the estimate by the value of `timeSpent` in the worklog.
     */
    adjustEstimate?: "new" | "leave" | "manual" | "auto";
    /** The value to set as the issue's remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `new`. */
    newEstimate?: string;
    /** The amount to reduce the issue's remaining estimate by, as days (\#d), hours (\#h), or minutes (\#m). For example, *2d*. Required when `adjustEstimate` is `manual`. */
    reduceBy?: string;
    /** Use [expand](#expansion) to include additional information about work logs in the response. This parameter accepts `properties`, which returns worklog properties. */
    expand?: string;
    /** Whether the worklog entry should be added to the issue even if the issue is not editable, because jira.issue.editable set to false or missing. For example, the issue is closed. Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope can use this flag. */
    overrideEditableFlag?: boolean;
}
export interface RequestBody$addWorklog {
    "application/json": Schemas.Worklog;
}
export interface Response$addWorklog$Status$201 {
    "application/json": Schemas.Worklog;
}
export interface Parameter$getWorklog {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    id: string;
    /**
     * Use [expand](#expansion) to include additional information about work logs in the response. This parameter accepts
     *
     * `properties`, which returns worklog properties.
     */
    expand?: string;
}
export interface Response$getWorklog$Status$200 {
    "application/json": Schemas.Worklog;
}
export interface Parameter$updateWorklog {
    /** The ID or key the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    id: string;
    /** Whether users watching the issue are notified by email. */
    notifyUsers?: boolean;
    /**
     * Defines how to update the issue's time estimate, the options are:
     *
     *  *  `new` Sets the estimate to a specific value, defined in `newEstimate`.
     *  *  `leave` Leaves the estimate unchanged.
     *  *  `auto` Updates the estimate by the difference between the original and updated value of `timeSpent` or `timeSpentSeconds`.
     */
    adjustEstimate?: "new" | "leave" | "manual" | "auto";
    /** The value to set as the issue's remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `new`. */
    newEstimate?: string;
    /** Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts `properties`, which returns worklog properties. */
    expand?: string;
    /** Whether the worklog should be added to the issue even if the issue is not editable. For example, because the issue is closed. Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope can use this flag. */
    overrideEditableFlag?: boolean;
}
export interface RequestBody$updateWorklog {
    "application/json": Schemas.Worklog;
}
export interface Response$updateWorklog$Status$200 {
    "application/json": Schemas.Worklog;
}
export interface Parameter$deleteWorklog {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    id: string;
    /** Whether users watching the issue are notified by email. */
    notifyUsers?: boolean;
    /**
     * Defines how to update the issue's time estimate, the options are:
     *
     *  *  `new` Sets the estimate to a specific value, defined in `newEstimate`.
     *  *  `leave` Leaves the estimate unchanged.
     *  *  `manual` Increases the estimate by amount specified in `increaseBy`.
     *  *  `auto` Reduces the estimate by the value of `timeSpent` in the worklog.
     */
    adjustEstimate?: "new" | "leave" | "manual" | "auto";
    /** The value to set as the issue's remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `new`. */
    newEstimate?: string;
    /** The amount to increase the issue's remaining estimate by, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `manual`. */
    increaseBy?: string;
    /** Whether the work log entry should be added to the issue even if the issue is not editable, because jira.issue.editable set to false or missing. For example, the issue is closed. Connect app users with admin permission and Forge app users with the `manage:jira-configuration` scope can use this flag. */
    overrideEditableFlag?: boolean;
}
export interface Parameter$getWorklogPropertyKeys {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    worklogId: string;
}
export interface Response$getWorklogPropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getWorklogProperty {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    worklogId: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface Response$getWorklogProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setWorklogProperty {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    worklogId: string;
    /** The key of the issue property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setWorklogProperty {
    "application/json": {};
}
export interface Response$setWorklogProperty$Status$200 {
    "application/json": {};
}
export interface Response$setWorklogProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteWorklogProperty {
    /** The ID or key of the issue. */
    issueIdOrKey: string;
    /** The ID of the worklog. */
    worklogId: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface RequestBody$linkIssues {
    "application/json": Schemas.LinkIssueRequestJsonBean;
}
export interface Response$linkIssues$Status$201 {
    "application/json": {};
}
export interface Parameter$getIssueLink {
    /** The ID of the issue link. */
    linkId: string;
}
export interface Response$getIssueLink$Status$200 {
    "application/json": Schemas.IssueLink;
}
export interface Parameter$deleteIssueLink {
    /** The ID of the issue link. */
    linkId: string;
}
export interface Response$getIssueLinkTypes$Status$200 {
    "application/json": Schemas.IssueLinkTypes;
}
export interface RequestBody$createIssueLinkType {
    "application/json": Schemas.IssueLinkType;
}
export interface Response$createIssueLinkType$Status$201 {
    "application/json": Schemas.IssueLinkType;
}
export interface Parameter$getIssueLinkType {
    /** The ID of the issue link type. */
    issueLinkTypeId: string;
}
export interface Response$getIssueLinkType$Status$200 {
    "application/json": Schemas.IssueLinkType;
}
export interface Parameter$updateIssueLinkType {
    /** The ID of the issue link type. */
    issueLinkTypeId: string;
}
export interface RequestBody$updateIssueLinkType {
    "application/json": Schemas.IssueLinkType;
}
export interface Response$updateIssueLinkType$Status$200 {
    "application/json": Schemas.IssueLinkType;
}
export interface Parameter$deleteIssueLinkType {
    /** The ID of the issue link type. */
    issueLinkTypeId: string;
}
export interface Response$getIssueSecuritySchemes$Status$200 {
    "application/json": Schemas.SecuritySchemes;
}
export interface Parameter$getIssueSecurityScheme {
    /** The ID of the issue security scheme. Use the [Get issue security schemes](#api-rest-api-3-issuesecurityschemes-get) operation to get a list of issue security scheme IDs. */
    id: number;
}
export interface Response$getIssueSecurityScheme$Status$200 {
    "application/json": Schemas.SecurityScheme;
}
export interface Parameter$getIssueSecurityLevelMembers {
    /** The ID of the issue security scheme. Use the [Get issue security schemes](#api-rest-api-3-issuesecurityschemes-get) operation to get a list of issue security scheme IDs. */
    issueSecuritySchemeId: number;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of issue security level IDs. To include multiple issue security levels separate IDs with ampersand: `issueSecurityLevelId=10000&issueSecurityLevelId=10001`. */
    issueSecurityLevelId?: number[];
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface Response$getIssueSecurityLevelMembers$Status$200 {
    "application/json": Schemas.PageBeanIssueSecurityLevelMember;
}
export interface Response$getIssueAllTypes$Status$200 {
    "application/json": Schemas.IssueTypeDetails[];
}
export interface RequestBody$createIssueType {
    "application/json": Schemas.IssueTypeCreateBean;
}
export interface Response$createIssueType$Status$201 {
    "application/json": Schemas.IssueTypeDetails;
}
export interface Parameter$getIssueTypesForProject {
    /** The ID of the project. */
    projectId: number;
    /**
     * The level of the issue type to filter by. Use:
     *
     *  *  `-1` for Subtask.
     *  *  `0` for Base.
     *  *  `1` for Epic.
     */
    level?: number;
}
export interface Response$getIssueTypesForProject$Status$200 {
    "application/json": Schemas.IssueTypeDetails[];
}
export interface Parameter$getIssueType {
    /** The ID of the issue type. */
    id: string;
}
export interface Response$getIssueType$Status$200 {
    "application/json": Schemas.IssueTypeDetails;
}
export interface Parameter$updateIssueType {
    /** The ID of the issue type. */
    id: string;
}
export interface RequestBody$updateIssueType {
    "application/json": Schemas.IssueTypeUpdateBean;
}
export interface Response$updateIssueType$Status$200 {
    "application/json": Schemas.IssueTypeDetails;
}
export interface Parameter$deleteIssueType {
    /** The ID of the issue type. */
    id: string;
    /** The ID of the replacement issue type. */
    alternativeIssueTypeId?: string;
}
export interface Parameter$getAlternativeIssueTypes {
    /** The ID of the issue type. */
    id: string;
}
export interface Response$getAlternativeIssueTypes$Status$200 {
    "application/json": Schemas.IssueTypeDetails[];
}
export interface Parameter$createIssueTypeAvatar {
    /** The ID of the issue type. */
    id: string;
    /** The X coordinate of the top-left corner of the crop region. */
    x?: number;
    /** The Y coordinate of the top-left corner of the crop region. */
    y?: number;
    /** The length of each side of the crop region. */
    size: number;
}
export interface RequestBody$createIssueTypeAvatar {
    "*/*": {};
}
export interface Response$createIssueTypeAvatar$Status$201 {
    "application/json": Schemas.Avatar;
}
export interface Parameter$getIssueTypePropertyKeys {
    /** The ID of the issue type. */
    issueTypeId: string;
}
export interface Response$getIssueTypePropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getIssueTypeProperty {
    /** The ID of the issue type. */
    issueTypeId: string;
    /** The key of the property. Use [Get issue type property keys](#api-rest-api-3-issuetype-issueTypeId-properties-get) to get a list of all issue type property keys. */
    propertyKey: string;
}
export interface Response$getIssueTypeProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setIssueTypeProperty {
    /** The ID of the issue type. */
    issueTypeId: string;
    /** The key of the issue type property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setIssueTypeProperty {
    "application/json": {};
}
export interface Response$setIssueTypeProperty$Status$200 {
    "application/json": {};
}
export interface Response$setIssueTypeProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteIssueTypeProperty {
    /** The ID of the issue type. */
    issueTypeId: string;
    /** The key of the property. Use [Get issue type property keys](#api-rest-api-3-issuetype-issueTypeId-properties-get) to get a list of all issue type property keys. */
    propertyKey: string;
}
export interface Parameter$getAllIssueTypeSchemes {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of issue type schemes IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
}
export interface Response$getAllIssueTypeSchemes$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeScheme;
}
export interface RequestBody$createIssueTypeScheme {
    "application/json": Schemas.IssueTypeSchemeDetails;
}
export interface Response$createIssueTypeScheme$Status$201 {
    "application/json": Schemas.IssueTypeSchemeID;
}
export interface Response$createIssueTypeScheme$Status$400 {
}
export interface Response$createIssueTypeScheme$Status$403 {
}
export interface Response$createIssueTypeScheme$Status$409 {
}
export interface Parameter$getIssueTypeSchemesMapping {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of issue type scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `issueTypeSchemeId=10000&issueTypeSchemeId=10001`. */
    issueTypeSchemeId?: number[];
}
export interface Response$getIssueTypeSchemesMapping$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeSchemeMapping;
}
export interface Parameter$getIssueTypeSchemeForProjects {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of project IDs. To include multiple project IDs, provide an ampersand-separated list. For example, `projectId=10000&projectId=10001`. */
    projectId: number[];
}
export interface Response$getIssueTypeSchemeForProjects$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeSchemeProjects;
}
export interface RequestBody$assignIssueTypeSchemeToProject {
    "application/json": Schemas.IssueTypeSchemeProjectAssociation;
}
export interface Response$assignIssueTypeSchemeToProject$Status$204 {
    "application/json": {};
}
export interface Response$assignIssueTypeSchemeToProject$Status$400 {
}
export interface Response$assignIssueTypeSchemeToProject$Status$403 {
}
export interface Response$assignIssueTypeSchemeToProject$Status$404 {
}
export interface Parameter$updateIssueTypeScheme {
    /** The ID of the issue type scheme. */
    issueTypeSchemeId: number;
}
export interface RequestBody$updateIssueTypeScheme {
    "application/json": Schemas.IssueTypeSchemeUpdateDetails;
}
export interface Response$updateIssueTypeScheme$Status$204 {
    "application/json": {};
}
export interface Response$updateIssueTypeScheme$Status$400 {
}
export interface Response$updateIssueTypeScheme$Status$403 {
}
export interface Response$updateIssueTypeScheme$Status$404 {
}
export interface Parameter$deleteIssueTypeScheme {
    /** The ID of the issue type scheme. */
    issueTypeSchemeId: number;
}
export interface Response$deleteIssueTypeScheme$Status$204 {
    "application/json": {};
}
export interface Response$deleteIssueTypeScheme$Status$400 {
}
export interface Response$deleteIssueTypeScheme$Status$403 {
}
export interface Response$deleteIssueTypeScheme$Status$404 {
}
export interface Parameter$addIssueTypesToIssueTypeScheme {
    /** The ID of the issue type scheme. */
    issueTypeSchemeId: number;
}
export interface RequestBody$addIssueTypesToIssueTypeScheme {
    "application/json": Schemas.IssueTypeIds;
}
export interface Response$addIssueTypesToIssueTypeScheme$Status$204 {
    "application/json": {};
}
export interface Response$addIssueTypesToIssueTypeScheme$Status$400 {
}
export interface Response$addIssueTypesToIssueTypeScheme$Status$403 {
}
export interface Response$addIssueTypesToIssueTypeScheme$Status$404 {
}
export interface Parameter$reorderIssueTypesInIssueTypeScheme {
    /** The ID of the issue type scheme. */
    issueTypeSchemeId: number;
}
export interface RequestBody$reorderIssueTypesInIssueTypeScheme {
    "application/json": Schemas.OrderOfIssueTypes;
}
export interface Response$reorderIssueTypesInIssueTypeScheme$Status$204 {
    "application/json": {};
}
export interface Response$reorderIssueTypesInIssueTypeScheme$Status$400 {
}
export interface Response$reorderIssueTypesInIssueTypeScheme$Status$403 {
}
export interface Response$reorderIssueTypesInIssueTypeScheme$Status$404 {
}
export interface Parameter$removeIssueTypeFromIssueTypeScheme {
    /** The ID of the issue type scheme. */
    issueTypeSchemeId: number;
    /** The ID of the issue type. */
    issueTypeId: number;
}
export interface Response$removeIssueTypeFromIssueTypeScheme$Status$204 {
    "application/json": {};
}
export interface Response$removeIssueTypeFromIssueTypeScheme$Status$400 {
}
export interface Response$removeIssueTypeFromIssueTypeScheme$Status$403 {
}
export interface Response$removeIssueTypeFromIssueTypeScheme$Status$404 {
}
export interface Parameter$getIssueTypeScreenSchemes {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of issue type screen scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
}
export interface Response$getIssueTypeScreenSchemes$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeScreenScheme;
}
export interface RequestBody$createIssueTypeScreenScheme {
    "application/json": Schemas.IssueTypeScreenSchemeDetails;
}
export interface Response$createIssueTypeScreenScheme$Status$201 {
    "application/json": Schemas.IssueTypeScreenSchemeId;
}
export interface Response$createIssueTypeScreenScheme$Status$400 {
}
export interface Response$createIssueTypeScreenScheme$Status$403 {
}
export interface Response$createIssueTypeScreenScheme$Status$404 {
}
export interface Response$createIssueTypeScreenScheme$Status$409 {
}
export interface Parameter$getIssueTypeScreenSchemeMappings {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of issue type screen scheme IDs. To include multiple issue type screen schemes, separate IDs with ampersand: `issueTypeScreenSchemeId=10000&issueTypeScreenSchemeId=10001`. */
    issueTypeScreenSchemeId?: number[];
}
export interface Response$getIssueTypeScreenSchemeMappings$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeScreenSchemeItem;
}
export interface Parameter$getIssueTypeScreenSchemeProjectAssociations {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of project IDs. To include multiple projects, separate IDs with ampersand: `projectId=10000&projectId=10001`. */
    projectId: number[];
}
export interface Response$getIssueTypeScreenSchemeProjectAssociations$Status$200 {
    "application/json": Schemas.PageBeanIssueTypeScreenSchemesProjects;
}
export interface RequestBody$assignIssueTypeScreenSchemeToProject {
    "application/json": Schemas.IssueTypeScreenSchemeProjectAssociation;
}
export interface Response$assignIssueTypeScreenSchemeToProject$Status$204 {
    "application/json": {};
}
export interface Response$assignIssueTypeScreenSchemeToProject$Status$400 {
}
export interface Response$assignIssueTypeScreenSchemeToProject$Status$403 {
}
export interface Response$assignIssueTypeScreenSchemeToProject$Status$404 {
}
export interface Parameter$updateIssueTypeScreenScheme {
    /** The ID of the issue type screen scheme. */
    issueTypeScreenSchemeId: string;
}
export interface RequestBody$updateIssueTypeScreenScheme {
    "application/json": Schemas.IssueTypeScreenSchemeUpdateDetails;
}
export interface Response$updateIssueTypeScreenScheme$Status$204 {
    "application/json": {};
}
export interface Response$updateIssueTypeScreenScheme$Status$400 {
}
export interface Response$updateIssueTypeScreenScheme$Status$403 {
}
export interface Response$updateIssueTypeScreenScheme$Status$404 {
}
export interface Parameter$deleteIssueTypeScreenScheme {
    /** The ID of the issue type screen scheme. */
    issueTypeScreenSchemeId: string;
}
export interface Response$deleteIssueTypeScreenScheme$Status$204 {
    "application/json": {};
}
export interface Response$deleteIssueTypeScreenScheme$Status$400 {
}
export interface Response$deleteIssueTypeScreenScheme$Status$404 {
}
export interface Parameter$appendMappingsForIssueTypeScreenScheme {
    /** The ID of the issue type screen scheme. */
    issueTypeScreenSchemeId: string;
}
export interface RequestBody$appendMappingsForIssueTypeScreenScheme {
    "application/json": Schemas.IssueTypeScreenSchemeMappingDetails;
}
export interface Response$appendMappingsForIssueTypeScreenScheme$Status$204 {
    "application/json": {};
}
export interface Response$appendMappingsForIssueTypeScreenScheme$Status$400 {
}
export interface Response$appendMappingsForIssueTypeScreenScheme$Status$404 {
}
export interface Response$appendMappingsForIssueTypeScreenScheme$Status$409 {
}
export interface Parameter$updateDefaultScreenScheme {
    /** The ID of the issue type screen scheme. */
    issueTypeScreenSchemeId: string;
}
export interface RequestBody$updateDefaultScreenScheme {
    "application/json": Schemas.UpdateDefaultScreenScheme;
}
export interface Response$updateDefaultScreenScheme$Status$204 {
    "application/json": {};
}
export interface Response$updateDefaultScreenScheme$Status$400 {
}
export interface Response$updateDefaultScreenScheme$Status$403 {
}
export interface Response$updateDefaultScreenScheme$Status$404 {
}
export interface Parameter$removeMappingsFromIssueTypeScreenScheme {
    /** The ID of the issue type screen scheme. */
    issueTypeScreenSchemeId: string;
}
export interface RequestBody$removeMappingsFromIssueTypeScreenScheme {
    "application/json": Schemas.IssueTypeIds;
}
export interface Response$removeMappingsFromIssueTypeScreenScheme$Status$204 {
    "application/json": {};
}
export interface Response$removeMappingsFromIssueTypeScreenScheme$Status$400 {
}
export interface Response$removeMappingsFromIssueTypeScreenScheme$Status$403 {
}
export interface Response$removeMappingsFromIssueTypeScreenScheme$Status$404 {
}
export interface Parameter$getProjectsForIssueTypeScreenScheme {
    /** The ID of the issue type screen scheme. */
    issueTypeScreenSchemeId: number;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getProjectsForIssueTypeScreenScheme$Status$200 {
    "application/json": Schemas.PageBeanProjectDetails;
}
export interface Response$getAutoComplete$Status$200 {
    "application/json": Schemas.JQLReferenceData;
}
export interface RequestBody$getAutoCompletePost {
    "application/json": Schemas.SearchAutoCompleteFilter;
}
export interface Response$getAutoCompletePost$Status$200 {
    "application/json": Schemas.JQLReferenceData;
}
export interface Parameter$getFieldAutoCompleteForQueryString {
    /** The name of the field. */
    fieldName?: string;
    /** The partial field item name entered by the user. */
    fieldValue?: string;
    /** The name of the [ CHANGED operator predicate](https://confluence.atlassian.com/x/hQORLQ#Advancedsearching-operatorsreference-CHANGEDCHANGED) for which the suggestions are generated. The valid predicate operators are *by*, *from*, and *to*. */
    predicateName?: string;
    /** The partial predicate item name entered by the user. */
    predicateValue?: string;
}
export interface Response$getFieldAutoCompleteForQueryString$Status$200 {
    "application/json": Schemas.AutoCompleteSuggestions;
}
export interface RequestBody$matchIssues {
    "application/json": Schemas.IssuesAndJQLQueries;
}
export interface Response$matchIssues$Status$200 {
    "application/json": Schemas.IssueMatches;
}
export interface Parameter$parseJqlQueries {
    /**
     * How to validate the JQL query and treat the validation results. Validation options include:
     *
     *  *  `strict` Returns all errors. If validation fails, the query structure is not returned.
     *  *  `warn` Returns all errors. If validation fails but the JQL query is correctly formed, the query structure is returned.
     *  *  `none` No validation is performed. If JQL query is correctly formed, the query structure is returned.
     */
    validation?: "strict" | "warn" | "none";
}
export interface RequestBody$parseJqlQueries {
    "application/json": Schemas.JqlQueriesToParse;
}
export interface Response$parseJqlQueries$Status$200 {
    "application/json": Schemas.ParsedJqlQueries;
}
export interface Response$parseJqlQueries$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$migrateQueries {
    "application/json": Schemas.JQLPersonalDataMigrationRequest;
}
export interface Response$migrateQueries$Status$200 {
    "application/json": Schemas.ConvertedJQLQueries;
}
export interface Parameter$getAllLabels {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getAllLabels$Status$200 {
    "application/json": Schemas.PageBeanString;
}
export interface Parameter$getMyPermissions {
    /** The key of project. Ignored if `projectId` is provided. */
    projectKey?: string;
    /** The ID of project. */
    projectId?: string;
    /** The key of the issue. Ignored if `issueId` is provided. */
    issueKey?: string;
    /** The ID of the issue. */
    issueId?: string;
    /** A list of permission keys. (Required) This parameter accepts a comma-separated list. To get the list of available permissions, use [Get all permissions](#api-rest-api-3-permissions-get). */
    permissions?: string;
    projectUuid?: string;
    projectConfigurationUuid?: string;
}
export interface Response$getMyPermissions$Status$200 {
    "application/json": Schemas.Permissions;
}
export interface Response$getMyPermissions$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getMyPermissions$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getMyPermissions$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getPreference {
    /** The key of the preference. */
    key: string;
}
export interface Response$getPreference$Status$200 {
    "application/json": string;
}
export interface Parameter$setPreference {
    /** The key of the preference. The maximum length is 255 characters. */
    key: string;
}
export interface RequestBody$setPreference {
    "application/json": string;
    "text/plain": string;
}
export interface Response$setPreference$Status$204 {
    "application/json": {};
}
export interface Parameter$removePreference {
    /** The key of the preference. */
    key: string;
}
export interface Response$getLocale$Status$200 {
    "application/json": Schemas.Locale;
}
export interface RequestBody$setLocale {
    "application/json": Schemas.Locale;
}
export interface Response$setLocale$Status$204 {
    "application/json": {};
}
export interface Response$deleteLocale$Status$204 {
    "application/json": {};
}
export interface Parameter$getCurrentUser {
    /**
     * Use [expand](#expansion) to include additional information about user in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `groups` Returns all groups, including nested groups, the user belongs to.
     *  *  `applicationRoles` Returns the application roles the user is assigned to.
     */
    expand?: string;
}
export interface Response$getCurrentUser$Status$200 {
    "application/json": Schemas.User;
}
export interface Parameter$getNotificationSchemes {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about any custom fields assigned to receive an event.
     *  *  `group` Returns information about any groups assigned to receive an event.
     *  *  `notificationSchemeEvents` Returns a list of event associations. This list is returned for all expandable information.
     *  *  `projectRole` Returns information about any project roles assigned to receive an event.
     *  *  `user` Returns information about any users assigned to receive an event.
     */
    expand?: string;
}
export interface Response$getNotificationSchemes$Status$200 {
    "application/json": Schemas.PageBeanNotificationScheme;
}
export interface Parameter$getNotificationScheme {
    /** The ID of the notification scheme. Use [Get notification schemes paginated](#api-rest-api-3-notificationscheme-get) to get a list of notification scheme IDs. */
    id: number;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about any custom fields assigned to receive an event.
     *  *  `group` Returns information about any groups assigned to receive an event.
     *  *  `notificationSchemeEvents` Returns a list of event associations. This list is returned for all expandable information.
     *  *  `projectRole` Returns information about any project roles assigned to receive an event.
     *  *  `user` Returns information about any users assigned to receive an event.
     */
    expand?: string;
}
export interface Response$getNotificationScheme$Status$200 {
    "application/json": Schemas.NotificationScheme;
}
export interface Response$getAllPermissions$Status$200 {
    "application/json": Schemas.Permissions;
}
export interface RequestBody$getBulkPermissions {
    "application/json": Schemas.BulkPermissionsRequestBean;
}
export interface Response$getBulkPermissions$Status$200 {
    "application/json": Schemas.BulkPermissionGrants;
}
export interface Response$getBulkPermissions$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getBulkPermissions$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$getPermittedProjects {
    "application/json": Schemas.PermissionsKeysBean;
}
export interface Response$getPermittedProjects$Status$200 {
    "application/json": Schemas.PermittedProjects;
}
export interface Response$getPermittedProjects$Status$400 {
}
export interface Parameter$getAllPermissionSchemes {
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface Response$getAllPermissionSchemes$Status$200 {
    "application/json": Schemas.PermissionSchemes;
}
export interface Parameter$createPermissionScheme {
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface RequestBody$createPermissionScheme {
    "application/json": Schemas.PermissionScheme;
}
export interface Response$createPermissionScheme$Status$201 {
    "application/json": Schemas.PermissionScheme;
}
export interface Parameter$getPermissionScheme {
    /** The ID of the permission scheme to return. */
    schemeId: number;
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface Response$getPermissionScheme$Status$200 {
    "application/json": Schemas.PermissionScheme;
}
export interface Parameter$updatePermissionScheme {
    /** The ID of the permission scheme to update. */
    schemeId: number;
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface RequestBody$updatePermissionScheme {
    "application/json": Schemas.PermissionScheme;
}
export interface Response$updatePermissionScheme$Status$200 {
    "application/json": Schemas.PermissionScheme;
}
export interface Parameter$deletePermissionScheme {
    /** The ID of the permission scheme being deleted. */
    schemeId: number;
}
export interface Parameter$getPermissionSchemeGrants {
    /** The ID of the permission scheme. */
    schemeId: number;
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
     *
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `user` Returns information about the user who is granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `all` Returns all expandable information.
     */
    expand?: string;
}
export interface Response$getPermissionSchemeGrants$Status$200 {
    "application/json": Schemas.PermissionGrants;
}
export interface Parameter$createPermissionGrant {
    /** The ID of the permission scheme in which to create a new permission grant. */
    schemeId: number;
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
     *
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `user` Returns information about the user who is granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `all` Returns all expandable information.
     */
    expand?: string;
}
export interface RequestBody$createPermissionGrant {
    "application/json": Schemas.PermissionGrant;
}
export interface Response$createPermissionGrant$Status$201 {
    "application/json": Schemas.PermissionGrant;
}
export interface Parameter$getPermissionSchemeGrant {
    /** The ID of the permission scheme. */
    schemeId: number;
    /** The ID of the permission grant. */
    permissionId: number;
    /**
     * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface Response$getPermissionSchemeGrant$Status$200 {
    "application/json": Schemas.PermissionGrant;
}
export interface Parameter$deletePermissionSchemeEntity {
    /** The ID of the permission scheme to delete the permission grant from. */
    schemeId: number;
    /** The ID of the permission grant to delete. */
    permissionId: number;
}
export interface Response$getPriorities$Status$200 {
    "application/json": Schemas.Priority[];
}
export interface Parameter$getPriority {
    /** The ID of the issue priority. */
    id: string;
}
export interface Response$getPriority$Status$200 {
    "application/json": Schemas.Priority;
}
export interface Parameter$getAllProjects {
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expanded options include:
     *
     *  *  `description` Returns the project description.
     *  *  `issueTypes` Returns all issue types associated with the project.
     *  *  `lead` Returns information about the project lead.
     *  *  `projectKeys` Returns all project keys associated with the project.
     */
    expand?: string;
    /** Returns the user's most recently accessed projects. You may specify the number of results to return up to a maximum of 20. If access is anonymous, then the recently accessed projects are based on the current HTTP session. */
    recent?: number;
    /** A list of project properties to return for the project. This parameter accepts a comma-separated list. */
    properties?: string[];
}
export interface Response$getAllProjects$Status$200 {
    "application/json": Schemas.Project[];
}
export interface RequestBody$createProject {
    "application/json": Schemas.CreateProjectDetails;
}
export interface Response$createProject$Status$201 {
    "application/json": Schemas.ProjectIdentifiers;
}
export interface Parameter$getRecent {
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expanded options include:
     *
     *  *  `description` Returns the project description.
     *  *  `projectKeys` Returns all project keys associated with a project.
     *  *  `lead` Returns information about the project lead.
     *  *  `issueTypes` Returns all issue types associated with the project.
     *  *  `url` Returns the URL associated with the project.
     *  *  `permissions` Returns the permissions associated with the project.
     *  *  `insight` EXPERIMENTAL. Returns the insight details of total issue count and last issue update time for the project.
     *  *  `*` Returns the project with all available expand options.
     */
    expand?: string;
    /** EXPERIMENTAL. A list of project properties to return for the project. This parameter accepts a comma-separated list. Invalid property names are ignored. */
    properties?: Schemas.StringList[];
}
export interface Response$getRecent$Status$200 {
    "application/json": Schemas.Project[];
}
export interface Parameter$searchProjects {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * [Order](#ordering) the results by a field.
     *
     *  *  `category` Sorts by project category. A complete list of category IDs is found using [Get all project categories](#api-rest-api-3-projectCategory-get).
     *  *  `issueCount` Sorts by the total number of issues in each project.
     *  *  `key` Sorts by project key.
     *  *  `lastIssueUpdatedTime` Sorts by the last issue update time.
     *  *  `name` Sorts by project name.
     *  *  `owner` Sorts by project lead.
     *  *  `archivedDate` EXPERIMENTAL. Sorts by project archived date.
     *  *  `deletedDate` EXPERIMENTAL. Sorts by project deleted date.
     */
    orderBy?: "category" | "-category" | "+category" | "key" | "-key" | "+key" | "name" | "-name" | "+name" | "owner" | "-owner" | "+owner" | "issueCount" | "-issueCount" | "+issueCount" | "lastIssueUpdatedDate" | "-lastIssueUpdatedDate" | "+lastIssueUpdatedDate" | "archivedDate" | "+archivedDate" | "-archivedDate" | "deletedDate" | "+deletedDate" | "-deletedDate";
    /** The project IDs to filter the results by. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. Up to 50 project IDs can be provided. */
    id?: number[];
    /** The project keys to filter the results by. To include multiple keys, provide an ampersand-separated list. For example, `keys=PA&keys=PB`. Up to 50 project keys can be provided. */
    keys?: string[];
    /** Filter the results using a literal string. Projects with a matching `key` or `name` are returned (case insensitive). */
    query?: string;
    /** Orders results by the [project type](https://confluence.atlassian.com/x/GwiiLQ#Jiraapplicationsoverview-Productfeaturesandprojecttypes). This parameter accepts a comma-separated list. Valid values are `business`, `service_desk`, and `software`. */
    typeKey?: string;
    /** The ID of the project's category. A complete list of category IDs is found using the [Get all project categories](#api-rest-api-3-projectCategory-get) operation. */
    categoryId?: number;
    /**
     * Filter results by projects for which the user can:
     *
     *  *  `view` the project, meaning that they have one of the following permissions:
     *
     *      *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *      *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *      *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  `browse` the project, meaning that they have the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  `edit` the project, meaning that they have one of the following permissions:
     *
     *      *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *      *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    action?: "view" | "browse" | "edit";
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expanded options include:
     *
     *  *  `description` Returns the project description.
     *  *  `projectKeys` Returns all project keys associated with a project.
     *  *  `lead` Returns information about the project lead.
     *  *  `issueTypes` Returns all issue types associated with the project.
     *  *  `url` Returns the URL associated with the project.
     *  *  `insight` EXPERIMENTAL. Returns the insight details of total issue count and last issue update time for the project.
     */
    expand?: string;
    /**
     * EXPERIMENTAL. Filter results by project status:
     *
     *  *  `live` Search live projects.
     *  *  `archived` Search archived projects.
     *  *  `deleted` Search deleted projects, those in the recycle bin.
     */
    status?: ("live" | "archived" | "deleted")[];
    /** EXPERIMENTAL. A list of project properties to return for the project. This parameter accepts a comma-separated list. */
    properties?: Schemas.StringList[];
    /** EXPERIMENTAL. A query string used to search properties. The query string cannot be specified using a JSON object. For example, to search for the value of `nested` from `{"something":{"nested":1,"other":2}}` use `[thepropertykey].something.nested=1`. Note that the propertyQuery key is enclosed in square brackets to enable searching where the propertyQuery key includes dot (.) or equals (=) characters. Note that `thepropertykey` is only returned when included in `properties`. */
    propertyQuery?: string;
}
export interface Response$searchProjects$Status$200 {
    "application/json": Schemas.PageBeanProject;
}
export interface Response$getAllProjectTypes$Status$200 {
    "application/json": Schemas.ProjectType[];
}
export interface Response$getAllAccessibleProjectTypes$Status$200 {
    "application/json": Schemas.ProjectType[];
}
export interface Parameter$getProjectTypeByKey {
    /** The key of the project type. */
    projectTypeKey: "software" | "service_desk" | "business" | "product_discovery";
}
export interface Response$getProjectTypeByKey$Status$200 {
    "application/json": Schemas.ProjectType;
}
export interface Parameter$getAccessibleProjectTypeByKey {
    /** The key of the project type. */
    projectTypeKey: "software" | "service_desk" | "business" | "product_discovery";
}
export interface Response$getAccessibleProjectTypeByKey$Status$200 {
    "application/json": Schemas.ProjectType;
}
export interface Parameter$getProject {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that the project description, issue types, and project lead are included in all responses by default. Expand options include:
     *
     *  *  `description` The project description.
     *  *  `issueTypes` The issue types associated with the project.
     *  *  `lead` The project lead.
     *  *  `projectKeys` All project keys associated with the project.
     *  *  `issueTypeHierarchy` The project issue type hierarchy.
     */
    expand?: string;
    /** A list of project properties to return for the project. This parameter accepts a comma-separated list. */
    properties?: string[];
}
export interface Response$getProject$Status$200 {
    "application/json": Schemas.Project;
}
export interface Parameter$updateProject {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that the project description, issue types, and project lead are included in all responses by default. Expand options include:
     *
     *  *  `description` The project description.
     *  *  `issueTypes` The issue types associated with the project.
     *  *  `lead` The project lead.
     *  *  `projectKeys` All project keys associated with the project.
     */
    expand?: string;
}
export interface RequestBody$updateProject {
    "application/json": Schemas.UpdateProjectDetails;
}
export interface Response$updateProject$Status$200 {
    "application/json": Schemas.Project;
}
export interface Parameter$deleteProject {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** Whether this project is placed in the Jira recycle bin where it will be available for restoration. */
    enableUndo?: boolean;
}
export interface Parameter$archiveProject {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$archiveProject$Status$204 {
    "application/json": {};
}
export interface Parameter$updateProjectAvatar {
    /** The ID or (case-sensitive) key of the project. */
    projectIdOrKey: string;
}
export interface RequestBody$updateProjectAvatar {
    "application/json": Schemas.Avatar;
}
export interface Response$updateProjectAvatar$Status$204 {
    "application/json": {};
}
export interface Parameter$deleteProjectAvatar {
    /** The project ID or (case-sensitive) key. */
    projectIdOrKey: string;
    /** The ID of the avatar. */
    id: number;
}
export interface Parameter$createProjectAvatar {
    /** The ID or (case-sensitive) key of the project. */
    projectIdOrKey: string;
    /** The X coordinate of the top-left corner of the crop region. */
    x?: number;
    /** The Y coordinate of the top-left corner of the crop region. */
    y?: number;
    /** The length of each side of the crop region. */
    size?: number;
}
export interface RequestBody$createProjectAvatar {
    "*/*": {};
}
export interface Response$createProjectAvatar$Status$201 {
    "application/json": Schemas.Avatar;
}
export interface Parameter$getAllProjectAvatars {
    /** The ID or (case-sensitive) key of the project. */
    projectIdOrKey: string;
}
export interface Response$getAllProjectAvatars$Status$200 {
    "application/json": Schemas.ProjectAvatars;
}
export interface Parameter$getProjectComponentsPaginated {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * [Order](#ordering) the results by a field:
     *
     *  *  `description` Sorts by the component description.
     *  *  `issueCount` Sorts by the count of issues associated with the component.
     *  *  `lead` Sorts by the user key of the component's project lead.
     *  *  `name` Sorts by component name.
     */
    orderBy?: "description" | "-description" | "+description" | "issueCount" | "-issueCount" | "+issueCount" | "lead" | "-lead" | "+lead" | "name" | "-name" | "+name";
    /** Filter the results using a literal string. Components with a matching `name` or `description` are returned (case insensitive). */
    query?: string;
}
export interface Response$getProjectComponentsPaginated$Status$200 {
    "application/json": Schemas.PageBeanComponentWithIssueCount;
}
export interface Parameter$getProjectComponents {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$getProjectComponents$Status$200 {
    "application/json": Schemas.ProjectComponent[];
}
export interface Parameter$deleteProjectAsynchronously {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$deleteProjectAsynchronously$Status$303 {
    "application/json": Schemas.TaskProgressBeanObject;
}
export interface Parameter$getFeaturesForProject {
    /** The ID or (case-sensitive) key of the project. */
    projectIdOrKey: string;
}
export interface Response$getFeaturesForProject$Status$200 {
    "application/json": Schemas.ContainerForProjectFeatures;
}
export interface Parameter$toggleFeatureForProject {
    /** The ID or (case-sensitive) key of the project. */
    projectIdOrKey: string;
    /** The key of the feature. */
    featureKey: string;
}
export interface RequestBody$toggleFeatureForProject {
    "application/json": Schemas.ProjectFeatureState;
}
export interface Response$toggleFeatureForProject$Status$200 {
    "application/json": Schemas.ContainerForProjectFeatures;
}
export interface Parameter$getProjectPropertyKeys {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$getProjectPropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getProjectProperty {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The project property key. Use [Get project property keys](#api-rest-api-3-project-projectIdOrKey-properties-get) to get a list of all project property keys. */
    propertyKey: string;
}
export interface Response$getProjectProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setProjectProperty {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The key of the project property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setProjectProperty {
    "application/json": {};
}
export interface Response$setProjectProperty$Status$200 {
    "application/json": {};
}
export interface Response$setProjectProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteProjectProperty {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The project property key. Use [Get project property keys](#api-rest-api-3-project-projectIdOrKey-properties-get) to get a list of all project property keys. */
    propertyKey: string;
}
export interface Parameter$restore {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$restore$Status$200 {
    "application/json": Schemas.Project;
}
export interface Parameter$getProjectRoles {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$getProjectRoles$Status$200 {
    "application/json": {
        [key: string]: string;
    };
}
export interface Parameter$getProjectRole {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface Response$getProjectRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$setActors {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface RequestBody$setActors {
    "application/json": Schemas.ProjectRoleActorsUpdateBean;
}
export interface Response$setActors$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$addActorUsers {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface RequestBody$addActorUsers {
    "application/json": Schemas.ActorsMap;
}
export interface Response$addActorUsers$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$deleteActor {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
    /** The user account ID of the user to remove from the project role. */
    user?: string;
    /** The name of the group to remove from the project role. */
    group?: string;
}
export interface Parameter$getProjectRoleDetails {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** Whether the roles should be filtered to include only those the user is assigned to. */
    currentMember?: boolean;
    excludeConnectAddons?: boolean;
}
export interface Response$getProjectRoleDetails$Status$200 {
    "application/json": Schemas.ProjectRoleDetails[];
}
export interface Parameter$getAllStatuses {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
}
export interface Response$getAllStatuses$Status$200 {
    "application/json": Schemas.IssueTypeWithStatus[];
}
export interface Parameter$updateProjectType {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The key of the new project type. */
    newProjectTypeKey: "software" | "service_desk" | "business";
}
export interface Response$updateProjectType$Status$200 {
    "application/json": Schemas.Project;
}
export interface Parameter$getProjectVersionsPaginated {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /**
     * [Order](#ordering) the results by a field:
     *
     *  *  `description` Sorts by version description.
     *  *  `name` Sorts by version name.
     *  *  `releaseDate` Sorts by release date, starting with the oldest date. Versions with no release date are listed last.
     *  *  `sequence` Sorts by the order of appearance in the user interface.
     *  *  `startDate` Sorts by start date, starting with the oldest date. Versions with no start date are listed last.
     */
    orderBy?: "description" | "-description" | "+description" | "name" | "-name" | "+name" | "releaseDate" | "-releaseDate" | "+releaseDate" | "sequence" | "-sequence" | "+sequence" | "startDate" | "-startDate" | "+startDate";
    /** Filter the results using a literal string. Versions with matching `name` or `description` are returned (case insensitive). */
    query?: string;
    /** A list of status values used to filter the results by version status. This parameter accepts a comma-separated list. The status values are `released`, `unreleased`, and `archived`. */
    status?: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `issuesstatus` Returns the number of issues in each status category for each version.
     *  *  `operations` Returns actions that can be performed on the specified version.
     */
    expand?: string;
}
export interface Response$getProjectVersionsPaginated$Status$200 {
    "application/json": Schemas.PageBeanVersion;
}
export interface Parameter$getProjectVersions {
    /** The project ID or project key (case sensitive). */
    projectIdOrKey: string;
    /** Use [expand](#expansion) to include additional information in the response. This parameter accepts `operations`, which returns actions that can be performed on the version. */
    expand?: string;
}
export interface Response$getProjectVersions$Status$200 {
    "application/json": Schemas.Version[];
}
export interface Parameter$getProjectEmail {
    /** The project ID. */
    projectId: number;
}
export interface Response$getProjectEmail$Status$200 {
    "application/json": Schemas.ProjectEmailAddress;
}
export interface Parameter$updateProjectEmail {
    /** The project ID. */
    projectId: number;
}
export interface RequestBody$updateProjectEmail {
    "application/json": Schemas.ProjectEmailAddress;
}
export interface Response$updateProjectEmail$Status$204 {
    "application/json": {};
}
export interface Parameter$getHierarchy {
    /** The ID of the project. */
    projectId: number;
}
export interface Response$getHierarchy$Status$200 {
    "application/json": Schemas.ProjectIssueTypeHierarchy;
}
export interface Parameter$getProjectIssueSecurityScheme {
    /** The project ID or project key (case sensitive). */
    projectKeyOrId: string;
}
export interface Response$getProjectIssueSecurityScheme$Status$200 {
    "application/json": Schemas.SecurityScheme;
}
export interface Parameter$getNotificationSchemeForProject {
    /** The project ID or project key (case sensitive). */
    projectKeyOrId: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about any custom fields assigned to receive an event.
     *  *  `group` Returns information about any groups assigned to receive an event.
     *  *  `notificationSchemeEvents` Returns a list of event associations. This list is returned for all expandable information.
     *  *  `projectRole` Returns information about any project roles assigned to receive an event.
     *  *  `user` Returns information about any users assigned to receive an event.
     */
    expand?: string;
}
export interface Response$getNotificationSchemeForProject$Status$200 {
    "application/json": Schemas.NotificationScheme;
}
export interface Parameter$getAssignedPermissionScheme {
    /** The project ID or project key (case sensitive). */
    projectKeyOrId: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface Response$getAssignedPermissionScheme$Status$200 {
    "application/json": Schemas.PermissionScheme;
}
export interface Parameter$assignPermissionScheme {
    /** The project ID or project key (case sensitive). */
    projectKeyOrId: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
     *
     *  *  `all` Returns all expandable information.
     *  *  `field` Returns information about the custom field granted the permission.
     *  *  `group` Returns information about the group that is granted the permission.
     *  *  `permissions` Returns all permission grants for each permission scheme.
     *  *  `projectRole` Returns information about the project role granted the permission.
     *  *  `user` Returns information about the user who is granted the permission.
     */
    expand?: string;
}
export interface RequestBody$assignPermissionScheme {
    "application/json": Schemas.IdBean;
}
export interface Response$assignPermissionScheme$Status$200 {
    "application/json": Schemas.PermissionScheme;
}
export interface Parameter$getSecurityLevelsForProject {
    /** The project ID or project key (case sensitive). */
    projectKeyOrId: string;
}
export interface Response$getSecurityLevelsForProject$Status$200 {
    "application/json": Schemas.ProjectIssueSecurityLevels;
}
export interface Response$getAllProjectCategories$Status$200 {
    "application/json": Schemas.ProjectCategory[];
}
export interface RequestBody$createProjectCategory {
    "application/json": Schemas.ProjectCategory;
}
export interface Response$createProjectCategory$Status$201 {
    "application/json": Schemas.ProjectCategory;
}
export interface Parameter$getProjectCategoryById {
    /** The ID of the project category. */
    id: number;
}
export interface Response$getProjectCategoryById$Status$200 {
    "application/json": Schemas.ProjectCategory;
}
export interface Parameter$updateProjectCategory {
    id: number;
}
export interface RequestBody$updateProjectCategory {
    "application/json": Schemas.ProjectCategory;
}
export interface Response$updateProjectCategory$Status$200 {
    "application/json": Schemas.UpdatedProjectCategory;
}
export interface Parameter$removeProjectCategory {
    /** ID of the project category to delete. */
    id: number;
}
export interface Parameter$validateProjectKey {
    /** The project key. */
    key?: string;
}
export interface Response$validateProjectKey$Status$200 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getValidProjectKey {
    /** The project key. */
    key?: string;
}
export interface Response$getValidProjectKey$Status$200 {
    "application/json": string;
}
export interface Parameter$getValidProjectName {
    /** The project name. */
    name: string;
}
export interface Response$getValidProjectName$Status$200 {
    "application/json": string;
}
export interface Response$getResolutions$Status$200 {
    "application/json": Schemas.Resolution[];
}
export interface Parameter$getResolution {
    /** The ID of the issue resolution value. */
    id: string;
}
export interface Response$getResolution$Status$200 {
    "application/json": Schemas.Resolution;
}
export interface Response$getAllProjectRoles$Status$200 {
    "application/json": Schemas.ProjectRole[];
}
export interface RequestBody$createProjectRole {
    "application/json": Schemas.CreateUpdateRoleRequestBean;
}
export interface Response$createProjectRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$getProjectRoleById {
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface Response$getProjectRoleById$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$fullyUpdateProjectRole {
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface RequestBody$fullyUpdateProjectRole {
    "application/json": Schemas.CreateUpdateRoleRequestBean;
}
export interface Response$fullyUpdateProjectRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$partialUpdateProjectRole {
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface RequestBody$partialUpdateProjectRole {
    "application/json": Schemas.CreateUpdateRoleRequestBean;
}
export interface Response$partialUpdateProjectRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$deleteProjectRole {
    /** The ID of the project role to delete. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
    /** The ID of the project role that will replace the one being deleted. */
    swap?: number;
}
export interface Parameter$getProjectRoleActorsForRole {
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface Response$getProjectRoleActorsForRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$addProjectRoleActorsToRole {
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
}
export interface RequestBody$addProjectRoleActorsToRole {
    "application/json": Schemas.ActorInputBean;
}
export interface Response$addProjectRoleActorsToRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$deleteProjectRoleActorsFromRole {
    /** The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs. */
    id: number;
    /** The user account ID of the user to remove as a default actor. */
    user?: string;
    /** The group name of the group to be removed as a default actor. */
    group?: string;
}
export interface Response$deleteProjectRoleActorsFromRole$Status$200 {
    "application/json": Schemas.ProjectRole;
}
export interface Parameter$getScreens {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of screen IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
}
export interface Response$getScreens$Status$200 {
    "application/json": Schemas.PageBeanScreen;
}
export interface RequestBody$createScreen {
    "application/json": Schemas.ScreenDetails;
}
export interface Response$createScreen$Status$201 {
    "application/json": Schemas.Screen;
}
export interface Response$createScreen$Status$400 {
}
export interface Response$createScreen$Status$403 {
}
export interface Parameter$addFieldToDefaultScreen {
    /** The ID of the field. */
    fieldId: string;
}
export interface Response$addFieldToDefaultScreen$Status$200 {
    "application/json": {};
}
export interface Parameter$updateScreen {
    /** The ID of the screen. */
    screenId: number;
}
export interface RequestBody$updateScreen {
    "application/json": Schemas.UpdateScreenDetails;
}
export interface Response$updateScreen$Status$200 {
    "application/json": Schemas.Screen;
}
export interface Response$updateScreen$Status$400 {
}
export interface Response$updateScreen$Status$403 {
}
export interface Response$updateScreen$Status$404 {
}
export interface Parameter$deleteScreen {
    /** The ID of the screen. */
    screenId: number;
}
export interface Response$deleteScreen$Status$400 {
}
export interface Response$deleteScreen$Status$403 {
}
export interface Response$deleteScreen$Status$404 {
}
export interface Parameter$getAvailableScreenFields {
    /** The ID of the screen. */
    screenId: number;
}
export interface Response$getAvailableScreenFields$Status$200 {
    "application/json": Schemas.ScreenableField[];
}
export interface Parameter$getAllScreenTabs {
    /** The ID of the screen. */
    screenId: number;
    /** The key of the project. */
    projectKey?: string;
}
export interface Response$getAllScreenTabs$Status$200 {
    "application/json": Schemas.ScreenableTab[];
}
export interface Parameter$addScreenTab {
    /** The ID of the screen. */
    screenId: number;
}
export interface RequestBody$addScreenTab {
    "application/json": Schemas.ScreenableTab;
}
export interface Response$addScreenTab$Status$200 {
    "application/json": Schemas.ScreenableTab;
}
export interface Parameter$renameScreenTab {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
}
export interface RequestBody$renameScreenTab {
    "application/json": Schemas.ScreenableTab;
}
export interface Response$renameScreenTab$Status$200 {
    "application/json": Schemas.ScreenableTab;
}
export interface Parameter$deleteScreenTab {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
}
export interface Parameter$getAllScreenTabFields {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
    /** The key of the project. */
    projectKey?: string;
}
export interface Response$getAllScreenTabFields$Status$200 {
    "application/json": Schemas.ScreenableField[];
}
export interface Parameter$addScreenTabField {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
}
export interface RequestBody$addScreenTabField {
    "application/json": Schemas.AddFieldBean;
}
export interface Response$addScreenTabField$Status$200 {
    "application/json": Schemas.ScreenableField;
}
export interface Parameter$removeScreenTabField {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
    /** The ID of the field. */
    id: string;
}
export interface Parameter$moveScreenTabField {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
    /** The ID of the field. */
    id: string;
}
export interface RequestBody$moveScreenTabField {
    "application/json": Schemas.MoveFieldBean;
}
export interface Response$moveScreenTabField$Status$204 {
    "application/json": {};
}
export interface Parameter$moveScreenTab {
    /** The ID of the screen. */
    screenId: number;
    /** The ID of the screen tab. */
    tabId: number;
    /** The position of tab. The base index is 0. */
    pos: number;
}
export interface Response$moveScreenTab$Status$204 {
    "application/json": {};
}
export interface Parameter$getScreenSchemes {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The list of screen scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. */
    id?: number[];
}
export interface Response$getScreenSchemes$Status$200 {
    "application/json": Schemas.PageBeanScreenScheme;
}
export interface RequestBody$createScreenScheme {
    "application/json": Schemas.ScreenSchemeDetails;
}
export interface Response$createScreenScheme$Status$201 {
    "application/json": Schemas.ScreenSchemeId;
}
export interface Response$createScreenScheme$Status$400 {
}
export interface Response$createScreenScheme$Status$403 {
}
export interface Response$createScreenScheme$Status$404 {
}
export interface Parameter$updateScreenScheme {
    /** The ID of the screen scheme. */
    screenSchemeId: string;
}
export interface RequestBody$updateScreenScheme {
    "application/json": Schemas.UpdateScreenSchemeDetails;
}
export interface Response$updateScreenScheme$Status$204 {
    "application/json": {};
}
export interface Response$updateScreenScheme$Status$400 {
}
export interface Response$updateScreenScheme$Status$403 {
}
export interface Response$updateScreenScheme$Status$404 {
}
export interface Parameter$deleteScreenScheme {
    /** The ID of the screen scheme. */
    screenSchemeId: string;
}
export interface Response$deleteScreenScheme$Status$400 {
}
export interface Response$deleteScreenScheme$Status$403 {
}
export interface Response$deleteScreenScheme$Status$404 {
}
export interface Parameter$searchForIssuesUsingJql {
    /**
     * The [JQL](https://confluence.atlassian.com/x/egORLQ) that defines the search. Note:
     *
     *  *  If no JQL expression is provided, all issues are returned.
     *  *  `username` and `userkey` cannot be used as search terms due to privacy reasons. Use `accountId` instead.
     *  *  If a user has hidden their email address in their user profile, partial matches of the email address will not find the user. An exact match is required.
     */
    jql?: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. To manage page size, Jira may return fewer items per page where a large number of fields are requested. The greatest number of items returned per page is achieved when requesting `id` or `key` only. */
    maxResults?: number;
    /**
     * Determines how to validate the JQL query and treat the validation results. Supported values are:
     *
     *  *  `strict` Returns a 400 response code if any errors are found, along with a list of all errors (and warnings).
     *  *  `warn` Returns all errors as warnings.
     *  *  `none` No validation is performed.
     *  *  `true` *Deprecated* A legacy synonym for `strict`.
     *  *  `false` *Deprecated* A legacy synonym for `warn`.
     *
     * Note: If the JQL is not correctly formed a 400 response code is returned, regardless of the `validateQuery` value.
     */
    validateQuery?: "strict" | "warn" | "none" | "true" | "false";
    /**
     * A list of fields to return for each issue, use it to retrieve a subset of fields. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `*all` Returns all fields.
     *  *  `*navigable` Returns navigable fields.
     *  *  Any issue field, prefixed with a minus to exclude.
     *
     * Examples:
     *
     *  *  `summary,comment` Returns only the summary and comments fields.
     *  *  `-description` Returns all navigable (default) fields except description.
     *  *  `*all,-comment` Returns all fields except comments.
     *
     * This parameter may be specified multiple times. For example, `fields=field1,field2&fields=field3`.
     *
     * Note: All navigable fields are returned by default. This differs from [GET issue](#api-rest-api-3-issue-issueIdOrKey-get) where the default is all fields.
     */
    fields?: string[];
    /**
     * Use [expand](#expansion) to include additional information about issues in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `renderedFields` Returns field values rendered in HTML format.
     *  *  `names` Returns the display name of each field.
     *  *  `schema` Returns the schema describing a field type.
     *  *  `transitions` Returns all possible transitions for the issue.
     *  *  `operations` Returns all possible operations for the issue.
     *  *  `editmeta` Returns information about how each field can be edited.
     *  *  `changelog` Returns a list of recent updates to an issue, sorted by date, starting from the most recent.
     *  *  `versionedRepresentations` Instead of `fields`, returns `versionedRepresentations` a JSON array containing each version of a field's value, with the highest numbered item representing the most recent version.
     */
    expand?: string;
    /** A list of issue property keys for issue properties to include in the results. This parameter accepts a comma-separated list. Multiple properties can also be provided using an ampersand separated list. For example, `properties=prop1,prop2&properties=prop3`. A maximum of 5 issue property keys can be specified. */
    properties?: string[];
    /** Reference fields by their key (rather than ID). */
    fieldsByKeys?: boolean;
}
export interface Response$searchForIssuesUsingJql$Status$200 {
    "application/json": Schemas.SearchResults;
}
export interface RequestBody$searchForIssuesUsingJqlPost {
    "application/json": Schemas.SearchRequestBean;
}
export interface Response$searchForIssuesUsingJqlPost$Status$200 {
    "application/json": Schemas.SearchResults;
}
export interface Parameter$getIssueSecurityLevel {
    /** The ID of the issue security level. */
    id: string;
}
export interface Response$getIssueSecurityLevel$Status$200 {
    "application/json": Schemas.SecurityLevel;
}
export interface Response$getServerInfo$Status$200 {
    "application/json": Schemas.ServerInformation;
}
export interface Response$getIssueNavigatorDefaultColumns$Status$200 {
    "application/json": Schemas.ColumnItem[];
}
export interface RequestBody$setIssueNavigatorDefaultColumns {
    "*/*": string[];
    "multipart/form-data": string[];
}
export interface Response$setIssueNavigatorDefaultColumns$Status$200 {
    "application/json": {};
}
export interface Response$getStatuses$Status$200 {
    "application/json": Schemas.StatusDetails[];
}
export interface Parameter$getStatus {
    /** The ID or name of the status. */
    idOrName: string;
}
export interface Response$getStatus$Status$200 {
    "application/json": Schemas.StatusDetails;
}
export interface Response$getStatusCategories$Status$200 {
    "application/json": Schemas.StatusCategory[];
}
export interface Parameter$getStatusCategory {
    /** The ID or key of the status category. */
    idOrKey: string;
}
export interface Response$getStatusCategory$Status$200 {
    "application/json": Schemas.StatusCategory;
}
export interface Parameter$getTask {
    /** The ID of the task. */
    taskId: string;
}
export interface Response$getTask$Status$200 {
    "application/json": Schemas.TaskProgressBeanObject;
}
export interface Parameter$cancelTask {
    /** The ID of the task. */
    taskId: string;
}
export interface Response$cancelTask$Status$202 {
    "application/json": {};
}
export interface Response$cancelTask$Status$400 {
    "application/json": string[];
}
export interface Response$cancelTask$Status$401 {
    "application/json": string[];
}
export interface Response$cancelTask$Status$403 {
    "application/json": string[];
}
export interface Response$cancelTask$Status$404 {
    "application/json": string[];
}
export interface Parameter$getAvatars {
    /** The avatar type. */
    type: "project" | "issuetype";
    /** The ID of the item the avatar is associated with. */
    entityId: string;
}
export interface Response$getAvatars$Status$200 {
    "application/json": Schemas.Avatars;
}
export interface Parameter$storeAvatar {
    /** The avatar type. */
    type: "project" | "issuetype";
    /** The ID of the item the avatar is associated with. */
    entityId: string;
    /** The X coordinate of the top-left corner of the crop region. */
    x?: number;
    /** The Y coordinate of the top-left corner of the crop region. */
    y?: number;
    /** The length of each side of the crop region. */
    size: number;
}
export interface RequestBody$storeAvatar {
    "*/*": {};
}
export interface Response$storeAvatar$Status$201 {
    "application/json": Schemas.Avatar;
}
export interface Parameter$deleteAvatar {
    /** The avatar type. */
    type: "project" | "issuetype";
    /** The ID of the item the avatar is associated with. */
    owningObjectId: string;
    /** The ID of the avatar. */
    id: number;
}
export interface Parameter$getAvatarImageByType {
    /** The icon type of the avatar. */
    type: "issuetype" | "project";
    /** The size of the avatar image. If not provided the default size is returned. */
    size?: "xsmall" | "small" | "medium" | "large" | "xlarge";
    /** The format to return the avatar image in. If not provided the original content format is returned. */
    format?: "png" | "svg";
}
export interface Response$getAvatarImageByType$Status$200 {
    "application/json": {};
}
export interface Response$getAvatarImageByType$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByType$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByType$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getAvatarImageByID {
    /** The icon type of the avatar. */
    type: "issuetype" | "project";
    /** The ID of the avatar. */
    id: number;
    /** The size of the avatar image. If not provided the default size is returned. */
    size?: "xsmall" | "small" | "medium" | "large" | "xlarge";
    /** The format to return the avatar image in. If not provided the original content format is returned. */
    format?: "png" | "svg";
}
export interface Response$getAvatarImageByID$Status$200 {
    "application/json": {};
}
export interface Response$getAvatarImageByID$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByID$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByID$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByID$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getAvatarImageByOwner {
    /** The icon type of the avatar. */
    type: "issuetype" | "project";
    /** The ID of the project or issue type the avatar belongs to. */
    entityId: string;
    /** The size of the avatar image. If not provided the default size is returned. */
    size?: "xsmall" | "small" | "medium" | "large" | "xlarge";
    /** The format to return the avatar image in. If not provided the original content format is returned. */
    format?: "png" | "svg";
}
export interface Response$getAvatarImageByOwner$Status$200 {
    "application/json": {};
}
export interface Response$getAvatarImageByOwner$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByOwner$Status$401 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByOwner$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getAvatarImageByOwner$Status$404 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getUser {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Required. */
    accountId?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide) for details. */
    username?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide) for details. */
    key?: string;
    /**
     * Use [expand](#expansion) to include additional information about users in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `groups` includes all groups and nested groups to which the user belongs.
     *  *  `applicationRoles` includes details of all the applications to which the user has access.
     */
    expand?: string;
}
export interface Response$getUser$Status$200 {
    "application/json": Schemas.User;
}
export interface RequestBody$createUser {
    "application/json": Schemas.NewUserDetails;
}
export interface Response$createUser$Status$201 {
    "application/json": Schemas.User;
}
export interface Parameter$removeUser {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    key?: string;
}
export interface Parameter$findBulkAssignableUsers {
    /** A query string that is matched against user attributes, such as `displayName` and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` is specified. */
    query?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** A query string that is matched exactly against user `accountId`. Required, unless `query` is specified. */
    accountId?: string;
    /** A list of project keys (case sensitive). This parameter accepts a comma-separated list. */
    projectKeys: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$findBulkAssignableUsers$Status$200 {
    "application/json": Schemas.User[];
}
export interface Parameter$findAssignableUsers {
    /** A query string that is matched against user attributes, such as `displayName`, and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `username` or `accountId` is specified. */
    query?: string;
    /** The sessionId of this request. SessionId is the same until the assignee is set. */
    sessionId?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** A query string that is matched exactly against user `accountId`. Required, unless `query` is specified. */
    accountId?: string;
    /** The project ID or project key (case sensitive). Required, unless `issueKey` is specified. */
    project?: string;
    /** The key of the issue. Required, unless `project` is specified. */
    issueKey?: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return. This operation may return less than the maximum number of items even if more are available. The operation fetches users up to the maximum and then, from the fetched users, returns only the users that can be assigned to the issue. */
    maxResults?: number;
    /** The ID of the transition. */
    actionDescriptorId?: number;
    recommend?: boolean;
}
export interface Response$findAssignableUsers$Status$200 {
    "application/json": Schemas.User[];
}
export interface Parameter$bulkGetUsers {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string[];
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    key?: string[];
    /** The account ID of a user. To specify multiple users, pass multiple `accountId` parameters. For example, `accountId=5b10a2844c20165700ede21g&accountId=5b10ac8d82e05b22cc7d4ef5`. */
    accountId: string[];
}
export interface Response$bulkGetUsers$Status$200 {
    "application/json": Schemas.PageBeanUser;
}
export interface Parameter$bulkGetUsersMigration {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** Username of a user. To specify multiple users, pass multiple copies of this parameter. For example, `username=fred&username=barney`. Required if `key` isn't provided. Cannot be provided if `key` is present. */
    username?: string[];
    /** Key of a user. To specify multiple users, pass multiple copies of this parameter. For example, `key=fred&key=barney`. Required if `username` isn't provided. Cannot be provided if `username` is present. */
    key?: string[];
}
export interface Response$bulkGetUsersMigration$Status$200 {
    "application/json": Schemas.UserMigrationBean[];
}
export interface Parameter$getUserDefaultColumns {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
    /** This parameter is no longer available See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
}
export interface Response$getUserDefaultColumns$Status$200 {
    "application/json": Schemas.ColumnItem[];
}
export interface Parameter$setUserColumns {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
}
export interface RequestBody$setUserColumns {
    "*/*": string[];
    "multipart/form-data": string[];
}
export interface Response$setUserColumns$Status$200 {
    "application/json": {};
}
export interface Parameter$resetUserColumns {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
}
export interface Parameter$getUserEmail {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, `5b10ac8d82e05b22cc7d4ef5`. */
    accountId: string;
}
export interface Response$getUserEmail$Status$200 {
    "application/json": Schemas.UnrestrictedUserEmail;
}
export interface Parameter$getUserEmailBulk {
    /** The account IDs of the users for which emails are required. An `accountId` is an identifier that uniquely identifies the user across all Atlassian products. For example, `5b10ac8d82e05b22cc7d4ef5`. Note, this should be treated as an opaque identifier (that is, do not assume any structure in the value). */
    accountId: string[];
}
export interface Response$getUserEmailBulk$Status$200 {
    "application/json": Schemas.UnrestrictedUserEmail;
}
export interface Parameter$getUserGroups {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    key?: string;
}
export interface Response$getUserGroups$Status$200 {
    "application/json": Schemas.GroupName[];
}
export interface Parameter$findUsersWithAllPermissions {
    /** A query string that is matched against user attributes, such as `displayName` and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` is specified. */
    query?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** A query string that is matched exactly against user `accountId`. Required, unless `query` is specified. */
    accountId?: string;
    /**
     * A comma separated list of permissions. Permissions can be specified as any:
     *
     *  *  permission returned by [Get all permissions](#api-rest-api-3-permissions-get).
     *  *  custom project permission added by Connect apps.
     *  *  (deprecated) one of the following:
     *
     *      *  ASSIGNABLE\_USER
     *      *  ASSIGN\_ISSUE
     *      *  ATTACHMENT\_DELETE\_ALL
     *      *  ATTACHMENT\_DELETE\_OWN
     *      *  BROWSE
     *      *  CLOSE\_ISSUE
     *      *  COMMENT\_DELETE\_ALL
     *      *  COMMENT\_DELETE\_OWN
     *      *  COMMENT\_EDIT\_ALL
     *      *  COMMENT\_EDIT\_OWN
     *      *  COMMENT\_ISSUE
     *      *  CREATE\_ATTACHMENT
     *      *  CREATE\_ISSUE
     *      *  DELETE\_ISSUE
     *      *  EDIT\_ISSUE
     *      *  LINK\_ISSUE
     *      *  MANAGE\_WATCHER\_LIST
     *      *  MODIFY\_REPORTER
     *      *  MOVE\_ISSUE
     *      *  PROJECT\_ADMIN
     *      *  RESOLVE\_ISSUE
     *      *  SCHEDULE\_ISSUE
     *      *  SET\_ISSUE\_SECURITY
     *      *  TRANSITION\_ISSUE
     *      *  VIEW\_VERSION\_CONTROL
     *      *  VIEW\_VOTERS\_AND\_WATCHERS
     *      *  VIEW\_WORKFLOW\_READONLY
     *      *  WORKLOG\_DELETE\_ALL
     *      *  WORKLOG\_DELETE\_OWN
     *      *  WORKLOG\_EDIT\_ALL
     *      *  WORKLOG\_EDIT\_OWN
     *      *  WORK\_ISSUE
     */
    permissions: string;
    /** The issue key for the issue. */
    issueKey?: string;
    /** The project key for the project (case sensitive). */
    projectKey?: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$findUsersWithAllPermissions$Status$200 {
    "application/json": Schemas.User[];
}
export interface Parameter$findUsersForPicker {
    /** A query string that is matched against user attributes, such as `displayName`, and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. */
    query: string;
    /** The maximum number of items to return. The total number of matched users is returned in `total`. */
    maxResults?: number;
    /** Include the URI to the user's avatar. */
    showAvatar?: boolean;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    exclude?: string[];
    /** A list of account IDs to exclude from the search results. This parameter accepts a comma-separated list. Multiple account IDs can also be provided using an ampersand-separated list. For example, `excludeAccountIds=5b10a2844c20165700ede21g,5b10a0effa615349cb016cd8&excludeAccountIds=5b10ac8d82e05b22cc7d4ef5`. Cannot be provided with `exclude`. */
    excludeAccountIds?: string[];
    avatarSize?: string;
    excludeConnectUsers?: boolean;
}
export interface Response$findUsersForPicker$Status$200 {
    "application/json": Schemas.FoundUsers;
}
export interface Parameter$getUserPropertyKeys {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    userKey?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
}
export interface Response$getUserPropertyKeys$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Parameter$getUserProperty {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    userKey?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** The key of the user's property. */
    propertyKey: string;
}
export interface Response$getUserProperty$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Parameter$setUserProperty {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    userKey?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** The key of the user's property. The maximum length is 255 characters. */
    propertyKey: string;
}
export interface RequestBody$setUserProperty {
    "application/json": {};
}
export interface Response$setUserProperty$Status$200 {
    "application/json": {};
}
export interface Response$setUserProperty$Status$201 {
    "application/json": {};
}
export interface Parameter$deleteUserProperty {
    /** The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. */
    accountId?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    userKey?: string;
    /** This parameter is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** The key of the user's property. */
    propertyKey: string;
}
export interface Parameter$findUsers {
    /** A query string that is matched against user attributes ( `displayName`, and `emailAddress`) to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` or `property` is specified. */
    query?: string;
    username?: string;
    /** A query string that is matched exactly against a user `accountId`. Required, unless `query` or `property` is specified. */
    accountId?: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** A query string used to search properties. Property keys are specified by path, so property keys containing dot (.) or equals (=) characters cannot be used. The query string cannot be specified using a JSON object. Example: To search for the value of `nested` from `{"something":{"nested":1,"other":2}}` use `thepropertykey.something.nested=1`. Required, unless `accountId` or `query` is specified. */
    property?: string;
}
export interface Response$findUsers$Status$200 {
    "application/json": Schemas.User[];
}
export interface Parameter$findUsersByQuery {
    /** The search query. */
    query: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$findUsersByQuery$Status$200 {
    "application/json": Schemas.PageBeanUser;
}
export interface Parameter$findUserKeysByQuery {
    /** The search query. */
    query: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$findUserKeysByQuery$Status$200 {
    "application/json": Schemas.PageBeanUserKey;
}
export interface Parameter$findUsersWithBrowsePermission {
    /** A query string that is matched against user attributes, such as `displayName` and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` is specified. */
    query?: string;
    /** This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. */
    username?: string;
    /** A query string that is matched exactly against user `accountId`. Required, unless `query` is specified. */
    accountId?: string;
    /** The issue key for the issue. Required, unless `projectKey` is specified. */
    issueKey?: string;
    /** The project key for the project (case sensitive). Required, unless `issueKey` is specified. */
    projectKey?: string;
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$findUsersWithBrowsePermission$Status$200 {
    "application/json": Schemas.User[];
}
export interface Parameter$getAllUsersDefault {
    /** The index of the first item to return. */
    startAt?: number;
    /** The maximum number of items to return. */
    maxResults?: number;
}
export interface Response$getAllUsersDefault$Status$200 {
    "application/json": Schemas.User[];
}
export interface Parameter$getAllUsers {
    /** The index of the first item to return. */
    startAt?: number;
    /** The maximum number of items to return. */
    maxResults?: number;
}
export interface Response$getAllUsers$Status$200 {
    "application/json": Schemas.User[];
}
export interface RequestBody$createVersion {
    "application/json": Schemas.Version;
}
export interface Response$createVersion$Status$201 {
    "application/json": Schemas.Version;
}
export interface Parameter$getVersion {
    /** The ID of the version. */
    id: string;
    /**
     * Use [expand](#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `operations` Returns the list of operations available for this version.
     *  *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property represents the number of issues with a status other than *to do*, *in progress*, and *done*.
     */
    expand?: string;
}
export interface Response$getVersion$Status$200 {
    "application/json": Schemas.Version;
}
export interface Parameter$updateVersion {
    /** The ID of the version. */
    id: string;
}
export interface RequestBody$updateVersion {
    "application/json": Schemas.Version;
}
export interface Response$updateVersion$Status$200 {
    "application/json": Schemas.Version;
}
export interface Parameter$deleteVersion {
    /** The ID of the version. */
    id: string;
    /** The ID of the version to update `fixVersion` to when the field contains the deleted version. The replacement version must be in the same project as the version being deleted and cannot be the version being deleted. */
    moveFixIssuesTo?: string;
    /** The ID of the version to update `affectedVersion` to when the field contains the deleted version. The replacement version must be in the same project as the version being deleted and cannot be the version being deleted. */
    moveAffectedIssuesTo?: string;
}
export interface Parameter$mergeVersions {
    /** The ID of the version to delete. */
    id: string;
    /** The ID of the version to merge into. */
    moveIssuesTo: string;
}
export interface Response$mergeVersions$Status$204 {
    "application/json": {};
}
export interface Parameter$moveVersion {
    /** The ID of the version to be moved. */
    id: string;
}
export interface RequestBody$moveVersion {
    "application/json": Schemas.VersionMoveBean;
}
export interface Response$moveVersion$Status$200 {
    "application/json": Schemas.Version;
}
export interface Parameter$getVersionRelatedIssues {
    /** The ID of the version. */
    id: string;
}
export interface Response$getVersionRelatedIssues$Status$200 {
    "application/json": Schemas.VersionIssueCounts;
}
export interface Parameter$deleteAndReplaceVersion {
    /** The ID of the version. */
    id: string;
}
export interface RequestBody$deleteAndReplaceVersion {
    "application/json": Schemas.DeleteAndReplaceVersionBean;
}
export interface Response$deleteAndReplaceVersion$Status$204 {
    "application/json": {};
}
export interface Parameter$getVersionUnresolvedIssues {
    /** The ID of the version. */
    id: string;
}
export interface Response$getVersionUnresolvedIssues$Status$200 {
    "application/json": Schemas.VersionUnresolvedIssuesCount;
}
export interface Parameter$getDynamicWebhooksForApp {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getDynamicWebhooksForApp$Status$200 {
    "application/json": Schemas.PageBeanWebhook;
}
export interface Response$getDynamicWebhooksForApp$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getDynamicWebhooksForApp$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$registerDynamicWebhooks {
    "application/json": Schemas.WebhookRegistrationDetails;
}
export interface Response$registerDynamicWebhooks$Status$200 {
    "application/json": Schemas.ContainerForRegisteredWebhooks;
}
export interface Response$registerDynamicWebhooks$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$registerDynamicWebhooks$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$deleteWebhookById {
    "application/json": Schemas.ContainerForWebhookIDs;
}
export interface Response$deleteWebhookById$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteWebhookById$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getFailedWebhooks {
    /** The maximum number of webhooks to return per page. If obeying the maxResults directive would result in records with the same failure time being split across pages, the directive is ignored and all records with the same failure time included on the page. */
    maxResults?: number;
    /** The time after which any webhook failure must have occurred for the record to be returned, expressed as milliseconds since the UNIX epoch. */
    after?: number;
}
export interface Response$getFailedWebhooks$Status$200 {
    "application/json": Schemas.FailedWebhooks;
}
export interface Response$getFailedWebhooks$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getFailedWebhooks$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$refreshWebhooks {
    "application/json": Schemas.ContainerForWebhookIDs;
}
export interface Response$refreshWebhooks$Status$200 {
    "application/json": Schemas.WebhooksExpirationDate;
}
export interface Response$refreshWebhooks$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$refreshWebhooks$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getAllWorkflows {
    /** The name of the workflow to be returned. Only one workflow can be specified. */
    workflowName?: string;
}
export interface Response$getAllWorkflows$Status$200 {
    "application/json": Schemas.DeprecatedWorkflow[];
}
export interface RequestBody$createWorkflow {
    "application/json": Schemas.CreateWorkflowDetails;
}
export interface Response$createWorkflow$Status$201 {
    "application/json": Schemas.WorkflowIDs;
}
export interface Response$createWorkflow$Status$400 {
}
export interface Response$createWorkflow$Status$403 {
}
export interface Response$createWorkflow$Status$404 {
}
export interface Parameter$getWorkflowTransitionRuleConfigurations {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The types of the transition rules to return. */
    types: ("postfunction" | "condition" | "validator")[];
    /** The transition rule class keys, as defined in the Connect app descriptor, of the transition rules to return. */
    keys?: string[];
    /** EXPERIMENTAL: The list of workflow names to filter by. */
    workflowNames?: string[];
    /** EXPERIMENTAL: The list of `tags` to filter by. */
    withTags?: string[];
    /** EXPERIMENTAL: Whether draft or published workflows are returned. If not provided, both workflow types are returned. */
    draft?: boolean;
    /** Use [expand](#expansion) to include additional information in the response. This parameter accepts `transition`, which, for each rule, returns information about the transition the rule is assigned to. */
    expand?: string;
}
export interface Response$getWorkflowTransitionRuleConfigurations$Status$200 {
    "application/json": Schemas.PageBeanWorkflowTransitionRules;
}
export interface Response$getWorkflowTransitionRuleConfigurations$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$getWorkflowTransitionRuleConfigurations$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$updateWorkflowTransitionRuleConfigurations {
    "application/json": Schemas.WorkflowTransitionRulesUpdate;
}
export interface Response$updateWorkflowTransitionRuleConfigurations$Status$200 {
    "application/json": Schemas.WorkflowTransitionRulesUpdateErrors;
}
export interface Response$updateWorkflowTransitionRuleConfigurations$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$updateWorkflowTransitionRuleConfigurations$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface RequestBody$deleteWorkflowTransitionRuleConfigurations {
    "application/json": Schemas.WorkflowsWithTransitionRulesDetails;
}
export interface Response$deleteWorkflowTransitionRuleConfigurations$Status$200 {
    "application/json": Schemas.WorkflowTransitionRulesUpdateErrors;
}
export interface Response$deleteWorkflowTransitionRuleConfigurations$Status$400 {
    "application/json": Schemas.ErrorCollection;
}
export interface Response$deleteWorkflowTransitionRuleConfigurations$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getWorkflowsPaginated {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
    /** The name of a workflow to return. To include multiple workflows, provide an ampersand-separated list. For example, `workflowName=name1&workflowName=name2`. */
    workflowName?: string[];
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
     *
     *  *  `transitions` For each workflow, returns information about the transitions inside the workflow.
     *  *  `transitions.rules` For each workflow transition, returns information about its rules. Transitions are included automatically if this expand is requested.
     *  *  `transitions.properties` For each workflow transition, returns information about its properties. Transitions are included automatically if this expand is requested.
     *  *  `statuses` For each workflow, returns information about the statuses inside the workflow.
     *  *  `statuses.properties` For each workflow status, returns information about its properties. Statuses are included automatically if this expand is requested.
     *  *  `default` For each workflow, returns information about whether this is the default workflow.
     *  *  `schemes` For each workflow, returns information about the workflow schemes the workflow is assigned to.
     *  *  `projects` For each workflow, returns information about the projects the workflow is assigned to, through workflow schemes.
     *  *  `hasDraftWorkflow` For each workflow, returns information about whether the workflow has a draft version.
     *  *  `operations` For each workflow, returns information about the actions that can be undertaken on the workflow.
     */
    expand?: string;
    /** String used to perform a case-insensitive partial match with workflow name. */
    queryString?: string;
    /**
     * [Order](#ordering) the results by a field:
     *
     *  *  `name` Sorts by workflow name.
     *  *  `created` Sorts by create time.
     *  *  `updated` Sorts by update time.
     */
    orderBy?: "name" | "-name" | "+name" | "created" | "-created" | "+created" | "updated" | "+updated" | "-updated";
    /** Filters active and inactive workflows. */
    isActive?: boolean;
}
export interface Response$getWorkflowsPaginated$Status$200 {
    "application/json": Schemas.PageBeanWorkflow;
}
export interface Response$getWorkflowsPaginated$Status$403 {
    "application/json": Schemas.ErrorCollection;
}
export interface Parameter$getWorkflowTransitionProperties {
    /** The ID of the transition. To get the ID, view the workflow in text mode in the Jira administration console. The ID is shown next to the transition. */
    transitionId: number;
    /** Some properties with keys that have the *jira.* prefix are reserved, which means they are not editable. To include these properties in the results, set this parameter to *true*. */
    includeReservedKeys?: boolean;
    /** The key of the property being returned, also known as the name of the property. If this parameter is not specified, all properties on the transition are returned. */
    key?: string;
    /** The name of the workflow that the transition belongs to. */
    workflowName: string;
    /** The workflow status. Set to *live* for active and inactive workflows, or *draft* for draft workflows. */
    workflowMode?: "live" | "draft";
}
export interface Response$getWorkflowTransitionProperties$Status$200 {
    "application/json": Schemas.WorkflowTransitionProperty;
}
export interface Parameter$updateWorkflowTransitionProperty {
    /** The ID of the transition. To get the ID, view the workflow in text mode in the Jira admin settings. The ID is shown next to the transition. */
    transitionId: number;
    /** The key of the property being updated, also known as the name of the property. Set this to the same value as the `key` defined in the request body. */
    key: string;
    /** The name of the workflow that the transition belongs to. */
    workflowName: string;
    /** The workflow status. Set to `live` for inactive workflows or `draft` for draft workflows. Active workflows cannot be edited. */
    workflowMode?: "live" | "draft";
}
export interface RequestBody$updateWorkflowTransitionProperty {
    "application/json": Schemas.WorkflowTransitionProperty;
}
export interface Response$updateWorkflowTransitionProperty$Status$200 {
    "application/json": Schemas.WorkflowTransitionProperty;
}
export interface Parameter$createWorkflowTransitionProperty {
    /** The ID of the transition. To get the ID, view the workflow in text mode in the Jira admin settings. The ID is shown next to the transition. */
    transitionId: number;
    /** The key of the property being added, also known as the name of the property. Set this to the same value as the `key` defined in the request body. */
    key: string;
    /** The name of the workflow that the transition belongs to. */
    workflowName: string;
    /** The workflow status. Set to *live* for inactive workflows or *draft* for draft workflows. Active workflows cannot be edited. */
    workflowMode?: "live" | "draft";
}
export interface RequestBody$createWorkflowTransitionProperty {
    "application/json": Schemas.WorkflowTransitionProperty;
}
export interface Response$createWorkflowTransitionProperty$Status$200 {
    "application/json": Schemas.WorkflowTransitionProperty;
}
export interface Parameter$deleteWorkflowTransitionProperty {
    /** The ID of the transition. To get the ID, view the workflow in text mode in the Jira admin settings. The ID is shown next to the transition. */
    transitionId: number;
    /** The name of the transition property to delete, also known as the name of the property. */
    key: string;
    /** The name of the workflow that the transition belongs to. */
    workflowName: string;
    /** The workflow status. Set to `live` for inactive workflows or `draft` for draft workflows. Active workflows cannot be edited. */
    workflowMode?: "live" | "draft";
}
export interface Parameter$deleteInactiveWorkflow {
    /** The entity ID of the workflow. */
    entityId: string;
}
export interface Response$deleteInactiveWorkflow$Status$400 {
}
export interface Response$deleteInactiveWorkflow$Status$403 {
}
export interface Response$deleteInactiveWorkflow$Status$404 {
}
export interface Parameter$getAllWorkflowSchemes {
    /** The index of the first item to return in a page of results (page offset). */
    startAt?: number;
    /** The maximum number of items to return per page. */
    maxResults?: number;
}
export interface Response$getAllWorkflowSchemes$Status$200 {
    "application/json": Schemas.PageBeanWorkflowScheme;
}
export interface RequestBody$createWorkflowScheme {
    "application/json": Schemas.WorkflowScheme;
}
export interface Response$createWorkflowScheme$Status$201 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$getWorkflowSchemeProjectAssociations {
    /** The ID of a project to return the workflow schemes for. To include multiple projects, provide an ampersand-Jim: oneseparated list. For example, `projectId=10000&projectId=10001`. */
    projectId: number[];
}
export interface Response$getWorkflowSchemeProjectAssociations$Status$200 {
    "application/json": Schemas.ContainerOfWorkflowSchemeAssociations;
}
export interface Response$getWorkflowSchemeProjectAssociations$Status$400 {
}
export interface Response$getWorkflowSchemeProjectAssociations$Status$403 {
}
export interface RequestBody$assignSchemeToProject {
    "application/json": Schemas.WorkflowSchemeProjectAssociation;
}
export interface Response$assignSchemeToProject$Status$204 {
    "application/json": {};
}
export interface Response$assignSchemeToProject$Status$400 {
}
export interface Response$assignSchemeToProject$Status$403 {
}
export interface Response$assignSchemeToProject$Status$404 {
}
export interface Parameter$getWorkflowScheme {
    /** The ID of the workflow scheme. Find this ID by editing the desired workflow scheme in Jira. The ID is shown in the URL as `schemeId`. For example, *schemeId=10301*. */
    id: number;
    /** Returns the workflow scheme's draft rather than scheme itself, if set to true. If the workflow scheme does not have a draft, then the workflow scheme is returned. */
    returnDraftIfExists?: boolean;
}
export interface Response$getWorkflowScheme$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$updateWorkflowScheme {
    /** The ID of the workflow scheme. Find this ID by editing the desired workflow scheme in Jira. The ID is shown in the URL as `schemeId`. For example, *schemeId=10301*. */
    id: number;
}
export interface RequestBody$updateWorkflowScheme {
    "application/json": Schemas.WorkflowScheme;
}
export interface Response$updateWorkflowScheme$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteWorkflowScheme {
    /** The ID of the workflow scheme. Find this ID by editing the desired workflow scheme in Jira. The ID is shown in the URL as `schemeId`. For example, *schemeId=10301*. */
    id: number;
}
export interface Parameter$createWorkflowSchemeDraftFromParent {
    /** The ID of the active workflow scheme that the draft is created from. */
    id: number;
}
export interface Response$createWorkflowSchemeDraftFromParent$Status$201 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$getDefaultWorkflow {
    /** The ID of the workflow scheme. */
    id: number;
    /** Set to `true` to return the default workflow for the workflow scheme's draft rather than scheme itself. If the workflow scheme does not have a draft, then the default workflow for the workflow scheme is returned. */
    returnDraftIfExists?: boolean;
}
export interface Response$getDefaultWorkflow$Status$200 {
    "application/json": Schemas.DefaultWorkflow;
}
export interface Parameter$updateDefaultWorkflow {
    /** The ID of the workflow scheme. */
    id: number;
}
export interface RequestBody$updateDefaultWorkflow {
    "application/json": Schemas.DefaultWorkflow;
}
export interface Response$updateDefaultWorkflow$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteDefaultWorkflow {
    /** The ID of the workflow scheme. */
    id: number;
    /** Set to true to create or update the draft of a workflow scheme and delete the mapping from the draft, when the workflow scheme cannot be edited. Defaults to `false`. */
    updateDraftIfNeeded?: boolean;
}
export interface Response$deleteDefaultWorkflow$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$getWorkflowSchemeDraft {
    /** The ID of the active workflow scheme that the draft was created from. */
    id: number;
}
export interface Response$getWorkflowSchemeDraft$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$updateWorkflowSchemeDraft {
    /** The ID of the active workflow scheme that the draft was created from. */
    id: number;
}
export interface RequestBody$updateWorkflowSchemeDraft {
    "application/json": Schemas.WorkflowScheme;
}
export interface Response$updateWorkflowSchemeDraft$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteWorkflowSchemeDraft {
    /** The ID of the active workflow scheme that the draft was created from. */
    id: number;
}
export interface Parameter$getDraftDefaultWorkflow {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
}
export interface Response$getDraftDefaultWorkflow$Status$200 {
    "application/json": Schemas.DefaultWorkflow;
}
export interface Parameter$updateDraftDefaultWorkflow {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
}
export interface RequestBody$updateDraftDefaultWorkflow {
    "application/json": Schemas.DefaultWorkflow;
}
export interface Response$updateDraftDefaultWorkflow$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteDraftDefaultWorkflow {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
}
export interface Response$deleteDraftDefaultWorkflow$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$getWorkflowSchemeDraftIssueType {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** The ID of the issue type. */
    issueType: string;
}
export interface Response$getWorkflowSchemeDraftIssueType$Status$200 {
    "application/json": Schemas.IssueTypeWorkflowMapping;
}
export interface Parameter$setWorkflowSchemeDraftIssueType {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** The ID of the issue type. */
    issueType: string;
}
export interface RequestBody$setWorkflowSchemeDraftIssueType {
    "application/json": Schemas.IssueTypeWorkflowMapping;
}
export interface Response$setWorkflowSchemeDraftIssueType$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteWorkflowSchemeDraftIssueType {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** The ID of the issue type. */
    issueType: string;
}
export interface Response$deleteWorkflowSchemeDraftIssueType$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$publishDraftWorkflowScheme {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** Whether the request only performs a validation. */
    validateOnly?: boolean;
}
export interface RequestBody$publishDraftWorkflowScheme {
    "application/json": Schemas.PublishDraftWorkflowScheme;
}
export interface Response$publishDraftWorkflowScheme$Status$303 {
    "application/json": Schemas.TaskProgressBeanObject;
}
export interface Response$publishDraftWorkflowScheme$Status$400 {
}
export interface Response$publishDraftWorkflowScheme$Status$404 {
}
export interface Parameter$getDraftWorkflow {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** The name of a workflow in the scheme. Limits the results to the workflow-issue type mapping for the specified workflow. */
    workflowName?: string;
}
export interface Response$getDraftWorkflow$Status$200 {
    "application/json": Schemas.IssueTypesWorkflowMapping;
}
export interface Parameter$updateDraftWorkflowMapping {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** The name of the workflow. */
    workflowName: string;
}
export interface RequestBody$updateDraftWorkflowMapping {
    "application/json": Schemas.IssueTypesWorkflowMapping;
}
export interface Response$updateDraftWorkflowMapping$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteDraftWorkflowMapping {
    /** The ID of the workflow scheme that the draft belongs to. */
    id: number;
    /** The name of the workflow. */
    workflowName: string;
}
export interface Parameter$getWorkflowSchemeIssueType {
    /** The ID of the workflow scheme. */
    id: number;
    /** The ID of the issue type. */
    issueType: string;
    /** Returns the mapping from the workflow scheme's draft rather than the workflow scheme, if set to true. If no draft exists, the mapping from the workflow scheme is returned. */
    returnDraftIfExists?: boolean;
}
export interface Response$getWorkflowSchemeIssueType$Status$200 {
    "application/json": Schemas.IssueTypeWorkflowMapping;
}
export interface Parameter$setWorkflowSchemeIssueType {
    /** The ID of the workflow scheme. */
    id: number;
    /** The ID of the issue type. */
    issueType: string;
}
export interface RequestBody$setWorkflowSchemeIssueType {
    "application/json": Schemas.IssueTypeWorkflowMapping;
}
export interface Response$setWorkflowSchemeIssueType$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteWorkflowSchemeIssueType {
    /** The ID of the workflow scheme. */
    id: number;
    /** The ID of the issue type. */
    issueType: string;
    /** Set to true to create or update the draft of a workflow scheme and update the mapping in the draft, when the workflow scheme cannot be edited. Defaults to `false`. */
    updateDraftIfNeeded?: boolean;
}
export interface Response$deleteWorkflowSchemeIssueType$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$getWorkflow {
    /** The ID of the workflow scheme. */
    id: number;
    /** The name of a workflow in the scheme. Limits the results to the workflow-issue type mapping for the specified workflow. */
    workflowName?: string;
    /** Returns the mapping from the workflow scheme's draft rather than the workflow scheme, if set to true. If no draft exists, the mapping from the workflow scheme is returned. */
    returnDraftIfExists?: boolean;
}
export interface Response$getWorkflow$Status$200 {
    "application/json": Schemas.IssueTypesWorkflowMapping;
}
export interface Parameter$updateWorkflowMapping {
    /** The ID of the workflow scheme. */
    id: number;
    /** The name of the workflow. */
    workflowName: string;
}
export interface RequestBody$updateWorkflowMapping {
    "application/json": Schemas.IssueTypesWorkflowMapping;
}
export interface Response$updateWorkflowMapping$Status$200 {
    "application/json": Schemas.WorkflowScheme;
}
export interface Parameter$deleteWorkflowMapping {
    /** The ID of the workflow scheme. */
    id: number;
    /** The name of the workflow. */
    workflowName: string;
    /** Set to true to create or update the draft of a workflow scheme and delete the mapping from the draft, when the workflow scheme cannot be edited. Defaults to `false`. */
    updateDraftIfNeeded?: boolean;
}
export interface Parameter$getIdsOfWorklogsDeletedSince {
    /** The date and time, as a UNIX timestamp in milliseconds, after which deleted worklogs are returned. */
    since?: number;
}
export interface Response$getIdsOfWorklogsDeletedSince$Status$200 {
    "application/json": Schemas.ChangedWorklogs;
}
export interface Parameter$getWorklogsForIds {
    /** Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts `properties` that returns the properties of each worklog. */
    expand?: string;
}
export interface RequestBody$getWorklogsForIds {
    "application/json": Schemas.WorklogIdsRequestBean;
}
export interface Response$getWorklogsForIds$Status$200 {
    "application/json": Schemas.Worklog[];
}
export interface Parameter$getIdsOfWorklogsModifiedSince {
    /** The date and time, as a UNIX timestamp in milliseconds, after which updated worklogs are returned. */
    since?: number;
    /** Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts `properties` that returns the properties of each worklog. */
    expand?: string;
}
export interface Response$getIdsOfWorklogsModifiedSince$Status$200 {
    "application/json": Schemas.ChangedWorklogs;
}
export interface Parameter$AddonPropertiesResource$getAddonProperties_get {
    /** The key of the app, as defined in its descriptor. */
    addonKey: string;
}
export interface Response$AddonPropertiesResource$getAddonProperties_get$Status$200 {
    "application/json": Schemas.PropertyKeys;
}
export interface Response$AddonPropertiesResource$getAddonProperties_get$Status$401 {
    "application/json": Schemas.OperationMessage;
}
export interface Parameter$AddonPropertiesResource$getAddonProperty_get {
    /** The key of the app, as defined in its descriptor. */
    addonKey: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface Response$AddonPropertiesResource$getAddonProperty_get$Status$200 {
    "application/json": Schemas.EntityProperty;
}
export interface Response$AddonPropertiesResource$getAddonProperty_get$Status$400 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$getAddonProperty_get$Status$401 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$getAddonProperty_get$Status$404 {
    "application/json": Schemas.OperationMessage;
}
export interface Parameter$AddonPropertiesResource$putAddonProperty_put {
    /** The key of the app, as defined in its descriptor. */
    addonKey: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface RequestBody$AddonPropertiesResource$putAddonProperty_put {
    "application/json": {};
}
export interface Response$AddonPropertiesResource$putAddonProperty_put$Status$200 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$putAddonProperty_put$Status$201 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$putAddonProperty_put$Status$400 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$putAddonProperty_put$Status$401 {
    "application/json": Schemas.OperationMessage;
}
export interface Parameter$AddonPropertiesResource$deleteAddonProperty_delete {
    /** The key of the app, as defined in its descriptor. */
    addonKey: string;
    /** The key of the property. */
    propertyKey: string;
}
export interface Response$AddonPropertiesResource$deleteAddonProperty_delete$Status$400 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$deleteAddonProperty_delete$Status$401 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$AddonPropertiesResource$deleteAddonProperty_delete$Status$404 {
    "application/json": Schemas.OperationMessage;
}
export interface Response$DynamicModulesResource$getModules_get$Status$200 {
    "application/json": Schemas.ConnectModules;
}
export interface Response$DynamicModulesResource$getModules_get$Status$401 {
    "application/json": Schemas.ErrorMessage;
}
export interface RequestBody$DynamicModulesResource$registerModules_post {
    "application/json": Schemas.ConnectModules;
}
export interface Response$DynamicModulesResource$registerModules_post$Status$400 {
    "application/json": Schemas.ErrorMessage;
}
export interface Response$DynamicModulesResource$registerModules_post$Status$401 {
    "application/json": Schemas.ErrorMessage;
}
export interface Parameter$DynamicModulesResource$removeModules_delete {
    /**
     * The key of the module to remove. To include multiple module keys, provide multiple copies of this parameter.
     * For example, `moduleKey=dynamic-attachment-entity-property&moduleKey=dynamic-select-field`.
     * Nonexistent keys are ignored.
     */
    moduleKey?: string[];
}
export interface Response$DynamicModulesResource$removeModules_delete$Status$401 {
    "application/json": Schemas.ErrorMessage;
}
export interface Parameter$AppIssueFieldValueUpdateResource$updateIssueFields_put {
    /** The ID of the transfer. */
    "Atlassian-Transfer-Id": string;
    /** The Atlassian account ID of the impersonated user. This user must be a member of the site admin group. */
    "Atlassian-Account-Id": string;
}
export interface RequestBody$AppIssueFieldValueUpdateResource$updateIssueFields_put {
    "application/json": Schemas.ConnectCustomFieldValues;
}
export interface Response$AppIssueFieldValueUpdateResource$updateIssueFields_put$Status$200 {
    "application/json": {};
}
export interface Parameter$MigrationResource$updateEntityPropertiesValue_put {
    /** The app migration transfer ID. */
    "Atlassian-Transfer-Id": string;
    /** The Atlassian account ID of the impersonated user. This user must be a member of the site admin group. */
    "Atlassian-Account-Id": string;
    /** The type indicating the object that contains the entity properties. */
    entityType: "IssueProperty" | "CommentProperty" | "DashboardItemProperty" | "IssueTypeProperty" | "ProjectProperty" | "UserProperty" | "WorklogProperty" | "BoardProperty" | "SprintProperty";
}
export interface RequestBody$MigrationResource$updateEntityPropertiesValue_put {
    "application/json": Schemas.EntityPropertyDetails[];
}
export interface Parameter$MigrationResource$workflowRuleSearch_post {
    /** The app migration transfer ID. */
    "Atlassian-Transfer-Id": string;
}
export interface RequestBody$MigrationResource$workflowRuleSearch_post {
    "application/json": Schemas.WorkflowRulesSearch;
}
export interface Response$MigrationResource$workflowRuleSearch_post$Status$200 {
    "application/json": Schemas.WorkflowRulesSearchDetails;
}
export declare type RequestContentType$updateMultipleCustomFieldValues = keyof RequestBody$updateMultipleCustomFieldValues;
export declare type ResponseContentType$updateMultipleCustomFieldValues = keyof Response$updateMultipleCustomFieldValues$Status$204;
export interface Params$updateMultipleCustomFieldValues {
    parameter: Parameter$updateMultipleCustomFieldValues;
    requestBody: RequestBody$updateMultipleCustomFieldValues["application/json"];
}
export declare type ResponseContentType$getCustomFieldConfiguration = keyof Response$getCustomFieldConfiguration$Status$200;
export interface Params$getCustomFieldConfiguration {
    parameter: Parameter$getCustomFieldConfiguration;
}
export declare type RequestContentType$updateCustomFieldConfiguration = keyof RequestBody$updateCustomFieldConfiguration;
export declare type ResponseContentType$updateCustomFieldConfiguration = keyof Response$updateCustomFieldConfiguration$Status$200;
export interface Params$updateCustomFieldConfiguration {
    parameter: Parameter$updateCustomFieldConfiguration;
    requestBody: RequestBody$updateCustomFieldConfiguration["application/json"];
}
export declare type RequestContentType$updateCustomFieldValue = keyof RequestBody$updateCustomFieldValue;
export declare type ResponseContentType$updateCustomFieldValue = keyof Response$updateCustomFieldValue$Status$204;
export interface Params$updateCustomFieldValue {
    parameter: Parameter$updateCustomFieldValue;
    requestBody: RequestBody$updateCustomFieldValue["application/json"];
}
export declare type ResponseContentType$getApplicationProperty = keyof Response$getApplicationProperty$Status$200;
export interface Params$getApplicationProperty {
    parameter: Parameter$getApplicationProperty;
}
export declare type ResponseContentType$getAdvancedSettings = keyof Response$getAdvancedSettings$Status$200;
export declare type RequestContentType$setApplicationProperty = keyof RequestBody$setApplicationProperty;
export declare type ResponseContentType$setApplicationProperty = keyof Response$setApplicationProperty$Status$200;
export interface Params$setApplicationProperty {
    parameter: Parameter$setApplicationProperty;
    requestBody: RequestBody$setApplicationProperty["application/json"];
}
export declare type ResponseContentType$getAllApplicationRoles = keyof Response$getAllApplicationRoles$Status$200;
export declare type ResponseContentType$getApplicationRole = keyof Response$getApplicationRole$Status$200;
export interface Params$getApplicationRole {
    parameter: Parameter$getApplicationRole;
}
export declare type ResponseContentType$getAttachmentContent = keyof Response$getAttachmentContent$Status$200;
export interface Params$getAttachmentContent {
    parameter: Parameter$getAttachmentContent;
}
export declare type ResponseContentType$getAttachmentMeta = keyof Response$getAttachmentMeta$Status$200;
export declare type ResponseContentType$getAttachmentThumbnail = keyof Response$getAttachmentThumbnail$Status$200;
export interface Params$getAttachmentThumbnail {
    parameter: Parameter$getAttachmentThumbnail;
}
export declare type ResponseContentType$getAttachment = keyof Response$getAttachment$Status$200;
export interface Params$getAttachment {
    parameter: Parameter$getAttachment;
}
export interface Params$removeAttachment {
    parameter: Parameter$removeAttachment;
}
export declare type ResponseContentType$expandAttachmentForHumans = keyof Response$expandAttachmentForHumans$Status$200;
export interface Params$expandAttachmentForHumans {
    parameter: Parameter$expandAttachmentForHumans;
}
export declare type ResponseContentType$expandAttachmentForMachines = keyof Response$expandAttachmentForMachines$Status$200;
export interface Params$expandAttachmentForMachines {
    parameter: Parameter$expandAttachmentForMachines;
}
export declare type ResponseContentType$getAuditRecords = keyof Response$getAuditRecords$Status$200;
export interface Params$getAuditRecords {
    parameter: Parameter$getAuditRecords;
}
export declare type ResponseContentType$getAllSystemAvatars = keyof Response$getAllSystemAvatars$Status$200;
export interface Params$getAllSystemAvatars {
    parameter: Parameter$getAllSystemAvatars;
}
export declare type RequestContentType$getCommentsByIds = keyof RequestBody$getCommentsByIds;
export declare type ResponseContentType$getCommentsByIds = keyof Response$getCommentsByIds$Status$200;
export interface Params$getCommentsByIds {
    parameter: Parameter$getCommentsByIds;
    requestBody: RequestBody$getCommentsByIds["application/json"];
}
export declare type ResponseContentType$getCommentPropertyKeys = keyof Response$getCommentPropertyKeys$Status$200;
export interface Params$getCommentPropertyKeys {
    parameter: Parameter$getCommentPropertyKeys;
}
export declare type ResponseContentType$getCommentProperty = keyof Response$getCommentProperty$Status$200;
export interface Params$getCommentProperty {
    parameter: Parameter$getCommentProperty;
}
export declare type RequestContentType$setCommentProperty = keyof RequestBody$setCommentProperty;
export declare type ResponseContentType$setCommentProperty = keyof Response$setCommentProperty$Status$200;
export interface Params$setCommentProperty {
    parameter: Parameter$setCommentProperty;
    requestBody: RequestBody$setCommentProperty["application/json"];
}
export interface Params$deleteCommentProperty {
    parameter: Parameter$deleteCommentProperty;
}
export declare type RequestContentType$createComponent = keyof RequestBody$createComponent;
export declare type ResponseContentType$createComponent = keyof Response$createComponent$Status$201;
export interface Params$createComponent {
    requestBody: RequestBody$createComponent["application/json"];
}
export declare type ResponseContentType$getComponent = keyof Response$getComponent$Status$200;
export interface Params$getComponent {
    parameter: Parameter$getComponent;
}
export declare type RequestContentType$updateComponent = keyof RequestBody$updateComponent;
export declare type ResponseContentType$updateComponent = keyof Response$updateComponent$Status$200;
export interface Params$updateComponent {
    parameter: Parameter$updateComponent;
    requestBody: RequestBody$updateComponent["application/json"];
}
export interface Params$deleteComponent {
    parameter: Parameter$deleteComponent;
}
export declare type ResponseContentType$getComponentRelatedIssues = keyof Response$getComponentRelatedIssues$Status$200;
export interface Params$getComponentRelatedIssues {
    parameter: Parameter$getComponentRelatedIssues;
}
export declare type ResponseContentType$getConfiguration = keyof Response$getConfiguration$Status$200;
export declare type ResponseContentType$getSelectedTimeTrackingImplementation = keyof Response$getSelectedTimeTrackingImplementation$Status$200;
export declare type RequestContentType$selectTimeTrackingImplementation = keyof RequestBody$selectTimeTrackingImplementation;
export declare type ResponseContentType$selectTimeTrackingImplementation = keyof Response$selectTimeTrackingImplementation$Status$204;
export interface Params$selectTimeTrackingImplementation {
    requestBody: RequestBody$selectTimeTrackingImplementation["application/json"];
}
export declare type ResponseContentType$getAvailableTimeTrackingImplementations = keyof Response$getAvailableTimeTrackingImplementations$Status$200;
export declare type ResponseContentType$getSharedTimeTrackingConfiguration = keyof Response$getSharedTimeTrackingConfiguration$Status$200;
export declare type RequestContentType$setSharedTimeTrackingConfiguration = keyof RequestBody$setSharedTimeTrackingConfiguration;
export declare type ResponseContentType$setSharedTimeTrackingConfiguration = keyof Response$setSharedTimeTrackingConfiguration$Status$200;
export interface Params$setSharedTimeTrackingConfiguration {
    requestBody: RequestBody$setSharedTimeTrackingConfiguration["application/json"];
}
export declare type ResponseContentType$getCustomFieldOption = keyof Response$getCustomFieldOption$Status$200;
export interface Params$getCustomFieldOption {
    parameter: Parameter$getCustomFieldOption;
}
export declare type ResponseContentType$getAllDashboards = keyof Response$getAllDashboards$Status$200;
export interface Params$getAllDashboards {
    parameter: Parameter$getAllDashboards;
}
export declare type RequestContentType$createDashboard = keyof RequestBody$createDashboard;
export declare type ResponseContentType$createDashboard = keyof Response$createDashboard$Status$200;
export interface Params$createDashboard {
    requestBody: RequestBody$createDashboard["application/json"];
}
export declare type ResponseContentType$getDashboardsPaginated = keyof Response$getDashboardsPaginated$Status$200;
export interface Params$getDashboardsPaginated {
    parameter: Parameter$getDashboardsPaginated;
}
export declare type ResponseContentType$getDashboardItemPropertyKeys = keyof Response$getDashboardItemPropertyKeys$Status$200;
export interface Params$getDashboardItemPropertyKeys {
    parameter: Parameter$getDashboardItemPropertyKeys;
}
export declare type ResponseContentType$getDashboardItemProperty = keyof Response$getDashboardItemProperty$Status$200;
export interface Params$getDashboardItemProperty {
    parameter: Parameter$getDashboardItemProperty;
}
export declare type RequestContentType$setDashboardItemProperty = keyof RequestBody$setDashboardItemProperty;
export declare type ResponseContentType$setDashboardItemProperty = keyof Response$setDashboardItemProperty$Status$200;
export interface Params$setDashboardItemProperty {
    parameter: Parameter$setDashboardItemProperty;
    requestBody: RequestBody$setDashboardItemProperty["application/json"];
}
export interface Params$deleteDashboardItemProperty {
    parameter: Parameter$deleteDashboardItemProperty;
}
export declare type ResponseContentType$getDashboard = keyof Response$getDashboard$Status$200;
export interface Params$getDashboard {
    parameter: Parameter$getDashboard;
}
export declare type RequestContentType$updateDashboard = keyof RequestBody$updateDashboard;
export declare type ResponseContentType$updateDashboard = keyof Response$updateDashboard$Status$200;
export interface Params$updateDashboard {
    parameter: Parameter$updateDashboard;
    requestBody: RequestBody$updateDashboard["application/json"];
}
export interface Params$deleteDashboard {
    parameter: Parameter$deleteDashboard;
}
export declare type RequestContentType$copyDashboard = keyof RequestBody$copyDashboard;
export declare type ResponseContentType$copyDashboard = keyof Response$copyDashboard$Status$200;
export interface Params$copyDashboard {
    parameter: Parameter$copyDashboard;
    requestBody: RequestBody$copyDashboard["application/json"];
}
export declare type ResponseContentType$getEvents = keyof Response$getEvents$Status$200;
export declare type RequestContentType$analyseExpression = keyof RequestBody$analyseExpression;
export declare type ResponseContentType$analyseExpression = keyof Response$analyseExpression$Status$200;
export interface Params$analyseExpression {
    parameter: Parameter$analyseExpression;
    requestBody: RequestBody$analyseExpression["application/json"];
}
export declare type RequestContentType$evaluateJiraExpression = keyof RequestBody$evaluateJiraExpression;
export declare type ResponseContentType$evaluateJiraExpression = keyof Response$evaluateJiraExpression$Status$200;
export interface Params$evaluateJiraExpression {
    parameter: Parameter$evaluateJiraExpression;
    requestBody: RequestBody$evaluateJiraExpression["application/json"];
}
export declare type ResponseContentType$getFields = keyof Response$getFields$Status$200;
export declare type RequestContentType$createCustomField = keyof RequestBody$createCustomField;
export declare type ResponseContentType$createCustomField = keyof Response$createCustomField$Status$201;
export interface Params$createCustomField {
    requestBody: RequestBody$createCustomField["application/json"];
}
export declare type ResponseContentType$getFieldsPaginated = keyof Response$getFieldsPaginated$Status$200;
export interface Params$getFieldsPaginated {
    parameter: Parameter$getFieldsPaginated;
}
export declare type RequestContentType$updateCustomField = keyof RequestBody$updateCustomField;
export declare type ResponseContentType$updateCustomField = keyof Response$updateCustomField$Status$204;
export interface Params$updateCustomField {
    parameter: Parameter$updateCustomField;
    requestBody: RequestBody$updateCustomField["application/json"];
}
export declare type ResponseContentType$getContextsForField = keyof Response$getContextsForField$Status$200;
export interface Params$getContextsForField {
    parameter: Parameter$getContextsForField;
}
export declare type RequestContentType$createCustomFieldContext = keyof RequestBody$createCustomFieldContext;
export declare type ResponseContentType$createCustomFieldContext = keyof Response$createCustomFieldContext$Status$201;
export interface Params$createCustomFieldContext {
    parameter: Parameter$createCustomFieldContext;
    requestBody: RequestBody$createCustomFieldContext["application/json"];
}
export declare type ResponseContentType$getDefaultValues = keyof Response$getDefaultValues$Status$200;
export interface Params$getDefaultValues {
    parameter: Parameter$getDefaultValues;
}
export declare type RequestContentType$setDefaultValues = keyof RequestBody$setDefaultValues;
export declare type ResponseContentType$setDefaultValues = keyof Response$setDefaultValues$Status$204;
export interface Params$setDefaultValues {
    parameter: Parameter$setDefaultValues;
    requestBody: RequestBody$setDefaultValues["application/json"];
}
export declare type ResponseContentType$getIssueTypeMappingsForContexts = keyof Response$getIssueTypeMappingsForContexts$Status$200;
export interface Params$getIssueTypeMappingsForContexts {
    parameter: Parameter$getIssueTypeMappingsForContexts;
}
export declare type RequestContentType$getCustomFieldContextsForProjectsAndIssueTypes = keyof RequestBody$getCustomFieldContextsForProjectsAndIssueTypes;
export declare type ResponseContentType$getCustomFieldContextsForProjectsAndIssueTypes = keyof Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$200;
export interface Params$getCustomFieldContextsForProjectsAndIssueTypes {
    parameter: Parameter$getCustomFieldContextsForProjectsAndIssueTypes;
    requestBody: RequestBody$getCustomFieldContextsForProjectsAndIssueTypes["application/json"];
}
export declare type ResponseContentType$getProjectContextMapping = keyof Response$getProjectContextMapping$Status$200;
export interface Params$getProjectContextMapping {
    parameter: Parameter$getProjectContextMapping;
}
export declare type RequestContentType$updateCustomFieldContext = keyof RequestBody$updateCustomFieldContext;
export declare type ResponseContentType$updateCustomFieldContext = keyof Response$updateCustomFieldContext$Status$204;
export interface Params$updateCustomFieldContext {
    parameter: Parameter$updateCustomFieldContext;
    requestBody: RequestBody$updateCustomFieldContext["application/json"];
}
export declare type ResponseContentType$deleteCustomFieldContext = keyof Response$deleteCustomFieldContext$Status$204;
export interface Params$deleteCustomFieldContext {
    parameter: Parameter$deleteCustomFieldContext;
}
export declare type RequestContentType$addIssueTypesToContext = keyof RequestBody$addIssueTypesToContext;
export declare type ResponseContentType$addIssueTypesToContext = keyof Response$addIssueTypesToContext$Status$204;
export interface Params$addIssueTypesToContext {
    parameter: Parameter$addIssueTypesToContext;
    requestBody: RequestBody$addIssueTypesToContext["application/json"];
}
export declare type RequestContentType$removeIssueTypesFromContext = keyof RequestBody$removeIssueTypesFromContext;
export declare type ResponseContentType$removeIssueTypesFromContext = keyof Response$removeIssueTypesFromContext$Status$204;
export interface Params$removeIssueTypesFromContext {
    parameter: Parameter$removeIssueTypesFromContext;
    requestBody: RequestBody$removeIssueTypesFromContext["application/json"];
}
export declare type ResponseContentType$getOptionsForContext = keyof Response$getOptionsForContext$Status$200;
export interface Params$getOptionsForContext {
    parameter: Parameter$getOptionsForContext;
}
export declare type RequestContentType$updateCustomFieldOption = keyof RequestBody$updateCustomFieldOption;
export declare type ResponseContentType$updateCustomFieldOption = keyof Response$updateCustomFieldOption$Status$200;
export interface Params$updateCustomFieldOption {
    parameter: Parameter$updateCustomFieldOption;
    requestBody: RequestBody$updateCustomFieldOption["application/json"];
}
export declare type RequestContentType$createCustomFieldOption = keyof RequestBody$createCustomFieldOption;
export declare type ResponseContentType$createCustomFieldOption = keyof Response$createCustomFieldOption$Status$200;
export interface Params$createCustomFieldOption {
    parameter: Parameter$createCustomFieldOption;
    requestBody: RequestBody$createCustomFieldOption["application/json"];
}
export declare type RequestContentType$reorderCustomFieldOptions = keyof RequestBody$reorderCustomFieldOptions;
export declare type ResponseContentType$reorderCustomFieldOptions = keyof Response$reorderCustomFieldOptions$Status$204;
export interface Params$reorderCustomFieldOptions {
    parameter: Parameter$reorderCustomFieldOptions;
    requestBody: RequestBody$reorderCustomFieldOptions["application/json"];
}
export interface Params$deleteCustomFieldOption {
    parameter: Parameter$deleteCustomFieldOption;
}
export declare type RequestContentType$assignProjectsToCustomFieldContext = keyof RequestBody$assignProjectsToCustomFieldContext;
export declare type ResponseContentType$assignProjectsToCustomFieldContext = keyof Response$assignProjectsToCustomFieldContext$Status$204;
export interface Params$assignProjectsToCustomFieldContext {
    parameter: Parameter$assignProjectsToCustomFieldContext;
    requestBody: RequestBody$assignProjectsToCustomFieldContext["application/json"];
}
export declare type RequestContentType$removeCustomFieldContextFromProjects = keyof RequestBody$removeCustomFieldContextFromProjects;
export declare type ResponseContentType$removeCustomFieldContextFromProjects = keyof Response$removeCustomFieldContextFromProjects$Status$204;
export interface Params$removeCustomFieldContextFromProjects {
    parameter: Parameter$removeCustomFieldContextFromProjects;
    requestBody: RequestBody$removeCustomFieldContextFromProjects["application/json"];
}
export declare type ResponseContentType$getContextsForFieldDeprecated = keyof Response$getContextsForFieldDeprecated$Status$200;
export interface Params$getContextsForFieldDeprecated {
    parameter: Parameter$getContextsForFieldDeprecated;
}
export declare type ResponseContentType$getScreensForField = keyof Response$getScreensForField$Status$200;
export interface Params$getScreensForField {
    parameter: Parameter$getScreensForField;
}
export declare type ResponseContentType$getAllIssueFieldOptions = keyof Response$getAllIssueFieldOptions$Status$200;
export interface Params$getAllIssueFieldOptions {
    parameter: Parameter$getAllIssueFieldOptions;
}
export declare type RequestContentType$createIssueFieldOption = keyof RequestBody$createIssueFieldOption;
export declare type ResponseContentType$createIssueFieldOption = keyof Response$createIssueFieldOption$Status$200;
export interface Params$createIssueFieldOption {
    parameter: Parameter$createIssueFieldOption;
    requestBody: RequestBody$createIssueFieldOption["application/json"];
}
export declare type ResponseContentType$getSelectableIssueFieldOptions = keyof Response$getSelectableIssueFieldOptions$Status$200;
export interface Params$getSelectableIssueFieldOptions {
    parameter: Parameter$getSelectableIssueFieldOptions;
}
export declare type ResponseContentType$getVisibleIssueFieldOptions = keyof Response$getVisibleIssueFieldOptions$Status$200;
export interface Params$getVisibleIssueFieldOptions {
    parameter: Parameter$getVisibleIssueFieldOptions;
}
export declare type ResponseContentType$getIssueFieldOption = keyof Response$getIssueFieldOption$Status$200;
export interface Params$getIssueFieldOption {
    parameter: Parameter$getIssueFieldOption;
}
export declare type RequestContentType$updateIssueFieldOption = keyof RequestBody$updateIssueFieldOption;
export declare type ResponseContentType$updateIssueFieldOption = keyof Response$updateIssueFieldOption$Status$200;
export interface Params$updateIssueFieldOption {
    parameter: Parameter$updateIssueFieldOption;
    requestBody: RequestBody$updateIssueFieldOption["application/json"];
}
export declare type ResponseContentType$deleteIssueFieldOption = keyof Response$deleteIssueFieldOption$Status$204;
export interface Params$deleteIssueFieldOption {
    parameter: Parameter$deleteIssueFieldOption;
}
export interface Params$replaceIssueFieldOption {
    parameter: Parameter$replaceIssueFieldOption;
}
export interface Params$deleteCustomField {
    parameter: Parameter$deleteCustomField;
}
export declare type ResponseContentType$restoreCustomField = keyof Response$restoreCustomField$Status$200;
export interface Params$restoreCustomField {
    parameter: Parameter$restoreCustomField;
}
export declare type ResponseContentType$trashCustomField = keyof Response$trashCustomField$Status$200;
export interface Params$trashCustomField {
    parameter: Parameter$trashCustomField;
}
export declare type ResponseContentType$getAllFieldConfigurations = keyof Response$getAllFieldConfigurations$Status$200;
export interface Params$getAllFieldConfigurations {
    parameter: Parameter$getAllFieldConfigurations;
}
export declare type RequestContentType$createFieldConfiguration = keyof RequestBody$createFieldConfiguration;
export declare type ResponseContentType$createFieldConfiguration = keyof Response$createFieldConfiguration$Status$200;
export interface Params$createFieldConfiguration {
    requestBody: RequestBody$createFieldConfiguration["application/json"];
}
export declare type RequestContentType$updateFieldConfiguration = keyof RequestBody$updateFieldConfiguration;
export declare type ResponseContentType$updateFieldConfiguration = keyof Response$updateFieldConfiguration$Status$204;
export interface Params$updateFieldConfiguration {
    parameter: Parameter$updateFieldConfiguration;
    requestBody: RequestBody$updateFieldConfiguration["application/json"];
}
export declare type ResponseContentType$deleteFieldConfiguration = keyof Response$deleteFieldConfiguration$Status$204;
export interface Params$deleteFieldConfiguration {
    parameter: Parameter$deleteFieldConfiguration;
}
export declare type ResponseContentType$getFieldConfigurationItems = keyof Response$getFieldConfigurationItems$Status$200;
export interface Params$getFieldConfigurationItems {
    parameter: Parameter$getFieldConfigurationItems;
}
export declare type RequestContentType$updateFieldConfigurationItems = keyof RequestBody$updateFieldConfigurationItems;
export declare type ResponseContentType$updateFieldConfigurationItems = keyof Response$updateFieldConfigurationItems$Status$204;
export interface Params$updateFieldConfigurationItems {
    parameter: Parameter$updateFieldConfigurationItems;
    requestBody: RequestBody$updateFieldConfigurationItems["application/json"];
}
export declare type ResponseContentType$getAllFieldConfigurationSchemes = keyof Response$getAllFieldConfigurationSchemes$Status$200;
export interface Params$getAllFieldConfigurationSchemes {
    parameter: Parameter$getAllFieldConfigurationSchemes;
}
export declare type RequestContentType$createFieldConfigurationScheme = keyof RequestBody$createFieldConfigurationScheme;
export declare type ResponseContentType$createFieldConfigurationScheme = keyof Response$createFieldConfigurationScheme$Status$201;
export interface Params$createFieldConfigurationScheme {
    requestBody: RequestBody$createFieldConfigurationScheme["application/json"];
}
export declare type ResponseContentType$getFieldConfigurationSchemeMappings = keyof Response$getFieldConfigurationSchemeMappings$Status$200;
export interface Params$getFieldConfigurationSchemeMappings {
    parameter: Parameter$getFieldConfigurationSchemeMappings;
}
export declare type ResponseContentType$getFieldConfigurationSchemeProjectMapping = keyof Response$getFieldConfigurationSchemeProjectMapping$Status$200;
export interface Params$getFieldConfigurationSchemeProjectMapping {
    parameter: Parameter$getFieldConfigurationSchemeProjectMapping;
}
export declare type RequestContentType$assignFieldConfigurationSchemeToProject = keyof RequestBody$assignFieldConfigurationSchemeToProject;
export declare type ResponseContentType$assignFieldConfigurationSchemeToProject = keyof Response$assignFieldConfigurationSchemeToProject$Status$204;
export interface Params$assignFieldConfigurationSchemeToProject {
    requestBody: RequestBody$assignFieldConfigurationSchemeToProject["application/json"];
}
export declare type RequestContentType$updateFieldConfigurationScheme = keyof RequestBody$updateFieldConfigurationScheme;
export declare type ResponseContentType$updateFieldConfigurationScheme = keyof Response$updateFieldConfigurationScheme$Status$204;
export interface Params$updateFieldConfigurationScheme {
    parameter: Parameter$updateFieldConfigurationScheme;
    requestBody: RequestBody$updateFieldConfigurationScheme["application/json"];
}
export declare type ResponseContentType$deleteFieldConfigurationScheme = keyof Response$deleteFieldConfigurationScheme$Status$204;
export interface Params$deleteFieldConfigurationScheme {
    parameter: Parameter$deleteFieldConfigurationScheme;
}
export declare type RequestContentType$setFieldConfigurationSchemeMapping = keyof RequestBody$setFieldConfigurationSchemeMapping;
export declare type ResponseContentType$setFieldConfigurationSchemeMapping = keyof Response$setFieldConfigurationSchemeMapping$Status$204;
export interface Params$setFieldConfigurationSchemeMapping {
    parameter: Parameter$setFieldConfigurationSchemeMapping;
    requestBody: RequestBody$setFieldConfigurationSchemeMapping["application/json"];
}
export declare type RequestContentType$removeIssueTypesFromGlobalFieldConfigurationScheme = keyof RequestBody$removeIssueTypesFromGlobalFieldConfigurationScheme;
export declare type ResponseContentType$removeIssueTypesFromGlobalFieldConfigurationScheme = keyof Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$204;
export interface Params$removeIssueTypesFromGlobalFieldConfigurationScheme {
    parameter: Parameter$removeIssueTypesFromGlobalFieldConfigurationScheme;
    requestBody: RequestBody$removeIssueTypesFromGlobalFieldConfigurationScheme["application/json"];
}
export declare type ResponseContentType$getFilters = keyof Response$getFilters$Status$200;
export interface Params$getFilters {
    parameter: Parameter$getFilters;
}
export declare type RequestContentType$createFilter = keyof RequestBody$createFilter;
export declare type ResponseContentType$createFilter = keyof Response$createFilter$Status$200;
export interface Params$createFilter {
    parameter: Parameter$createFilter;
    requestBody: RequestBody$createFilter["application/json"];
}
export declare type ResponseContentType$getDefaultShareScope = keyof Response$getDefaultShareScope$Status$200;
export declare type RequestContentType$setDefaultShareScope = keyof RequestBody$setDefaultShareScope;
export declare type ResponseContentType$setDefaultShareScope = keyof Response$setDefaultShareScope$Status$200;
export interface Params$setDefaultShareScope {
    requestBody: RequestBody$setDefaultShareScope["application/json"];
}
export declare type ResponseContentType$getFavouriteFilters = keyof Response$getFavouriteFilters$Status$200;
export interface Params$getFavouriteFilters {
    parameter: Parameter$getFavouriteFilters;
}
export declare type ResponseContentType$getMyFilters = keyof Response$getMyFilters$Status$200;
export interface Params$getMyFilters {
    parameter: Parameter$getMyFilters;
}
export declare type ResponseContentType$getFiltersPaginated = keyof Response$getFiltersPaginated$Status$200;
export interface Params$getFiltersPaginated {
    parameter: Parameter$getFiltersPaginated;
}
export declare type ResponseContentType$getFilter = keyof Response$getFilter$Status$200;
export interface Params$getFilter {
    parameter: Parameter$getFilter;
}
export declare type RequestContentType$updateFilter = keyof RequestBody$updateFilter;
export declare type ResponseContentType$updateFilter = keyof Response$updateFilter$Status$200;
export interface Params$updateFilter {
    parameter: Parameter$updateFilter;
    requestBody: RequestBody$updateFilter["application/json"];
}
export interface Params$deleteFilter {
    parameter: Parameter$deleteFilter;
}
export declare type ResponseContentType$getColumns = keyof Response$getColumns$Status$200;
export interface Params$getColumns {
    parameter: Parameter$getColumns;
}
export declare type RequestContentType$setColumns = keyof RequestBody$setColumns;
export declare type ResponseContentType$setColumns = keyof Response$setColumns$Status$200;
export interface Params$setColumns<T extends RequestContentType$setColumns> {
    headers: {
        "Content-Type": T;
    };
    parameter: Parameter$setColumns;
    requestBody: RequestBody$setColumns[T];
}
export interface Params$resetColumns {
    parameter: Parameter$resetColumns;
}
export declare type ResponseContentType$setFavouriteForFilter = keyof Response$setFavouriteForFilter$Status$200;
export interface Params$setFavouriteForFilter {
    parameter: Parameter$setFavouriteForFilter;
}
export declare type ResponseContentType$deleteFavouriteForFilter = keyof Response$deleteFavouriteForFilter$Status$200;
export interface Params$deleteFavouriteForFilter {
    parameter: Parameter$deleteFavouriteForFilter;
}
export declare type ResponseContentType$getSharePermissions = keyof Response$getSharePermissions$Status$200;
export interface Params$getSharePermissions {
    parameter: Parameter$getSharePermissions;
}
export declare type RequestContentType$addSharePermission = keyof RequestBody$addSharePermission;
export declare type ResponseContentType$addSharePermission = keyof Response$addSharePermission$Status$201;
export interface Params$addSharePermission {
    parameter: Parameter$addSharePermission;
    requestBody: RequestBody$addSharePermission["application/json"];
}
export declare type ResponseContentType$getSharePermission = keyof Response$getSharePermission$Status$200;
export interface Params$getSharePermission {
    parameter: Parameter$getSharePermission;
}
export interface Params$deleteSharePermission {
    parameter: Parameter$deleteSharePermission;
}
export declare type ResponseContentType$getGroup = keyof Response$getGroup$Status$200;
export interface Params$getGroup {
    parameter: Parameter$getGroup;
}
export declare type RequestContentType$createGroup = keyof RequestBody$createGroup;
export declare type ResponseContentType$createGroup = keyof Response$createGroup$Status$201;
export interface Params$createGroup {
    requestBody: RequestBody$createGroup["application/json"];
}
export interface Params$removeGroup {
    parameter: Parameter$removeGroup;
}
export declare type ResponseContentType$bulkGetGroups = keyof Response$bulkGetGroups$Status$200;
export interface Params$bulkGetGroups {
    parameter: Parameter$bulkGetGroups;
}
export declare type ResponseContentType$getUsersFromGroup = keyof Response$getUsersFromGroup$Status$200;
export interface Params$getUsersFromGroup {
    parameter: Parameter$getUsersFromGroup;
}
export declare type RequestContentType$addUserToGroup = keyof RequestBody$addUserToGroup;
export declare type ResponseContentType$addUserToGroup = keyof Response$addUserToGroup$Status$201;
export interface Params$addUserToGroup {
    parameter: Parameter$addUserToGroup;
    requestBody: RequestBody$addUserToGroup["application/json"];
}
export interface Params$removeUserFromGroup {
    parameter: Parameter$removeUserFromGroup;
}
export declare type ResponseContentType$findGroups = keyof Response$findGroups$Status$200;
export interface Params$findGroups {
    parameter: Parameter$findGroups;
}
export declare type ResponseContentType$findUsersAndGroups = keyof Response$findUsersAndGroups$Status$200;
export interface Params$findUsersAndGroups {
    parameter: Parameter$findUsersAndGroups;
}
export declare type ResponseContentType$getLicense = keyof Response$getLicense$Status$200;
export declare type RequestContentType$createIssue = keyof RequestBody$createIssue;
export declare type ResponseContentType$createIssue = keyof Response$createIssue$Status$201;
export interface Params$createIssue {
    parameter: Parameter$createIssue;
    requestBody: RequestBody$createIssue["application/json"];
}
export declare type RequestContentType$createIssues = keyof RequestBody$createIssues;
export declare type ResponseContentType$createIssues = keyof Response$createIssues$Status$201;
export interface Params$createIssues {
    requestBody: RequestBody$createIssues["application/json"];
}
export declare type ResponseContentType$getCreateIssueMeta = keyof Response$getCreateIssueMeta$Status$200;
export interface Params$getCreateIssueMeta {
    parameter: Parameter$getCreateIssueMeta;
}
export declare type ResponseContentType$getIssuePickerResource = keyof Response$getIssuePickerResource$Status$200;
export interface Params$getIssuePickerResource {
    parameter: Parameter$getIssuePickerResource;
}
export declare type RequestContentType$bulkSetIssuesPropertiesList = keyof RequestBody$bulkSetIssuesPropertiesList;
export interface Params$bulkSetIssuesPropertiesList {
    requestBody: RequestBody$bulkSetIssuesPropertiesList["application/json"];
}
export declare type RequestContentType$bulkSetIssuePropertiesByIssue = keyof RequestBody$bulkSetIssuePropertiesByIssue;
export interface Params$bulkSetIssuePropertiesByIssue {
    requestBody: RequestBody$bulkSetIssuePropertiesByIssue["application/json"];
}
export declare type RequestContentType$bulkSetIssueProperty = keyof RequestBody$bulkSetIssueProperty;
export interface Params$bulkSetIssueProperty {
    parameter: Parameter$bulkSetIssueProperty;
    requestBody: RequestBody$bulkSetIssueProperty["application/json"];
}
export declare type RequestContentType$bulkDeleteIssueProperty = keyof RequestBody$bulkDeleteIssueProperty;
export interface Params$bulkDeleteIssueProperty {
    parameter: Parameter$bulkDeleteIssueProperty;
    requestBody: RequestBody$bulkDeleteIssueProperty["application/json"];
}
export declare type RequestContentType$getIsWatchingIssueBulk = keyof RequestBody$getIsWatchingIssueBulk;
export declare type ResponseContentType$getIsWatchingIssueBulk = keyof Response$getIsWatchingIssueBulk$Status$200;
export interface Params$getIsWatchingIssueBulk {
    requestBody: RequestBody$getIsWatchingIssueBulk["application/json"];
}
export declare type ResponseContentType$getIssue = keyof Response$getIssue$Status$200;
export interface Params$getIssue {
    parameter: Parameter$getIssue;
}
export declare type RequestContentType$editIssue = keyof RequestBody$editIssue;
export declare type ResponseContentType$editIssue = keyof Response$editIssue$Status$204;
export interface Params$editIssue {
    parameter: Parameter$editIssue;
    requestBody: RequestBody$editIssue["application/json"];
}
export interface Params$deleteIssue {
    parameter: Parameter$deleteIssue;
}
export declare type RequestContentType$assignIssue = keyof RequestBody$assignIssue;
export declare type ResponseContentType$assignIssue = keyof Response$assignIssue$Status$204;
export interface Params$assignIssue {
    parameter: Parameter$assignIssue;
    requestBody: RequestBody$assignIssue["application/json"];
}
export declare type RequestContentType$addAttachment = keyof RequestBody$addAttachment;
export declare type ResponseContentType$addAttachment = keyof Response$addAttachment$Status$200;
export interface Params$addAttachment {
    parameter: Parameter$addAttachment;
    requestBody: RequestBody$addAttachment["multipart/form-data"];
}
export declare type ResponseContentType$getChangeLogs = keyof Response$getChangeLogs$Status$200;
export interface Params$getChangeLogs {
    parameter: Parameter$getChangeLogs;
}
export declare type RequestContentType$getChangeLogsByIds = keyof RequestBody$getChangeLogsByIds;
export declare type ResponseContentType$getChangeLogsByIds = keyof Response$getChangeLogsByIds$Status$200;
export interface Params$getChangeLogsByIds {
    parameter: Parameter$getChangeLogsByIds;
    requestBody: RequestBody$getChangeLogsByIds["application/json"];
}
export declare type ResponseContentType$getComments = keyof Response$getComments$Status$200;
export interface Params$getComments {
    parameter: Parameter$getComments;
}
export declare type RequestContentType$addComment = keyof RequestBody$addComment;
export declare type ResponseContentType$addComment = keyof Response$addComment$Status$201;
export interface Params$addComment {
    parameter: Parameter$addComment;
    requestBody: RequestBody$addComment["application/json"];
}
export declare type ResponseContentType$getComment = keyof Response$getComment$Status$200;
export interface Params$getComment {
    parameter: Parameter$getComment;
}
export declare type RequestContentType$updateComment = keyof RequestBody$updateComment;
export declare type ResponseContentType$updateComment = keyof Response$updateComment$Status$200;
export interface Params$updateComment {
    parameter: Parameter$updateComment;
    requestBody: RequestBody$updateComment["application/json"];
}
export interface Params$deleteComment {
    parameter: Parameter$deleteComment;
}
export declare type ResponseContentType$getEditIssueMeta = keyof Response$getEditIssueMeta$Status$200;
export interface Params$getEditIssueMeta {
    parameter: Parameter$getEditIssueMeta;
}
export declare type RequestContentType$notify = keyof RequestBody$notify;
export declare type ResponseContentType$notify = keyof Response$notify$Status$204;
export interface Params$notify {
    parameter: Parameter$notify;
    requestBody: RequestBody$notify["application/json"];
}
export declare type ResponseContentType$getIssuePropertyKeys = keyof Response$getIssuePropertyKeys$Status$200;
export interface Params$getIssuePropertyKeys {
    parameter: Parameter$getIssuePropertyKeys;
}
export declare type ResponseContentType$getIssueProperty = keyof Response$getIssueProperty$Status$200;
export interface Params$getIssueProperty {
    parameter: Parameter$getIssueProperty;
}
export declare type RequestContentType$setIssueProperty = keyof RequestBody$setIssueProperty;
export declare type ResponseContentType$setIssueProperty = keyof Response$setIssueProperty$Status$200;
export interface Params$setIssueProperty {
    parameter: Parameter$setIssueProperty;
    requestBody: RequestBody$setIssueProperty["application/json"];
}
export interface Params$deleteIssueProperty {
    parameter: Parameter$deleteIssueProperty;
}
export declare type ResponseContentType$getRemoteIssueLinks = keyof Response$getRemoteIssueLinks$Status$200;
export interface Params$getRemoteIssueLinks {
    parameter: Parameter$getRemoteIssueLinks;
}
export declare type RequestContentType$createOrUpdateRemoteIssueLink = keyof RequestBody$createOrUpdateRemoteIssueLink;
export declare type ResponseContentType$createOrUpdateRemoteIssueLink = keyof Response$createOrUpdateRemoteIssueLink$Status$200;
export interface Params$createOrUpdateRemoteIssueLink {
    parameter: Parameter$createOrUpdateRemoteIssueLink;
    requestBody: RequestBody$createOrUpdateRemoteIssueLink["application/json"];
}
export interface Params$deleteRemoteIssueLinkByGlobalId {
    parameter: Parameter$deleteRemoteIssueLinkByGlobalId;
}
export declare type ResponseContentType$getRemoteIssueLinkById = keyof Response$getRemoteIssueLinkById$Status$200;
export interface Params$getRemoteIssueLinkById {
    parameter: Parameter$getRemoteIssueLinkById;
}
export declare type RequestContentType$updateRemoteIssueLink = keyof RequestBody$updateRemoteIssueLink;
export declare type ResponseContentType$updateRemoteIssueLink = keyof Response$updateRemoteIssueLink$Status$204;
export interface Params$updateRemoteIssueLink {
    parameter: Parameter$updateRemoteIssueLink;
    requestBody: RequestBody$updateRemoteIssueLink["application/json"];
}
export interface Params$deleteRemoteIssueLinkById {
    parameter: Parameter$deleteRemoteIssueLinkById;
}
export declare type ResponseContentType$getTransitions = keyof Response$getTransitions$Status$200;
export interface Params$getTransitions {
    parameter: Parameter$getTransitions;
}
export declare type RequestContentType$doTransition = keyof RequestBody$doTransition;
export declare type ResponseContentType$doTransition = keyof Response$doTransition$Status$204;
export interface Params$doTransition {
    parameter: Parameter$doTransition;
    requestBody: RequestBody$doTransition["application/json"];
}
export declare type ResponseContentType$getVotes = keyof Response$getVotes$Status$200;
export interface Params$getVotes {
    parameter: Parameter$getVotes;
}
export declare type ResponseContentType$addVote = keyof Response$addVote$Status$204;
export interface Params$addVote {
    parameter: Parameter$addVote;
}
export interface Params$removeVote {
    parameter: Parameter$removeVote;
}
export declare type ResponseContentType$getIssueWatchers = keyof Response$getIssueWatchers$Status$200;
export interface Params$getIssueWatchers {
    parameter: Parameter$getIssueWatchers;
}
export declare type RequestContentType$addWatcher = keyof RequestBody$addWatcher;
export declare type ResponseContentType$addWatcher = keyof Response$addWatcher$Status$204;
export interface Params$addWatcher {
    parameter: Parameter$addWatcher;
    requestBody: RequestBody$addWatcher["application/json"];
}
export interface Params$removeWatcher {
    parameter: Parameter$removeWatcher;
}
export declare type ResponseContentType$getIssueWorklog = keyof Response$getIssueWorklog$Status$200;
export interface Params$getIssueWorklog {
    parameter: Parameter$getIssueWorklog;
}
export declare type RequestContentType$addWorklog = keyof RequestBody$addWorklog;
export declare type ResponseContentType$addWorklog = keyof Response$addWorklog$Status$201;
export interface Params$addWorklog {
    parameter: Parameter$addWorklog;
    requestBody: RequestBody$addWorklog["application/json"];
}
export declare type ResponseContentType$getWorklog = keyof Response$getWorklog$Status$200;
export interface Params$getWorklog {
    parameter: Parameter$getWorklog;
}
export declare type RequestContentType$updateWorklog = keyof RequestBody$updateWorklog;
export declare type ResponseContentType$updateWorklog = keyof Response$updateWorklog$Status$200;
export interface Params$updateWorklog {
    parameter: Parameter$updateWorklog;
    requestBody: RequestBody$updateWorklog["application/json"];
}
export interface Params$deleteWorklog {
    parameter: Parameter$deleteWorklog;
}
export declare type ResponseContentType$getWorklogPropertyKeys = keyof Response$getWorklogPropertyKeys$Status$200;
export interface Params$getWorklogPropertyKeys {
    parameter: Parameter$getWorklogPropertyKeys;
}
export declare type ResponseContentType$getWorklogProperty = keyof Response$getWorklogProperty$Status$200;
export interface Params$getWorklogProperty {
    parameter: Parameter$getWorklogProperty;
}
export declare type RequestContentType$setWorklogProperty = keyof RequestBody$setWorklogProperty;
export declare type ResponseContentType$setWorklogProperty = keyof Response$setWorklogProperty$Status$200;
export interface Params$setWorklogProperty {
    parameter: Parameter$setWorklogProperty;
    requestBody: RequestBody$setWorklogProperty["application/json"];
}
export interface Params$deleteWorklogProperty {
    parameter: Parameter$deleteWorklogProperty;
}
export declare type RequestContentType$linkIssues = keyof RequestBody$linkIssues;
export declare type ResponseContentType$linkIssues = keyof Response$linkIssues$Status$201;
export interface Params$linkIssues {
    requestBody: RequestBody$linkIssues["application/json"];
}
export declare type ResponseContentType$getIssueLink = keyof Response$getIssueLink$Status$200;
export interface Params$getIssueLink {
    parameter: Parameter$getIssueLink;
}
export interface Params$deleteIssueLink {
    parameter: Parameter$deleteIssueLink;
}
export declare type ResponseContentType$getIssueLinkTypes = keyof Response$getIssueLinkTypes$Status$200;
export declare type RequestContentType$createIssueLinkType = keyof RequestBody$createIssueLinkType;
export declare type ResponseContentType$createIssueLinkType = keyof Response$createIssueLinkType$Status$201;
export interface Params$createIssueLinkType {
    requestBody: RequestBody$createIssueLinkType["application/json"];
}
export declare type ResponseContentType$getIssueLinkType = keyof Response$getIssueLinkType$Status$200;
export interface Params$getIssueLinkType {
    parameter: Parameter$getIssueLinkType;
}
export declare type RequestContentType$updateIssueLinkType = keyof RequestBody$updateIssueLinkType;
export declare type ResponseContentType$updateIssueLinkType = keyof Response$updateIssueLinkType$Status$200;
export interface Params$updateIssueLinkType {
    parameter: Parameter$updateIssueLinkType;
    requestBody: RequestBody$updateIssueLinkType["application/json"];
}
export interface Params$deleteIssueLinkType {
    parameter: Parameter$deleteIssueLinkType;
}
export declare type ResponseContentType$getIssueSecuritySchemes = keyof Response$getIssueSecuritySchemes$Status$200;
export declare type ResponseContentType$getIssueSecurityScheme = keyof Response$getIssueSecurityScheme$Status$200;
export interface Params$getIssueSecurityScheme {
    parameter: Parameter$getIssueSecurityScheme;
}
export declare type ResponseContentType$getIssueSecurityLevelMembers = keyof Response$getIssueSecurityLevelMembers$Status$200;
export interface Params$getIssueSecurityLevelMembers {
    parameter: Parameter$getIssueSecurityLevelMembers;
}
export declare type ResponseContentType$getIssueAllTypes = keyof Response$getIssueAllTypes$Status$200;
export declare type RequestContentType$createIssueType = keyof RequestBody$createIssueType;
export declare type ResponseContentType$createIssueType = keyof Response$createIssueType$Status$201;
export interface Params$createIssueType {
    requestBody: RequestBody$createIssueType["application/json"];
}
export declare type ResponseContentType$getIssueTypesForProject = keyof Response$getIssueTypesForProject$Status$200;
export interface Params$getIssueTypesForProject {
    parameter: Parameter$getIssueTypesForProject;
}
export declare type ResponseContentType$getIssueType = keyof Response$getIssueType$Status$200;
export interface Params$getIssueType {
    parameter: Parameter$getIssueType;
}
export declare type RequestContentType$updateIssueType = keyof RequestBody$updateIssueType;
export declare type ResponseContentType$updateIssueType = keyof Response$updateIssueType$Status$200;
export interface Params$updateIssueType {
    parameter: Parameter$updateIssueType;
    requestBody: RequestBody$updateIssueType["application/json"];
}
export interface Params$deleteIssueType {
    parameter: Parameter$deleteIssueType;
}
export declare type ResponseContentType$getAlternativeIssueTypes = keyof Response$getAlternativeIssueTypes$Status$200;
export interface Params$getAlternativeIssueTypes {
    parameter: Parameter$getAlternativeIssueTypes;
}
export declare type RequestContentType$createIssueTypeAvatar = keyof RequestBody$createIssueTypeAvatar;
export declare type ResponseContentType$createIssueTypeAvatar = keyof Response$createIssueTypeAvatar$Status$201;
export interface Params$createIssueTypeAvatar {
    parameter: Parameter$createIssueTypeAvatar;
    requestBody: RequestBody$createIssueTypeAvatar["*/*"];
}
export declare type ResponseContentType$getIssueTypePropertyKeys = keyof Response$getIssueTypePropertyKeys$Status$200;
export interface Params$getIssueTypePropertyKeys {
    parameter: Parameter$getIssueTypePropertyKeys;
}
export declare type ResponseContentType$getIssueTypeProperty = keyof Response$getIssueTypeProperty$Status$200;
export interface Params$getIssueTypeProperty {
    parameter: Parameter$getIssueTypeProperty;
}
export declare type RequestContentType$setIssueTypeProperty = keyof RequestBody$setIssueTypeProperty;
export declare type ResponseContentType$setIssueTypeProperty = keyof Response$setIssueTypeProperty$Status$200;
export interface Params$setIssueTypeProperty {
    parameter: Parameter$setIssueTypeProperty;
    requestBody: RequestBody$setIssueTypeProperty["application/json"];
}
export interface Params$deleteIssueTypeProperty {
    parameter: Parameter$deleteIssueTypeProperty;
}
export declare type ResponseContentType$getAllIssueTypeSchemes = keyof Response$getAllIssueTypeSchemes$Status$200;
export interface Params$getAllIssueTypeSchemes {
    parameter: Parameter$getAllIssueTypeSchemes;
}
export declare type RequestContentType$createIssueTypeScheme = keyof RequestBody$createIssueTypeScheme;
export declare type ResponseContentType$createIssueTypeScheme = keyof Response$createIssueTypeScheme$Status$201;
export interface Params$createIssueTypeScheme {
    requestBody: RequestBody$createIssueTypeScheme["application/json"];
}
export declare type ResponseContentType$getIssueTypeSchemesMapping = keyof Response$getIssueTypeSchemesMapping$Status$200;
export interface Params$getIssueTypeSchemesMapping {
    parameter: Parameter$getIssueTypeSchemesMapping;
}
export declare type ResponseContentType$getIssueTypeSchemeForProjects = keyof Response$getIssueTypeSchemeForProjects$Status$200;
export interface Params$getIssueTypeSchemeForProjects {
    parameter: Parameter$getIssueTypeSchemeForProjects;
}
export declare type RequestContentType$assignIssueTypeSchemeToProject = keyof RequestBody$assignIssueTypeSchemeToProject;
export declare type ResponseContentType$assignIssueTypeSchemeToProject = keyof Response$assignIssueTypeSchemeToProject$Status$204;
export interface Params$assignIssueTypeSchemeToProject {
    requestBody: RequestBody$assignIssueTypeSchemeToProject["application/json"];
}
export declare type RequestContentType$updateIssueTypeScheme = keyof RequestBody$updateIssueTypeScheme;
export declare type ResponseContentType$updateIssueTypeScheme = keyof Response$updateIssueTypeScheme$Status$204;
export interface Params$updateIssueTypeScheme {
    parameter: Parameter$updateIssueTypeScheme;
    requestBody: RequestBody$updateIssueTypeScheme["application/json"];
}
export declare type ResponseContentType$deleteIssueTypeScheme = keyof Response$deleteIssueTypeScheme$Status$204;
export interface Params$deleteIssueTypeScheme {
    parameter: Parameter$deleteIssueTypeScheme;
}
export declare type RequestContentType$addIssueTypesToIssueTypeScheme = keyof RequestBody$addIssueTypesToIssueTypeScheme;
export declare type ResponseContentType$addIssueTypesToIssueTypeScheme = keyof Response$addIssueTypesToIssueTypeScheme$Status$204;
export interface Params$addIssueTypesToIssueTypeScheme {
    parameter: Parameter$addIssueTypesToIssueTypeScheme;
    requestBody: RequestBody$addIssueTypesToIssueTypeScheme["application/json"];
}
export declare type RequestContentType$reorderIssueTypesInIssueTypeScheme = keyof RequestBody$reorderIssueTypesInIssueTypeScheme;
export declare type ResponseContentType$reorderIssueTypesInIssueTypeScheme = keyof Response$reorderIssueTypesInIssueTypeScheme$Status$204;
export interface Params$reorderIssueTypesInIssueTypeScheme {
    parameter: Parameter$reorderIssueTypesInIssueTypeScheme;
    requestBody: RequestBody$reorderIssueTypesInIssueTypeScheme["application/json"];
}
export declare type ResponseContentType$removeIssueTypeFromIssueTypeScheme = keyof Response$removeIssueTypeFromIssueTypeScheme$Status$204;
export interface Params$removeIssueTypeFromIssueTypeScheme {
    parameter: Parameter$removeIssueTypeFromIssueTypeScheme;
}
export declare type ResponseContentType$getIssueTypeScreenSchemes = keyof Response$getIssueTypeScreenSchemes$Status$200;
export interface Params$getIssueTypeScreenSchemes {
    parameter: Parameter$getIssueTypeScreenSchemes;
}
export declare type RequestContentType$createIssueTypeScreenScheme = keyof RequestBody$createIssueTypeScreenScheme;
export declare type ResponseContentType$createIssueTypeScreenScheme = keyof Response$createIssueTypeScreenScheme$Status$201;
export interface Params$createIssueTypeScreenScheme {
    requestBody: RequestBody$createIssueTypeScreenScheme["application/json"];
}
export declare type ResponseContentType$getIssueTypeScreenSchemeMappings = keyof Response$getIssueTypeScreenSchemeMappings$Status$200;
export interface Params$getIssueTypeScreenSchemeMappings {
    parameter: Parameter$getIssueTypeScreenSchemeMappings;
}
export declare type ResponseContentType$getIssueTypeScreenSchemeProjectAssociations = keyof Response$getIssueTypeScreenSchemeProjectAssociations$Status$200;
export interface Params$getIssueTypeScreenSchemeProjectAssociations {
    parameter: Parameter$getIssueTypeScreenSchemeProjectAssociations;
}
export declare type RequestContentType$assignIssueTypeScreenSchemeToProject = keyof RequestBody$assignIssueTypeScreenSchemeToProject;
export declare type ResponseContentType$assignIssueTypeScreenSchemeToProject = keyof Response$assignIssueTypeScreenSchemeToProject$Status$204;
export interface Params$assignIssueTypeScreenSchemeToProject {
    requestBody: RequestBody$assignIssueTypeScreenSchemeToProject["application/json"];
}
export declare type RequestContentType$updateIssueTypeScreenScheme = keyof RequestBody$updateIssueTypeScreenScheme;
export declare type ResponseContentType$updateIssueTypeScreenScheme = keyof Response$updateIssueTypeScreenScheme$Status$204;
export interface Params$updateIssueTypeScreenScheme {
    parameter: Parameter$updateIssueTypeScreenScheme;
    requestBody: RequestBody$updateIssueTypeScreenScheme["application/json"];
}
export declare type ResponseContentType$deleteIssueTypeScreenScheme = keyof Response$deleteIssueTypeScreenScheme$Status$204;
export interface Params$deleteIssueTypeScreenScheme {
    parameter: Parameter$deleteIssueTypeScreenScheme;
}
export declare type RequestContentType$appendMappingsForIssueTypeScreenScheme = keyof RequestBody$appendMappingsForIssueTypeScreenScheme;
export declare type ResponseContentType$appendMappingsForIssueTypeScreenScheme = keyof Response$appendMappingsForIssueTypeScreenScheme$Status$204;
export interface Params$appendMappingsForIssueTypeScreenScheme {
    parameter: Parameter$appendMappingsForIssueTypeScreenScheme;
    requestBody: RequestBody$appendMappingsForIssueTypeScreenScheme["application/json"];
}
export declare type RequestContentType$updateDefaultScreenScheme = keyof RequestBody$updateDefaultScreenScheme;
export declare type ResponseContentType$updateDefaultScreenScheme = keyof Response$updateDefaultScreenScheme$Status$204;
export interface Params$updateDefaultScreenScheme {
    parameter: Parameter$updateDefaultScreenScheme;
    requestBody: RequestBody$updateDefaultScreenScheme["application/json"];
}
export declare type RequestContentType$removeMappingsFromIssueTypeScreenScheme = keyof RequestBody$removeMappingsFromIssueTypeScreenScheme;
export declare type ResponseContentType$removeMappingsFromIssueTypeScreenScheme = keyof Response$removeMappingsFromIssueTypeScreenScheme$Status$204;
export interface Params$removeMappingsFromIssueTypeScreenScheme {
    parameter: Parameter$removeMappingsFromIssueTypeScreenScheme;
    requestBody: RequestBody$removeMappingsFromIssueTypeScreenScheme["application/json"];
}
export declare type ResponseContentType$getProjectsForIssueTypeScreenScheme = keyof Response$getProjectsForIssueTypeScreenScheme$Status$200;
export interface Params$getProjectsForIssueTypeScreenScheme {
    parameter: Parameter$getProjectsForIssueTypeScreenScheme;
}
export declare type ResponseContentType$getAutoComplete = keyof Response$getAutoComplete$Status$200;
export declare type RequestContentType$getAutoCompletePost = keyof RequestBody$getAutoCompletePost;
export declare type ResponseContentType$getAutoCompletePost = keyof Response$getAutoCompletePost$Status$200;
export interface Params$getAutoCompletePost {
    requestBody: RequestBody$getAutoCompletePost["application/json"];
}
export declare type ResponseContentType$getFieldAutoCompleteForQueryString = keyof Response$getFieldAutoCompleteForQueryString$Status$200;
export interface Params$getFieldAutoCompleteForQueryString {
    parameter: Parameter$getFieldAutoCompleteForQueryString;
}
export declare type RequestContentType$matchIssues = keyof RequestBody$matchIssues;
export declare type ResponseContentType$matchIssues = keyof Response$matchIssues$Status$200;
export interface Params$matchIssues {
    requestBody: RequestBody$matchIssues["application/json"];
}
export declare type RequestContentType$parseJqlQueries = keyof RequestBody$parseJqlQueries;
export declare type ResponseContentType$parseJqlQueries = keyof Response$parseJqlQueries$Status$200;
export interface Params$parseJqlQueries {
    parameter: Parameter$parseJqlQueries;
    requestBody: RequestBody$parseJqlQueries["application/json"];
}
export declare type RequestContentType$migrateQueries = keyof RequestBody$migrateQueries;
export declare type ResponseContentType$migrateQueries = keyof Response$migrateQueries$Status$200;
export interface Params$migrateQueries {
    requestBody: RequestBody$migrateQueries["application/json"];
}
export declare type ResponseContentType$getAllLabels = keyof Response$getAllLabels$Status$200;
export interface Params$getAllLabels {
    parameter: Parameter$getAllLabels;
}
export declare type ResponseContentType$getMyPermissions = keyof Response$getMyPermissions$Status$200;
export interface Params$getMyPermissions {
    parameter: Parameter$getMyPermissions;
}
export declare type ResponseContentType$getPreference = keyof Response$getPreference$Status$200;
export interface Params$getPreference {
    parameter: Parameter$getPreference;
}
export declare type RequestContentType$setPreference = keyof RequestBody$setPreference;
export declare type ResponseContentType$setPreference = keyof Response$setPreference$Status$204;
export interface Params$setPreference<T extends RequestContentType$setPreference> {
    headers: {
        "Content-Type": T;
    };
    parameter: Parameter$setPreference;
    requestBody: RequestBody$setPreference[T];
}
export interface Params$removePreference {
    parameter: Parameter$removePreference;
}
export declare type ResponseContentType$getLocale = keyof Response$getLocale$Status$200;
export declare type RequestContentType$setLocale = keyof RequestBody$setLocale;
export declare type ResponseContentType$setLocale = keyof Response$setLocale$Status$204;
export interface Params$setLocale {
    requestBody: RequestBody$setLocale["application/json"];
}
export declare type ResponseContentType$deleteLocale = keyof Response$deleteLocale$Status$204;
export declare type ResponseContentType$getCurrentUser = keyof Response$getCurrentUser$Status$200;
export interface Params$getCurrentUser {
    parameter: Parameter$getCurrentUser;
}
export declare type ResponseContentType$getNotificationSchemes = keyof Response$getNotificationSchemes$Status$200;
export interface Params$getNotificationSchemes {
    parameter: Parameter$getNotificationSchemes;
}
export declare type ResponseContentType$getNotificationScheme = keyof Response$getNotificationScheme$Status$200;
export interface Params$getNotificationScheme {
    parameter: Parameter$getNotificationScheme;
}
export declare type ResponseContentType$getAllPermissions = keyof Response$getAllPermissions$Status$200;
export declare type RequestContentType$getBulkPermissions = keyof RequestBody$getBulkPermissions;
export declare type ResponseContentType$getBulkPermissions = keyof Response$getBulkPermissions$Status$200;
export interface Params$getBulkPermissions {
    requestBody: RequestBody$getBulkPermissions["application/json"];
}
export declare type RequestContentType$getPermittedProjects = keyof RequestBody$getPermittedProjects;
export declare type ResponseContentType$getPermittedProjects = keyof Response$getPermittedProjects$Status$200;
export interface Params$getPermittedProjects {
    requestBody: RequestBody$getPermittedProjects["application/json"];
}
export declare type ResponseContentType$getAllPermissionSchemes = keyof Response$getAllPermissionSchemes$Status$200;
export interface Params$getAllPermissionSchemes {
    parameter: Parameter$getAllPermissionSchemes;
}
export declare type RequestContentType$createPermissionScheme = keyof RequestBody$createPermissionScheme;
export declare type ResponseContentType$createPermissionScheme = keyof Response$createPermissionScheme$Status$201;
export interface Params$createPermissionScheme {
    parameter: Parameter$createPermissionScheme;
    requestBody: RequestBody$createPermissionScheme["application/json"];
}
export declare type ResponseContentType$getPermissionScheme = keyof Response$getPermissionScheme$Status$200;
export interface Params$getPermissionScheme {
    parameter: Parameter$getPermissionScheme;
}
export declare type RequestContentType$updatePermissionScheme = keyof RequestBody$updatePermissionScheme;
export declare type ResponseContentType$updatePermissionScheme = keyof Response$updatePermissionScheme$Status$200;
export interface Params$updatePermissionScheme {
    parameter: Parameter$updatePermissionScheme;
    requestBody: RequestBody$updatePermissionScheme["application/json"];
}
export interface Params$deletePermissionScheme {
    parameter: Parameter$deletePermissionScheme;
}
export declare type ResponseContentType$getPermissionSchemeGrants = keyof Response$getPermissionSchemeGrants$Status$200;
export interface Params$getPermissionSchemeGrants {
    parameter: Parameter$getPermissionSchemeGrants;
}
export declare type RequestContentType$createPermissionGrant = keyof RequestBody$createPermissionGrant;
export declare type ResponseContentType$createPermissionGrant = keyof Response$createPermissionGrant$Status$201;
export interface Params$createPermissionGrant {
    parameter: Parameter$createPermissionGrant;
    requestBody: RequestBody$createPermissionGrant["application/json"];
}
export declare type ResponseContentType$getPermissionSchemeGrant = keyof Response$getPermissionSchemeGrant$Status$200;
export interface Params$getPermissionSchemeGrant {
    parameter: Parameter$getPermissionSchemeGrant;
}
export interface Params$deletePermissionSchemeEntity {
    parameter: Parameter$deletePermissionSchemeEntity;
}
export declare type ResponseContentType$getPriorities = keyof Response$getPriorities$Status$200;
export declare type ResponseContentType$getPriority = keyof Response$getPriority$Status$200;
export interface Params$getPriority {
    parameter: Parameter$getPriority;
}
export declare type ResponseContentType$getAllProjects = keyof Response$getAllProjects$Status$200;
export interface Params$getAllProjects {
    parameter: Parameter$getAllProjects;
}
export declare type RequestContentType$createProject = keyof RequestBody$createProject;
export declare type ResponseContentType$createProject = keyof Response$createProject$Status$201;
export interface Params$createProject {
    requestBody: RequestBody$createProject["application/json"];
}
export declare type ResponseContentType$getRecent = keyof Response$getRecent$Status$200;
export interface Params$getRecent {
    parameter: Parameter$getRecent;
}
export declare type ResponseContentType$searchProjects = keyof Response$searchProjects$Status$200;
export interface Params$searchProjects {
    parameter: Parameter$searchProjects;
}
export declare type ResponseContentType$getAllProjectTypes = keyof Response$getAllProjectTypes$Status$200;
export declare type ResponseContentType$getAllAccessibleProjectTypes = keyof Response$getAllAccessibleProjectTypes$Status$200;
export declare type ResponseContentType$getProjectTypeByKey = keyof Response$getProjectTypeByKey$Status$200;
export interface Params$getProjectTypeByKey {
    parameter: Parameter$getProjectTypeByKey;
}
export declare type ResponseContentType$getAccessibleProjectTypeByKey = keyof Response$getAccessibleProjectTypeByKey$Status$200;
export interface Params$getAccessibleProjectTypeByKey {
    parameter: Parameter$getAccessibleProjectTypeByKey;
}
export declare type ResponseContentType$getProject = keyof Response$getProject$Status$200;
export interface Params$getProject {
    parameter: Parameter$getProject;
}
export declare type RequestContentType$updateProject = keyof RequestBody$updateProject;
export declare type ResponseContentType$updateProject = keyof Response$updateProject$Status$200;
export interface Params$updateProject {
    parameter: Parameter$updateProject;
    requestBody: RequestBody$updateProject["application/json"];
}
export interface Params$deleteProject {
    parameter: Parameter$deleteProject;
}
export declare type ResponseContentType$archiveProject = keyof Response$archiveProject$Status$204;
export interface Params$archiveProject {
    parameter: Parameter$archiveProject;
}
export declare type RequestContentType$updateProjectAvatar = keyof RequestBody$updateProjectAvatar;
export declare type ResponseContentType$updateProjectAvatar = keyof Response$updateProjectAvatar$Status$204;
export interface Params$updateProjectAvatar {
    parameter: Parameter$updateProjectAvatar;
    requestBody: RequestBody$updateProjectAvatar["application/json"];
}
export interface Params$deleteProjectAvatar {
    parameter: Parameter$deleteProjectAvatar;
}
export declare type RequestContentType$createProjectAvatar = keyof RequestBody$createProjectAvatar;
export declare type ResponseContentType$createProjectAvatar = keyof Response$createProjectAvatar$Status$201;
export interface Params$createProjectAvatar {
    parameter: Parameter$createProjectAvatar;
    requestBody: RequestBody$createProjectAvatar["*/*"];
}
export declare type ResponseContentType$getAllProjectAvatars = keyof Response$getAllProjectAvatars$Status$200;
export interface Params$getAllProjectAvatars {
    parameter: Parameter$getAllProjectAvatars;
}
export declare type ResponseContentType$getProjectComponentsPaginated = keyof Response$getProjectComponentsPaginated$Status$200;
export interface Params$getProjectComponentsPaginated {
    parameter: Parameter$getProjectComponentsPaginated;
}
export declare type ResponseContentType$getProjectComponents = keyof Response$getProjectComponents$Status$200;
export interface Params$getProjectComponents {
    parameter: Parameter$getProjectComponents;
}
export interface Params$deleteProjectAsynchronously {
    parameter: Parameter$deleteProjectAsynchronously;
}
export declare type ResponseContentType$getFeaturesForProject = keyof Response$getFeaturesForProject$Status$200;
export interface Params$getFeaturesForProject {
    parameter: Parameter$getFeaturesForProject;
}
export declare type RequestContentType$toggleFeatureForProject = keyof RequestBody$toggleFeatureForProject;
export declare type ResponseContentType$toggleFeatureForProject = keyof Response$toggleFeatureForProject$Status$200;
export interface Params$toggleFeatureForProject {
    parameter: Parameter$toggleFeatureForProject;
    requestBody: RequestBody$toggleFeatureForProject["application/json"];
}
export declare type ResponseContentType$getProjectPropertyKeys = keyof Response$getProjectPropertyKeys$Status$200;
export interface Params$getProjectPropertyKeys {
    parameter: Parameter$getProjectPropertyKeys;
}
export declare type ResponseContentType$getProjectProperty = keyof Response$getProjectProperty$Status$200;
export interface Params$getProjectProperty {
    parameter: Parameter$getProjectProperty;
}
export declare type RequestContentType$setProjectProperty = keyof RequestBody$setProjectProperty;
export declare type ResponseContentType$setProjectProperty = keyof Response$setProjectProperty$Status$200;
export interface Params$setProjectProperty {
    parameter: Parameter$setProjectProperty;
    requestBody: RequestBody$setProjectProperty["application/json"];
}
export interface Params$deleteProjectProperty {
    parameter: Parameter$deleteProjectProperty;
}
export declare type ResponseContentType$restore = keyof Response$restore$Status$200;
export interface Params$restore {
    parameter: Parameter$restore;
}
export declare type ResponseContentType$getProjectRoles = keyof Response$getProjectRoles$Status$200;
export interface Params$getProjectRoles {
    parameter: Parameter$getProjectRoles;
}
export declare type ResponseContentType$getProjectRole = keyof Response$getProjectRole$Status$200;
export interface Params$getProjectRole {
    parameter: Parameter$getProjectRole;
}
export declare type RequestContentType$setActors = keyof RequestBody$setActors;
export declare type ResponseContentType$setActors = keyof Response$setActors$Status$200;
export interface Params$setActors {
    parameter: Parameter$setActors;
    requestBody: RequestBody$setActors["application/json"];
}
export declare type RequestContentType$addActorUsers = keyof RequestBody$addActorUsers;
export declare type ResponseContentType$addActorUsers = keyof Response$addActorUsers$Status$200;
export interface Params$addActorUsers {
    parameter: Parameter$addActorUsers;
    requestBody: RequestBody$addActorUsers["application/json"];
}
export interface Params$deleteActor {
    parameter: Parameter$deleteActor;
}
export declare type ResponseContentType$getProjectRoleDetails = keyof Response$getProjectRoleDetails$Status$200;
export interface Params$getProjectRoleDetails {
    parameter: Parameter$getProjectRoleDetails;
}
export declare type ResponseContentType$getAllStatuses = keyof Response$getAllStatuses$Status$200;
export interface Params$getAllStatuses {
    parameter: Parameter$getAllStatuses;
}
export declare type ResponseContentType$updateProjectType = keyof Response$updateProjectType$Status$200;
export interface Params$updateProjectType {
    parameter: Parameter$updateProjectType;
}
export declare type ResponseContentType$getProjectVersionsPaginated = keyof Response$getProjectVersionsPaginated$Status$200;
export interface Params$getProjectVersionsPaginated {
    parameter: Parameter$getProjectVersionsPaginated;
}
export declare type ResponseContentType$getProjectVersions = keyof Response$getProjectVersions$Status$200;
export interface Params$getProjectVersions {
    parameter: Parameter$getProjectVersions;
}
export declare type ResponseContentType$getProjectEmail = keyof Response$getProjectEmail$Status$200;
export interface Params$getProjectEmail {
    parameter: Parameter$getProjectEmail;
}
export declare type RequestContentType$updateProjectEmail = keyof RequestBody$updateProjectEmail;
export declare type ResponseContentType$updateProjectEmail = keyof Response$updateProjectEmail$Status$204;
export interface Params$updateProjectEmail {
    parameter: Parameter$updateProjectEmail;
    requestBody: RequestBody$updateProjectEmail["application/json"];
}
export declare type ResponseContentType$getHierarchy = keyof Response$getHierarchy$Status$200;
export interface Params$getHierarchy {
    parameter: Parameter$getHierarchy;
}
export declare type ResponseContentType$getProjectIssueSecurityScheme = keyof Response$getProjectIssueSecurityScheme$Status$200;
export interface Params$getProjectIssueSecurityScheme {
    parameter: Parameter$getProjectIssueSecurityScheme;
}
export declare type ResponseContentType$getNotificationSchemeForProject = keyof Response$getNotificationSchemeForProject$Status$200;
export interface Params$getNotificationSchemeForProject {
    parameter: Parameter$getNotificationSchemeForProject;
}
export declare type ResponseContentType$getAssignedPermissionScheme = keyof Response$getAssignedPermissionScheme$Status$200;
export interface Params$getAssignedPermissionScheme {
    parameter: Parameter$getAssignedPermissionScheme;
}
export declare type RequestContentType$assignPermissionScheme = keyof RequestBody$assignPermissionScheme;
export declare type ResponseContentType$assignPermissionScheme = keyof Response$assignPermissionScheme$Status$200;
export interface Params$assignPermissionScheme {
    parameter: Parameter$assignPermissionScheme;
    requestBody: RequestBody$assignPermissionScheme["application/json"];
}
export declare type ResponseContentType$getSecurityLevelsForProject = keyof Response$getSecurityLevelsForProject$Status$200;
export interface Params$getSecurityLevelsForProject {
    parameter: Parameter$getSecurityLevelsForProject;
}
export declare type ResponseContentType$getAllProjectCategories = keyof Response$getAllProjectCategories$Status$200;
export declare type RequestContentType$createProjectCategory = keyof RequestBody$createProjectCategory;
export declare type ResponseContentType$createProjectCategory = keyof Response$createProjectCategory$Status$201;
export interface Params$createProjectCategory {
    requestBody: RequestBody$createProjectCategory["application/json"];
}
export declare type ResponseContentType$getProjectCategoryById = keyof Response$getProjectCategoryById$Status$200;
export interface Params$getProjectCategoryById {
    parameter: Parameter$getProjectCategoryById;
}
export declare type RequestContentType$updateProjectCategory = keyof RequestBody$updateProjectCategory;
export declare type ResponseContentType$updateProjectCategory = keyof Response$updateProjectCategory$Status$200;
export interface Params$updateProjectCategory {
    parameter: Parameter$updateProjectCategory;
    requestBody: RequestBody$updateProjectCategory["application/json"];
}
export interface Params$removeProjectCategory {
    parameter: Parameter$removeProjectCategory;
}
export declare type ResponseContentType$validateProjectKey = keyof Response$validateProjectKey$Status$200;
export interface Params$validateProjectKey {
    parameter: Parameter$validateProjectKey;
}
export declare type ResponseContentType$getValidProjectKey = keyof Response$getValidProjectKey$Status$200;
export interface Params$getValidProjectKey {
    parameter: Parameter$getValidProjectKey;
}
export declare type ResponseContentType$getValidProjectName = keyof Response$getValidProjectName$Status$200;
export interface Params$getValidProjectName {
    parameter: Parameter$getValidProjectName;
}
export declare type ResponseContentType$getResolutions = keyof Response$getResolutions$Status$200;
export declare type ResponseContentType$getResolution = keyof Response$getResolution$Status$200;
export interface Params$getResolution {
    parameter: Parameter$getResolution;
}
export declare type ResponseContentType$getAllProjectRoles = keyof Response$getAllProjectRoles$Status$200;
export declare type RequestContentType$createProjectRole = keyof RequestBody$createProjectRole;
export declare type ResponseContentType$createProjectRole = keyof Response$createProjectRole$Status$200;
export interface Params$createProjectRole {
    requestBody: RequestBody$createProjectRole["application/json"];
}
export declare type ResponseContentType$getProjectRoleById = keyof Response$getProjectRoleById$Status$200;
export interface Params$getProjectRoleById {
    parameter: Parameter$getProjectRoleById;
}
export declare type RequestContentType$fullyUpdateProjectRole = keyof RequestBody$fullyUpdateProjectRole;
export declare type ResponseContentType$fullyUpdateProjectRole = keyof Response$fullyUpdateProjectRole$Status$200;
export interface Params$fullyUpdateProjectRole {
    parameter: Parameter$fullyUpdateProjectRole;
    requestBody: RequestBody$fullyUpdateProjectRole["application/json"];
}
export declare type RequestContentType$partialUpdateProjectRole = keyof RequestBody$partialUpdateProjectRole;
export declare type ResponseContentType$partialUpdateProjectRole = keyof Response$partialUpdateProjectRole$Status$200;
export interface Params$partialUpdateProjectRole {
    parameter: Parameter$partialUpdateProjectRole;
    requestBody: RequestBody$partialUpdateProjectRole["application/json"];
}
export interface Params$deleteProjectRole {
    parameter: Parameter$deleteProjectRole;
}
export declare type ResponseContentType$getProjectRoleActorsForRole = keyof Response$getProjectRoleActorsForRole$Status$200;
export interface Params$getProjectRoleActorsForRole {
    parameter: Parameter$getProjectRoleActorsForRole;
}
export declare type RequestContentType$addProjectRoleActorsToRole = keyof RequestBody$addProjectRoleActorsToRole;
export declare type ResponseContentType$addProjectRoleActorsToRole = keyof Response$addProjectRoleActorsToRole$Status$200;
export interface Params$addProjectRoleActorsToRole {
    parameter: Parameter$addProjectRoleActorsToRole;
    requestBody: RequestBody$addProjectRoleActorsToRole["application/json"];
}
export declare type ResponseContentType$deleteProjectRoleActorsFromRole = keyof Response$deleteProjectRoleActorsFromRole$Status$200;
export interface Params$deleteProjectRoleActorsFromRole {
    parameter: Parameter$deleteProjectRoleActorsFromRole;
}
export declare type ResponseContentType$getScreens = keyof Response$getScreens$Status$200;
export interface Params$getScreens {
    parameter: Parameter$getScreens;
}
export declare type RequestContentType$createScreen = keyof RequestBody$createScreen;
export declare type ResponseContentType$createScreen = keyof Response$createScreen$Status$201;
export interface Params$createScreen {
    requestBody: RequestBody$createScreen["application/json"];
}
export declare type ResponseContentType$addFieldToDefaultScreen = keyof Response$addFieldToDefaultScreen$Status$200;
export interface Params$addFieldToDefaultScreen {
    parameter: Parameter$addFieldToDefaultScreen;
}
export declare type RequestContentType$updateScreen = keyof RequestBody$updateScreen;
export declare type ResponseContentType$updateScreen = keyof Response$updateScreen$Status$200;
export interface Params$updateScreen {
    parameter: Parameter$updateScreen;
    requestBody: RequestBody$updateScreen["application/json"];
}
export interface Params$deleteScreen {
    parameter: Parameter$deleteScreen;
}
export declare type ResponseContentType$getAvailableScreenFields = keyof Response$getAvailableScreenFields$Status$200;
export interface Params$getAvailableScreenFields {
    parameter: Parameter$getAvailableScreenFields;
}
export declare type ResponseContentType$getAllScreenTabs = keyof Response$getAllScreenTabs$Status$200;
export interface Params$getAllScreenTabs {
    parameter: Parameter$getAllScreenTabs;
}
export declare type RequestContentType$addScreenTab = keyof RequestBody$addScreenTab;
export declare type ResponseContentType$addScreenTab = keyof Response$addScreenTab$Status$200;
export interface Params$addScreenTab {
    parameter: Parameter$addScreenTab;
    requestBody: RequestBody$addScreenTab["application/json"];
}
export declare type RequestContentType$renameScreenTab = keyof RequestBody$renameScreenTab;
export declare type ResponseContentType$renameScreenTab = keyof Response$renameScreenTab$Status$200;
export interface Params$renameScreenTab {
    parameter: Parameter$renameScreenTab;
    requestBody: RequestBody$renameScreenTab["application/json"];
}
export interface Params$deleteScreenTab {
    parameter: Parameter$deleteScreenTab;
}
export declare type ResponseContentType$getAllScreenTabFields = keyof Response$getAllScreenTabFields$Status$200;
export interface Params$getAllScreenTabFields {
    parameter: Parameter$getAllScreenTabFields;
}
export declare type RequestContentType$addScreenTabField = keyof RequestBody$addScreenTabField;
export declare type ResponseContentType$addScreenTabField = keyof Response$addScreenTabField$Status$200;
export interface Params$addScreenTabField {
    parameter: Parameter$addScreenTabField;
    requestBody: RequestBody$addScreenTabField["application/json"];
}
export interface Params$removeScreenTabField {
    parameter: Parameter$removeScreenTabField;
}
export declare type RequestContentType$moveScreenTabField = keyof RequestBody$moveScreenTabField;
export declare type ResponseContentType$moveScreenTabField = keyof Response$moveScreenTabField$Status$204;
export interface Params$moveScreenTabField {
    parameter: Parameter$moveScreenTabField;
    requestBody: RequestBody$moveScreenTabField["application/json"];
}
export declare type ResponseContentType$moveScreenTab = keyof Response$moveScreenTab$Status$204;
export interface Params$moveScreenTab {
    parameter: Parameter$moveScreenTab;
}
export declare type ResponseContentType$getScreenSchemes = keyof Response$getScreenSchemes$Status$200;
export interface Params$getScreenSchemes {
    parameter: Parameter$getScreenSchemes;
}
export declare type RequestContentType$createScreenScheme = keyof RequestBody$createScreenScheme;
export declare type ResponseContentType$createScreenScheme = keyof Response$createScreenScheme$Status$201;
export interface Params$createScreenScheme {
    requestBody: RequestBody$createScreenScheme["application/json"];
}
export declare type RequestContentType$updateScreenScheme = keyof RequestBody$updateScreenScheme;
export declare type ResponseContentType$updateScreenScheme = keyof Response$updateScreenScheme$Status$204;
export interface Params$updateScreenScheme {
    parameter: Parameter$updateScreenScheme;
    requestBody: RequestBody$updateScreenScheme["application/json"];
}
export interface Params$deleteScreenScheme {
    parameter: Parameter$deleteScreenScheme;
}
export declare type ResponseContentType$searchForIssuesUsingJql = keyof Response$searchForIssuesUsingJql$Status$200;
export interface Params$searchForIssuesUsingJql {
    parameter: Parameter$searchForIssuesUsingJql;
}
export declare type RequestContentType$searchForIssuesUsingJqlPost = keyof RequestBody$searchForIssuesUsingJqlPost;
export declare type ResponseContentType$searchForIssuesUsingJqlPost = keyof Response$searchForIssuesUsingJqlPost$Status$200;
export interface Params$searchForIssuesUsingJqlPost {
    requestBody: RequestBody$searchForIssuesUsingJqlPost["application/json"];
}
export declare type ResponseContentType$getIssueSecurityLevel = keyof Response$getIssueSecurityLevel$Status$200;
export interface Params$getIssueSecurityLevel {
    parameter: Parameter$getIssueSecurityLevel;
}
export declare type ResponseContentType$getServerInfo = keyof Response$getServerInfo$Status$200;
export declare type ResponseContentType$getIssueNavigatorDefaultColumns = keyof Response$getIssueNavigatorDefaultColumns$Status$200;
export declare type RequestContentType$setIssueNavigatorDefaultColumns = keyof RequestBody$setIssueNavigatorDefaultColumns;
export declare type ResponseContentType$setIssueNavigatorDefaultColumns = keyof Response$setIssueNavigatorDefaultColumns$Status$200;
export interface Params$setIssueNavigatorDefaultColumns<T extends RequestContentType$setIssueNavigatorDefaultColumns> {
    headers: {
        "Content-Type": T;
    };
    requestBody: RequestBody$setIssueNavigatorDefaultColumns[T];
}
export declare type ResponseContentType$getStatuses = keyof Response$getStatuses$Status$200;
export declare type ResponseContentType$getStatus = keyof Response$getStatus$Status$200;
export interface Params$getStatus {
    parameter: Parameter$getStatus;
}
export declare type ResponseContentType$getStatusCategories = keyof Response$getStatusCategories$Status$200;
export declare type ResponseContentType$getStatusCategory = keyof Response$getStatusCategory$Status$200;
export interface Params$getStatusCategory {
    parameter: Parameter$getStatusCategory;
}
export declare type ResponseContentType$getTask = keyof Response$getTask$Status$200;
export interface Params$getTask {
    parameter: Parameter$getTask;
}
export declare type ResponseContentType$cancelTask = keyof Response$cancelTask$Status$202;
export interface Params$cancelTask {
    parameter: Parameter$cancelTask;
}
export declare type ResponseContentType$getAvatars = keyof Response$getAvatars$Status$200;
export interface Params$getAvatars {
    parameter: Parameter$getAvatars;
}
export declare type RequestContentType$storeAvatar = keyof RequestBody$storeAvatar;
export declare type ResponseContentType$storeAvatar = keyof Response$storeAvatar$Status$201;
export interface Params$storeAvatar {
    parameter: Parameter$storeAvatar;
    requestBody: RequestBody$storeAvatar["*/*"];
}
export interface Params$deleteAvatar {
    parameter: Parameter$deleteAvatar;
}
export declare type ResponseContentType$getAvatarImageByType = keyof Response$getAvatarImageByType$Status$200;
export interface Params$getAvatarImageByType<U extends ResponseContentType$getAvatarImageByType> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$getAvatarImageByType;
}
export declare type ResponseContentType$getAvatarImageByID = keyof Response$getAvatarImageByID$Status$200;
export interface Params$getAvatarImageByID<U extends ResponseContentType$getAvatarImageByID> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$getAvatarImageByID;
}
export declare type ResponseContentType$getAvatarImageByOwner = keyof Response$getAvatarImageByOwner$Status$200;
export interface Params$getAvatarImageByOwner<U extends ResponseContentType$getAvatarImageByOwner> {
    headers: {
        Accept: U;
    };
    parameter: Parameter$getAvatarImageByOwner;
}
export declare type ResponseContentType$getUser = keyof Response$getUser$Status$200;
export interface Params$getUser {
    parameter: Parameter$getUser;
}
export declare type RequestContentType$createUser = keyof RequestBody$createUser;
export declare type ResponseContentType$createUser = keyof Response$createUser$Status$201;
export interface Params$createUser {
    requestBody: RequestBody$createUser["application/json"];
}
export interface Params$removeUser {
    parameter: Parameter$removeUser;
}
export declare type ResponseContentType$findBulkAssignableUsers = keyof Response$findBulkAssignableUsers$Status$200;
export interface Params$findBulkAssignableUsers {
    parameter: Parameter$findBulkAssignableUsers;
}
export declare type ResponseContentType$findAssignableUsers = keyof Response$findAssignableUsers$Status$200;
export interface Params$findAssignableUsers {
    parameter: Parameter$findAssignableUsers;
}
export declare type ResponseContentType$bulkGetUsers = keyof Response$bulkGetUsers$Status$200;
export interface Params$bulkGetUsers {
    parameter: Parameter$bulkGetUsers;
}
export declare type ResponseContentType$bulkGetUsersMigration = keyof Response$bulkGetUsersMigration$Status$200;
export interface Params$bulkGetUsersMigration {
    parameter: Parameter$bulkGetUsersMigration;
}
export declare type ResponseContentType$getUserDefaultColumns = keyof Response$getUserDefaultColumns$Status$200;
export interface Params$getUserDefaultColumns {
    parameter: Parameter$getUserDefaultColumns;
}
export declare type RequestContentType$setUserColumns = keyof RequestBody$setUserColumns;
export declare type ResponseContentType$setUserColumns = keyof Response$setUserColumns$Status$200;
export interface Params$setUserColumns<T extends RequestContentType$setUserColumns> {
    headers: {
        "Content-Type": T;
    };
    parameter: Parameter$setUserColumns;
    requestBody: RequestBody$setUserColumns[T];
}
export interface Params$resetUserColumns {
    parameter: Parameter$resetUserColumns;
}
export declare type ResponseContentType$getUserEmail = keyof Response$getUserEmail$Status$200;
export interface Params$getUserEmail {
    parameter: Parameter$getUserEmail;
}
export declare type ResponseContentType$getUserEmailBulk = keyof Response$getUserEmailBulk$Status$200;
export interface Params$getUserEmailBulk {
    parameter: Parameter$getUserEmailBulk;
}
export declare type ResponseContentType$getUserGroups = keyof Response$getUserGroups$Status$200;
export interface Params$getUserGroups {
    parameter: Parameter$getUserGroups;
}
export declare type ResponseContentType$findUsersWithAllPermissions = keyof Response$findUsersWithAllPermissions$Status$200;
export interface Params$findUsersWithAllPermissions {
    parameter: Parameter$findUsersWithAllPermissions;
}
export declare type ResponseContentType$findUsersForPicker = keyof Response$findUsersForPicker$Status$200;
export interface Params$findUsersForPicker {
    parameter: Parameter$findUsersForPicker;
}
export declare type ResponseContentType$getUserPropertyKeys = keyof Response$getUserPropertyKeys$Status$200;
export interface Params$getUserPropertyKeys {
    parameter: Parameter$getUserPropertyKeys;
}
export declare type ResponseContentType$getUserProperty = keyof Response$getUserProperty$Status$200;
export interface Params$getUserProperty {
    parameter: Parameter$getUserProperty;
}
export declare type RequestContentType$setUserProperty = keyof RequestBody$setUserProperty;
export declare type ResponseContentType$setUserProperty = keyof Response$setUserProperty$Status$200;
export interface Params$setUserProperty {
    parameter: Parameter$setUserProperty;
    requestBody: RequestBody$setUserProperty["application/json"];
}
export interface Params$deleteUserProperty {
    parameter: Parameter$deleteUserProperty;
}
export declare type ResponseContentType$findUsers = keyof Response$findUsers$Status$200;
export interface Params$findUsers {
    parameter: Parameter$findUsers;
}
export declare type ResponseContentType$findUsersByQuery = keyof Response$findUsersByQuery$Status$200;
export interface Params$findUsersByQuery {
    parameter: Parameter$findUsersByQuery;
}
export declare type ResponseContentType$findUserKeysByQuery = keyof Response$findUserKeysByQuery$Status$200;
export interface Params$findUserKeysByQuery {
    parameter: Parameter$findUserKeysByQuery;
}
export declare type ResponseContentType$findUsersWithBrowsePermission = keyof Response$findUsersWithBrowsePermission$Status$200;
export interface Params$findUsersWithBrowsePermission {
    parameter: Parameter$findUsersWithBrowsePermission;
}
export declare type ResponseContentType$getAllUsersDefault = keyof Response$getAllUsersDefault$Status$200;
export interface Params$getAllUsersDefault {
    parameter: Parameter$getAllUsersDefault;
}
export declare type ResponseContentType$getAllUsers = keyof Response$getAllUsers$Status$200;
export interface Params$getAllUsers {
    parameter: Parameter$getAllUsers;
}
export declare type RequestContentType$createVersion = keyof RequestBody$createVersion;
export declare type ResponseContentType$createVersion = keyof Response$createVersion$Status$201;
export interface Params$createVersion {
    requestBody: RequestBody$createVersion["application/json"];
}
export declare type ResponseContentType$getVersion = keyof Response$getVersion$Status$200;
export interface Params$getVersion {
    parameter: Parameter$getVersion;
}
export declare type RequestContentType$updateVersion = keyof RequestBody$updateVersion;
export declare type ResponseContentType$updateVersion = keyof Response$updateVersion$Status$200;
export interface Params$updateVersion {
    parameter: Parameter$updateVersion;
    requestBody: RequestBody$updateVersion["application/json"];
}
export interface Params$deleteVersion {
    parameter: Parameter$deleteVersion;
}
export declare type ResponseContentType$mergeVersions = keyof Response$mergeVersions$Status$204;
export interface Params$mergeVersions {
    parameter: Parameter$mergeVersions;
}
export declare type RequestContentType$moveVersion = keyof RequestBody$moveVersion;
export declare type ResponseContentType$moveVersion = keyof Response$moveVersion$Status$200;
export interface Params$moveVersion {
    parameter: Parameter$moveVersion;
    requestBody: RequestBody$moveVersion["application/json"];
}
export declare type ResponseContentType$getVersionRelatedIssues = keyof Response$getVersionRelatedIssues$Status$200;
export interface Params$getVersionRelatedIssues {
    parameter: Parameter$getVersionRelatedIssues;
}
export declare type RequestContentType$deleteAndReplaceVersion = keyof RequestBody$deleteAndReplaceVersion;
export declare type ResponseContentType$deleteAndReplaceVersion = keyof Response$deleteAndReplaceVersion$Status$204;
export interface Params$deleteAndReplaceVersion {
    parameter: Parameter$deleteAndReplaceVersion;
    requestBody: RequestBody$deleteAndReplaceVersion["application/json"];
}
export declare type ResponseContentType$getVersionUnresolvedIssues = keyof Response$getVersionUnresolvedIssues$Status$200;
export interface Params$getVersionUnresolvedIssues {
    parameter: Parameter$getVersionUnresolvedIssues;
}
export declare type ResponseContentType$getDynamicWebhooksForApp = keyof Response$getDynamicWebhooksForApp$Status$200;
export interface Params$getDynamicWebhooksForApp {
    parameter: Parameter$getDynamicWebhooksForApp;
}
export declare type RequestContentType$registerDynamicWebhooks = keyof RequestBody$registerDynamicWebhooks;
export declare type ResponseContentType$registerDynamicWebhooks = keyof Response$registerDynamicWebhooks$Status$200;
export interface Params$registerDynamicWebhooks {
    requestBody: RequestBody$registerDynamicWebhooks["application/json"];
}
export declare type RequestContentType$deleteWebhookById = keyof RequestBody$deleteWebhookById;
export interface Params$deleteWebhookById {
    requestBody: RequestBody$deleteWebhookById["application/json"];
}
export declare type ResponseContentType$getFailedWebhooks = keyof Response$getFailedWebhooks$Status$200;
export interface Params$getFailedWebhooks {
    parameter: Parameter$getFailedWebhooks;
}
export declare type RequestContentType$refreshWebhooks = keyof RequestBody$refreshWebhooks;
export declare type ResponseContentType$refreshWebhooks = keyof Response$refreshWebhooks$Status$200;
export interface Params$refreshWebhooks {
    requestBody: RequestBody$refreshWebhooks["application/json"];
}
export declare type ResponseContentType$getAllWorkflows = keyof Response$getAllWorkflows$Status$200;
export interface Params$getAllWorkflows {
    parameter: Parameter$getAllWorkflows;
}
export declare type RequestContentType$createWorkflow = keyof RequestBody$createWorkflow;
export declare type ResponseContentType$createWorkflow = keyof Response$createWorkflow$Status$201;
export interface Params$createWorkflow {
    requestBody: RequestBody$createWorkflow["application/json"];
}
export declare type ResponseContentType$getWorkflowTransitionRuleConfigurations = keyof Response$getWorkflowTransitionRuleConfigurations$Status$200;
export interface Params$getWorkflowTransitionRuleConfigurations {
    parameter: Parameter$getWorkflowTransitionRuleConfigurations;
}
export declare type RequestContentType$updateWorkflowTransitionRuleConfigurations = keyof RequestBody$updateWorkflowTransitionRuleConfigurations;
export declare type ResponseContentType$updateWorkflowTransitionRuleConfigurations = keyof Response$updateWorkflowTransitionRuleConfigurations$Status$200;
export interface Params$updateWorkflowTransitionRuleConfigurations {
    requestBody: RequestBody$updateWorkflowTransitionRuleConfigurations["application/json"];
}
export declare type RequestContentType$deleteWorkflowTransitionRuleConfigurations = keyof RequestBody$deleteWorkflowTransitionRuleConfigurations;
export declare type ResponseContentType$deleteWorkflowTransitionRuleConfigurations = keyof Response$deleteWorkflowTransitionRuleConfigurations$Status$200;
export interface Params$deleteWorkflowTransitionRuleConfigurations {
    requestBody: RequestBody$deleteWorkflowTransitionRuleConfigurations["application/json"];
}
export declare type ResponseContentType$getWorkflowsPaginated = keyof Response$getWorkflowsPaginated$Status$200;
export interface Params$getWorkflowsPaginated {
    parameter: Parameter$getWorkflowsPaginated;
}
export declare type ResponseContentType$getWorkflowTransitionProperties = keyof Response$getWorkflowTransitionProperties$Status$200;
export interface Params$getWorkflowTransitionProperties {
    parameter: Parameter$getWorkflowTransitionProperties;
}
export declare type RequestContentType$updateWorkflowTransitionProperty = keyof RequestBody$updateWorkflowTransitionProperty;
export declare type ResponseContentType$updateWorkflowTransitionProperty = keyof Response$updateWorkflowTransitionProperty$Status$200;
export interface Params$updateWorkflowTransitionProperty {
    parameter: Parameter$updateWorkflowTransitionProperty;
    requestBody: RequestBody$updateWorkflowTransitionProperty["application/json"];
}
export declare type RequestContentType$createWorkflowTransitionProperty = keyof RequestBody$createWorkflowTransitionProperty;
export declare type ResponseContentType$createWorkflowTransitionProperty = keyof Response$createWorkflowTransitionProperty$Status$200;
export interface Params$createWorkflowTransitionProperty {
    parameter: Parameter$createWorkflowTransitionProperty;
    requestBody: RequestBody$createWorkflowTransitionProperty["application/json"];
}
export interface Params$deleteWorkflowTransitionProperty {
    parameter: Parameter$deleteWorkflowTransitionProperty;
}
export interface Params$deleteInactiveWorkflow {
    parameter: Parameter$deleteInactiveWorkflow;
}
export declare type ResponseContentType$getAllWorkflowSchemes = keyof Response$getAllWorkflowSchemes$Status$200;
export interface Params$getAllWorkflowSchemes {
    parameter: Parameter$getAllWorkflowSchemes;
}
export declare type RequestContentType$createWorkflowScheme = keyof RequestBody$createWorkflowScheme;
export declare type ResponseContentType$createWorkflowScheme = keyof Response$createWorkflowScheme$Status$201;
export interface Params$createWorkflowScheme {
    requestBody: RequestBody$createWorkflowScheme["application/json"];
}
export declare type ResponseContentType$getWorkflowSchemeProjectAssociations = keyof Response$getWorkflowSchemeProjectAssociations$Status$200;
export interface Params$getWorkflowSchemeProjectAssociations {
    parameter: Parameter$getWorkflowSchemeProjectAssociations;
}
export declare type RequestContentType$assignSchemeToProject = keyof RequestBody$assignSchemeToProject;
export declare type ResponseContentType$assignSchemeToProject = keyof Response$assignSchemeToProject$Status$204;
export interface Params$assignSchemeToProject {
    requestBody: RequestBody$assignSchemeToProject["application/json"];
}
export declare type ResponseContentType$getWorkflowScheme = keyof Response$getWorkflowScheme$Status$200;
export interface Params$getWorkflowScheme {
    parameter: Parameter$getWorkflowScheme;
}
export declare type RequestContentType$updateWorkflowScheme = keyof RequestBody$updateWorkflowScheme;
export declare type ResponseContentType$updateWorkflowScheme = keyof Response$updateWorkflowScheme$Status$200;
export interface Params$updateWorkflowScheme {
    parameter: Parameter$updateWorkflowScheme;
    requestBody: RequestBody$updateWorkflowScheme["application/json"];
}
export interface Params$deleteWorkflowScheme {
    parameter: Parameter$deleteWorkflowScheme;
}
export declare type ResponseContentType$createWorkflowSchemeDraftFromParent = keyof Response$createWorkflowSchemeDraftFromParent$Status$201;
export interface Params$createWorkflowSchemeDraftFromParent {
    parameter: Parameter$createWorkflowSchemeDraftFromParent;
}
export declare type ResponseContentType$getDefaultWorkflow = keyof Response$getDefaultWorkflow$Status$200;
export interface Params$getDefaultWorkflow {
    parameter: Parameter$getDefaultWorkflow;
}
export declare type RequestContentType$updateDefaultWorkflow = keyof RequestBody$updateDefaultWorkflow;
export declare type ResponseContentType$updateDefaultWorkflow = keyof Response$updateDefaultWorkflow$Status$200;
export interface Params$updateDefaultWorkflow {
    parameter: Parameter$updateDefaultWorkflow;
    requestBody: RequestBody$updateDefaultWorkflow["application/json"];
}
export declare type ResponseContentType$deleteDefaultWorkflow = keyof Response$deleteDefaultWorkflow$Status$200;
export interface Params$deleteDefaultWorkflow {
    parameter: Parameter$deleteDefaultWorkflow;
}
export declare type ResponseContentType$getWorkflowSchemeDraft = keyof Response$getWorkflowSchemeDraft$Status$200;
export interface Params$getWorkflowSchemeDraft {
    parameter: Parameter$getWorkflowSchemeDraft;
}
export declare type RequestContentType$updateWorkflowSchemeDraft = keyof RequestBody$updateWorkflowSchemeDraft;
export declare type ResponseContentType$updateWorkflowSchemeDraft = keyof Response$updateWorkflowSchemeDraft$Status$200;
export interface Params$updateWorkflowSchemeDraft {
    parameter: Parameter$updateWorkflowSchemeDraft;
    requestBody: RequestBody$updateWorkflowSchemeDraft["application/json"];
}
export interface Params$deleteWorkflowSchemeDraft {
    parameter: Parameter$deleteWorkflowSchemeDraft;
}
export declare type ResponseContentType$getDraftDefaultWorkflow = keyof Response$getDraftDefaultWorkflow$Status$200;
export interface Params$getDraftDefaultWorkflow {
    parameter: Parameter$getDraftDefaultWorkflow;
}
export declare type RequestContentType$updateDraftDefaultWorkflow = keyof RequestBody$updateDraftDefaultWorkflow;
export declare type ResponseContentType$updateDraftDefaultWorkflow = keyof Response$updateDraftDefaultWorkflow$Status$200;
export interface Params$updateDraftDefaultWorkflow {
    parameter: Parameter$updateDraftDefaultWorkflow;
    requestBody: RequestBody$updateDraftDefaultWorkflow["application/json"];
}
export declare type ResponseContentType$deleteDraftDefaultWorkflow = keyof Response$deleteDraftDefaultWorkflow$Status$200;
export interface Params$deleteDraftDefaultWorkflow {
    parameter: Parameter$deleteDraftDefaultWorkflow;
}
export declare type ResponseContentType$getWorkflowSchemeDraftIssueType = keyof Response$getWorkflowSchemeDraftIssueType$Status$200;
export interface Params$getWorkflowSchemeDraftIssueType {
    parameter: Parameter$getWorkflowSchemeDraftIssueType;
}
export declare type RequestContentType$setWorkflowSchemeDraftIssueType = keyof RequestBody$setWorkflowSchemeDraftIssueType;
export declare type ResponseContentType$setWorkflowSchemeDraftIssueType = keyof Response$setWorkflowSchemeDraftIssueType$Status$200;
export interface Params$setWorkflowSchemeDraftIssueType {
    parameter: Parameter$setWorkflowSchemeDraftIssueType;
    requestBody: RequestBody$setWorkflowSchemeDraftIssueType["application/json"];
}
export declare type ResponseContentType$deleteWorkflowSchemeDraftIssueType = keyof Response$deleteWorkflowSchemeDraftIssueType$Status$200;
export interface Params$deleteWorkflowSchemeDraftIssueType {
    parameter: Parameter$deleteWorkflowSchemeDraftIssueType;
}
export declare type RequestContentType$publishDraftWorkflowScheme = keyof RequestBody$publishDraftWorkflowScheme;
export interface Params$publishDraftWorkflowScheme {
    parameter: Parameter$publishDraftWorkflowScheme;
    requestBody: RequestBody$publishDraftWorkflowScheme["application/json"];
}
export declare type ResponseContentType$getDraftWorkflow = keyof Response$getDraftWorkflow$Status$200;
export interface Params$getDraftWorkflow {
    parameter: Parameter$getDraftWorkflow;
}
export declare type RequestContentType$updateDraftWorkflowMapping = keyof RequestBody$updateDraftWorkflowMapping;
export declare type ResponseContentType$updateDraftWorkflowMapping = keyof Response$updateDraftWorkflowMapping$Status$200;
export interface Params$updateDraftWorkflowMapping {
    parameter: Parameter$updateDraftWorkflowMapping;
    requestBody: RequestBody$updateDraftWorkflowMapping["application/json"];
}
export interface Params$deleteDraftWorkflowMapping {
    parameter: Parameter$deleteDraftWorkflowMapping;
}
export declare type ResponseContentType$getWorkflowSchemeIssueType = keyof Response$getWorkflowSchemeIssueType$Status$200;
export interface Params$getWorkflowSchemeIssueType {
    parameter: Parameter$getWorkflowSchemeIssueType;
}
export declare type RequestContentType$setWorkflowSchemeIssueType = keyof RequestBody$setWorkflowSchemeIssueType;
export declare type ResponseContentType$setWorkflowSchemeIssueType = keyof Response$setWorkflowSchemeIssueType$Status$200;
export interface Params$setWorkflowSchemeIssueType {
    parameter: Parameter$setWorkflowSchemeIssueType;
    requestBody: RequestBody$setWorkflowSchemeIssueType["application/json"];
}
export declare type ResponseContentType$deleteWorkflowSchemeIssueType = keyof Response$deleteWorkflowSchemeIssueType$Status$200;
export interface Params$deleteWorkflowSchemeIssueType {
    parameter: Parameter$deleteWorkflowSchemeIssueType;
}
export declare type ResponseContentType$getWorkflow = keyof Response$getWorkflow$Status$200;
export interface Params$getWorkflow {
    parameter: Parameter$getWorkflow;
}
export declare type RequestContentType$updateWorkflowMapping = keyof RequestBody$updateWorkflowMapping;
export declare type ResponseContentType$updateWorkflowMapping = keyof Response$updateWorkflowMapping$Status$200;
export interface Params$updateWorkflowMapping {
    parameter: Parameter$updateWorkflowMapping;
    requestBody: RequestBody$updateWorkflowMapping["application/json"];
}
export interface Params$deleteWorkflowMapping {
    parameter: Parameter$deleteWorkflowMapping;
}
export declare type ResponseContentType$getIdsOfWorklogsDeletedSince = keyof Response$getIdsOfWorklogsDeletedSince$Status$200;
export interface Params$getIdsOfWorklogsDeletedSince {
    parameter: Parameter$getIdsOfWorklogsDeletedSince;
}
export declare type RequestContentType$getWorklogsForIds = keyof RequestBody$getWorklogsForIds;
export declare type ResponseContentType$getWorklogsForIds = keyof Response$getWorklogsForIds$Status$200;
export interface Params$getWorklogsForIds {
    parameter: Parameter$getWorklogsForIds;
    requestBody: RequestBody$getWorklogsForIds["application/json"];
}
export declare type ResponseContentType$getIdsOfWorklogsModifiedSince = keyof Response$getIdsOfWorklogsModifiedSince$Status$200;
export interface Params$getIdsOfWorklogsModifiedSince {
    parameter: Parameter$getIdsOfWorklogsModifiedSince;
}
export declare type ResponseContentType$AddonPropertiesResource$getAddonProperties_get = keyof Response$AddonPropertiesResource$getAddonProperties_get$Status$200;
export interface Params$AddonPropertiesResource$getAddonProperties_get {
    parameter: Parameter$AddonPropertiesResource$getAddonProperties_get;
}
export declare type ResponseContentType$AddonPropertiesResource$getAddonProperty_get = keyof Response$AddonPropertiesResource$getAddonProperty_get$Status$200;
export interface Params$AddonPropertiesResource$getAddonProperty_get {
    parameter: Parameter$AddonPropertiesResource$getAddonProperty_get;
}
export declare type RequestContentType$AddonPropertiesResource$putAddonProperty_put = keyof RequestBody$AddonPropertiesResource$putAddonProperty_put;
export declare type ResponseContentType$AddonPropertiesResource$putAddonProperty_put = keyof Response$AddonPropertiesResource$putAddonProperty_put$Status$200;
export interface Params$AddonPropertiesResource$putAddonProperty_put {
    parameter: Parameter$AddonPropertiesResource$putAddonProperty_put;
    requestBody: RequestBody$AddonPropertiesResource$putAddonProperty_put["application/json"];
}
export interface Params$AddonPropertiesResource$deleteAddonProperty_delete {
    parameter: Parameter$AddonPropertiesResource$deleteAddonProperty_delete;
}
export declare type ResponseContentType$DynamicModulesResource$getModules_get = keyof Response$DynamicModulesResource$getModules_get$Status$200;
export declare type RequestContentType$DynamicModulesResource$registerModules_post = keyof RequestBody$DynamicModulesResource$registerModules_post;
export interface Params$DynamicModulesResource$registerModules_post {
    requestBody: RequestBody$DynamicModulesResource$registerModules_post["application/json"];
}
export interface Params$DynamicModulesResource$removeModules_delete {
    parameter: Parameter$DynamicModulesResource$removeModules_delete;
}
export declare type RequestContentType$AppIssueFieldValueUpdateResource$updateIssueFields_put = keyof RequestBody$AppIssueFieldValueUpdateResource$updateIssueFields_put;
export declare type ResponseContentType$AppIssueFieldValueUpdateResource$updateIssueFields_put = keyof Response$AppIssueFieldValueUpdateResource$updateIssueFields_put$Status$200;
export interface Params$AppIssueFieldValueUpdateResource$updateIssueFields_put {
    parameter: Parameter$AppIssueFieldValueUpdateResource$updateIssueFields_put;
    requestBody: RequestBody$AppIssueFieldValueUpdateResource$updateIssueFields_put["application/json"];
}
export declare type RequestContentType$MigrationResource$updateEntityPropertiesValue_put = keyof RequestBody$MigrationResource$updateEntityPropertiesValue_put;
export interface Params$MigrationResource$updateEntityPropertiesValue_put {
    parameter: Parameter$MigrationResource$updateEntityPropertiesValue_put;
    requestBody: RequestBody$MigrationResource$updateEntityPropertiesValue_put["application/json"];
}
export declare type RequestContentType$MigrationResource$workflowRuleSearch_post = keyof RequestBody$MigrationResource$workflowRuleSearch_post;
export declare type ResponseContentType$MigrationResource$workflowRuleSearch_post = keyof Response$MigrationResource$workflowRuleSearch_post$Status$200;
export interface Params$MigrationResource$workflowRuleSearch_post {
    parameter: Parameter$MigrationResource$workflowRuleSearch_post;
    requestBody: RequestBody$MigrationResource$workflowRuleSearch_post["application/json"];
}
export declare type HttpMethod = "GET" | "PUT" | "POST" | "DELETE" | "OPTIONS" | "HEAD" | "PATCH" | "TRACE";
export interface ObjectLike {
    [key: string]: any;
}
export interface QueryParameter {
    value: any;
    style?: "form" | "spaceDelimited" | "pipeDelimited" | "deepObject";
    explode: boolean;
}
export interface QueryParameters {
    [key: string]: QueryParameter;
}
export declare type SuccessResponses = Response$updateMultipleCustomFieldValues$Status$204 | Response$getCustomFieldConfiguration$Status$200 | Response$updateCustomFieldConfiguration$Status$200 | Response$updateCustomFieldValue$Status$204 | Response$getApplicationProperty$Status$200 | Response$getAdvancedSettings$Status$200 | Response$setApplicationProperty$Status$200 | Response$getAllApplicationRoles$Status$200 | Response$getApplicationRole$Status$200 | Response$getAttachmentContent$Status$200 | Response$getAttachmentMeta$Status$200 | Response$getAttachmentThumbnail$Status$200 | Response$getAttachment$Status$200 | Response$expandAttachmentForHumans$Status$200 | Response$expandAttachmentForMachines$Status$200 | Response$getAuditRecords$Status$200 | Response$getAllSystemAvatars$Status$200 | Response$getCommentsByIds$Status$200 | Response$getCommentPropertyKeys$Status$200 | Response$getCommentProperty$Status$200 | Response$setCommentProperty$Status$200 | Response$setCommentProperty$Status$201 | Response$createComponent$Status$201 | Response$getComponent$Status$200 | Response$updateComponent$Status$200 | Response$getComponentRelatedIssues$Status$200 | Response$getConfiguration$Status$200 | Response$getSelectedTimeTrackingImplementation$Status$200 | Response$getSelectedTimeTrackingImplementation$Status$204 | Response$selectTimeTrackingImplementation$Status$204 | Response$getAvailableTimeTrackingImplementations$Status$200 | Response$getSharedTimeTrackingConfiguration$Status$200 | Response$setSharedTimeTrackingConfiguration$Status$200 | Response$getCustomFieldOption$Status$200 | Response$getAllDashboards$Status$200 | Response$createDashboard$Status$200 | Response$getDashboardsPaginated$Status$200 | Response$getDashboardItemPropertyKeys$Status$200 | Response$getDashboardItemProperty$Status$200 | Response$setDashboardItemProperty$Status$200 | Response$setDashboardItemProperty$Status$201 | Response$getDashboard$Status$200 | Response$updateDashboard$Status$200 | Response$copyDashboard$Status$200 | Response$getEvents$Status$200 | Response$analyseExpression$Status$200 | Response$evaluateJiraExpression$Status$200 | Response$getFields$Status$200 | Response$createCustomField$Status$201 | Response$getFieldsPaginated$Status$200 | Response$updateCustomField$Status$204 | Response$getContextsForField$Status$200 | Response$createCustomFieldContext$Status$201 | Response$getDefaultValues$Status$200 | Response$setDefaultValues$Status$204 | Response$getIssueTypeMappingsForContexts$Status$200 | Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$200 | Response$getProjectContextMapping$Status$200 | Response$updateCustomFieldContext$Status$204 | Response$deleteCustomFieldContext$Status$204 | Response$addIssueTypesToContext$Status$204 | Response$removeIssueTypesFromContext$Status$204 | Response$getOptionsForContext$Status$200 | Response$updateCustomFieldOption$Status$200 | Response$createCustomFieldOption$Status$200 | Response$reorderCustomFieldOptions$Status$204 | Response$assignProjectsToCustomFieldContext$Status$204 | Response$removeCustomFieldContextFromProjects$Status$204 | Response$getContextsForFieldDeprecated$Status$200 | Response$getScreensForField$Status$200 | Response$getAllIssueFieldOptions$Status$200 | Response$createIssueFieldOption$Status$200 | Response$getSelectableIssueFieldOptions$Status$200 | Response$getVisibleIssueFieldOptions$Status$200 | Response$getIssueFieldOption$Status$200 | Response$updateIssueFieldOption$Status$200 | Response$deleteIssueFieldOption$Status$204 | Response$restoreCustomField$Status$200 | Response$trashCustomField$Status$200 | Response$getAllFieldConfigurations$Status$200 | Response$createFieldConfiguration$Status$200 | Response$updateFieldConfiguration$Status$204 | Response$deleteFieldConfiguration$Status$204 | Response$getFieldConfigurationItems$Status$200 | Response$updateFieldConfigurationItems$Status$204 | Response$getAllFieldConfigurationSchemes$Status$200 | Response$createFieldConfigurationScheme$Status$201 | Response$getFieldConfigurationSchemeMappings$Status$200 | Response$getFieldConfigurationSchemeProjectMapping$Status$200 | Response$assignFieldConfigurationSchemeToProject$Status$204 | Response$updateFieldConfigurationScheme$Status$204 | Response$deleteFieldConfigurationScheme$Status$204 | Response$setFieldConfigurationSchemeMapping$Status$204 | Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$204 | Response$getFilters$Status$200 | Response$createFilter$Status$200 | Response$getDefaultShareScope$Status$200 | Response$setDefaultShareScope$Status$200 | Response$getFavouriteFilters$Status$200 | Response$getMyFilters$Status$200 | Response$getFiltersPaginated$Status$200 | Response$getFilter$Status$200 | Response$updateFilter$Status$200 | Response$getColumns$Status$200 | Response$setColumns$Status$200 | Response$setFavouriteForFilter$Status$200 | Response$deleteFavouriteForFilter$Status$200 | Response$getSharePermissions$Status$200 | Response$addSharePermission$Status$201 | Response$getSharePermission$Status$200 | Response$getGroup$Status$200 | Response$createGroup$Status$201 | Response$bulkGetGroups$Status$200 | Response$getUsersFromGroup$Status$200 | Response$addUserToGroup$Status$201 | Response$findGroups$Status$200 | Response$findUsersAndGroups$Status$200 | Response$getLicense$Status$200 | Response$createIssue$Status$201 | Response$createIssues$Status$201 | Response$getCreateIssueMeta$Status$200 | Response$getIssuePickerResource$Status$200 | Response$getIsWatchingIssueBulk$Status$200 | Response$getIssue$Status$200 | Response$editIssue$Status$204 | Response$assignIssue$Status$204 | Response$addAttachment$Status$200 | Response$getChangeLogs$Status$200 | Response$getChangeLogsByIds$Status$200 | Response$getComments$Status$200 | Response$addComment$Status$201 | Response$getComment$Status$200 | Response$updateComment$Status$200 | Response$getEditIssueMeta$Status$200 | Response$notify$Status$204 | Response$getIssuePropertyKeys$Status$200 | Response$getIssueProperty$Status$200 | Response$setIssueProperty$Status$200 | Response$setIssueProperty$Status$201 | Response$getRemoteIssueLinks$Status$200 | Response$createOrUpdateRemoteIssueLink$Status$200 | Response$createOrUpdateRemoteIssueLink$Status$201 | Response$getRemoteIssueLinkById$Status$200 | Response$updateRemoteIssueLink$Status$204 | Response$getTransitions$Status$200 | Response$doTransition$Status$204 | Response$getVotes$Status$200 | Response$addVote$Status$204 | Response$getIssueWatchers$Status$200 | Response$addWatcher$Status$204 | Response$getIssueWorklog$Status$200 | Response$addWorklog$Status$201 | Response$getWorklog$Status$200 | Response$updateWorklog$Status$200 | Response$getWorklogPropertyKeys$Status$200 | Response$getWorklogProperty$Status$200 | Response$setWorklogProperty$Status$200 | Response$setWorklogProperty$Status$201 | Response$linkIssues$Status$201 | Response$getIssueLink$Status$200 | Response$getIssueLinkTypes$Status$200 | Response$createIssueLinkType$Status$201 | Response$getIssueLinkType$Status$200 | Response$updateIssueLinkType$Status$200 | Response$getIssueSecuritySchemes$Status$200 | Response$getIssueSecurityScheme$Status$200 | Response$getIssueSecurityLevelMembers$Status$200 | Response$getIssueAllTypes$Status$200 | Response$createIssueType$Status$201 | Response$getIssueTypesForProject$Status$200 | Response$getIssueType$Status$200 | Response$updateIssueType$Status$200 | Response$getAlternativeIssueTypes$Status$200 | Response$createIssueTypeAvatar$Status$201 | Response$getIssueTypePropertyKeys$Status$200 | Response$getIssueTypeProperty$Status$200 | Response$setIssueTypeProperty$Status$200 | Response$setIssueTypeProperty$Status$201 | Response$getAllIssueTypeSchemes$Status$200 | Response$createIssueTypeScheme$Status$201 | Response$getIssueTypeSchemesMapping$Status$200 | Response$getIssueTypeSchemeForProjects$Status$200 | Response$assignIssueTypeSchemeToProject$Status$204 | Response$updateIssueTypeScheme$Status$204 | Response$deleteIssueTypeScheme$Status$204 | Response$addIssueTypesToIssueTypeScheme$Status$204 | Response$reorderIssueTypesInIssueTypeScheme$Status$204 | Response$removeIssueTypeFromIssueTypeScheme$Status$204 | Response$getIssueTypeScreenSchemes$Status$200 | Response$createIssueTypeScreenScheme$Status$201 | Response$getIssueTypeScreenSchemeMappings$Status$200 | Response$getIssueTypeScreenSchemeProjectAssociations$Status$200 | Response$assignIssueTypeScreenSchemeToProject$Status$204 | Response$updateIssueTypeScreenScheme$Status$204 | Response$deleteIssueTypeScreenScheme$Status$204 | Response$appendMappingsForIssueTypeScreenScheme$Status$204 | Response$updateDefaultScreenScheme$Status$204 | Response$removeMappingsFromIssueTypeScreenScheme$Status$204 | Response$getProjectsForIssueTypeScreenScheme$Status$200 | Response$getAutoComplete$Status$200 | Response$getAutoCompletePost$Status$200 | Response$getFieldAutoCompleteForQueryString$Status$200 | Response$matchIssues$Status$200 | Response$parseJqlQueries$Status$200 | Response$migrateQueries$Status$200 | Response$getAllLabels$Status$200 | Response$getMyPermissions$Status$200 | Response$getPreference$Status$200 | Response$setPreference$Status$204 | Response$getLocale$Status$200 | Response$setLocale$Status$204 | Response$deleteLocale$Status$204 | Response$getCurrentUser$Status$200 | Response$getNotificationSchemes$Status$200 | Response$getNotificationScheme$Status$200 | Response$getAllPermissions$Status$200 | Response$getBulkPermissions$Status$200 | Response$getPermittedProjects$Status$200 | Response$getAllPermissionSchemes$Status$200 | Response$createPermissionScheme$Status$201 | Response$getPermissionScheme$Status$200 | Response$updatePermissionScheme$Status$200 | Response$getPermissionSchemeGrants$Status$200 | Response$createPermissionGrant$Status$201 | Response$getPermissionSchemeGrant$Status$200 | Response$getPriorities$Status$200 | Response$getPriority$Status$200 | Response$getAllProjects$Status$200 | Response$createProject$Status$201 | Response$getRecent$Status$200 | Response$searchProjects$Status$200 | Response$getAllProjectTypes$Status$200 | Response$getAllAccessibleProjectTypes$Status$200 | Response$getProjectTypeByKey$Status$200 | Response$getAccessibleProjectTypeByKey$Status$200 | Response$getProject$Status$200 | Response$updateProject$Status$200 | Response$archiveProject$Status$204 | Response$updateProjectAvatar$Status$204 | Response$createProjectAvatar$Status$201 | Response$getAllProjectAvatars$Status$200 | Response$getProjectComponentsPaginated$Status$200 | Response$getProjectComponents$Status$200 | Response$getFeaturesForProject$Status$200 | Response$toggleFeatureForProject$Status$200 | Response$getProjectPropertyKeys$Status$200 | Response$getProjectProperty$Status$200 | Response$setProjectProperty$Status$200 | Response$setProjectProperty$Status$201 | Response$restore$Status$200 | Response$getProjectRoles$Status$200 | Response$getProjectRole$Status$200 | Response$setActors$Status$200 | Response$addActorUsers$Status$200 | Response$getProjectRoleDetails$Status$200 | Response$getAllStatuses$Status$200 | Response$updateProjectType$Status$200 | Response$getProjectVersionsPaginated$Status$200 | Response$getProjectVersions$Status$200 | Response$getProjectEmail$Status$200 | Response$updateProjectEmail$Status$204 | Response$getHierarchy$Status$200 | Response$getProjectIssueSecurityScheme$Status$200 | Response$getNotificationSchemeForProject$Status$200 | Response$getAssignedPermissionScheme$Status$200 | Response$assignPermissionScheme$Status$200 | Response$getSecurityLevelsForProject$Status$200 | Response$getAllProjectCategories$Status$200 | Response$createProjectCategory$Status$201 | Response$getProjectCategoryById$Status$200 | Response$updateProjectCategory$Status$200 | Response$validateProjectKey$Status$200 | Response$getValidProjectKey$Status$200 | Response$getValidProjectName$Status$200 | Response$getResolutions$Status$200 | Response$getResolution$Status$200 | Response$getAllProjectRoles$Status$200 | Response$createProjectRole$Status$200 | Response$getProjectRoleById$Status$200 | Response$fullyUpdateProjectRole$Status$200 | Response$partialUpdateProjectRole$Status$200 | Response$getProjectRoleActorsForRole$Status$200 | Response$addProjectRoleActorsToRole$Status$200 | Response$deleteProjectRoleActorsFromRole$Status$200 | Response$getScreens$Status$200 | Response$createScreen$Status$201 | Response$addFieldToDefaultScreen$Status$200 | Response$updateScreen$Status$200 | Response$getAvailableScreenFields$Status$200 | Response$getAllScreenTabs$Status$200 | Response$addScreenTab$Status$200 | Response$renameScreenTab$Status$200 | Response$getAllScreenTabFields$Status$200 | Response$addScreenTabField$Status$200 | Response$moveScreenTabField$Status$204 | Response$moveScreenTab$Status$204 | Response$getScreenSchemes$Status$200 | Response$createScreenScheme$Status$201 | Response$updateScreenScheme$Status$204 | Response$searchForIssuesUsingJql$Status$200 | Response$searchForIssuesUsingJqlPost$Status$200 | Response$getIssueSecurityLevel$Status$200 | Response$getServerInfo$Status$200 | Response$getIssueNavigatorDefaultColumns$Status$200 | Response$setIssueNavigatorDefaultColumns$Status$200 | Response$getStatuses$Status$200 | Response$getStatus$Status$200 | Response$getStatusCategories$Status$200 | Response$getStatusCategory$Status$200 | Response$getTask$Status$200 | Response$cancelTask$Status$202 | Response$getAvatars$Status$200 | Response$storeAvatar$Status$201 | Response$getAvatarImageByType$Status$200 | Response$getAvatarImageByID$Status$200 | Response$getAvatarImageByOwner$Status$200 | Response$getUser$Status$200 | Response$createUser$Status$201 | Response$findBulkAssignableUsers$Status$200 | Response$findAssignableUsers$Status$200 | Response$bulkGetUsers$Status$200 | Response$bulkGetUsersMigration$Status$200 | Response$getUserDefaultColumns$Status$200 | Response$setUserColumns$Status$200 | Response$getUserEmail$Status$200 | Response$getUserEmailBulk$Status$200 | Response$getUserGroups$Status$200 | Response$findUsersWithAllPermissions$Status$200 | Response$findUsersForPicker$Status$200 | Response$getUserPropertyKeys$Status$200 | Response$getUserProperty$Status$200 | Response$setUserProperty$Status$200 | Response$setUserProperty$Status$201 | Response$findUsers$Status$200 | Response$findUsersByQuery$Status$200 | Response$findUserKeysByQuery$Status$200 | Response$findUsersWithBrowsePermission$Status$200 | Response$getAllUsersDefault$Status$200 | Response$getAllUsers$Status$200 | Response$createVersion$Status$201 | Response$getVersion$Status$200 | Response$updateVersion$Status$200 | Response$mergeVersions$Status$204 | Response$moveVersion$Status$200 | Response$getVersionRelatedIssues$Status$200 | Response$deleteAndReplaceVersion$Status$204 | Response$getVersionUnresolvedIssues$Status$200 | Response$getDynamicWebhooksForApp$Status$200 | Response$registerDynamicWebhooks$Status$200 | Response$getFailedWebhooks$Status$200 | Response$refreshWebhooks$Status$200 | Response$getAllWorkflows$Status$200 | Response$createWorkflow$Status$201 | Response$getWorkflowTransitionRuleConfigurations$Status$200 | Response$updateWorkflowTransitionRuleConfigurations$Status$200 | Response$deleteWorkflowTransitionRuleConfigurations$Status$200 | Response$getWorkflowsPaginated$Status$200 | Response$getWorkflowTransitionProperties$Status$200 | Response$updateWorkflowTransitionProperty$Status$200 | Response$createWorkflowTransitionProperty$Status$200 | Response$getAllWorkflowSchemes$Status$200 | Response$createWorkflowScheme$Status$201 | Response$getWorkflowSchemeProjectAssociations$Status$200 | Response$assignSchemeToProject$Status$204 | Response$getWorkflowScheme$Status$200 | Response$updateWorkflowScheme$Status$200 | Response$createWorkflowSchemeDraftFromParent$Status$201 | Response$getDefaultWorkflow$Status$200 | Response$updateDefaultWorkflow$Status$200 | Response$deleteDefaultWorkflow$Status$200 | Response$getWorkflowSchemeDraft$Status$200 | Response$updateWorkflowSchemeDraft$Status$200 | Response$getDraftDefaultWorkflow$Status$200 | Response$updateDraftDefaultWorkflow$Status$200 | Response$deleteDraftDefaultWorkflow$Status$200 | Response$getWorkflowSchemeDraftIssueType$Status$200 | Response$setWorkflowSchemeDraftIssueType$Status$200 | Response$deleteWorkflowSchemeDraftIssueType$Status$200 | Response$getDraftWorkflow$Status$200 | Response$updateDraftWorkflowMapping$Status$200 | Response$getWorkflowSchemeIssueType$Status$200 | Response$setWorkflowSchemeIssueType$Status$200 | Response$deleteWorkflowSchemeIssueType$Status$200 | Response$getWorkflow$Status$200 | Response$updateWorkflowMapping$Status$200 | Response$getIdsOfWorklogsDeletedSince$Status$200 | Response$getWorklogsForIds$Status$200 | Response$getIdsOfWorklogsModifiedSince$Status$200 | Response$AddonPropertiesResource$getAddonProperties_get$Status$200 | Response$AddonPropertiesResource$getAddonProperty_get$Status$200 | Response$AddonPropertiesResource$putAddonProperty_put$Status$200 | Response$AddonPropertiesResource$putAddonProperty_put$Status$201 | Response$DynamicModulesResource$getModules_get$Status$200 | Response$AppIssueFieldValueUpdateResource$updateIssueFields_put$Status$200 | Response$MigrationResource$workflowRuleSearch_post$Status$200;
export declare namespace ErrorResponse {
    type updateMultipleCustomFieldValues = void;
    type getCustomFieldConfiguration = void;
    type updateCustomFieldConfiguration = void;
    type updateCustomFieldValue = void;
    type getApplicationProperty = void;
    type getAdvancedSettings = void;
    type setApplicationProperty = void;
    type getAllApplicationRoles = void;
    type getApplicationRole = void;
    type getAttachmentContent = void;
    type getAttachmentMeta = void;
    type getAttachmentThumbnail = void;
    type getAttachment = void;
    type removeAttachment = void;
    type expandAttachmentForHumans = void;
    type expandAttachmentForMachines = void;
    type getAuditRecords = void;
    type getAllSystemAvatars = void;
    type getCommentsByIds = void;
    type getCommentPropertyKeys = void;
    type getCommentProperty = void;
    type setCommentProperty = void;
    type deleteCommentProperty = void;
    type createComponent = void;
    type getComponent = void;
    type updateComponent = void;
    type deleteComponent = void;
    type getComponentRelatedIssues = void;
    type getConfiguration = void;
    type getSelectedTimeTrackingImplementation = void;
    type selectTimeTrackingImplementation = void;
    type getAvailableTimeTrackingImplementations = void;
    type getSharedTimeTrackingConfiguration = void;
    type setSharedTimeTrackingConfiguration = void;
    type getCustomFieldOption = void;
    type getAllDashboards = Response$getAllDashboards$Status$400 | Response$getAllDashboards$Status$401;
    type createDashboard = Response$createDashboard$Status$400 | Response$createDashboard$Status$401;
    type getDashboardsPaginated = Response$getDashboardsPaginated$Status$400 | Response$getDashboardsPaginated$Status$401;
    type getDashboardItemPropertyKeys = void;
    type getDashboardItemProperty = void;
    type setDashboardItemProperty = void;
    type deleteDashboardItemProperty = void;
    type getDashboard = Response$getDashboard$Status$400 | Response$getDashboard$Status$401;
    type updateDashboard = Response$updateDashboard$Status$400 | Response$updateDashboard$Status$401 | Response$updateDashboard$Status$404;
    type deleteDashboard = Response$deleteDashboard$Status$400 | Response$deleteDashboard$Status$401;
    type copyDashboard = Response$copyDashboard$Status$400 | Response$copyDashboard$Status$401 | Response$copyDashboard$Status$404;
    type getEvents = void;
    type analyseExpression = Response$analyseExpression$Status$400 | Response$analyseExpression$Status$404;
    type evaluateJiraExpression = Response$evaluateJiraExpression$Status$400 | Response$evaluateJiraExpression$Status$404;
    type getFields = void;
    type createCustomField = void;
    type getFieldsPaginated = Response$getFieldsPaginated$Status$400 | Response$getFieldsPaginated$Status$403;
    type updateCustomField = Response$updateCustomField$Status$400 | Response$updateCustomField$Status$403 | Response$updateCustomField$Status$404;
    type getContextsForField = Response$getContextsForField$Status$403 | Response$getContextsForField$Status$404;
    type createCustomFieldContext = Response$createCustomFieldContext$Status$409;
    type getDefaultValues = Response$getDefaultValues$Status$403 | Response$getDefaultValues$Status$404;
    type setDefaultValues = Response$setDefaultValues$Status$400 | Response$setDefaultValues$Status$403 | Response$setDefaultValues$Status$404;
    type getIssueTypeMappingsForContexts = Response$getIssueTypeMappingsForContexts$Status$403;
    type getCustomFieldContextsForProjectsAndIssueTypes = Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$400 | Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$403 | Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$404;
    type getProjectContextMapping = Response$getProjectContextMapping$Status$403 | Response$getProjectContextMapping$Status$404;
    type updateCustomFieldContext = Response$updateCustomFieldContext$Status$400 | Response$updateCustomFieldContext$Status$403 | Response$updateCustomFieldContext$Status$404;
    type deleteCustomFieldContext = Response$deleteCustomFieldContext$Status$400 | Response$deleteCustomFieldContext$Status$403 | Response$deleteCustomFieldContext$Status$404;
    type addIssueTypesToContext = Response$addIssueTypesToContext$Status$400 | Response$addIssueTypesToContext$Status$403 | Response$addIssueTypesToContext$Status$404 | Response$addIssueTypesToContext$Status$409;
    type removeIssueTypesFromContext = Response$removeIssueTypesFromContext$Status$400 | Response$removeIssueTypesFromContext$Status$403 | Response$removeIssueTypesFromContext$Status$404;
    type getOptionsForContext = Response$getOptionsForContext$Status$400 | Response$getOptionsForContext$Status$403 | Response$getOptionsForContext$Status$404;
    type updateCustomFieldOption = Response$updateCustomFieldOption$Status$400 | Response$updateCustomFieldOption$Status$403 | Response$updateCustomFieldOption$Status$404;
    type createCustomFieldOption = Response$createCustomFieldOption$Status$400 | Response$createCustomFieldOption$Status$403 | Response$createCustomFieldOption$Status$404;
    type reorderCustomFieldOptions = Response$reorderCustomFieldOptions$Status$400 | Response$reorderCustomFieldOptions$Status$403 | Response$reorderCustomFieldOptions$Status$404;
    type deleteCustomFieldOption = Response$deleteCustomFieldOption$Status$400 | Response$deleteCustomFieldOption$Status$403 | Response$deleteCustomFieldOption$Status$404;
    type assignProjectsToCustomFieldContext = Response$assignProjectsToCustomFieldContext$Status$400 | Response$assignProjectsToCustomFieldContext$Status$403 | Response$assignProjectsToCustomFieldContext$Status$404;
    type removeCustomFieldContextFromProjects = Response$removeCustomFieldContextFromProjects$Status$400 | Response$removeCustomFieldContextFromProjects$Status$403 | Response$removeCustomFieldContextFromProjects$Status$404;
    type getContextsForFieldDeprecated = void;
    type getScreensForField = void;
    type getAllIssueFieldOptions = void;
    type createIssueFieldOption = void;
    type getSelectableIssueFieldOptions = void;
    type getVisibleIssueFieldOptions = void;
    type getIssueFieldOption = void;
    type updateIssueFieldOption = void;
    type deleteIssueFieldOption = void;
    type replaceIssueFieldOption = Response$replaceIssueFieldOption$Status$403;
    type deleteCustomField = Response$deleteCustomField$Status$400 | Response$deleteCustomField$Status$401 | Response$deleteCustomField$Status$403 | Response$deleteCustomField$Status$404 | Response$deleteCustomField$Status$409;
    type restoreCustomField = Response$restoreCustomField$Status$400 | Response$restoreCustomField$Status$401 | Response$restoreCustomField$Status$403 | Response$restoreCustomField$Status$404;
    type trashCustomField = Response$trashCustomField$Status$400 | Response$trashCustomField$Status$401 | Response$trashCustomField$Status$403 | Response$trashCustomField$Status$404;
    type getAllFieldConfigurations = void;
    type createFieldConfiguration = void;
    type updateFieldConfiguration = void;
    type deleteFieldConfiguration = void;
    type getFieldConfigurationItems = void;
    type updateFieldConfigurationItems = void;
    type getAllFieldConfigurationSchemes = void;
    type createFieldConfigurationScheme = Response$createFieldConfigurationScheme$Status$400 | Response$createFieldConfigurationScheme$Status$403;
    type getFieldConfigurationSchemeMappings = void;
    type getFieldConfigurationSchemeProjectMapping = void;
    type assignFieldConfigurationSchemeToProject = Response$assignFieldConfigurationSchemeToProject$Status$400 | Response$assignFieldConfigurationSchemeToProject$Status$403 | Response$assignFieldConfigurationSchemeToProject$Status$404;
    type updateFieldConfigurationScheme = Response$updateFieldConfigurationScheme$Status$400 | Response$updateFieldConfigurationScheme$Status$403 | Response$updateFieldConfigurationScheme$Status$404;
    type deleteFieldConfigurationScheme = void;
    type setFieldConfigurationSchemeMapping = void;
    type removeIssueTypesFromGlobalFieldConfigurationScheme = Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$400 | Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$401 | Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$403 | Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$404;
    type getFilters = void;
    type createFilter = void;
    type getDefaultShareScope = void;
    type setDefaultShareScope = void;
    type getFavouriteFilters = void;
    type getMyFilters = void;
    type getFiltersPaginated = Response$getFiltersPaginated$Status$400;
    type getFilter = void;
    type updateFilter = void;
    type deleteFilter = void;
    type getColumns = void;
    type setColumns = void;
    type resetColumns = void;
    type setFavouriteForFilter = void;
    type deleteFavouriteForFilter = void;
    type getSharePermissions = void;
    type addSharePermission = void;
    type getSharePermission = void;
    type deleteSharePermission = void;
    type getGroup = void;
    type createGroup = void;
    type removeGroup = void;
    type bulkGetGroups = Response$bulkGetGroups$Status$403;
    type getUsersFromGroup = void;
    type addUserToGroup = void;
    type removeUserFromGroup = void;
    type findGroups = void;
    type findUsersAndGroups = void;
    type getLicense = void;
    type createIssue = Response$createIssue$Status$400 | Response$createIssue$Status$401 | Response$createIssue$Status$403;
    type createIssues = Response$createIssues$Status$400;
    type getCreateIssueMeta = void;
    type getIssuePickerResource = void;
    type bulkSetIssuesPropertiesList = Response$bulkSetIssuesPropertiesList$Status$400 | Response$bulkSetIssuesPropertiesList$Status$401;
    type bulkSetIssuePropertiesByIssue = Response$bulkSetIssuePropertiesByIssue$Status$400 | Response$bulkSetIssuePropertiesByIssue$Status$401 | Response$bulkSetIssuePropertiesByIssue$Status$403;
    type bulkSetIssueProperty = Response$bulkSetIssueProperty$Status$400 | Response$bulkSetIssueProperty$Status$401;
    type bulkDeleteIssueProperty = Response$bulkDeleteIssueProperty$Status$400 | Response$bulkDeleteIssueProperty$Status$401;
    type getIsWatchingIssueBulk = void;
    type getIssue = void;
    type editIssue = void;
    type deleteIssue = void;
    type assignIssue = void;
    type addAttachment = void;
    type getChangeLogs = void;
    type getChangeLogsByIds = void;
    type getComments = void;
    type addComment = void;
    type getComment = void;
    type updateComment = void;
    type deleteComment = void;
    type getEditIssueMeta = void;
    type notify = void;
    type getIssuePropertyKeys = void;
    type getIssueProperty = void;
    type setIssueProperty = void;
    type deleteIssueProperty = void;
    type getRemoteIssueLinks = void;
    type createOrUpdateRemoteIssueLink = Response$createOrUpdateRemoteIssueLink$Status$400;
    type deleteRemoteIssueLinkByGlobalId = void;
    type getRemoteIssueLinkById = void;
    type updateRemoteIssueLink = Response$updateRemoteIssueLink$Status$400;
    type deleteRemoteIssueLinkById = void;
    type getTransitions = void;
    type doTransition = void;
    type getVotes = void;
    type addVote = void;
    type removeVote = void;
    type getIssueWatchers = void;
    type addWatcher = void;
    type removeWatcher = void;
    type getIssueWorklog = void;
    type addWorklog = void;
    type getWorklog = void;
    type updateWorklog = void;
    type deleteWorklog = void;
    type getWorklogPropertyKeys = void;
    type getWorklogProperty = void;
    type setWorklogProperty = void;
    type deleteWorklogProperty = void;
    type linkIssues = void;
    type getIssueLink = void;
    type deleteIssueLink = void;
    type getIssueLinkTypes = void;
    type createIssueLinkType = void;
    type getIssueLinkType = void;
    type updateIssueLinkType = void;
    type deleteIssueLinkType = void;
    type getIssueSecuritySchemes = void;
    type getIssueSecurityScheme = void;
    type getIssueSecurityLevelMembers = void;
    type getIssueAllTypes = void;
    type createIssueType = void;
    type getIssueTypesForProject = void;
    type getIssueType = void;
    type updateIssueType = void;
    type deleteIssueType = void;
    type getAlternativeIssueTypes = void;
    type createIssueTypeAvatar = void;
    type getIssueTypePropertyKeys = void;
    type getIssueTypeProperty = void;
    type setIssueTypeProperty = void;
    type deleteIssueTypeProperty = void;
    type getAllIssueTypeSchemes = void;
    type createIssueTypeScheme = Response$createIssueTypeScheme$Status$400 | Response$createIssueTypeScheme$Status$403 | Response$createIssueTypeScheme$Status$409;
    type getIssueTypeSchemesMapping = void;
    type getIssueTypeSchemeForProjects = void;
    type assignIssueTypeSchemeToProject = Response$assignIssueTypeSchemeToProject$Status$400 | Response$assignIssueTypeSchemeToProject$Status$403 | Response$assignIssueTypeSchemeToProject$Status$404;
    type updateIssueTypeScheme = Response$updateIssueTypeScheme$Status$400 | Response$updateIssueTypeScheme$Status$403 | Response$updateIssueTypeScheme$Status$404;
    type deleteIssueTypeScheme = Response$deleteIssueTypeScheme$Status$400 | Response$deleteIssueTypeScheme$Status$403 | Response$deleteIssueTypeScheme$Status$404;
    type addIssueTypesToIssueTypeScheme = Response$addIssueTypesToIssueTypeScheme$Status$400 | Response$addIssueTypesToIssueTypeScheme$Status$403 | Response$addIssueTypesToIssueTypeScheme$Status$404;
    type reorderIssueTypesInIssueTypeScheme = Response$reorderIssueTypesInIssueTypeScheme$Status$400 | Response$reorderIssueTypesInIssueTypeScheme$Status$403 | Response$reorderIssueTypesInIssueTypeScheme$Status$404;
    type removeIssueTypeFromIssueTypeScheme = Response$removeIssueTypeFromIssueTypeScheme$Status$400 | Response$removeIssueTypeFromIssueTypeScheme$Status$403 | Response$removeIssueTypeFromIssueTypeScheme$Status$404;
    type getIssueTypeScreenSchemes = void;
    type createIssueTypeScreenScheme = Response$createIssueTypeScreenScheme$Status$400 | Response$createIssueTypeScreenScheme$Status$403 | Response$createIssueTypeScreenScheme$Status$404 | Response$createIssueTypeScreenScheme$Status$409;
    type getIssueTypeScreenSchemeMappings = void;
    type getIssueTypeScreenSchemeProjectAssociations = void;
    type assignIssueTypeScreenSchemeToProject = Response$assignIssueTypeScreenSchemeToProject$Status$400 | Response$assignIssueTypeScreenSchemeToProject$Status$403 | Response$assignIssueTypeScreenSchemeToProject$Status$404;
    type updateIssueTypeScreenScheme = Response$updateIssueTypeScreenScheme$Status$400 | Response$updateIssueTypeScreenScheme$Status$403 | Response$updateIssueTypeScreenScheme$Status$404;
    type deleteIssueTypeScreenScheme = Response$deleteIssueTypeScreenScheme$Status$400 | Response$deleteIssueTypeScreenScheme$Status$404;
    type appendMappingsForIssueTypeScreenScheme = Response$appendMappingsForIssueTypeScreenScheme$Status$400 | Response$appendMappingsForIssueTypeScreenScheme$Status$404 | Response$appendMappingsForIssueTypeScreenScheme$Status$409;
    type updateDefaultScreenScheme = Response$updateDefaultScreenScheme$Status$400 | Response$updateDefaultScreenScheme$Status$403 | Response$updateDefaultScreenScheme$Status$404;
    type removeMappingsFromIssueTypeScreenScheme = Response$removeMappingsFromIssueTypeScreenScheme$Status$400 | Response$removeMappingsFromIssueTypeScreenScheme$Status$403 | Response$removeMappingsFromIssueTypeScreenScheme$Status$404;
    type getProjectsForIssueTypeScreenScheme = void;
    type getAutoComplete = void;
    type getAutoCompletePost = void;
    type getFieldAutoCompleteForQueryString = void;
    type matchIssues = void;
    type parseJqlQueries = Response$parseJqlQueries$Status$400;
    type migrateQueries = void;
    type getAllLabels = void;
    type getMyPermissions = Response$getMyPermissions$Status$400 | Response$getMyPermissions$Status$401 | Response$getMyPermissions$Status$404;
    type getPreference = void;
    type setPreference = void;
    type removePreference = void;
    type getLocale = void;
    type setLocale = void;
    type deleteLocale = void;
    type getCurrentUser = void;
    type getNotificationSchemes = void;
    type getNotificationScheme = void;
    type getAllPermissions = void;
    type getBulkPermissions = Response$getBulkPermissions$Status$400 | Response$getBulkPermissions$Status$403;
    type getPermittedProjects = Response$getPermittedProjects$Status$400;
    type getAllPermissionSchemes = void;
    type createPermissionScheme = void;
    type getPermissionScheme = void;
    type updatePermissionScheme = void;
    type deletePermissionScheme = void;
    type getPermissionSchemeGrants = void;
    type createPermissionGrant = void;
    type getPermissionSchemeGrant = void;
    type deletePermissionSchemeEntity = void;
    type getPriorities = void;
    type getPriority = void;
    type getAllProjects = void;
    type createProject = void;
    type getRecent = void;
    type searchProjects = void;
    type getAllProjectTypes = void;
    type getAllAccessibleProjectTypes = void;
    type getProjectTypeByKey = void;
    type getAccessibleProjectTypeByKey = void;
    type getProject = void;
    type updateProject = void;
    type deleteProject = void;
    type archiveProject = void;
    type updateProjectAvatar = void;
    type deleteProjectAvatar = void;
    type createProjectAvatar = void;
    type getAllProjectAvatars = void;
    type getProjectComponentsPaginated = void;
    type getProjectComponents = void;
    type deleteProjectAsynchronously = void;
    type getFeaturesForProject = void;
    type toggleFeatureForProject = void;
    type getProjectPropertyKeys = void;
    type getProjectProperty = void;
    type setProjectProperty = void;
    type deleteProjectProperty = void;
    type restore = void;
    type getProjectRoles = void;
    type getProjectRole = void;
    type setActors = void;
    type addActorUsers = void;
    type deleteActor = void;
    type getProjectRoleDetails = void;
    type getAllStatuses = void;
    type updateProjectType = void;
    type getProjectVersionsPaginated = void;
    type getProjectVersions = void;
    type getProjectEmail = void;
    type updateProjectEmail = void;
    type getHierarchy = void;
    type getProjectIssueSecurityScheme = void;
    type getNotificationSchemeForProject = void;
    type getAssignedPermissionScheme = void;
    type assignPermissionScheme = void;
    type getSecurityLevelsForProject = void;
    type getAllProjectCategories = void;
    type createProjectCategory = void;
    type getProjectCategoryById = void;
    type updateProjectCategory = void;
    type removeProjectCategory = void;
    type validateProjectKey = void;
    type getValidProjectKey = void;
    type getValidProjectName = void;
    type getResolutions = void;
    type getResolution = void;
    type getAllProjectRoles = void;
    type createProjectRole = void;
    type getProjectRoleById = void;
    type fullyUpdateProjectRole = void;
    type partialUpdateProjectRole = void;
    type deleteProjectRole = void;
    type getProjectRoleActorsForRole = void;
    type addProjectRoleActorsToRole = void;
    type deleteProjectRoleActorsFromRole = void;
    type getScreens = void;
    type createScreen = Response$createScreen$Status$400 | Response$createScreen$Status$403;
    type addFieldToDefaultScreen = void;
    type updateScreen = Response$updateScreen$Status$400 | Response$updateScreen$Status$403 | Response$updateScreen$Status$404;
    type deleteScreen = Response$deleteScreen$Status$400 | Response$deleteScreen$Status$403 | Response$deleteScreen$Status$404;
    type getAvailableScreenFields = void;
    type getAllScreenTabs = void;
    type addScreenTab = void;
    type renameScreenTab = void;
    type deleteScreenTab = void;
    type getAllScreenTabFields = void;
    type addScreenTabField = void;
    type removeScreenTabField = void;
    type moveScreenTabField = void;
    type moveScreenTab = void;
    type getScreenSchemes = void;
    type createScreenScheme = Response$createScreenScheme$Status$400 | Response$createScreenScheme$Status$403 | Response$createScreenScheme$Status$404;
    type updateScreenScheme = Response$updateScreenScheme$Status$400 | Response$updateScreenScheme$Status$403 | Response$updateScreenScheme$Status$404;
    type deleteScreenScheme = Response$deleteScreenScheme$Status$400 | Response$deleteScreenScheme$Status$403 | Response$deleteScreenScheme$Status$404;
    type searchForIssuesUsingJql = void;
    type searchForIssuesUsingJqlPost = void;
    type getIssueSecurityLevel = void;
    type getServerInfo = void;
    type getIssueNavigatorDefaultColumns = void;
    type setIssueNavigatorDefaultColumns = void;
    type getStatuses = void;
    type getStatus = void;
    type getStatusCategories = void;
    type getStatusCategory = void;
    type getTask = void;
    type cancelTask = Response$cancelTask$Status$400 | Response$cancelTask$Status$401 | Response$cancelTask$Status$403 | Response$cancelTask$Status$404;
    type getAvatars = void;
    type storeAvatar = void;
    type deleteAvatar = void;
    type getAvatarImageByType = Response$getAvatarImageByType$Status$401 | Response$getAvatarImageByType$Status$403 | Response$getAvatarImageByType$Status$404;
    type getAvatarImageByID = Response$getAvatarImageByID$Status$400 | Response$getAvatarImageByID$Status$401 | Response$getAvatarImageByID$Status$403 | Response$getAvatarImageByID$Status$404;
    type getAvatarImageByOwner = Response$getAvatarImageByOwner$Status$400 | Response$getAvatarImageByOwner$Status$401 | Response$getAvatarImageByOwner$Status$403 | Response$getAvatarImageByOwner$Status$404;
    type getUser = void;
    type createUser = void;
    type removeUser = void;
    type findBulkAssignableUsers = void;
    type findAssignableUsers = void;
    type bulkGetUsers = void;
    type bulkGetUsersMigration = void;
    type getUserDefaultColumns = void;
    type setUserColumns = void;
    type resetUserColumns = void;
    type getUserEmail = void;
    type getUserEmailBulk = void;
    type getUserGroups = void;
    type findUsersWithAllPermissions = void;
    type findUsersForPicker = void;
    type getUserPropertyKeys = void;
    type getUserProperty = void;
    type setUserProperty = void;
    type deleteUserProperty = void;
    type findUsers = void;
    type findUsersByQuery = void;
    type findUserKeysByQuery = void;
    type findUsersWithBrowsePermission = void;
    type getAllUsersDefault = void;
    type getAllUsers = void;
    type createVersion = void;
    type getVersion = void;
    type updateVersion = void;
    type deleteVersion = void;
    type mergeVersions = void;
    type moveVersion = void;
    type getVersionRelatedIssues = void;
    type deleteAndReplaceVersion = void;
    type getVersionUnresolvedIssues = void;
    type getDynamicWebhooksForApp = Response$getDynamicWebhooksForApp$Status$400 | Response$getDynamicWebhooksForApp$Status$403;
    type registerDynamicWebhooks = Response$registerDynamicWebhooks$Status$400 | Response$registerDynamicWebhooks$Status$403;
    type deleteWebhookById = Response$deleteWebhookById$Status$400 | Response$deleteWebhookById$Status$403;
    type getFailedWebhooks = Response$getFailedWebhooks$Status$400 | Response$getFailedWebhooks$Status$403;
    type refreshWebhooks = Response$refreshWebhooks$Status$400 | Response$refreshWebhooks$Status$403;
    type getAllWorkflows = void;
    type createWorkflow = Response$createWorkflow$Status$400 | Response$createWorkflow$Status$403 | Response$createWorkflow$Status$404;
    type getWorkflowTransitionRuleConfigurations = Response$getWorkflowTransitionRuleConfigurations$Status$400 | Response$getWorkflowTransitionRuleConfigurations$Status$403;
    type updateWorkflowTransitionRuleConfigurations = Response$updateWorkflowTransitionRuleConfigurations$Status$400 | Response$updateWorkflowTransitionRuleConfigurations$Status$403;
    type deleteWorkflowTransitionRuleConfigurations = Response$deleteWorkflowTransitionRuleConfigurations$Status$400 | Response$deleteWorkflowTransitionRuleConfigurations$Status$403;
    type getWorkflowsPaginated = Response$getWorkflowsPaginated$Status$403;
    type getWorkflowTransitionProperties = void;
    type updateWorkflowTransitionProperty = void;
    type createWorkflowTransitionProperty = void;
    type deleteWorkflowTransitionProperty = void;
    type deleteInactiveWorkflow = Response$deleteInactiveWorkflow$Status$400 | Response$deleteInactiveWorkflow$Status$403 | Response$deleteInactiveWorkflow$Status$404;
    type getAllWorkflowSchemes = void;
    type createWorkflowScheme = void;
    type getWorkflowSchemeProjectAssociations = Response$getWorkflowSchemeProjectAssociations$Status$400 | Response$getWorkflowSchemeProjectAssociations$Status$403;
    type assignSchemeToProject = Response$assignSchemeToProject$Status$400 | Response$assignSchemeToProject$Status$403 | Response$assignSchemeToProject$Status$404;
    type getWorkflowScheme = void;
    type updateWorkflowScheme = void;
    type deleteWorkflowScheme = void;
    type createWorkflowSchemeDraftFromParent = void;
    type getDefaultWorkflow = void;
    type updateDefaultWorkflow = void;
    type deleteDefaultWorkflow = void;
    type getWorkflowSchemeDraft = void;
    type updateWorkflowSchemeDraft = void;
    type deleteWorkflowSchemeDraft = void;
    type getDraftDefaultWorkflow = void;
    type updateDraftDefaultWorkflow = void;
    type deleteDraftDefaultWorkflow = void;
    type getWorkflowSchemeDraftIssueType = void;
    type setWorkflowSchemeDraftIssueType = void;
    type deleteWorkflowSchemeDraftIssueType = void;
    type publishDraftWorkflowScheme = Response$publishDraftWorkflowScheme$Status$400 | Response$publishDraftWorkflowScheme$Status$404;
    type getDraftWorkflow = void;
    type updateDraftWorkflowMapping = void;
    type deleteDraftWorkflowMapping = void;
    type getWorkflowSchemeIssueType = void;
    type setWorkflowSchemeIssueType = void;
    type deleteWorkflowSchemeIssueType = void;
    type getWorkflow = void;
    type updateWorkflowMapping = void;
    type deleteWorkflowMapping = void;
    type getIdsOfWorklogsDeletedSince = void;
    type getWorklogsForIds = void;
    type getIdsOfWorklogsModifiedSince = void;
    type AddonPropertiesResource$getAddonProperties_get = Response$AddonPropertiesResource$getAddonProperties_get$Status$401;
    type AddonPropertiesResource$getAddonProperty_get = Response$AddonPropertiesResource$getAddonProperty_get$Status$400 | Response$AddonPropertiesResource$getAddonProperty_get$Status$401 | Response$AddonPropertiesResource$getAddonProperty_get$Status$404;
    type AddonPropertiesResource$putAddonProperty_put = Response$AddonPropertiesResource$putAddonProperty_put$Status$400 | Response$AddonPropertiesResource$putAddonProperty_put$Status$401;
    type AddonPropertiesResource$deleteAddonProperty_delete = Response$AddonPropertiesResource$deleteAddonProperty_delete$Status$400 | Response$AddonPropertiesResource$deleteAddonProperty_delete$Status$401 | Response$AddonPropertiesResource$deleteAddonProperty_delete$Status$404;
    type DynamicModulesResource$getModules_get = Response$DynamicModulesResource$getModules_get$Status$401;
    type DynamicModulesResource$registerModules_post = Response$DynamicModulesResource$registerModules_post$Status$400 | Response$DynamicModulesResource$registerModules_post$Status$401;
    type DynamicModulesResource$removeModules_delete = Response$DynamicModulesResource$removeModules_delete$Status$401;
    type AppIssueFieldValueUpdateResource$updateIssueFields_put = void;
    type MigrationResource$updateEntityPropertiesValue_put = void;
    type MigrationResource$workflowRuleSearch_post = void;
}
export interface ApiClient<RequestOption> {
    request: <T = SuccessResponses>(httpMethod: HttpMethod, url: string, headers: ObjectLike | any, requestBody: ObjectLike | any, queryParameters: QueryParameters | undefined, options?: RequestOption) => Promise<T>;
}
export declare class Client<RequestOption> {
    private apiClient;
    private baseUrl;
    constructor(apiClient: ApiClient<RequestOption>, baseUrl: string);
    /**
     * Update custom fields
     * Updates the value of one or more custom fields on one or more issues. Combinations of custom field and issue should be unique within the request. Custom fields can only be updated by the Forge app that created them.
     *
     * **[Permissions](#permissions) required:** Only the app that created the custom field can update its values with this operation.
     * operationId: updateMultipleCustomFieldValues
     * Request URI: /rest/api/3/app/field/value
     */
    updateMultipleCustomFieldValues(params: Params$updateMultipleCustomFieldValues, option?: RequestOption): Promise<Response$updateMultipleCustomFieldValues$Status$204["application/json"]>;
    /**
     * Get custom field configurations
     * Returns a [paginated](#pagination) list of configurations for a custom field created by a [Forge app](https://developer.atlassian.com/platform/forge/).
     *
     * The result can be filtered by one of these criteria:
     *
     *  *  `id`.
     *  *  `fieldContextId`.
     *  *  `issueId`.
     *  *  `projectKeyOrId` and `issueTypeId`.
     *
     * Otherwise, all configurations are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the Forge app that created the custom field.
     * operationId: getCustomFieldConfiguration
     * Request URI: /rest/api/3/app/field/{fieldIdOrKey}/context/configuration
     */
    getCustomFieldConfiguration(params: Params$getCustomFieldConfiguration, option?: RequestOption): Promise<Response$getCustomFieldConfiguration$Status$200["application/json"]>;
    /**
     * Update custom field configurations
     * Update the configuration for contexts of a custom field created by a [Forge app](https://developer.atlassian.com/platform/forge/).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the Forge app that created the custom field.
     * operationId: updateCustomFieldConfiguration
     * Request URI: /rest/api/3/app/field/{fieldIdOrKey}/context/configuration
     */
    updateCustomFieldConfiguration(params: Params$updateCustomFieldConfiguration, option?: RequestOption): Promise<Response$updateCustomFieldConfiguration$Status$200["application/json"]>;
    /**
     * Update custom field value
     * Updates the value of a custom field on one or more issues. Custom fields can only be updated by the Forge app that created them.
     *
     * **[Permissions](#permissions) required:** Only the app that created the custom field can update its values with this operation.
     * operationId: updateCustomFieldValue
     * Request URI: /rest/api/3/app/field/{fieldIdOrKey}/value
     */
    updateCustomFieldValue(params: Params$updateCustomFieldValue, option?: RequestOption): Promise<Response$updateCustomFieldValue$Status$204["application/json"]>;
    /**
     * Get application property
     * Returns all application properties or an application property.
     *
     * If you specify a value for the `key` parameter, then an application property is returned as an object (not in an array). Otherwise, an array of all editable application properties is returned. See [Set application property](#api-rest-api-3-application-properties-id-put) for descriptions of editable properties.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getApplicationProperty
     * Request URI: /rest/api/3/application-properties
     */
    getApplicationProperty(params: Params$getApplicationProperty, option?: RequestOption): Promise<Response$getApplicationProperty$Status$200["application/json"]>;
    /**
     * Get advanced settings
     * Returns the application properties that are accessible on the *Advanced Settings* page. To navigate to the *Advanced Settings* page in Jira, choose the Jira icon > **Jira settings** > **System**, **General Configuration** and then click **Advanced Settings** (in the upper right).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAdvancedSettings
     * Request URI: /rest/api/3/application-properties/advanced-settings
     */
    getAdvancedSettings(option?: RequestOption): Promise<Response$getAdvancedSettings$Status$200["application/json"]>;
    /**
     * Set application property
     * Changes the value of an application property. For example, you can change the value of the `jira.clone.prefix` from its default value of *CLONE -* to *Clone -* if you prefer sentence case capitalization. Editable properties are described below along with their default values.
     *
     * #### Advanced settings ####
     *
     * The advanced settings below are also accessible in [Jira](https://confluence.atlassian.com/x/vYXKM).
     *
     * | Key | Description | Default value |
     * | -- | -- | -- |
     * | `jira.clone.prefix` | The string of text prefixed to the title of a cloned issue. | `CLONE -` |
     * | `jira.date.picker.java.format` | The date format for the Java (server-side) generated dates. This must be the same as the `jira.date.picker.javascript.format` format setting. | `d/MMM/yy` |
     * | `jira.date.picker.javascript.format` | The date format for the JavaScript (client-side) generated dates. This must be the same as the `jira.date.picker.java.format` format setting. | `%e/%b/%y` |
     * | `jira.date.time.picker.java.format` | The date format for the Java (server-side) generated date times. This must be the same as the `jira.date.time.picker.javascript.format` format setting. | `dd/MMM/yy h:mm a` |
     * | `jira.date.time.picker.javascript.format` | The date format for the JavaScript (client-side) generated date times. This must be the same as the `jira.date.time.picker.java.format` format setting. | `%e/%b/%y %I:%M %p` |
     * | `jira.issue.actions.order` | The default order of actions (such as *Comments* or *Change history*) displayed on the issue view. | `asc` |
     * | `jira.table.cols.subtasks` | The columns to show while viewing subtask issues in a table. For example, a list of subtasks on an issue. | `issuetype, status, assignee, progress` |
     * | `jira.view.issue.links.sort.order` | The sort order of the list of issue links on the issue view. | `type, status, priority` |
     * | `jira.comment.collapsing.minimum.hidden` | The minimum number of comments required for comment collapsing to occur. A value of `0` disables comment collapsing. | `4` |
     * | `jira.newsletter.tip.delay.days` | The number of days before a prompt to sign up to the Jira Insiders newsletter is shown. A value of `-1` disables this feature. | `7` |
     *
     *
     * #### Look and feel ####
     *
     * The settings listed below adjust the [look and feel](https://confluence.atlassian.com/x/VwCLLg).
     *
     * | Key | Description | Default value |
     * | -- | -- | -- |
     * | `jira.lf.date.time` | The [ time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `h:mm a` |
     * | `jira.lf.date.day` | The [ day format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `EEEE h:mm a` |
     * | `jira.lf.date.complete` | The [ date and time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy h:mm a` |
     * | `jira.lf.date.dmy` | The [ date format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy` |
     * | `jira.date.time.picker.use.iso8061` | When enabled, sets Monday as the first day of the week in the date picker, as specified by the ISO8601 standard. | `false` |
     * | `jira.lf.logo.url` | The URL of the logo image file. | `/images/icon-jira-logo.png` |
     * | `jira.lf.logo.show.application.title` | Controls the visibility of the application title on the sidebar. | `false` |
     * | `jira.lf.favicon.url` | The URL of the favicon. | `/favicon.ico` |
     * | `jira.lf.favicon.hires.url` | The URL of the high-resolution favicon. | `/images/64jira.png` |
     * | `jira.lf.navigation.bgcolour` | The background color of the sidebar. | `#0747A6` |
     * | `jira.lf.navigation.highlightcolour` | The color of the text and logo of the sidebar. | `#DEEBFF` |
     * | `jira.lf.hero.button.base.bg.colour` | The background color of the hero button. | `#3b7fc4` |
     * | `jira.title` | The text for the application title. The application title can also be set in *General settings*. | `Jira` |
     * | `jira.option.globalsharing` | Whether filters and dashboards can be shared with anyone signed into Jira. | `true` |
     * | `xflow.product.suggestions.enabled` | Whether to expose product suggestions for other Atlassian products within Jira. | `true` |
     *
     *
     * #### Other settings ####
     *
     * | Key | Description | Default value |
     * | -- | -- | -- |
     * | `jira.issuenav.criteria.autoupdate` | Whether instant updates to search criteria is active. | `true` |
     *
     *
     * *Note: Be careful when changing [application properties and advanced settings](https://confluence.atlassian.com/x/vYXKM).*
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setApplicationProperty
     * Request URI: /rest/api/3/application-properties/{id}
     */
    setApplicationProperty(params: Params$setApplicationProperty, option?: RequestOption): Promise<Response$setApplicationProperty$Status$200["application/json"]>;
    /**
     * Get all application roles
     * Returns all application roles. In Jira, application roles are managed using the [Application access configuration](https://confluence.atlassian.com/x/3YxjL) page.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllApplicationRoles
     * Request URI: /rest/api/3/applicationrole
     */
    getAllApplicationRoles(option?: RequestOption): Promise<Response$getAllApplicationRoles$Status$200["application/json"]>;
    /**
     * Get application role
     * Returns an application role.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getApplicationRole
     * Request URI: /rest/api/3/applicationrole/{key}
     */
    getApplicationRole(params: Params$getApplicationRole, option?: RequestOption): Promise<Response$getApplicationRole$Status$200["application/json"]>;
    /**
     * Get attachment content
     * Returns the contents of an attachment. A `Range` header can be set to define a range of bytes within the attachment to download. See the [HTTP Range header standard](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Range) for details.
     *
     * To return a thumbnail of the attachment, use [Download attachment thumbnail](#api-rest-api-3-attachment-thumbnail-id-get).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** For the issue containing the attachment:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getAttachmentContent
     * Request URI: /rest/api/3/attachment/content/{id}
     */
    getAttachmentContent(params: Params$getAttachmentContent, option?: RequestOption): Promise<Response$getAttachmentContent$Status$200["application/json"]>;
    /**
     * Get Jira attachment settings
     * Returns the attachment settings, that is, whether attachments are enabled and the maximum attachment size allowed.
     *
     * Note that there are also [project permissions](https://confluence.atlassian.com/x/yodKLg) that restrict whether users can create and delete attachments.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAttachmentMeta
     * Request URI: /rest/api/3/attachment/meta
     */
    getAttachmentMeta(option?: RequestOption): Promise<Response$getAttachmentMeta$Status$200["application/json"]>;
    /**
     * Get attachment thumbnail
     * Returns the thumbnail of an attachment.
     *
     * To return the attachment contents, use [Download attachment content](#api-rest-api-3-attachment-content-id-get).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** For the issue containing the attachment:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getAttachmentThumbnail
     * Request URI: /rest/api/3/attachment/thumbnail/{id}
     */
    getAttachmentThumbnail(params: Params$getAttachmentThumbnail, option?: RequestOption): Promise<Response$getAttachmentThumbnail$Status$200["application/json"]>;
    /**
     * Get attachment metadata
     * Returns the metadata for an attachment. Note that the attachment itself is not returned.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getAttachment
     * Request URI: /rest/api/3/attachment/{id}
     */
    getAttachment(params: Params$getAttachment, option?: RequestOption): Promise<Response$getAttachment$Status$200["application/json"]>;
    /**
     * Delete attachment
     * Deletes an attachment from an issue.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** For the project holding the issue containing the attachment:
     *
     *  *  *Delete own attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by the calling user.
     *  *  *Delete all attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by any user.
     * operationId: removeAttachment
     * Request URI: /rest/api/3/attachment/{id}
     */
    removeAttachment(params: Params$removeAttachment, option?: RequestOption): Promise<void>;
    /**
     * Get all metadata for an expanded attachment
     * Returns the metadata for the contents of an attachment, if it is an archive, and metadata for the attachment itself. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned and metadata for the ZIP archive. Currently, only the ZIP archive format is supported.
     *
     * Use this operation to retrieve data that is presented to the user, as this operation returns the metadata for the attachment itself, such as the attachment's ID and name. Otherwise, use [ Get contents metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-raw-get), which only returns the metadata for the attachment's contents.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** For the issue containing the attachment:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: expandAttachmentForHumans
     * Request URI: /rest/api/3/attachment/{id}/expand/human
     */
    expandAttachmentForHumans(params: Params$expandAttachmentForHumans, option?: RequestOption): Promise<Response$expandAttachmentForHumans$Status$200["application/json"]>;
    /**
     * Get contents metadata for an expanded attachment
     * Returns the metadata for the contents of an attachment, if it is an archive. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned. Currently, only the ZIP archive format is supported.
     *
     * Use this operation if you are processing the data without presenting it to the user, as this operation only returns the metadata for the contents of the attachment. Otherwise, to retrieve data to present to the user, use [ Get all metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-human-get) which also returns the metadata for the attachment itself, such as the attachment's ID and name.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** For the issue containing the attachment:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: expandAttachmentForMachines
     * Request URI: /rest/api/3/attachment/{id}/expand/raw
     */
    expandAttachmentForMachines(params: Params$expandAttachmentForMachines, option?: RequestOption): Promise<Response$expandAttachmentForMachines$Status$200["application/json"]>;
    /**
     * Get audit records
     * Returns a list of audit records. The list can be filtered to include items:
     *
     *  *  where each item in `filter` has at least one match in any of these fields:
     *
     *      *  `summary`
     *      *  `category`
     *      *  `eventSource`
     *      *  `objectItem.name` If the object is a user, account ID is available to filter.
     *      *  `objectItem.parentName`
     *      *  `objectItem.typeName`
     *      *  `changedValues.changedFrom`
     *      *  `changedValues.changedTo`
     *      *  `remoteAddress`
     *
     *     For example, if `filter` contains *man ed*, an audit record containing `summary": "User added to group"` and `"category": "group management"` is returned.
     *  *  created on or after a date and time.
     *  *  created or or before a date and time.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAuditRecords
     * Request URI: /rest/api/3/auditing/record
     */
    getAuditRecords(params: Params$getAuditRecords, option?: RequestOption): Promise<Response$getAuditRecords$Status$200["application/json"]>;
    /**
     * Get system avatars by type
     * Returns a list of system avatar details by owner type, where the owner types are issue type, project, or user.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAllSystemAvatars
     * Request URI: /rest/api/3/avatar/{type}/system
     */
    getAllSystemAvatars(params: Params$getAllSystemAvatars, option?: RequestOption): Promise<Response$getAllSystemAvatars$Status$200["application/json"]>;
    /**
     * Get comments by IDs
     * Returns a [paginated](#pagination) list of comments specified by a list of comment IDs.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Comments are returned where the user:
     *
     *  *  has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getCommentsByIds
     * Request URI: /rest/api/3/comment/list
     */
    getCommentsByIds(params: Params$getCommentsByIds, option?: RequestOption): Promise<Response$getCommentsByIds$Status$200["application/json"]>;
    /**
     * Get comment property keys
     * Returns the keys of all the properties of a comment.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getCommentPropertyKeys
     * Request URI: /rest/api/3/comment/{commentId}/properties
     */
    getCommentPropertyKeys(params: Params$getCommentPropertyKeys, option?: RequestOption): Promise<Response$getCommentPropertyKeys$Status$200["application/json"]>;
    /**
     * Get comment property
     * Returns the value of a comment property.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getCommentProperty
     * Request URI: /rest/api/3/comment/{commentId}/properties/{propertyKey}
     */
    getCommentProperty(params: Params$getCommentProperty, option?: RequestOption): Promise<Response$getCommentProperty$Status$200["application/json"]>;
    /**
     * Set comment property
     * Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * **[Permissions](#permissions) required:** either of:
     *
     *  *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
     *  *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.
     *
     * Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
     * operationId: setCommentProperty
     * Request URI: /rest/api/3/comment/{commentId}/properties/{propertyKey}
     */
    setCommentProperty(params: Params$setCommentProperty, option?: RequestOption): Promise<(Response$setCommentProperty$Status$200 | Response$setCommentProperty$Status$201)["application/json"]>;
    /**
     * Delete comment property
     * Deletes a comment property.
     *
     * **[Permissions](#permissions) required:** either of:
     *
     *  *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
     *  *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.
     *
     * Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
     * operationId: deleteCommentProperty
     * Request URI: /rest/api/3/comment/{commentId}/properties/{propertyKey}
     */
    deleteCommentProperty(params: Params$deleteCommentProperty, option?: RequestOption): Promise<void>;
    /**
     * Create component
     * Creates a component. Use components to provide containers for issues within a project.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createComponent
     * Request URI: /rest/api/3/component
     */
    createComponent(params: Params$createComponent, option?: RequestOption): Promise<Response$createComponent$Status$201["application/json"]>;
    /**
     * Get component
     * Returns a component.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
     * operationId: getComponent
     * Request URI: /rest/api/3/component/{id}
     */
    getComponent(params: Params$getComponent, option?: RequestOption): Promise<Response$getComponent$Status$200["application/json"]>;
    /**
     * Update component
     * Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateComponent
     * Request URI: /rest/api/3/component/{id}
     */
    updateComponent(params: Params$updateComponent, option?: RequestOption): Promise<Response$updateComponent$Status$200["application/json"]>;
    /**
     * Delete component
     * Deletes a component.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteComponent
     * Request URI: /rest/api/3/component/{id}
     */
    deleteComponent(params: Params$deleteComponent, option?: RequestOption): Promise<void>;
    /**
     * Get component issues count
     * Returns the counts of issues assigned to the component.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getComponentRelatedIssues
     * Request URI: /rest/api/3/component/{id}/relatedIssueCounts
     */
    getComponentRelatedIssues(params: Params$getComponentRelatedIssues, option?: RequestOption): Promise<Response$getComponentRelatedIssues$Status$200["application/json"]>;
    /**
     * Get global settings
     * Returns the [global settings](https://confluence.atlassian.com/x/qYXKM) in Jira. These settings determine whether optional features (for example, subtasks, time tracking, and others) are enabled. If time tracking is enabled, this operation also returns the time tracking configuration.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getConfiguration
     * Request URI: /rest/api/3/configuration
     */
    getConfiguration(option?: RequestOption): Promise<Response$getConfiguration$Status$200["application/json"]>;
    /**
     * Get selected time tracking provider
     * Returns the time tracking provider that is currently selected. Note that if time tracking is disabled, then a successful but empty response is returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getSelectedTimeTrackingImplementation
     * Request URI: /rest/api/3/configuration/timetracking
     */
    getSelectedTimeTrackingImplementation(option?: RequestOption): Promise<(Response$getSelectedTimeTrackingImplementation$Status$200 | Response$getSelectedTimeTrackingImplementation$Status$204)["application/json"]>;
    /**
     * Select time tracking provider
     * Selects a time tracking provider.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: selectTimeTrackingImplementation
     * Request URI: /rest/api/3/configuration/timetracking
     */
    selectTimeTrackingImplementation(params: Params$selectTimeTrackingImplementation, option?: RequestOption): Promise<Response$selectTimeTrackingImplementation$Status$204["application/json"]>;
    /**
     * Get all time tracking providers
     * Returns all time tracking providers. By default, Jira only has one time tracking provider: *JIRA provided time tracking*. However, you can install other time tracking providers via apps from the Atlassian Marketplace. For more information on time tracking providers, see the documentation for the [ Time Tracking Provider](https://developer.atlassian.com/cloud/jira/platform/modules/time-tracking-provider/) module.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAvailableTimeTrackingImplementations
     * Request URI: /rest/api/3/configuration/timetracking/list
     */
    getAvailableTimeTrackingImplementations(option?: RequestOption): Promise<Response$getAvailableTimeTrackingImplementations$Status$200["application/json"]>;
    /**
     * Get time tracking settings
     * Returns the time tracking settings. This includes settings such as the time format, default time unit, and others. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getSharedTimeTrackingConfiguration
     * Request URI: /rest/api/3/configuration/timetracking/options
     */
    getSharedTimeTrackingConfiguration(option?: RequestOption): Promise<Response$getSharedTimeTrackingConfiguration$Status$200["application/json"]>;
    /**
     * Set time tracking settings
     * Sets the time tracking settings.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setSharedTimeTrackingConfiguration
     * Request URI: /rest/api/3/configuration/timetracking/options
     */
    setSharedTimeTrackingConfiguration(params: Params$setSharedTimeTrackingConfiguration, option?: RequestOption): Promise<Response$setSharedTimeTrackingConfiguration$Status$200["application/json"]>;
    /**
     * Get custom field option
     * Returns a custom field option. For example, an option in a select list.
     *
     * Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** The custom field option is returned as follows:
     *
     *  *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the custom field is used in, and the field is visible in at least one layout the user has permission to view.
     * operationId: getCustomFieldOption
     * Request URI: /rest/api/3/customFieldOption/{id}
     */
    getCustomFieldOption(params: Params$getCustomFieldOption, option?: RequestOption): Promise<Response$getCustomFieldOption$Status$200["application/json"]>;
    /**
     * Get all dashboards
     * Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAllDashboards
     * Request URI: /rest/api/3/dashboard
     */
    getAllDashboards(params: Params$getAllDashboards, option?: RequestOption): Promise<Response$getAllDashboards$Status$200["application/json"]>;
    /**
     * Create dashboard
     * Creates a dashboard.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: createDashboard
     * Request URI: /rest/api/3/dashboard
     */
    createDashboard(params: Params$createDashboard, option?: RequestOption): Promise<Response$createDashboard$Status$200["application/json"]>;
    /**
     * Search for dashboards
     * Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:
     *
     *  *  Dashboards owned by the user. Not returned for anonymous users.
     *  *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
     *  *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
     *  *  Dashboards shared with a public project.
     *  *  Dashboards shared with the public.
     * operationId: getDashboardsPaginated
     * Request URI: /rest/api/3/dashboard/search
     */
    getDashboardsPaginated(params: Params$getDashboardsPaginated, option?: RequestOption): Promise<Response$getDashboardsPaginated$Status$200["application/json"]>;
    /**
     * Get dashboard item property keys
     * Returns the keys of all properties for a dashboard item.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira’s anonymous access is permitted.
     * operationId: getDashboardItemPropertyKeys
     * Request URI: /rest/api/3/dashboard/{dashboardId}/items/{itemId}/properties
     */
    getDashboardItemPropertyKeys(params: Params$getDashboardItemPropertyKeys, option?: RequestOption): Promise<Response$getDashboardItemPropertyKeys$Status$200["application/json"]>;
    /**
     * Get dashboard item property
     * Returns the key and value of a dashboard item property.
     *
     * A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
     *
     * When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
     *
     * There is no resource to set or get dashboard items.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira’s anonymous access is permitted.
     * operationId: getDashboardItemProperty
     * Request URI: /rest/api/3/dashboard/{dashboardId}/items/{itemId}/properties/{propertyKey}
     */
    getDashboardItemProperty(params: Params$getDashboardItemProperty, option?: RequestOption): Promise<Response$getDashboardItemProperty$Status$200["application/json"]>;
    /**
     * Set dashboard item property
     * Sets the value of a dashboard item property. Use this resource in apps to store custom data against a dashboard item.
     *
     * A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
     *
     * When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
     *
     * There is no resource to set or get dashboard items.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
     * operationId: setDashboardItemProperty
     * Request URI: /rest/api/3/dashboard/{dashboardId}/items/{itemId}/properties/{propertyKey}
     */
    setDashboardItemProperty(params: Params$setDashboardItemProperty, option?: RequestOption): Promise<(Response$setDashboardItemProperty$Status$200 | Response$setDashboardItemProperty$Status$201)["application/json"]>;
    /**
     * Delete dashboard item property
     * Deletes a dashboard item property.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
     * operationId: deleteDashboardItemProperty
     * Request URI: /rest/api/3/dashboard/{dashboardId}/items/{itemId}/properties/{propertyKey}
     */
    deleteDashboardItemProperty(params: Params$deleteDashboardItemProperty, option?: RequestOption): Promise<void>;
    /**
     * Get dashboard
     * Returns a dashboard.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     *
     * However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
     * operationId: getDashboard
     * Request URI: /rest/api/3/dashboard/{id}
     */
    getDashboard(params: Params$getDashboard, option?: RequestOption): Promise<Response$getDashboard$Status$200["application/json"]>;
    /**
     * Update dashboard
     * Updates a dashboard, replacing all the dashboard details with those provided.
     *
     * **[Permissions](#permissions) required:** None
     *
     * The dashboard to be updated must be owned by the user.
     * operationId: updateDashboard
     * Request URI: /rest/api/3/dashboard/{id}
     */
    updateDashboard(params: Params$updateDashboard, option?: RequestOption): Promise<Response$updateDashboard$Status$200["application/json"]>;
    /**
     * Delete dashboard
     * Deletes a dashboard.
     *
     * **[Permissions](#permissions) required:** None
     *
     * The dashboard to be deleted must be owned by the user.
     * operationId: deleteDashboard
     * Request URI: /rest/api/3/dashboard/{id}
     */
    deleteDashboard(params: Params$deleteDashboard, option?: RequestOption): Promise<void>;
    /**
     * Copy dashboard
     * Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.
     *
     * **[Permissions](#permissions) required:** None
     *
     * The dashboard to be copied must be owned by or shared with the user.
     * operationId: copyDashboard
     * Request URI: /rest/api/3/dashboard/{id}/copy
     */
    copyDashboard(params: Params$copyDashboard, option?: RequestOption): Promise<Response$copyDashboard$Status$200["application/json"]>;
    /**
     * Get events
     * Returns all issue events.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getEvents
     * Request URI: /rest/api/3/events
     */
    getEvents(option?: RequestOption): Promise<Response$getEvents$Status$200["application/json"]>;
    /**
     * Analyse Jira expression
     * Analyses and validates Jira expressions.
     *
     * As an experimental feature, this operation can also attempt to type-check the expressions.
     *
     * Learn more about Jira expressions in the [documentation](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/).
     *
     * **[Permissions](#permissions) required**: None.
     * operationId: analyseExpression
     * Request URI: /rest/api/3/expression/analyse
     */
    analyseExpression(params: Params$analyseExpression, option?: RequestOption): Promise<Response$analyseExpression$Status$200["application/json"]>;
    /**
     * Evaluate Jira expression
     * Evaluates a Jira expression and returns its value.
     *
     * This resource can be used to test Jira expressions that you plan to use elsewhere, or to fetch data in a flexible way. Consult the [Jira expressions documentation](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/) for more details.
     *
     * #### Context variables ####
     *
     * The following context variables are available to Jira expressions evaluated by this resource. Their presence depends on various factors; usually you need to manually request them in the context object sent in the payload, but some of them are added automatically under certain conditions.
     *
     *  *  `user` ([User](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#user)): The current user. Always available and equal to `null` if the request is anonymous.
     *  *  `app` ([App](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#app)): The [Connect app](https://developer.atlassian.com/cloud/jira/platform/index/#connect-apps) that made the request. Available only for authenticated requests made by Connect Apps (read more here: [Authentication for Connect apps](https://developer.atlassian.com/cloud/jira/platform/security-for-connect-apps/)).
     *  *  `issue` ([Issue](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#issue)): The current issue. Available only when the issue is provided in the request context object.
     *  *  `issues` ([List](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#list) of [Issues](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#issue)): A collection of issues matching a JQL query. Available only when JQL is provided in the request context object.
     *  *  `project` ([Project](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#project)): The current project. Available only when the project is provided in the request context object.
     *  *  `sprint` ([Sprint](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#sprint)): The current sprint. Available only when the sprint is provided in the request context object.
     *  *  `board` ([Board](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#board)): The current board. Available only when the board is provided in the request context object.
     *  *  `serviceDesk` ([ServiceDesk](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#servicedesk)): The current service desk. Available only when the service desk is provided in the request context object.
     *  *  `customerRequest` ([CustomerRequest](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#customerrequest)): The current customer request. Available only when the customer request is provided in the request context object.
     *
     * Also, custom context variables can be passed in the request with their types. Those variables can be accessed by key in the Jira expression. These variable types are available for use in a custom context:
     *
     *  *  `user`: A [user](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#user) specified as an Atlassian account ID.
     *  *  `issue`: An [issue](https://developer.atlassian.com/cloud/jira/platform/jira-expressions-type-reference#issue) specified by ID or key. All the fields of the issue object are available in the Jira expression.
     *  *  `json`: A JSON object containing custom content.
     *  *  `list`: A JSON list of `user`, `issue`, or `json` variable types.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required**: None. However, an expression may return different results for different users depending on their permissions. For example, different users may see different comments on the same issue.
     * Permission to access Jira Software is required to access Jira Software context variables (`board` and `sprint`) or fields (for example, `issue.sprint`).
     * operationId: evaluateJiraExpression
     * Request URI: /rest/api/3/expression/eval
     */
    evaluateJiraExpression(params: Params$evaluateJiraExpression, option?: RequestOption): Promise<Response$evaluateJiraExpression$Status$200["application/json"]>;
    /**
     * Get fields
     * Returns system and custom issue fields according to the following rules:
     *
     *  *  Fields that cannot be added to the issue navigator are always returned.
     *  *  Fields that cannot be placed on an issue screen are always returned.
     *  *  Fields that depend on global Jira settings are only returned if the setting is enabled. That is, timetracking fields, subtasks, votes, and watches.
     *  *  For all other fields, this operation only returns the fields that the user has permission to view (that is, the field is used in at least one project that the user has *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.)
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getFields
     * Request URI: /rest/api/3/field
     */
    getFields(option?: RequestOption): Promise<Response$getFields$Status$200["application/json"]>;
    /**
     * Create custom field
     * Creates a custom field.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createCustomField
     * Request URI: /rest/api/3/field
     */
    createCustomField(params: Params$createCustomField, option?: RequestOption): Promise<Response$createCustomField$Status$201["application/json"]>;
    /**
     * Get fields paginated
     * Returns a [paginated](#pagination) list of fields for Classic Jira projects. The list can include:
     *
     *  *  all fields.
     *  *  specific fields, by defining `id`.
     *  *  fields that contain a string in the field name or description, by defining `query`.
     *  *  specific fields that contain a string in the field name or description, by defining `id` and `query`.
     *
     * Only custom fields can be queried, `type` must be set to `custom`.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getFieldsPaginated
     * Request URI: /rest/api/3/field/search
     */
    getFieldsPaginated(params: Params$getFieldsPaginated, option?: RequestOption): Promise<Response$getFieldsPaginated$Status$200["application/json"]>;
    /**
     * Update custom field
     * Updates a custom field.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateCustomField
     * Request URI: /rest/api/3/field/{fieldId}
     */
    updateCustomField(params: Params$updateCustomField, option?: RequestOption): Promise<Response$updateCustomField$Status$204["application/json"]>;
    /**
     * Get custom field contexts
     * Returns a [paginated](#pagination) list of [ contexts](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html) for a custom field. Contexts can be returned as follows:
     *
     *  *  With no other parameters set, all contexts.
     *  *  By defining `id` only, all contexts from the list of IDs.
     *  *  By defining `isAnyIssueType`, limit the list of contexts returned to either those that apply to all issue types (true) or those that apply to only a subset of issue types (false)
     *  *  By defining `isGlobalContext`, limit the list of contexts return to either those that apply to all projects (global contexts) (true) or those that apply to only a subset of projects (false).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getContextsForField
     * Request URI: /rest/api/3/field/{fieldId}/context
     */
    getContextsForField(params: Params$getContextsForField, option?: RequestOption): Promise<Response$getContextsForField$Status$200["application/json"]>;
    /**
     * Create custom field context
     * Creates a custom field context.
     *
     * If `projectIds` is empty, a global context is created. A global context is one that applies to all project. If `issueTypeIds` is empty, the context applies to all issue types.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createCustomFieldContext
     * Request URI: /rest/api/3/field/{fieldId}/context
     */
    createCustomFieldContext(params: Params$createCustomFieldContext, option?: RequestOption): Promise<Response$createCustomFieldContext$Status$201["application/json"]>;
    /**
     * Get custom field contexts default values
     * Returns a [paginated](#pagination) list of defaults for a custom field. The results can be filtered by `contextId`, otherwise all values are returned. If no defaults are set for a context, nothing is returned.
     * The returned object depends on type of the custom field:
     *
     *  *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
     *  *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
     *  *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
     *  *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
     *  *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
     *  *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
     *  *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
     *  *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
     *  *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
     *  *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
     *  *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
     *  *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
     *  *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
     *  *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
     *  *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
     *  *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
     *  *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
     *  *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getDefaultValues
     * Request URI: /rest/api/3/field/{fieldId}/context/defaultValue
     */
    getDefaultValues(params: Params$getDefaultValues, option?: RequestOption): Promise<Response$getDefaultValues$Status$200["application/json"]>;
    /**
     * Set custom field contexts default values
     * Sets default for contexts of a custom field. Default are defined using these objects:
     *
     *  *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
     *  *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
     *  *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
     *  *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
     *  *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
     *  *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
     *  *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
     *  *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group picker.
     *  *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group picker.
     *  *  `CustomFieldContextDefaultValueURL` (type `url`) for URL.
     *  *  `CustomFieldContextDefaultValueProject` (type `project`) for project picker.
     *  *  `CustomFieldContextDefaultValueFloat` (type `float`) for float (a floating-point number).
     *  *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
     *  *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text field.
     *  *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area field.
     *  *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) field.
     *  *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version picker.
     *  *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version picker.
     *
     * Only one type of default object can be included in a request. To remove a default for a context, set the default parameter to `null`.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setDefaultValues
     * Request URI: /rest/api/3/field/{fieldId}/context/defaultValue
     */
    setDefaultValues(params: Params$setDefaultValues, option?: RequestOption): Promise<Response$setDefaultValues$Status$204["application/json"]>;
    /**
     * Get issue types for custom field context
     * Returns a [paginated](#pagination) list of context to issue type mappings for a custom field. Mappings are returned for all contexts or a list of contexts. Mappings are ordered first by context ID and then by issue type ID.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypeMappingsForContexts
     * Request URI: /rest/api/3/field/{fieldId}/context/issuetypemapping
     */
    getIssueTypeMappingsForContexts(params: Params$getIssueTypeMappingsForContexts, option?: RequestOption): Promise<Response$getIssueTypeMappingsForContexts$Status$200["application/json"]>;
    /**
     * Get custom field contexts for projects and issue types
     * Returns a [paginated](#pagination) list of project and issue type mappings and, for each mapping, the ID of a [custom field context](https://confluence.atlassian.com/x/k44fOw) that applies to the project and issue type.
     *
     * If there is no custom field context assigned to the project then, if present, the custom field context that applies to all projects is returned if it also applies to the issue type or all issue types. If a custom field context is not found, the returned custom field context ID is `null`.
     *
     * Duplicate project and issue type mappings cannot be provided in the request.
     *
     * The order of the returned values is the same as provided in the request.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getCustomFieldContextsForProjectsAndIssueTypes
     * Request URI: /rest/api/3/field/{fieldId}/context/mapping
     */
    getCustomFieldContextsForProjectsAndIssueTypes(params: Params$getCustomFieldContextsForProjectsAndIssueTypes, option?: RequestOption): Promise<Response$getCustomFieldContextsForProjectsAndIssueTypes$Status$200["application/json"]>;
    /**
     * Get project mappings for custom field context
     * Returns a [paginated](#pagination) list of context to project mappings for a custom field. The result can be filtered by `contextId`. Otherwise, all mappings are returned. Invalid IDs are ignored.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getProjectContextMapping
     * Request URI: /rest/api/3/field/{fieldId}/context/projectmapping
     */
    getProjectContextMapping(params: Params$getProjectContextMapping, option?: RequestOption): Promise<Response$getProjectContextMapping$Status$200["application/json"]>;
    /**
     * Update custom field context
     * Updates a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateCustomFieldContext
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}
     */
    updateCustomFieldContext(params: Params$updateCustomFieldContext, option?: RequestOption): Promise<Response$updateCustomFieldContext$Status$204["application/json"]>;
    /**
     * Delete custom field context
     * Deletes a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteCustomFieldContext
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}
     */
    deleteCustomFieldContext(params: Params$deleteCustomFieldContext, option?: RequestOption): Promise<Response$deleteCustomFieldContext$Status$204["application/json"]>;
    /**
     * Add issue types to context
     * Adds issue types to a custom field context, appending the issue types to the issue types list.
     *
     * A custom field context without any issue types applies to all issue types. Adding issue types to such a custom field context would result in it applying to only the listed issue types.
     *
     * If any of the issue types exists in the custom field context, the operation fails and no issue types are added.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addIssueTypesToContext
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/issuetype
     */
    addIssueTypesToContext(params: Params$addIssueTypesToContext, option?: RequestOption): Promise<Response$addIssueTypesToContext$Status$204["application/json"]>;
    /**
     * Remove issue types from context
     * Removes issue types from a custom field context.
     *
     * A custom field context without any issue types applies to all issue types.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeIssueTypesFromContext
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/issuetype/remove
     */
    removeIssueTypesFromContext(params: Params$removeIssueTypesFromContext, option?: RequestOption): Promise<Response$removeIssueTypesFromContext$Status$204["application/json"]>;
    /**
     * Get custom field options (context)
     * Returns a [paginated](#pagination) list of all custom field option for a context. Options are returned first then cascading options, in the order they display in Jira.
     *
     * This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getOptionsForContext
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/option
     */
    getOptionsForContext(params: Params$getOptionsForContext, option?: RequestOption): Promise<Response$getOptionsForContext$Status$200["application/json"]>;
    /**
     * Update custom field options (context)
     * Updates the options of a custom field.
     *
     * If any of the options are not found, no options are updated. Options where the values in the request match the current values aren't updated and aren't reported in the response.
     *
     * Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateCustomFieldOption
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/option
     */
    updateCustomFieldOption(params: Params$updateCustomFieldOption, option?: RequestOption): Promise<Response$updateCustomFieldOption$Status$200["application/json"]>;
    /**
     * Create custom field options (context)
     * Creates options and, where the custom select field is of the type Select List (cascading), cascading options for a custom select field. The options are added to a context of the field.
     *
     * The maximum number of options that can be created per request is 1000 and each field can have a maximum of 10000 options.
     *
     * This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createCustomFieldOption
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/option
     */
    createCustomFieldOption(params: Params$createCustomFieldOption, option?: RequestOption): Promise<Response$createCustomFieldOption$Status$200["application/json"]>;
    /**
     * Reorder custom field options (context)
     * Changes the order of custom field options or cascading options in a context.
     *
     * This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: reorderCustomFieldOptions
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/option/move
     */
    reorderCustomFieldOptions(params: Params$reorderCustomFieldOptions, option?: RequestOption): Promise<Response$reorderCustomFieldOptions$Status$204["application/json"]>;
    /**
     * Delete custom field options (context)
     * Deletes a custom field option.
     *
     * Options with cascading options cannot be deleted without deleting the cascading options first.
     *
     * This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteCustomFieldOption
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/option/{optionId}
     */
    deleteCustomFieldOption(params: Params$deleteCustomFieldOption, option?: RequestOption): Promise<void>;
    /**
     * Assign custom field context to projects
     * Assigns a custom field context to projects.
     *
     * If any project in the request is assigned to any context of the custom field, the operation fails.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: assignProjectsToCustomFieldContext
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/project
     */
    assignProjectsToCustomFieldContext(params: Params$assignProjectsToCustomFieldContext, option?: RequestOption): Promise<Response$assignProjectsToCustomFieldContext$Status$204["application/json"]>;
    /**
     * Remove custom field context from projects
     * Removes a custom field context from projects.
     *
     * A custom field context without any projects applies to all projects. Removing all projects from a custom field context would result in it applying to all projects.
     *
     * If any project in the request is not assigned to the context, or the operation would result in two global contexts for the field, the operation fails.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeCustomFieldContextFromProjects
     * Request URI: /rest/api/3/field/{fieldId}/context/{contextId}/project/remove
     */
    removeCustomFieldContextFromProjects(params: Params$removeCustomFieldContextFromProjects, option?: RequestOption): Promise<Response$removeCustomFieldContextFromProjects$Status$204["application/json"]>;
    /**
     * @deprecated
     * Get contexts for a field
     * Returns a [paginated](#pagination) list of the contexts a field is used in. Deprecated, use [ Get custom field contexts](#api-rest-api-3-field-fieldId-context-get).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getContextsForFieldDeprecated
     * Request URI: /rest/api/3/field/{fieldId}/contexts
     */
    getContextsForFieldDeprecated(params: Params$getContextsForFieldDeprecated, option?: RequestOption): Promise<Response$getContextsForFieldDeprecated$Status$200["application/json"]>;
    /**
     * Get screens for a field
     * Returns a [paginated](#pagination) list of the screens a field is used in.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getScreensForField
     * Request URI: /rest/api/3/field/{fieldId}/screens
     */
    getScreensForField(params: Params$getScreensForField, option?: RequestOption): Promise<Response$getScreensForField$Status$200["application/json"]>;
    /**
     * Get all issue field options
     * Returns a [paginated](#pagination) list of all the options of a select list issue field. A select list issue field is a type of [issue field](https://developer.atlassian.com/cloud/jira/platform/modules/issue-field/) that enables a user to select a value from a list of options.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the app providing the field.
     * operationId: getAllIssueFieldOptions
     * Request URI: /rest/api/3/field/{fieldKey}/option
     */
    getAllIssueFieldOptions(params: Params$getAllIssueFieldOptions, option?: RequestOption): Promise<Response$getAllIssueFieldOptions$Status$200["application/json"]>;
    /**
     * Create issue field option
     * Creates an option for a select list issue field.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the app providing the field.
     * operationId: createIssueFieldOption
     * Request URI: /rest/api/3/field/{fieldKey}/option
     */
    createIssueFieldOption(params: Params$createIssueFieldOption, option?: RequestOption): Promise<Response$createIssueFieldOption$Status$200["application/json"]>;
    /**
     * Get selectable issue field options
     * Returns a [paginated](#pagination) list of options for a select list issue field that can be viewed and selected by the user.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getSelectableIssueFieldOptions
     * Request URI: /rest/api/3/field/{fieldKey}/option/suggestions/edit
     */
    getSelectableIssueFieldOptions(params: Params$getSelectableIssueFieldOptions, option?: RequestOption): Promise<Response$getSelectableIssueFieldOptions$Status$200["application/json"]>;
    /**
     * Get visible issue field options
     * Returns a [paginated](#pagination) list of options for a select list issue field that can be viewed by the user.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getVisibleIssueFieldOptions
     * Request URI: /rest/api/3/field/{fieldKey}/option/suggestions/search
     */
    getVisibleIssueFieldOptions(params: Params$getVisibleIssueFieldOptions, option?: RequestOption): Promise<Response$getVisibleIssueFieldOptions$Status$200["application/json"]>;
    /**
     * Get issue field option
     * Returns an option from a select list issue field.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the app providing the field.
     * operationId: getIssueFieldOption
     * Request URI: /rest/api/3/field/{fieldKey}/option/{optionId}
     */
    getIssueFieldOption(params: Params$getIssueFieldOption, option?: RequestOption): Promise<Response$getIssueFieldOption$Status$200["application/json"]>;
    /**
     * Update issue field option
     * Updates or creates an option for a select list issue field. This operation requires that the option ID is provided when creating an option, therefore, the option ID needs to be specified as a path and body parameter. The option ID provided in the path and body must be identical.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the app providing the field.
     * operationId: updateIssueFieldOption
     * Request URI: /rest/api/3/field/{fieldKey}/option/{optionId}
     */
    updateIssueFieldOption(params: Params$updateIssueFieldOption, option?: RequestOption): Promise<Response$updateIssueFieldOption$Status$200["application/json"]>;
    /**
     * Delete issue field option
     * Deletes an option from a select list issue field.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the app providing the field.
     * operationId: deleteIssueFieldOption
     * Request URI: /rest/api/3/field/{fieldKey}/option/{optionId}
     */
    deleteIssueFieldOption(params: Params$deleteIssueFieldOption, option?: RequestOption): Promise<Response$deleteIssueFieldOption$Status$204["application/json"]>;
    /**
     * Replace issue field option
     * Deselects an issue-field select-list option from all issues where it is selected. A different option can be selected to replace the deselected option. The update can also be limited to a smaller set of issues by using a JQL query.
     *
     * Connect app users with admin permissions (from user permissions and app scopes) and Forge app users with the `manage:jira-configuration` scope can override the screen security configuration using `overrideScreenSecurity` and `overrideEditableFlag`.
     *
     * This is an [asynchronous operation](#async). The response object contains a link to the long-running task.
     *
     * Note that this operation **only works for issue field select list options added by Connect apps**, it cannot be used with issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg). Jira permissions are not required for the app providing the field.
     * operationId: replaceIssueFieldOption
     * Request URI: /rest/api/3/field/{fieldKey}/option/{optionId}/issue
     */
    replaceIssueFieldOption(params: Params$replaceIssueFieldOption, option?: RequestOption): Promise<void>;
    /**
     * Delete custom field
     * Deletes a custom field. The custom field is deleted whether it is in the trash or not. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
     *
     * This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteCustomField
     * Request URI: /rest/api/3/field/{id}
     */
    deleteCustomField(params: Params$deleteCustomField, option?: RequestOption): Promise<void>;
    /**
     * Restore custom field from trash
     * Restores a custom field from trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: restoreCustomField
     * Request URI: /rest/api/3/field/{id}/restore
     */
    restoreCustomField(params: Params$restoreCustomField, option?: RequestOption): Promise<Response$restoreCustomField$Status$200["application/json"]>;
    /**
     * Move custom field to trash
     * Moves a custom field to trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: trashCustomField
     * Request URI: /rest/api/3/field/{id}/trash
     */
    trashCustomField(params: Params$trashCustomField, option?: RequestOption): Promise<Response$trashCustomField$Status$200["application/json"]>;
    /**
     * Get all field configurations
     * Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:
     *
     *  *  a list of field configuration item IDs.
     *  *  whether the field configuration is a default.
     *  *  whether the field configuration name or description contains a query string.
     *
     * Only field configurations used in company-managed (classic) projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllFieldConfigurations
     * Request URI: /rest/api/3/fieldconfiguration
     */
    getAllFieldConfigurations(params: Params$getAllFieldConfigurations, option?: RequestOption): Promise<Response$getAllFieldConfigurations$Status$200["application/json"]>;
    /**
     * Create field configuration
     * Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.
     *
     * This operation can only create configurations for use in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createFieldConfiguration
     * Request URI: /rest/api/3/fieldconfiguration
     */
    createFieldConfiguration(params: Params$createFieldConfiguration, option?: RequestOption): Promise<Response$createFieldConfiguration$Status$200["application/json"]>;
    /**
     * Update field configuration
     * Updates a field configuration. The name and the description provided in the request override the existing values.
     *
     * This operation can only update configurations used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateFieldConfiguration
     * Request URI: /rest/api/3/fieldconfiguration/{id}
     */
    updateFieldConfiguration(params: Params$updateFieldConfiguration, option?: RequestOption): Promise<Response$updateFieldConfiguration$Status$204["application/json"]>;
    /**
     * Delete field configuration
     * Deletes a field configuration.
     *
     * This operation can only delete configurations used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteFieldConfiguration
     * Request URI: /rest/api/3/fieldconfiguration/{id}
     */
    deleteFieldConfiguration(params: Params$deleteFieldConfiguration, option?: RequestOption): Promise<Response$deleteFieldConfiguration$Status$204["application/json"]>;
    /**
     * Get field configuration items
     * Returns a [paginated](#pagination) list of all fields for a configuration.
     *
     * Only the fields from configurations used in company-managed (classic) projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getFieldConfigurationItems
     * Request URI: /rest/api/3/fieldconfiguration/{id}/fields
     */
    getFieldConfigurationItems(params: Params$getFieldConfigurationItems, option?: RequestOption): Promise<Response$getFieldConfigurationItems$Status$200["application/json"]>;
    /**
     * Update field configuration items
     * Updates fields in a field configuration. The properties of the field configuration fields provided override the existing values.
     *
     * This operation can only update field configurations used in company-managed (classic) projects.
     *
     * The operation can set the renderer for text fields to the default text renderer (`text-renderer`) or wiki style renderer (`wiki-renderer`). However, the renderer cannot be updated for fields using the autocomplete renderer (`autocomplete-renderer`).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateFieldConfigurationItems
     * Request URI: /rest/api/3/fieldconfiguration/{id}/fields
     */
    updateFieldConfigurationItems(params: Params$updateFieldConfigurationItems, option?: RequestOption): Promise<Response$updateFieldConfigurationItems$Status$204["application/json"]>;
    /**
     * Get all field configuration schemes
     * Returns a [paginated](#pagination) list of field configuration schemes.
     *
     * Only field configuration schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllFieldConfigurationSchemes
     * Request URI: /rest/api/3/fieldconfigurationscheme
     */
    getAllFieldConfigurationSchemes(params: Params$getAllFieldConfigurationSchemes, option?: RequestOption): Promise<Response$getAllFieldConfigurationSchemes$Status$200["application/json"]>;
    /**
     * Create field configuration scheme
     * Creates a field configuration scheme.
     *
     * This operation can only create field configuration schemes used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createFieldConfigurationScheme
     * Request URI: /rest/api/3/fieldconfigurationscheme
     */
    createFieldConfigurationScheme(params: Params$createFieldConfigurationScheme, option?: RequestOption): Promise<Response$createFieldConfigurationScheme$Status$201["application/json"]>;
    /**
     * Get field configuration issue type items
     * Returns a [paginated](#pagination) list of field configuration issue type items.
     *
     * Only items used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getFieldConfigurationSchemeMappings
     * Request URI: /rest/api/3/fieldconfigurationscheme/mapping
     */
    getFieldConfigurationSchemeMappings(params: Params$getFieldConfigurationSchemeMappings, option?: RequestOption): Promise<Response$getFieldConfigurationSchemeMappings$Status$200["application/json"]>;
    /**
     * Get field configuration schemes for projects
     * Returns a [paginated](#pagination) list of field configuration schemes and, for each scheme, a list of the projects that use it.
     *
     * The list is sorted by field configuration scheme ID. The first item contains the list of project IDs assigned to the default field configuration scheme.
     *
     * Only field configuration schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getFieldConfigurationSchemeProjectMapping
     * Request URI: /rest/api/3/fieldconfigurationscheme/project
     */
    getFieldConfigurationSchemeProjectMapping(params: Params$getFieldConfigurationSchemeProjectMapping, option?: RequestOption): Promise<Response$getFieldConfigurationSchemeProjectMapping$Status$200["application/json"]>;
    /**
     * Assign field configuration scheme to project
     * Assigns a field configuration scheme to a project. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme.
     *
     * Field configuration schemes can only be assigned to classic projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: assignFieldConfigurationSchemeToProject
     * Request URI: /rest/api/3/fieldconfigurationscheme/project
     */
    assignFieldConfigurationSchemeToProject(params: Params$assignFieldConfigurationSchemeToProject, option?: RequestOption): Promise<Response$assignFieldConfigurationSchemeToProject$Status$204["application/json"]>;
    /**
     * Update field configuration scheme
     * Updates a field configuration scheme.
     *
     * This operation can only update field configuration schemes used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateFieldConfigurationScheme
     * Request URI: /rest/api/3/fieldconfigurationscheme/{id}
     */
    updateFieldConfigurationScheme(params: Params$updateFieldConfigurationScheme, option?: RequestOption): Promise<Response$updateFieldConfigurationScheme$Status$204["application/json"]>;
    /**
     * Delete field configuration scheme
     * Deletes a field configuration scheme.
     *
     * This operation can only delete field configuration schemes used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteFieldConfigurationScheme
     * Request URI: /rest/api/3/fieldconfigurationscheme/{id}
     */
    deleteFieldConfigurationScheme(params: Params$deleteFieldConfigurationScheme, option?: RequestOption): Promise<Response$deleteFieldConfigurationScheme$Status$204["application/json"]>;
    /**
     * Assign issue types to field configurations
     * Assigns issue types to field configurations on field configuration scheme.
     *
     * This operation can only modify field configuration schemes used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setFieldConfigurationSchemeMapping
     * Request URI: /rest/api/3/fieldconfigurationscheme/{id}/mapping
     */
    setFieldConfigurationSchemeMapping(params: Params$setFieldConfigurationSchemeMapping, option?: RequestOption): Promise<Response$setFieldConfigurationSchemeMapping$Status$204["application/json"]>;
    /**
     * Remove issue types from field configuration scheme
     * Removes issue types from the field configuration scheme.
     *
     * This operation can only modify field configuration schemes used in company-managed (classic) projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeIssueTypesFromGlobalFieldConfigurationScheme
     * Request URI: /rest/api/3/fieldconfigurationscheme/{id}/mapping/delete
     */
    removeIssueTypesFromGlobalFieldConfigurationScheme(params: Params$removeIssueTypesFromGlobalFieldConfigurationScheme, option?: RequestOption): Promise<Response$removeIssueTypesFromGlobalFieldConfigurationScheme$Status$204["application/json"]>;
    /**
     * @deprecated
     * Get filters
     * Returns all filters. Deprecated, use [ Search for filters](#api-rest-api-3-filter-search-get) that supports search and pagination.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None, however, only the following filters are returned:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: getFilters
     * Request URI: /rest/api/3/filter
     */
    getFilters(params: Params$getFilters, option?: RequestOption): Promise<Response$getFilters$Status$200["application/json"]>;
    /**
     * Create filter
     * Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: createFilter
     * Request URI: /rest/api/3/filter
     */
    createFilter(params: Params$createFilter, option?: RequestOption): Promise<Response$createFilter$Status$200["application/json"]>;
    /**
     * Get default share scope
     * Returns the default sharing settings for new filters and dashboards for a user.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getDefaultShareScope
     * Request URI: /rest/api/3/filter/defaultShareScope
     */
    getDefaultShareScope(option?: RequestOption): Promise<Response$getDefaultShareScope$Status$200["application/json"]>;
    /**
     * Set default share scope
     * Sets the default sharing for new filters and dashboards for a user.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: setDefaultShareScope
     * Request URI: /rest/api/3/filter/defaultShareScope
     */
    setDefaultShareScope(params: Params$setDefaultShareScope, option?: RequestOption): Promise<Response$setDefaultShareScope$Status$200["application/json"]>;
    /**
     * Get favorite filters
     * Returns the visible favorite filters of the user.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** A favorite filter is only visible to the user where the filter is:
     *
     *  *  owned by the user.
     *  *  shared with a group that the user is a member of.
     *  *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  shared with a public project.
     *  *  shared with the public.
     *
     * For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
     * operationId: getFavouriteFilters
     * Request URI: /rest/api/3/filter/favourite
     */
    getFavouriteFilters(params: Params$getFavouriteFilters, option?: RequestOption): Promise<Response$getFavouriteFilters$Status$200["application/json"]>;
    /**
     * Get my filters
     * Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:
     *
     *  *  owned by the user.
     *  *  shared with a group that the user is a member of.
     *  *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  shared with a public project.
     *  *  shared with the public.
     *
     * For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
     * operationId: getMyFilters
     * Request URI: /rest/api/3/filter/my
     */
    getMyFilters(params: Params$getMyFilters, option?: RequestOption): Promise<Response$getMyFilters$Status$200["application/json"]>;
    /**
     * Search for filters
     * Returns a [paginated](#pagination) list of filters. Use this operation to get:
     *
     *  *  specific filters, by defining `id` only.
     *  *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: getFiltersPaginated
     * Request URI: /rest/api/3/filter/search
     */
    getFiltersPaginated(params: Params$getFiltersPaginated, option?: RequestOption): Promise<Response$getFiltersPaginated$Status$200["application/json"]>;
    /**
     * Get filter
     * Returns a filter.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None, however, the filter is only returned where it is:
     *
     *  *  owned by the user.
     *  *  shared with a group that the user is a member of.
     *  *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  shared with a public project.
     *  *  shared with the public.
     * operationId: getFilter
     * Request URI: /rest/api/3/filter/{id}
     */
    getFilter(params: Params$getFilter, option?: RequestOption): Promise<Response$getFilter$Status$200["application/json"]>;
    /**
     * Update filter
     * Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
     * operationId: updateFilter
     * Request URI: /rest/api/3/filter/{id}
     */
    updateFilter(params: Params$updateFilter, option?: RequestOption): Promise<Response$updateFilter$Status$200["application/json"]>;
    /**
     * Delete filter
     * Delete a filter.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteFilter
     * Request URI: /rest/api/3/filter/{id}
     */
    deleteFilter(params: Params$deleteFilter, option?: RequestOption): Promise<void>;
    /**
     * Get columns
     * Returns the columns configured for a filter. The column configuration is used when the filter's results are viewed in *List View* with the *Columns* set to *Filter*.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None, however, column details are only returned for:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: getColumns
     * Request URI: /rest/api/3/filter/{id}/columns
     */
    getColumns(params: Params$getColumns, option?: RequestOption): Promise<Response$getColumns$Status$200["application/json"]>;
    /**
     * Set columns
     * Sets the columns for a filter. Only navigable fields can be set as columns. Use [Get fields](#api-rest-api-3-field-get) to get the list fields in Jira. A navigable field has `navigable` set to `true`.
     *
     * The parameters for this resource are expressed as HTML form data. For example, in curl:
     *
     * `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/filter/10000/columns`
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only set for:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: setColumns
     * Request URI: /rest/api/3/filter/{id}/columns
     */
    setColumns<RequestContentType extends RequestContentType$setColumns>(params: Params$setColumns<RequestContentType>, option?: RequestOption): Promise<Response$setColumns$Status$200["application/json"]>;
    /**
     * Reset columns
     * Reset the user's column configuration for the filter to the default.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only reset for:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: resetColumns
     * Request URI: /rest/api/3/filter/{id}/columns
     */
    resetColumns(params: Params$resetColumns, option?: RequestOption): Promise<void>;
    /**
     * Add filter as favorite
     * Add a filter as a favorite for the user.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however, the user can only favorite:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: setFavouriteForFilter
     * Request URI: /rest/api/3/filter/{id}/favourite
     */
    setFavouriteForFilter(params: Params$setFavouriteForFilter, option?: RequestOption): Promise<Response$setFavouriteForFilter$Status$200["application/json"]>;
    /**
     * Remove filter as favorite
     * Removes a filter as a favorite for the user. Note that this operation only removes filters visible to the user from the user's favorites list. For example, if the user favorites a public filter that is subsequently made private (and is therefore no longer visible on their favorites list) they cannot remove it from their favorites list.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: deleteFavouriteForFilter
     * Request URI: /rest/api/3/filter/{id}/favourite
     */
    deleteFavouriteForFilter(params: Params$deleteFavouriteForFilter, option?: RequestOption): Promise<Response$deleteFavouriteForFilter$Status$200["application/json"]>;
    /**
     * Get share permissions
     * Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None, however, share permissions are only returned for:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: getSharePermissions
     * Request URI: /rest/api/3/filter/{id}/permission
     */
    getSharePermissions(params: Params$getSharePermissions, option?: RequestOption): Promise<Response$getSharePermissions$Status$200["application/json"]>;
    /**
     * Add share permission
     * Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.
     *
     * Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).
     *
     * **[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
     * operationId: addSharePermission
     * Request URI: /rest/api/3/filter/{id}/permission
     */
    addSharePermission(params: Params$addSharePermission, option?: RequestOption): Promise<Response$addSharePermission$Status$201["application/json"]>;
    /**
     * Get share permission
     * Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None, however, a share permission is only returned for:
     *
     *  *  filters owned by the user.
     *  *  filters shared with a group that the user is a member of.
     *  *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
     *  *  filters shared with a public project.
     *  *  filters shared with the public.
     * operationId: getSharePermission
     * Request URI: /rest/api/3/filter/{id}/permission/{permissionId}
     */
    getSharePermission(params: Params$getSharePermission, option?: RequestOption): Promise<Response$getSharePermission$Status$200["application/json"]>;
    /**
     * Delete share permission
     * Deletes a share permission from a filter.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
     * operationId: deleteSharePermission
     * Request URI: /rest/api/3/filter/{id}/permission/{permissionId}
     */
    deleteSharePermission(params: Params$deleteSharePermission, option?: RequestOption): Promise<void>;
    /**
     * @deprecated
     * Get group
     * This operation is deprecated, use [`group/member`](#api-rest-api-3-group-member-get).
     *
     * Returns all users in a group.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getGroup
     * Request URI: /rest/api/3/group
     */
    getGroup(params: Params$getGroup, option?: RequestOption): Promise<Response$getGroup$Status$200["application/json"]>;
    /**
     * Create group
     * Creates a group.
     *
     * **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
     * operationId: createGroup
     * Request URI: /rest/api/3/group
     */
    createGroup(params: Params$createGroup, option?: RequestOption): Promise<Response$createGroup$Status$201["application/json"]>;
    /**
     * Remove group
     * Deletes a group.
     *
     * **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* strategic [group](https://confluence.atlassian.com/x/24xjL)).
     * operationId: removeGroup
     * Request URI: /rest/api/3/group
     */
    removeGroup(params: Params$removeGroup, option?: RequestOption): Promise<void>;
    /**
     * Bulk get groups
     * Returns a [paginated](#pagination) list of groups.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: bulkGetGroups
     * Request URI: /rest/api/3/group/bulk
     */
    bulkGetGroups(params: Params$bulkGetGroups, option?: RequestOption): Promise<Response$bulkGetGroups$Status$200["application/json"]>;
    /**
     * Get users from group
     * Returns a [paginated](#pagination) list of all users in a group.
     *
     * Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getUsersFromGroup
     * Request URI: /rest/api/3/group/member
     */
    getUsersFromGroup(params: Params$getUsersFromGroup, option?: RequestOption): Promise<Response$getUsersFromGroup$Status$200["application/json"]>;
    /**
     * Add user to group
     * Adds a user to a group.
     *
     * **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
     * operationId: addUserToGroup
     * Request URI: /rest/api/3/group/user
     */
    addUserToGroup(params: Params$addUserToGroup, option?: RequestOption): Promise<Response$addUserToGroup$Status$201["application/json"]>;
    /**
     * Remove user from group
     * Removes a user from a group.
     *
     * **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
     * operationId: removeUserFromGroup
     * Request URI: /rest/api/3/group/user
     */
    removeUserFromGroup(params: Params$removeUserFromGroup, option?: RequestOption): Promise<void>;
    /**
     * Find groups
     * Returns a list of groups whose names contain a query string. A list of group names can be provided to exclude groups from the results.
     *
     * The primary use case for this resource is to populate a group picker suggestions list. To this end, the returned object includes the `html` field where the matched query term is highlighted in the group name with the HTML strong tag. Also, the groups list is wrapped in a response object that contains a header for use in the picker, specifically *Showing X of Y matching groups*.
     *
     * The list returns with the groups sorted. If no groups match the list criteria, an empty list is returned.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg). Anonymous calls and calls by users without the required permission return an empty list.
     * operationId: findGroups
     * Request URI: /rest/api/3/groups/picker
     */
    findGroups(params: Params$findGroups, option?: RequestOption): Promise<Response$findGroups$Status$200["application/json"]>;
    /**
     * Find users and groups
     * Returns a list of users and groups matching a string. The string is used:
     *
     *  *  for users, to find a case-insensitive match with display name and e-mail address. Note that if a user has hidden their email address in their user profile, partial matches of the email address will not find the user. An exact match is required.
     *  *  for groups, to find a case-sensitive match with group name.
     *
     * For example, if the string *tin* is used, records with the display name *Tina*, email address *sarah@tinplatetraining.com*, and the group *accounting* would be returned.
     *
     * Optionally, the search can be refined to:
     *
     *  *  the projects and issue types associated with a custom field, such as a user picker. The search can then be further refined to return only users and groups that have permission to view specific:
     *
     *      *  projects.
     *      *  issue types.
     *
     *     If multiple projects or issue types are specified, they must be a subset of those enabled for the custom field or no results are returned. For example, if a field is enabled for projects A, B, and C then the search could be limited to projects B and C. However, if the search is limited to projects B and D, nothing is returned.
     *  *  not return Connect app users and groups.
     *  *  return groups that have a case-insensitive match with the query.
     *
     * The primary use case for this resource is to populate a picker field suggestion list with users or groups. To this end, the returned object includes an `html` field for each list. This field highlights the matched query term in the item name with the HTML strong tag. Also, each list is wrapped in a response object that contains a header for use in a picker, specifically *Showing X of Y matching groups*.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: findUsersAndGroups
     * Request URI: /rest/api/3/groupuserpicker
     */
    findUsersAndGroups(params: Params$findUsersAndGroups, option?: RequestOption): Promise<Response$findUsersAndGroups$Status$200["application/json"]>;
    /**
     * Get license
     * Returns licensing information about the Jira instance.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getLicense
     * Request URI: /rest/api/3/instance/license
     */
    getLicense(option?: RequestOption): Promise<Response$getLicense$Status$200["application/json"]>;
    /**
     * Create issue
     * Creates an issue or, where the option to create subtasks is enabled in Jira, a subtask. A transition may be applied, to move the issue or subtask to a workflow step other than the default start step, and issue properties set.
     *
     * The content of the issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issue's create screen. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
     *
     * Creating a subtask differs from creating an issue as follows:
     *
     *  *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
     *  *  `parent` must contain the ID or key of the parent issue.
     *
     * In a next-gen project any issue may be made a child providing that the parent and child are members of the same project. In a classic project the parent field is only valid for subtasks.
     *
     * **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which the issue or subtask is created.
     * operationId: createIssue
     * Request URI: /rest/api/3/issue
     */
    createIssue(params: Params$createIssue, option?: RequestOption): Promise<Response$createIssue$Status$201["application/json"]>;
    /**
     * Bulk create issue
     * Creates issues and, where the option to create subtasks is enabled in Jira, subtasks. Transitions may be applied, to move the issues or subtasks to a workflow step other than the default start step, and issue properties set.
     *
     * The content of each issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issues' create screens. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
     *
     * Creating a subtask differs from creating an issue as follows:
     *
     *  *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
     *  *  `parent` the must contain the ID or key of the parent issue.
     *
     * **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which each issue or subtask is created.
     * operationId: createIssues
     * Request URI: /rest/api/3/issue/bulk
     */
    createIssues(params: Params$createIssues, option?: RequestOption): Promise<Response$createIssues$Status$201["application/json"]>;
    /**
     * Get create issue metadata
     * Returns details of projects, issue types within projects, and, when requested, the create screen fields for each issue type for the user. Use the information to populate the requests in [ Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).
     *
     * The request can be restricted to specific projects or issue types using the query parameters. The response will contain information for the valid projects, issue types, or project and issue type combinations requested. Note that invalid project, issue type, or project and issue type combinations do not generate errors.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Create issues* [project permission](https://confluence.atlassian.com/x/yodKLg) in the requested projects.
     * operationId: getCreateIssueMeta
     * Request URI: /rest/api/3/issue/createmeta
     */
    getCreateIssueMeta(params: Params$getCreateIssueMeta, option?: RequestOption): Promise<Response$getCreateIssueMeta$Status$200["application/json"]>;
    /**
     * Get issue picker suggestions
     * Returns lists of issues matching a query string. Use this resource to provide auto-completion suggestions when the user is looking for an issue using a word or string.
     *
     * This operation returns two lists:
     *
     *  *  `History Search` which includes issues from the user's history of created, edited, or viewed issues that contain the string in the `query` parameter.
     *  *  `Current Search` which includes issues that match the JQL expression in `currentJQL` and contain the string in the `query` parameter.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getIssuePickerResource
     * Request URI: /rest/api/3/issue/picker
     */
    getIssuePickerResource(params: Params$getIssuePickerResource, option?: RequestOption): Promise<Response$getIssuePickerResource$Status$200["application/json"]>;
    /**
     * Bulk set issues properties by list
     * Sets or updates a list of entity property values on issues. A list of up to 10 entity properties can be specified along with up to 10,000 issues on which to set or update that list of entity properties.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON. The maximum length of single issue property value is 32768 characters. This operation can be accessed anonymously.
     *
     * This operation is:
     *
     *  *  transactional, either all properties are updated in all eligible issues or, when errors occur, no properties are updated.
     *  *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: bulkSetIssuesPropertiesList
     * Request URI: /rest/api/3/issue/properties
     */
    bulkSetIssuesPropertiesList(params: Params$bulkSetIssuesPropertiesList, option?: RequestOption): Promise<void>;
    /**
     * Bulk set issue properties by issue
     * Sets or updates entity property values on issues. Up to 10 entity properties can be specified for each issue and up to 100 issues included in the request.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON.
     *
     * This operation is:
     *
     *  *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
     *  *  non-transactional. Updating some entities may fail. Such information will available in the task result.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: bulkSetIssuePropertiesByIssue
     * Request URI: /rest/api/3/issue/properties/multi
     */
    bulkSetIssuePropertiesByIssue(params: Params$bulkSetIssuePropertiesByIssue, option?: RequestOption): Promise<void>;
    /**
     * Bulk set issue property
     * Sets a property value on multiple issues.
     *
     * The value set can be a constant or determined by a [Jira expression](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/). Expressions must be computable with constant complexity when applied to a set of issues. Expressions must also comply with the [restrictions](https://developer.atlassian.com/cloud/jira/platform/jira-expressions/#restrictions) that apply to all Jira expressions.
     *
     * The issues to be updated can be specified by a filter.
     *
     * The filter identifies issues eligible for update using these criteria:
     *
     *  *  `entityIds` Only issues from this list are eligible.
     *  *  `currentValue` Only issues with the property set to this value are eligible.
     *  *  `hasProperty`:
     *
     *      *  If *true*, only issues with the property are eligible.
     *      *  If *false*, only issues without the property are eligible.
     *
     * If more than one criteria is specified, they are joined with the logical *AND*: only issues that satisfy all criteria are eligible.
     *
     * If an invalid combination of criteria is provided, an error is returned. For example, specifying a `currentValue` and `hasProperty` as *false* would not match any issues (because without the property the property cannot have a value).
     *
     * The filter is optional. Without the filter all the issues visible to the user and where the user has the EDIT\_ISSUES permission for the issue are considered eligible.
     *
     * This operation is:
     *
     *  *  transactional, either all eligible issues are updated or, when errors occur, none are updated.
     *  *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for each project containing issues.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for each issue.
     * operationId: bulkSetIssueProperty
     * Request URI: /rest/api/3/issue/properties/{propertyKey}
     */
    bulkSetIssueProperty(params: Params$bulkSetIssueProperty, option?: RequestOption): Promise<void>;
    /**
     * Bulk delete issue property
     * Deletes a property value from multiple issues. The issues to be updated can be specified by filter criteria.
     *
     * The criteria the filter used to identify eligible issues are:
     *
     *  *  `entityIds` Only issues from this list are eligible.
     *  *  `currentValue` Only issues with the property set to this value are eligible.
     *
     * If both criteria is specified, they are joined with the logical *AND*: only issues that satisfy both criteria are considered eligible.
     *
     * If no filter criteria are specified, all the issues visible to the user and where the user has the EDIT\_ISSUES permission for the issue are considered eligible.
     *
     * This operation is:
     *
     *  *  transactional, either the property is deleted from all eligible issues or, when errors occur, no properties are deleted.
     *  *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [ project permission](https://confluence.atlassian.com/x/yodKLg) for each project containing issues.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for each issue.
     * operationId: bulkDeleteIssueProperty
     * Request URI: /rest/api/3/issue/properties/{propertyKey}
     */
    bulkDeleteIssueProperty(params: Params$bulkDeleteIssueProperty, option?: RequestOption): Promise<void>;
    /**
     * Get is watching issue bulk
     * Returns, for the user, details of the watched status of issues from a list. If an issue ID is invalid, the returned watched status is `false`.
     *
     * This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getIsWatchingIssueBulk
     * Request URI: /rest/api/3/issue/watching
     */
    getIsWatchingIssueBulk(params: Params$getIsWatchingIssueBulk, option?: RequestOption): Promise<Response$getIsWatchingIssueBulk$Status$200["application/json"]>;
    /**
     * Get issue
     * Returns the details for an issue.
     *
     * The issue is identified by its ID or key, however, if the identifier doesn't match an issue, a case-insensitive search and check for moved issues is performed. If a matching issue is found its details are returned, a 302 or other redirect is **not** returned. The issue key returned in the response is the key of the issue found.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getIssue
     * Request URI: /rest/api/3/issue/{issueIdOrKey}
     */
    getIssue(params: Params$getIssue, option?: RequestOption): Promise<Response$getIssue$Status$200["application/json"]>;
    /**
     * Edit issue
     * Edits an issue. A transition may be applied and issue properties updated as part of the edit.
     *
     * The edits to the issue's fields are defined using `update` and `fields`. The fields that can be edited are determined using [ Get edit issue metadata](#api-rest-api-3-issue-issueIdOrKey-editmeta-get).
     *
     * The parent field may be set by key or ID. For standard issue types, the parent may be removed by setting `update.parent.set.none` to *true*. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
     *
     * Connect app users with admin permission (from user permissions and app scopes) and Forge app users with the `manage:jira-configuration` scope can override the screen security configuration using `overrideScreenSecurity` and `overrideEditableFlag`.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: editIssue
     * Request URI: /rest/api/3/issue/{issueIdOrKey}
     */
    editIssue(params: Params$editIssue, option?: RequestOption): Promise<Response$editIssue$Status$204["application/json"]>;
    /**
     * Delete issue
     * Deletes an issue.
     *
     * An issue cannot be deleted if it has one or more subtasks. To delete an issue with subtasks, set `deleteSubtasks`. This causes the issue's subtasks to be deleted with the issue.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Delete issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: deleteIssue
     * Request URI: /rest/api/3/issue/{issueIdOrKey}
     */
    deleteIssue(params: Params$deleteIssue, option?: RequestOption): Promise<void>;
    /**
     * Assign issue
     * Assigns an issue to a user. Use this operation when the calling user does not have the *Edit Issues* permission but has the *Assign issue* permission for the project that the issue is in.
     *
     * If `name` or `accountId` is set to:
     *
     *  *  `"-1"`, the issue is assigned to the default assignee for the project.
     *  *  `null`, the issue is set to unassigned.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse Projects* and *Assign Issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: assignIssue
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/assignee
     */
    assignIssue(params: Params$assignIssue, option?: RequestOption): Promise<Response$assignIssue$Status$204["application/json"]>;
    /**
     * Add attachment
     * Adds one or more attachments to an issue. Attachments are posted as multipart/form-data ([RFC 1867](https://www.ietf.org/rfc/rfc1867.txt)).
     *
     * Note that:
     *
     *  *  The request must have a `X-Atlassian-Token: no-check` header, if not it is blocked. See [Special headers](#special-request-headers) for more information.
     *  *  The name of the multipart/form-data parameter that contains the attachments must be `file`.
     *
     * The following examples upload a file called *myfile.txt* to the issue *TEST-123*:
     *
     * #### curl ####
     *
     *     curl --location --request POST 'https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments'
     *      -u 'email@example.com:<api_token>'
     *      -H 'X-Atlassian-Token: no-check'
     *      --form 'file=@"myfile.txt"'
     *
     * #### Node.js ####
     *
     *     // This code sample uses the 'node-fetch' and 'form-data' libraries:
     *      // https://www.npmjs.com/package/node-fetch
     *      // https://www.npmjs.com/package/form-data
     *      const fetch = require('node-fetch');
     *      const FormData = require('form-data');
     *      const fs = require('fs');
     *
     *      const filePath = 'myfile.txt';
     *      const form = new FormData();
     *      const stats = fs.statSync(filePath);
     *      const fileSizeInBytes = stats.size;
     *      const fileStream = fs.createReadStream(filePath);
     *
     *      form.append('file', fileStream, {knownLength: fileSizeInBytes});
     *
     *      fetch('https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments', {
     *          method: 'POST',
     *          body: form,
     *          headers: {
     *              'Authorization': `Basic ${Buffer.from(
     *                  'email@example.com:'
     *              ).toString('base64')}`,
     *              'Accept': 'application/json',
     *              'X-Atlassian-Token': 'no-check'
     *          }
     *      })
     *          .then(response => {
     *              console.log(
     *                  `Response: ${response.status} ${response.statusText}`
     *              );
     *              return response.text();
     *          })
     *          .then(text => console.log(text))
     *          .catch(err => console.error(err));
     *
     * #### Java ####
     *
     *     // This code sample uses the  'Unirest' library:
     *      // http://unirest.io/java.html
     *      HttpResponse response = Unirest.post("https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments")
     *              .basicAuth("email@example.com", "")
     *              .header("Accept", "application/json")
     *              .header("X-Atlassian-Token", "no-check")
     *              .field("file", new File("myfile.txt"))
     *              .asJson();
     *
     *              System.out.println(response.getBody());
     *
     * #### Python ####
     *
     *     # This code sample uses the 'requests' library:
     *      # http://docs.python-requests.org
     *      import requests
     *      from requests.auth import HTTPBasicAuth
     *      import json
     *
     *      url = "https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments"
     *
     *      auth = HTTPBasicAuth("email@example.com", "")
     *
     *      headers = {
     *         "Accept": "application/json",
     *         "X-Atlassian-Token": "no-check"
     *      }
     *
     *      response = requests.request(
     *         "POST",
     *         url,
     *         headers = headers,
     *         auth = auth,
     *         files = {
     *              "file": ("myfile.txt", open("myfile.txt","rb"), "application-type")
     *         }
     *      )
     *
     *      print(json.dumps(json.loads(response.text), sort_keys=True, indent=4, separators=(",", ": ")))
     *
     * #### PHP ####
     *
     *     // This code sample uses the 'Unirest' library:
     *      // http://unirest.io/php.html
     *      Unirest\Request::auth('email@example.com', '');
     *
     *      $headers = array(
     *        'Accept' => 'application/json',
     *        'X-Atlassian-Token' => 'no-check'
     *      );
     *
     *      $parameters = array(
     *        'file' => File::add('myfile.txt')
     *      );
     *
     *      $response = Unirest\Request::post(
     *        'https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments',
     *        $headers,
     *        $parameters
     *      );
     *
     *      var_dump($response)
     *
     * #### Forge ####
     *
     *     // This sample uses Atlassian Forge and the `form-data` library.
     *      // https://developer.atlassian.com/platform/forge/
     *      // https://www.npmjs.com/package/form-data
     *      import api from "@forge/api";
     *      import FormData from "form-data";
     *
     *      const form = new FormData();
     *      form.append('file', fileStream, {knownLength: fileSizeInBytes});
     *
     *      const response = await api.asApp().requestJira('/rest/api/2/issue/{issueIdOrKey}/attachments', {
     *          method: 'POST',
     *          body: form,
     *          headers: {
     *              'Accept': 'application/json',
     *              'X-Atlassian-Token': 'no-check'
     *          }
     *      });
     *
     *      console.log(`Response: ${response.status} ${response.statusText}`);
     *      console.log(await response.json());
     *
     * Tip: Use a client library. Many client libraries have classes for handling multipart POST operations. For example, in Java, the Apache HTTP Components library provides a [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html) class for multipart POST operations.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse Projects* and *Create attachments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: addAttachment
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/attachments
     */
    addAttachment(params: Params$addAttachment, option?: RequestOption): Promise<Response$addAttachment$Status$200["application/json"]>;
    /**
     * Get changelogs
     * Returns a [paginated](#pagination) list of all changelogs for an issue sorted by date, starting from the oldest.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getChangeLogs
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/changelog
     */
    getChangeLogs(params: Params$getChangeLogs, option?: RequestOption): Promise<Response$getChangeLogs$Status$200["application/json"]>;
    /**
     * Get changelogs by IDs
     * Returns changelogs for an issue specified by a list of changelog IDs.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getChangeLogsByIds
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/changelog/list
     */
    getChangeLogsByIds(params: Params$getChangeLogsByIds, option?: RequestOption): Promise<Response$getChangeLogsByIds$Status$200["application/json"]>;
    /**
     * Get comments
     * Returns all comments for an issue.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Comments are included in the response where the user has:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the comment has visibility restrictions, belongs to the group or has the role visibility is role visibility is restricted to.
     * operationId: getComments
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/comment
     */
    getComments(params: Params$getComments, option?: RequestOption): Promise<Response$getComments$Status$200["application/json"]>;
    /**
     * Add comment
     * Adds a comment to an issue.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Add comments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: addComment
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/comment
     */
    addComment(params: Params$addComment, option?: RequestOption): Promise<Response$addComment$Status$201["application/json"]>;
    /**
     * Get comment
     * Returns a comment.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
     * operationId: getComment
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/comment/{id}
     */
    getComment(params: Params$getComment, option?: RequestOption): Promise<Response$getComment$Status$200["application/json"]>;
    /**
     * Update comment
     * Updates a comment.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Edit all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any comment or *Edit own comments* to update comment created by the user.
     *  *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
     * operationId: updateComment
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/comment/{id}
     */
    updateComment(params: Params$updateComment, option?: RequestOption): Promise<Response$updateComment$Status$200["application/json"]>;
    /**
     * Delete comment
     * Deletes a comment.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Delete all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any comment or *Delete own comments* to delete comment created by the user,
     *  *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
     * operationId: deleteComment
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/comment/{id}
     */
    deleteComment(params: Params$deleteComment, option?: RequestOption): Promise<void>;
    /**
     * Get edit issue metadata
     * Returns the edit screen fields for an issue that are visible to and editable by the user. Use the information to populate the requests in [Edit issue](#api-rest-api-3-issue-issueIdOrKey-put).
     *
     * Connect app users with admin permission (from user permissions and app scopes) and Forge app users with the `manage:jira-configuration` scope can return additional details using:
     *
     *  *  `overrideScreenSecurity` Returns hidden fields.
     *  *  `overrideEditableFlag` Returns uneditable fields. For example, where an issue has a workflow status of closed none of its fields are editable.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *
     * Note: For any fields to be editable the user must have the *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the issue.
     * operationId: getEditIssueMeta
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/editmeta
     */
    getEditIssueMeta(params: Params$getEditIssueMeta, option?: RequestOption): Promise<Response$getEditIssueMeta$Status$200["application/json"]>;
    /**
     * Send notification for issue
     * Creates an email notification for an issue and adds it to the mail queue.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: notify
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/notify
     */
    notify(params: Params$notify, option?: RequestOption): Promise<Response$notify$Status$204["application/json"]>;
    /**
     * Get issue property keys
     * Returns the URLs and keys of an issue's properties.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Property details are only returned where the user has:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getIssuePropertyKeys
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/properties
     */
    getIssuePropertyKeys(params: Params$getIssuePropertyKeys, option?: RequestOption): Promise<Response$getIssuePropertyKeys$Status$200["application/json"]>;
    /**
     * Get issue property
     * Returns the key and value of an issue's property.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getIssueProperty
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}
     */
    getIssueProperty(params: Params$getIssueProperty, option?: RequestOption): Promise<Response$getIssueProperty$Status$200["application/json"]>;
    /**
     * Set issue property
     * Sets the value of an issue's property. Use this resource to store custom data against an issue.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: setIssueProperty
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}
     */
    setIssueProperty(params: Params$setIssueProperty, option?: RequestOption): Promise<(Response$setIssueProperty$Status$200 | Response$setIssueProperty$Status$201)["application/json"]>;
    /**
     * Delete issue property
     * Deletes an issue's property.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: deleteIssueProperty
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/properties/{propertyKey}
     */
    deleteIssueProperty(params: Params$deleteIssueProperty, option?: RequestOption): Promise<void>;
    /**
     * Get remote issue links
     * Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
     *
     * This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getRemoteIssueLinks
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/remotelink
     */
    getRemoteIssueLinks(params: Params$getRemoteIssueLinks, option?: RequestOption): Promise<Response$getRemoteIssueLinks$Status$200["application/json"]>;
    /**
     * Create or update remote issue link
     * Creates or updates a remote issue link for an issue.
     *
     * If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.
     *
     * This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: createOrUpdateRemoteIssueLink
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/remotelink
     */
    createOrUpdateRemoteIssueLink(params: Params$createOrUpdateRemoteIssueLink, option?: RequestOption): Promise<(Response$createOrUpdateRemoteIssueLink$Status$200 | Response$createOrUpdateRemoteIssueLink$Status$201)["application/json"]>;
    /**
     * Delete remote issue link by global ID
     * Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
     *
     * This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
     * operationId: deleteRemoteIssueLinkByGlobalId
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/remotelink
     */
    deleteRemoteIssueLinkByGlobalId(params: Params$deleteRemoteIssueLinkByGlobalId, option?: RequestOption): Promise<void>;
    /**
     * Get remote issue link by ID
     * Returns a remote issue link for an issue.
     *
     * This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: getRemoteIssueLinkById
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/remotelink/{linkId}
     */
    getRemoteIssueLinkById(params: Params$getRemoteIssueLinkById, option?: RequestOption): Promise<Response$getRemoteIssueLinkById$Status$200["application/json"]>;
    /**
     * Update remote issue link by ID
     * Updates a remote issue link for an issue.
     *
     * Note: Fields without values in the request are set to null.
     *
     * This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: updateRemoteIssueLink
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/remotelink/{linkId}
     */
    updateRemoteIssueLink(params: Params$updateRemoteIssueLink, option?: RequestOption): Promise<Response$updateRemoteIssueLink$Status$204["application/json"]>;
    /**
     * Delete remote issue link by ID
     * Deletes a remote issue link from an issue.
     *
     * This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: deleteRemoteIssueLinkById
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/remotelink/{linkId}
     */
    deleteRemoteIssueLinkById(params: Params$deleteRemoteIssueLinkById, option?: RequestOption): Promise<void>;
    /**
     * Get transitions
     * Returns either all transitions or a transition that can be performed by the user on an issue, based on the issue's status.
     *
     * Note, if a request is made for a transition that does not exist or cannot be performed on the issue, given its status, the response will return any empty transitions list.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required: A list or transition is returned only when the user has:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *
     * However, if the user does not have the *Transition issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) the response will not list any transitions.
     * operationId: getTransitions
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/transitions
     */
    getTransitions(params: Params$getTransitions, option?: RequestOption): Promise<Response$getTransitions$Status$200["application/json"]>;
    /**
     * Transition issue
     * Performs an issue transition and, if the transition has a screen, updates the fields from the transition screen.
     *
     * sortByCategory To update the fields on the transition screen, specify the fields in the `fields` or `update` parameters in the request body. Get details about the fields using [ Get transitions](#api-rest-api-3-issue-issueIdOrKey-transitions-get) with the `transitions.fields` expand.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Transition issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: doTransition
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/transitions
     */
    doTransition(params: Params$doTransition, option?: RequestOption): Promise<Response$doTransition$Status$204["application/json"]>;
    /**
     * Get votes
     * Returns details about the votes on an issue.
     *
     * This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *
     * Note that users with the necessary permissions for this operation but without the *View voters and watchers* project permissions are not returned details in the `voters` field.
     * operationId: getVotes
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/votes
     */
    getVotes(params: Params$getVotes, option?: RequestOption): Promise<Response$getVotes$Status$200["application/json"]>;
    /**
     * Add vote
     * Adds the user's vote to an issue. This is the equivalent of the user clicking *Vote* on an issue in Jira.
     *
     * This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: addVote
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/votes
     */
    addVote(params: Params$addVote, option?: RequestOption): Promise<Response$addVote$Status$204["application/json"]>;
    /**
     * Delete vote
     * Deletes a user's vote from an issue. This is the equivalent of the user clicking *Unvote* on an issue in Jira.
     *
     * This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: removeVote
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/votes
     */
    removeVote(params: Params$removeVote, option?: RequestOption): Promise<void>;
    /**
     * Get issue watchers
     * Returns the watchers for an issue.
     *
     * This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  To see details of users on the watchlist other than themselves, *View voters and watchers* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     * operationId: getIssueWatchers
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/watchers
     */
    getIssueWatchers(params: Params$getIssueWatchers, option?: RequestOption): Promise<Response$getIssueWatchers$Status$200["application/json"]>;
    /**
     * Add watcher
     * Adds a user as a watcher of an issue by passing the account ID of the user. For example, `"5b10ac8d82e05b22cc7d4ef5"`. If no user is specified the calling user is added.
     *
     * This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  To add users other than themselves to the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     * operationId: addWatcher
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/watchers
     */
    addWatcher(params: Params$addWatcher, option?: RequestOption): Promise<Response$addWatcher$Status$204["application/json"]>;
    /**
     * Delete watcher
     * Deletes a user as a watcher of an issue.
     *
     * This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  To remove users other than themselves from the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     * operationId: removeWatcher
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/watchers
     */
    removeWatcher(params: Params$removeWatcher, option?: RequestOption): Promise<void>;
    /**
     * Get issue worklogs
     * Returns worklogs for an issue, starting from the oldest worklog or from the worklog started on or after a date and time.
     *
     * Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Workloads are only returned where the user has:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getIssueWorklog
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog
     */
    getIssueWorklog(params: Params$getIssueWorklog, option?: RequestOption): Promise<Response$getIssueWorklog$Status$200["application/json"]>;
    /**
     * Add worklog
     * Adds a worklog to an issue.
     *
     * Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* and *Work on issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: addWorklog
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog
     */
    addWorklog(params: Params$addWorklog, option?: RequestOption): Promise<Response$addWorklog$Status$201["application/json"]>;
    /**
     * Get worklog
     * Returns a worklog.
     *
     * Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getWorklog
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{id}
     */
    getWorklog(params: Params$getWorklog, option?: RequestOption): Promise<Response$getWorklog$Status$200["application/json"]>;
    /**
     * Update worklog
     * Updates a worklog.
     *
     * Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: updateWorklog
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{id}
     */
    updateWorklog(params: Params$updateWorklog, option?: RequestOption): Promise<Response$updateWorklog$Status$200["application/json"]>;
    /**
     * Delete worklog
     * Deletes a worklog from an issue.
     *
     * Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Delete all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any worklog or *Delete own worklogs* to delete worklogs created by the user,
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: deleteWorklog
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{id}
     */
    deleteWorklog(params: Params$deleteWorklog, option?: RequestOption): Promise<void>;
    /**
     * Get worklog property keys
     * Returns the keys of all properties for a worklog.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getWorklogPropertyKeys
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{worklogId}/properties
     */
    getWorklogPropertyKeys(params: Params$getWorklogPropertyKeys, option?: RequestOption): Promise<Response$getWorklogPropertyKeys$Status$200["application/json"]>;
    /**
     * Get worklog property
     * Returns the value of a worklog property.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: getWorklogProperty
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{worklogId}/properties/{propertyKey}
     */
    getWorklogProperty(params: Params$getWorklogProperty, option?: RequestOption): Promise<Response$getWorklogProperty$Status$200["application/json"]>;
    /**
     * Set worklog property
     * Sets the value of a worklog property. Use this operation to store custom data against the worklog.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: setWorklogProperty
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{worklogId}/properties/{propertyKey}
     */
    setWorklogProperty(params: Params$setWorklogProperty, option?: RequestOption): Promise<(Response$setWorklogProperty$Status$200 | Response$setWorklogProperty$Status$201)["application/json"]>;
    /**
     * Delete worklog property
     * Deletes a worklog property.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: deleteWorklogProperty
     * Request URI: /rest/api/3/issue/{issueIdOrKey}/worklog/{worklogId}/properties/{propertyKey}
     */
    deleteWorklogProperty(params: Params$deleteWorklogProperty, option?: RequestOption): Promise<void>;
    /**
     * Create issue link
     * Creates a link between two issues. Use this operation to indicate a relationship between two issues and optionally add a comment to the from (outward) issue. To use this resource the site must have [Issue Linking](https://confluence.atlassian.com/x/yoXKM) enabled.
     *
     * This resource returns nothing on the creation of an issue link. To obtain the ID of the issue link, use `https://your-domain.atlassian.net/rest/api/3/issue/[linked issue key]?fields=issuelinks`.
     *
     * If the link request duplicates a link, the response indicates that the issue link was created. If the request included a comment, the comment is added.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues to be linked,
     *  *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) on the project containing the from (outward) issue,
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     *  *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
     * operationId: linkIssues
     * Request URI: /rest/api/3/issueLink
     */
    linkIssues(params: Params$linkIssues, option?: RequestOption): Promise<Response$linkIssues$Status$201["application/json"]>;
    /**
     * Get issue link
     * Returns an issue link.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the linked issues.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
     * operationId: getIssueLink
     * Request URI: /rest/api/3/issueLink/{linkId}
     */
    getIssueLink(params: Params$getIssueLink, option?: RequestOption): Promise<Response$getIssueLink$Status$200["application/json"]>;
    /**
     * Delete issue link
     * Deletes an issue link.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  Browse project [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues in the link.
     *  *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one of the projects containing issues in the link.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
     * operationId: deleteIssueLink
     * Request URI: /rest/api/3/issueLink/{linkId}
     */
    deleteIssueLink(params: Params$deleteIssueLink, option?: RequestOption): Promise<void>;
    /**
     * Get issue link types
     * Returns a list of all issue link types.
     *
     * To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
     * operationId: getIssueLinkTypes
     * Request URI: /rest/api/3/issueLinkType
     */
    getIssueLinkTypes(option?: RequestOption): Promise<Response$getIssueLinkTypes$Status$200["application/json"]>;
    /**
     * Create issue link type
     * Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.
     *
     * To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createIssueLinkType
     * Request URI: /rest/api/3/issueLinkType
     */
    createIssueLinkType(params: Params$createIssueLinkType, option?: RequestOption): Promise<Response$createIssueLinkType$Status$201["application/json"]>;
    /**
     * Get issue link type
     * Returns an issue link type.
     *
     * To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
     * operationId: getIssueLinkType
     * Request URI: /rest/api/3/issueLinkType/{issueLinkTypeId}
     */
    getIssueLinkType(params: Params$getIssueLinkType, option?: RequestOption): Promise<Response$getIssueLinkType$Status$200["application/json"]>;
    /**
     * Update issue link type
     * Updates an issue link type.
     *
     * To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateIssueLinkType
     * Request URI: /rest/api/3/issueLinkType/{issueLinkTypeId}
     */
    updateIssueLinkType(params: Params$updateIssueLinkType, option?: RequestOption): Promise<Response$updateIssueLinkType$Status$200["application/json"]>;
    /**
     * Delete issue link type
     * Deletes an issue link type.
     *
     * To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteIssueLinkType
     * Request URI: /rest/api/3/issueLinkType/{issueLinkTypeId}
     */
    deleteIssueLinkType(params: Params$deleteIssueLinkType, option?: RequestOption): Promise<void>;
    /**
     * Get issue security schemes
     * Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueSecuritySchemes
     * Request URI: /rest/api/3/issuesecurityschemes
     */
    getIssueSecuritySchemes(option?: RequestOption): Promise<Response$getIssueSecuritySchemes$Status$200["application/json"]>;
    /**
     * Get issue security scheme
     * Returns an issue security scheme along with its security levels.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
     * operationId: getIssueSecurityScheme
     * Request URI: /rest/api/3/issuesecurityschemes/{id}
     */
    getIssueSecurityScheme(params: Params$getIssueSecurityScheme, option?: RequestOption): Promise<Response$getIssueSecurityScheme$Status$200["application/json"]>;
    /**
     * Get issue security level members
     * Returns issue security level members.
     *
     * Only issue security level members in context of classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueSecurityLevelMembers
     * Request URI: /rest/api/3/issuesecurityschemes/{issueSecuritySchemeId}/members
     */
    getIssueSecurityLevelMembers(params: Params$getIssueSecurityLevelMembers, option?: RequestOption): Promise<Response$getIssueSecurityLevelMembers$Status$200["application/json"]>;
    /**
     * Get all issue types for user
     * Returns all issue types.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Issue types are only returned as follows:
     *
     *  *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), all issue types are returned.
     *  *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for one or more projects, the issue types associated with the projects the user has permission to browse are returned.
     * operationId: getIssueAllTypes
     * Request URI: /rest/api/3/issuetype
     */
    getIssueAllTypes(option?: RequestOption): Promise<Response$getIssueAllTypes$Status$200["application/json"]>;
    /**
     * Create issue type
     * Creates an issue type and adds it to the default issue type scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createIssueType
     * Request URI: /rest/api/3/issuetype
     */
    createIssueType(params: Params$createIssueType, option?: RequestOption): Promise<Response$createIssueType$Status$201["application/json"]>;
    /**
     * Get issue types for project
     * Returns issue types for a project.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in the relevant project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypesForProject
     * Request URI: /rest/api/3/issuetype/project
     */
    getIssueTypesForProject(params: Params$getIssueTypesForProject, option?: RequestOption): Promise<Response$getIssueTypesForProject$Status$200["application/json"]>;
    /**
     * Get issue type
     * Returns an issue type.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in a project the issue type is associated with or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueType
     * Request URI: /rest/api/3/issuetype/{id}
     */
    getIssueType(params: Params$getIssueType, option?: RequestOption): Promise<Response$getIssueType$Status$200["application/json"]>;
    /**
     * Update issue type
     * Updates the issue type.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateIssueType
     * Request URI: /rest/api/3/issuetype/{id}
     */
    updateIssueType(params: Params$updateIssueType, option?: RequestOption): Promise<Response$updateIssueType$Status$200["application/json"]>;
    /**
     * Delete issue type
     * Deletes the issue type. If the issue type is in use, all uses are updated with the alternative issue type (`alternativeIssueTypeId`). A list of alternative issue types are obtained from the [Get alternative issue types](#api-rest-api-3-issuetype-id-alternatives-get) resource.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteIssueType
     * Request URI: /rest/api/3/issuetype/{id}
     */
    deleteIssueType(params: Params$deleteIssueType, option?: RequestOption): Promise<void>;
    /**
     * Get alternative issue types
     * Returns a list of issue types that can be used to replace the issue type. The alternative issue types are those assigned to the same workflow scheme, field configuration scheme, and screen scheme.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAlternativeIssueTypes
     * Request URI: /rest/api/3/issuetype/{id}/alternatives
     */
    getAlternativeIssueTypes(params: Params$getAlternativeIssueTypes, option?: RequestOption): Promise<Response$getAlternativeIssueTypes$Status$200["application/json"]>;
    /**
     * Load issue type avatar
     * Loads an avatar for the issue type.
     *
     * Specify the avatar's local file location in the body of the request. Also, include the following headers:
     *
     *  *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
     *  *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
     *
     * For example:
     * `curl --request POST \ --user email@example.com:<api_token> \ --header 'X-Atlassian-Token: no-check' \ --header 'Content-Type: image/< image_type>' \ --data-binary "<@/path/to/file/with/your/avatar>" \ --url 'https://your-domain.atlassian.net/rest/api/3/issuetype/{issueTypeId}'This`
     *
     * The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
     *
     * The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
     *
     * After creating the avatar, use [ Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createIssueTypeAvatar
     * Request URI: /rest/api/3/issuetype/{id}/avatar2
     */
    createIssueTypeAvatar(params: Params$createIssueTypeAvatar, option?: RequestOption): Promise<Response$createIssueTypeAvatar$Status$201["application/json"]>;
    /**
     * Get issue type property keys
     * Returns all the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys of the issue type.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the property keys of any issue type.
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the property keys of any issue types associated with the projects the user has permission to browse.
     * operationId: getIssueTypePropertyKeys
     * Request URI: /rest/api/3/issuetype/{issueTypeId}/properties
     */
    getIssueTypePropertyKeys(params: Params$getIssueTypePropertyKeys, option?: RequestOption): Promise<Response$getIssueTypePropertyKeys$Status$200["application/json"]>;
    /**
     * Get issue type property
     * Returns the key and value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the details of any issue type.
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the details of any issue types associated with the projects the user has permission to browse.
     * operationId: getIssueTypeProperty
     * Request URI: /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}
     */
    getIssueTypeProperty(params: Params$getIssueTypeProperty, option?: RequestOption): Promise<Response$getIssueTypeProperty$Status$200["application/json"]>;
    /**
     * Set issue type property
     * Creates or updates the value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). Use this resource to store and update data against an issue type.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setIssueTypeProperty
     * Request URI: /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}
     */
    setIssueTypeProperty(params: Params$setIssueTypeProperty, option?: RequestOption): Promise<(Response$setIssueTypeProperty$Status$200 | Response$setIssueTypeProperty$Status$201)["application/json"]>;
    /**
     * Delete issue type property
     * Deletes the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteIssueTypeProperty
     * Request URI: /rest/api/3/issuetype/{issueTypeId}/properties/{propertyKey}
     */
    deleteIssueTypeProperty(params: Params$deleteIssueTypeProperty, option?: RequestOption): Promise<void>;
    /**
     * Get all issue type schemes
     * Returns a [paginated](#pagination) list of issue type schemes.
     *
     * Only issue type schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllIssueTypeSchemes
     * Request URI: /rest/api/3/issuetypescheme
     */
    getAllIssueTypeSchemes(params: Params$getAllIssueTypeSchemes, option?: RequestOption): Promise<Response$getAllIssueTypeSchemes$Status$200["application/json"]>;
    /**
     * Create issue type scheme
     * Creates an issue type scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createIssueTypeScheme
     * Request URI: /rest/api/3/issuetypescheme
     */
    createIssueTypeScheme(params: Params$createIssueTypeScheme, option?: RequestOption): Promise<Response$createIssueTypeScheme$Status$201["application/json"]>;
    /**
     * Get issue type scheme items
     * Returns a [paginated](#pagination) list of issue type scheme items.
     *
     * Only issue type scheme items used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypeSchemesMapping
     * Request URI: /rest/api/3/issuetypescheme/mapping
     */
    getIssueTypeSchemesMapping(params: Params$getIssueTypeSchemesMapping, option?: RequestOption): Promise<Response$getIssueTypeSchemesMapping$Status$200["application/json"]>;
    /**
     * Get issue type schemes for projects
     * Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.
     *
     * Only issue type schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypeSchemeForProjects
     * Request URI: /rest/api/3/issuetypescheme/project
     */
    getIssueTypeSchemeForProjects(params: Params$getIssueTypeSchemeForProjects, option?: RequestOption): Promise<Response$getIssueTypeSchemeForProjects$Status$200["application/json"]>;
    /**
     * Assign issue type scheme to project
     * Assigns an issue type scheme to a project.
     *
     * If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.
     *
     * Issue type schemes can only be assigned to classic projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: assignIssueTypeSchemeToProject
     * Request URI: /rest/api/3/issuetypescheme/project
     */
    assignIssueTypeSchemeToProject(params: Params$assignIssueTypeSchemeToProject, option?: RequestOption): Promise<Response$assignIssueTypeSchemeToProject$Status$204["application/json"]>;
    /**
     * Update issue type scheme
     * Updates an issue type scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateIssueTypeScheme
     * Request URI: /rest/api/3/issuetypescheme/{issueTypeSchemeId}
     */
    updateIssueTypeScheme(params: Params$updateIssueTypeScheme, option?: RequestOption): Promise<Response$updateIssueTypeScheme$Status$204["application/json"]>;
    /**
     * Delete issue type scheme
     * Deletes an issue type scheme.
     *
     * Only issue type schemes used in classic projects can be deleted.
     *
     * Any projects assigned to the scheme are reassigned to the default issue type scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteIssueTypeScheme
     * Request URI: /rest/api/3/issuetypescheme/{issueTypeSchemeId}
     */
    deleteIssueTypeScheme(params: Params$deleteIssueTypeScheme, option?: RequestOption): Promise<Response$deleteIssueTypeScheme$Status$204["application/json"]>;
    /**
     * Add issue types to issue type scheme
     * Adds issue types to an issue type scheme.
     *
     * The added issue types are appended to the issue types list.
     *
     * If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addIssueTypesToIssueTypeScheme
     * Request URI: /rest/api/3/issuetypescheme/{issueTypeSchemeId}/issuetype
     */
    addIssueTypesToIssueTypeScheme(params: Params$addIssueTypesToIssueTypeScheme, option?: RequestOption): Promise<Response$addIssueTypesToIssueTypeScheme$Status$204["application/json"]>;
    /**
     * Change order of issue types
     * Changes the order of issue types in an issue type scheme.
     *
     * The request body parameters must meet the following requirements:
     *
     *  *  all of the issue types must belong to the issue type scheme.
     *  *  either `after` or `position` must be provided.
     *  *  the issue type in `after` must not be in the issue type list.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: reorderIssueTypesInIssueTypeScheme
     * Request URI: /rest/api/3/issuetypescheme/{issueTypeSchemeId}/issuetype/move
     */
    reorderIssueTypesInIssueTypeScheme(params: Params$reorderIssueTypesInIssueTypeScheme, option?: RequestOption): Promise<Response$reorderIssueTypesInIssueTypeScheme$Status$204["application/json"]>;
    /**
     * Remove issue type from issue type scheme
     * Removes an issue type from an issue type scheme.
     *
     * This operation cannot remove:
     *
     *  *  any issue type used by issues.
     *  *  any issue types from the default issue type scheme.
     *  *  the last standard issue type from an issue type scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeIssueTypeFromIssueTypeScheme
     * Request URI: /rest/api/3/issuetypescheme/{issueTypeSchemeId}/issuetype/{issueTypeId}
     */
    removeIssueTypeFromIssueTypeScheme(params: Params$removeIssueTypeFromIssueTypeScheme, option?: RequestOption): Promise<Response$removeIssueTypeFromIssueTypeScheme$Status$204["application/json"]>;
    /**
     * Get issue type screen schemes
     * Returns a [paginated](#pagination) list of issue type screen schemes.
     *
     * Only issue type screen schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypeScreenSchemes
     * Request URI: /rest/api/3/issuetypescreenscheme
     */
    getIssueTypeScreenSchemes(params: Params$getIssueTypeScreenSchemes, option?: RequestOption): Promise<Response$getIssueTypeScreenSchemes$Status$200["application/json"]>;
    /**
     * Create issue type screen scheme
     * Creates an issue type screen scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createIssueTypeScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme
     */
    createIssueTypeScreenScheme(params: Params$createIssueTypeScreenScheme, option?: RequestOption): Promise<Response$createIssueTypeScreenScheme$Status$201["application/json"]>;
    /**
     * Get issue type screen scheme items
     * Returns a [paginated](#pagination) list of issue type screen scheme items.
     *
     * Only issue type screen schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypeScreenSchemeMappings
     * Request URI: /rest/api/3/issuetypescreenscheme/mapping
     */
    getIssueTypeScreenSchemeMappings(params: Params$getIssueTypeScreenSchemeMappings, option?: RequestOption): Promise<Response$getIssueTypeScreenSchemeMappings$Status$200["application/json"]>;
    /**
     * Get issue type screen schemes for projects
     * Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.
     *
     * Only issue type screen schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueTypeScreenSchemeProjectAssociations
     * Request URI: /rest/api/3/issuetypescreenscheme/project
     */
    getIssueTypeScreenSchemeProjectAssociations(params: Params$getIssueTypeScreenSchemeProjectAssociations, option?: RequestOption): Promise<Response$getIssueTypeScreenSchemeProjectAssociations$Status$200["application/json"]>;
    /**
     * Assign issue type screen scheme to project
     * Assigns an issue type screen scheme to a project.
     *
     * Issue type screen schemes can only be assigned to classic projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: assignIssueTypeScreenSchemeToProject
     * Request URI: /rest/api/3/issuetypescreenscheme/project
     */
    assignIssueTypeScreenSchemeToProject(params: Params$assignIssueTypeScreenSchemeToProject, option?: RequestOption): Promise<Response$assignIssueTypeScreenSchemeToProject$Status$204["application/json"]>;
    /**
     * Update issue type screen scheme
     * Updates an issue type screen scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateIssueTypeScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme/{issueTypeScreenSchemeId}
     */
    updateIssueTypeScreenScheme(params: Params$updateIssueTypeScreenScheme, option?: RequestOption): Promise<Response$updateIssueTypeScreenScheme$Status$204["application/json"]>;
    /**
     * Delete issue type screen scheme
     * Deletes an issue type screen scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteIssueTypeScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme/{issueTypeScreenSchemeId}
     */
    deleteIssueTypeScreenScheme(params: Params$deleteIssueTypeScreenScheme, option?: RequestOption): Promise<Response$deleteIssueTypeScreenScheme$Status$204["application/json"]>;
    /**
     * Append mappings to issue type screen scheme
     * Appends issue type to screen scheme mappings to an issue type screen scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: appendMappingsForIssueTypeScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme/{issueTypeScreenSchemeId}/mapping
     */
    appendMappingsForIssueTypeScreenScheme(params: Params$appendMappingsForIssueTypeScreenScheme, option?: RequestOption): Promise<Response$appendMappingsForIssueTypeScreenScheme$Status$204["application/json"]>;
    /**
     * Update issue type screen scheme default screen scheme
     * Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateDefaultScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme/{issueTypeScreenSchemeId}/mapping/default
     */
    updateDefaultScreenScheme(params: Params$updateDefaultScreenScheme, option?: RequestOption): Promise<Response$updateDefaultScreenScheme$Status$204["application/json"]>;
    /**
     * Remove mappings from issue type screen scheme
     * Removes issue type to screen scheme mappings from an issue type screen scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeMappingsFromIssueTypeScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme/{issueTypeScreenSchemeId}/mapping/remove
     */
    removeMappingsFromIssueTypeScreenScheme(params: Params$removeMappingsFromIssueTypeScreenScheme, option?: RequestOption): Promise<Response$removeMappingsFromIssueTypeScreenScheme$Status$204["application/json"]>;
    /**
     * Get issue type screen scheme projects
     * Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.
     *
     * Only company-managed projects associated with an issue type screen scheme are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getProjectsForIssueTypeScreenScheme
     * Request URI: /rest/api/3/issuetypescreenscheme/{issueTypeScreenSchemeId}/project
     */
    getProjectsForIssueTypeScreenScheme(params: Params$getProjectsForIssueTypeScreenScheme, option?: RequestOption): Promise<Response$getProjectsForIssueTypeScreenScheme$Status$200["application/json"]>;
    /**
     * Get field reference data (GET)
     * Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.
     *
     * To filter visible field details by project or collapse non-unique fields by field type then [Get field reference data (POST)](#api-rest-api-3-jql-autocompletedata-post) can be used.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAutoComplete
     * Request URI: /rest/api/3/jql/autocompletedata
     */
    getAutoComplete(option?: RequestOption): Promise<Response$getAutoComplete$Status$200["application/json"]>;
    /**
     * Get field reference data (POST)
     * Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.
     *
     * This operation can filter the custom fields returned by project. Invalid project IDs in `projectIds` are ignored. System fields are always returned.
     *
     * It can also return the collapsed field for custom fields. Collapsed fields enable searches to be performed across all fields with the same name and of the same field type. For example, the collapsed field `Component - Component[Dropdown]` enables dropdown fields `Component - cf[10061]` and `Component - cf[10062]` to be searched simultaneously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAutoCompletePost
     * Request URI: /rest/api/3/jql/autocompletedata
     */
    getAutoCompletePost(params: Params$getAutoCompletePost, option?: RequestOption): Promise<Response$getAutoCompletePost$Status$200["application/json"]>;
    /**
     * Get field auto complete suggestions
     * Returns the JQL search auto complete suggestions for a field.
     *
     * Suggestions can be obtained by providing:
     *
     *  *  `fieldName` to get a list of all values for the field.
     *  *  `fieldName` and `fieldValue` to get a list of values containing the text in `fieldValue`.
     *  *  `fieldName` and `predicateName` to get a list of all predicate values for the field.
     *  *  `fieldName`, `predicateName`, and `predicateValue` to get a list of predicate values containing the text in `predicateValue`.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getFieldAutoCompleteForQueryString
     * Request URI: /rest/api/3/jql/autocompletedata/suggestions
     */
    getFieldAutoCompleteForQueryString(params: Params$getFieldAutoCompleteForQueryString, option?: RequestOption): Promise<Response$getFieldAutoCompleteForQueryString$Status$200["application/json"]>;
    /**
     * Check issues against JQL
     * Checks whether one or more issues would be returned by one or more JQL queries.
     *
     * **[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: matchIssues
     * Request URI: /rest/api/3/jql/match
     */
    matchIssues(params: Params$matchIssues, option?: RequestOption): Promise<Response$matchIssues$Status$200["application/json"]>;
    /**
     * Parse JQL query
     * Parses and validates JQL queries.
     *
     * Validation is performed in context of the current user.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: parseJqlQueries
     * Request URI: /rest/api/3/jql/parse
     */
    parseJqlQueries(params: Params$parseJqlQueries, option?: RequestOption): Promise<Response$parseJqlQueries$Status$200["application/json"]>;
    /**
     * Convert user identifiers to account IDs in JQL queries
     * Converts one or more JQL queries with user identifiers (username or user key) to equivalent JQL queries with account IDs.
     *
     * You may wish to use this operation if your system stores JQL queries and you want to make them GDPR-compliant. For more information about GDPR-related changes, see the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/).
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: migrateQueries
     * Request URI: /rest/api/3/jql/pdcleaner
     */
    migrateQueries(params: Params$migrateQueries, option?: RequestOption): Promise<Response$migrateQueries$Status$200["application/json"]>;
    /**
     * Get all labels
     * Returns a [paginated](#pagination) list of labels.
     * operationId: getAllLabels
     * Request URI: /rest/api/3/label
     */
    getAllLabels(params: Params$getAllLabels, option?: RequestOption): Promise<Response$getAllLabels$Status$200["application/json"]>;
    /**
     * Get my permissions
     * Returns a list of permissions indicating which permissions the user has. Details of the user's permissions can be obtained in a global, project, or issue context.
     *
     * The user is reported as having a project permission:
     *
     *  *  in the global context, if the user has the project permission in any project.
     *  *  for a project, where the project permission is determined using issue data, if the user meets the permission's criteria for any issue in the project. Otherwise, if the user has the project permission in the project.
     *  *  for an issue, where a project permission is determined using issue data, if the user has the permission in the issue. Otherwise, if the user has the project permission in the project containing the issue.
     *
     * This means that users may be shown as having an issue permission (such as EDIT\_ISSUES) in the global context or a project context but may not have the permission for any or all issues. For example, if Reporters have the EDIT\_ISSUES permission a user would be shown as having this permission in the global context or the context of a project, because any user can be a reporter. However, if they are not the user who reported the issue queried they would not have EDIT\_ISSUES permission for that issue.
     *
     * Global permissions are unaffected by context.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getMyPermissions
     * Request URI: /rest/api/3/mypermissions
     */
    getMyPermissions(params: Params$getMyPermissions, option?: RequestOption): Promise<Response$getMyPermissions$Status$200["application/json"]>;
    /**
     * Get preference
     * Returns the value of a preference of the current user.
     *
     * Note that these keys are deprecated:
     *
     *  *  *jira.user.locale* The locale of the user. By default this is not set and the user takes the locale of the instance.
     *  *  *jira.user.timezone* The time zone of the user. By default this is not set and the user takes the timezone of the instance.
     *
     * Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getPreference
     * Request URI: /rest/api/3/mypreferences
     */
    getPreference(params: Params$getPreference, option?: RequestOption): Promise<Response$getPreference$Status$200["application/json"]>;
    /**
     * Set preference
     * Creates a preference for the user or updates a preference's value by sending a plain text string. For example, `false`. An arbitrary preference can be created with the value containing up to 255 characters. In addition, the following keys define system preferences that can be set or created:
     *
     *  *  *user.notifications.mimetype* The mime type used in notifications sent to the user. Defaults to `html`.
     *  *  *user.notify.own.changes* Whether the user gets notified of their own changes. Defaults to `false`.
     *  *  *user.default.share.private* Whether new [ filters](https://confluence.atlassian.com/x/eQiiLQ) are set to private. Defaults to `true`.
     *  *  *user.keyboard.shortcuts.disabled* Whether keyboard shortcuts are disabled. Defaults to `false`.
     *  *  *user.autowatch.disabled* Whether the user automatically watches issues they create or add a comment to. By default, not set: the user takes the instance autowatch setting.
     *
     * Note that these keys are deprecated:
     *
     *  *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
     *  *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
     *
     * Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: setPreference
     * Request URI: /rest/api/3/mypreferences
     */
    setPreference<RequestContentType extends RequestContentType$setPreference>(params: Params$setPreference<RequestContentType>, option?: RequestOption): Promise<Response$setPreference$Status$204["application/json"]>;
    /**
     * Delete preference
     * Deletes a preference of the user, which restores the default value of system defined settings.
     *
     * Note that these keys are deprecated:
     *
     *  *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
     *  *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
     *
     * Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: removePreference
     * Request URI: /rest/api/3/mypreferences
     */
    removePreference(params: Params$removePreference, option?: RequestOption): Promise<void>;
    /**
     * Get locale
     * Returns the locale for the user.
     *
     * If the user has no language preference set (which is the default setting) or this resource is accessed anonymous, the browser locale detected by Jira is returned. Jira detects the browser locale using the *Accept-Language* header in the request. However, if this doesn't match a locale available Jira, the site default locale is returned.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getLocale
     * Request URI: /rest/api/3/mypreferences/locale
     */
    getLocale(option?: RequestOption): Promise<Response$getLocale$Status$200["application/json"]>;
    /**
     * @deprecated
     * Set locale
     * Deprecated, use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API instead.
     *
     * Sets the locale of the user. The locale must be one supported by the instance of Jira.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: setLocale
     * Request URI: /rest/api/3/mypreferences/locale
     */
    setLocale(params: Params$setLocale, option?: RequestOption): Promise<Response$setLocale$Status$204["application/json"]>;
    /**
     * @deprecated
     * Delete locale
     * Deprecated, use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API instead.
     *
     * Deletes the locale of the user, which restores the default setting.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: deleteLocale
     * Request URI: /rest/api/3/mypreferences/locale
     */
    deleteLocale(option?: RequestOption): Promise<Response$deleteLocale$Status$204["application/json"]>;
    /**
     * Get current user
     * Returns details for the current user.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getCurrentUser
     * Request URI: /rest/api/3/myself
     */
    getCurrentUser(params: Params$getCurrentUser, option?: RequestOption): Promise<Response$getCurrentUser$Status$200["application/json"]>;
    /**
     * Get notification schemes paginated
     * Returns a [paginated](#pagination) list of [notification schemes](https://confluence.atlassian.com/x/8YdKLg) ordered by display name.
     *
     * ### About notification schemes ###
     *
     * A notification scheme is a list of events and recipients who will receive notifications for those events. The list is contained within the `notificationSchemeEvents` object and contains pairs of `events` and `notifications`:
     *
     *  *  `event` Identifies the type of event. The events can be [Jira system events](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-eventsEvents) or [custom events](https://confluence.atlassian.com/x/AIlKLg).
     *  *  `notifications` Identifies the [recipients](https://confluence.atlassian.com/x/8YdKLg#Creatinganotificationscheme-recipientsRecipients) of notifications for each event. Recipients can be any of the following types:
     *
     *      *  `CurrentAssignee`
     *      *  `Reporter`
     *      *  `CurrentUser`
     *      *  `ProjectLead`
     *      *  `ComponentLead`
     *      *  `User` (the `parameter` is the user key)
     *      *  `Group` (the `parameter` is the group name)
     *      *  `ProjectRole` (the `parameter` is the project role ID)
     *      *  `EmailAddress`
     *      *  `AllWatchers`
     *      *  `UserCustomField` (the `parameter` is the ID of the custom field)
     *      *  `GroupCustomField`(the `parameter` is the ID of the custom field)
     *
     * *Note that you should allow for events without recipients to appear in responses.*
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however the user must have permission to administer at least one project associated with a notification scheme for it to be returned.
     * operationId: getNotificationSchemes
     * Request URI: /rest/api/3/notificationscheme
     */
    getNotificationSchemes(params: Params$getNotificationSchemes, option?: RequestOption): Promise<Response$getNotificationSchemes$Status$200["application/json"]>;
    /**
     * Get notification scheme
     * Returns a [notification scheme](https://confluence.atlassian.com/x/8YdKLg), including the list of events and the recipients who will receive notifications for those events.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however the user must have permission to administer at least one project associated with the notification scheme.
     * operationId: getNotificationScheme
     * Request URI: /rest/api/3/notificationscheme/{id}
     */
    getNotificationScheme(params: Params$getNotificationScheme, option?: RequestOption): Promise<Response$getNotificationScheme$Status$200["application/json"]>;
    /**
     * Get all permissions
     * Returns all permissions, including:
     *
     *  *  global permissions.
     *  *  project permissions.
     *  *  global permissions added by plugins.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllPermissions
     * Request URI: /rest/api/3/permissions
     */
    getAllPermissions(option?: RequestOption): Promise<Response$getAllPermissions$Status$200["application/json"]>;
    /**
     * Get bulk permissions
     * Returns:
     *
     *  *  for a list of global permissions, the global permissions granted to a user.
     *  *  for a list of project permissions and lists of projects and issues, for each project permission a list of the projects and issues a user can access or manipulate.
     *
     * If no account ID is provided, the operation returns details for the logged in user.
     *
     * Note that:
     *
     *  *  Invalid project and issue IDs are ignored.
     *  *  A maximum of 1000 projects and 1000 issues can be checked.
     *  *  Null values in `globalPermissions`, `projectPermissions`, `projectPermissions.projects`, and `projectPermissions.issues` are ignored.
     *  *  Empty strings in `projectPermissions.permissions` are ignored.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to check the permissions for other users, otherwise none. However, Connect apps can make a call from the app server to the product to obtain permission details for any user, without admin permission. This Connect app ability doesn't apply to calls made using AP.request() in a browser.
     * operationId: getBulkPermissions
     * Request URI: /rest/api/3/permissions/check
     */
    getBulkPermissions(params: Params$getBulkPermissions, option?: RequestOption): Promise<Response$getBulkPermissions$Status$200["application/json"]>;
    /**
     * Get permitted projects
     * Returns all the projects where the user is granted a list of project permissions.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getPermittedProjects
     * Request URI: /rest/api/3/permissions/project
     */
    getPermittedProjects(params: Params$getPermittedProjects, option?: RequestOption): Promise<Response$getPermittedProjects$Status$200["application/json"]>;
    /**
     * Get all permission schemes
     * Returns all permission schemes.
     *
     * ### About permission schemes and grants ###
     *
     * A permission scheme is a collection of permission grants. A permission grant consists of a `holder` and a `permission`.
     *
     * #### Holder object ####
     *
     * The `holder` object contains information about the user or group being granted the permission. For example, the *Administer projects* permission is granted to a group named *Teams in space administrators*. In this case, the type is `"type": "group"`, and the parameter is the group name, `"parameter": "Teams in space administrators"`. The `holder` object is defined by the following properties:
     *
     *  *  `type` Identifies the user or group (see the list of types below).
     *  *  `parameter` The value of this property depends on the `type`. For example, if the `type` is a group, then you need to specify the group name.
     *
     * The following `types` are available. The expected values for the `parameter` are given in parenthesis (some `types` may not have a `parameter`):
     *
     *  *  `anyone` Grant for anonymous users.
     *  *  `applicationRole` Grant for users with access to the specified application (application name). See [Update product access settings](https://confluence.atlassian.com/x/3YxjL) for more information.
     *  *  `assignee` Grant for the user currently assigned to an issue.
     *  *  `group` Grant for the specified group (group name).
     *  *  `groupCustomField` Grant for a user in the group selected in the specified custom field (custom field ID).
     *  *  `projectLead` Grant for a project lead.
     *  *  `projectRole` Grant for the specified project role (project role ID).
     *  *  `reporter` Grant for the user who reported the issue.
     *  *  `sd.customer.portal.only` Jira Service Desk only. Grants customers permission to access the customer portal but not Jira. See [Customizing Jira Service Desk permissions](https://confluence.atlassian.com/x/24dKLg) for more information.
     *  *  `user` Grant for the specified user (user ID - historically this was the userkey but that is deprecated and the account ID should be used).
     *  *  `userCustomField` Grant for a user selected in the specified custom field (custom field ID).
     *
     * #### Built-in permissions ####
     *
     * The [built-in Jira permissions](https://confluence.atlassian.com/x/yodKLg) are listed below. Apps can also define custom permissions. See the [project permission](https://developer.atlassian.com/cloud/jira/platform/modules/project-permission/) and [global permission](https://developer.atlassian.com/cloud/jira/platform/modules/global-permission/) module documentation for more information.
     *
     * **Project permissions**
     *
     *  *  `ADMINISTER_PROJECTS`
     *  *  `BROWSE_PROJECTS`
     *  *  `MANAGE_SPRINTS_PERMISSION` (Jira Software only)
     *  *  `SERVICEDESK_AGENT` (Jira Service Desk only)
     *  *  `VIEW_DEV_TOOLS` (Jira Software only)
     *  *  `VIEW_READONLY_WORKFLOW`
     *
     * **Issue permissions**
     *
     *  *  `ASSIGNABLE_USER`
     *  *  `ASSIGN_ISSUES`
     *  *  `CLOSE_ISSUES`
     *  *  `CREATE_ISSUES`
     *  *  `DELETE_ISSUES`
     *  *  `EDIT_ISSUES`
     *  *  `LINK_ISSUES`
     *  *  `MODIFY_REPORTER`
     *  *  `MOVE_ISSUES`
     *  *  `RESOLVE_ISSUES`
     *  *  `SCHEDULE_ISSUES`
     *  *  `SET_ISSUE_SECURITY`
     *  *  `TRANSITION_ISSUES`
     *
     * **Voters and watchers permissions**
     *
     *  *  `MANAGE_WATCHERS`
     *  *  `VIEW_VOTERS_AND_WATCHERS`
     *
     * **Comments permissions**
     *
     *  *  `ADD_COMMENTS`
     *  *  `DELETE_ALL_COMMENTS`
     *  *  `DELETE_OWN_COMMENTS`
     *  *  `EDIT_ALL_COMMENTS`
     *  *  `EDIT_OWN_COMMENTS`
     *
     * **Attachments permissions**
     *
     *  *  `CREATE_ATTACHMENTS`
     *  *  `DELETE_ALL_ATTACHMENTS`
     *  *  `DELETE_OWN_ATTACHMENTS`
     *
     * **Time tracking permissions**
     *
     *  *  `DELETE_ALL_WORKLOGS`
     *  *  `DELETE_OWN_WORKLOGS`
     *  *  `EDIT_ALL_WORKLOGS`
     *  *  `EDIT_OWN_WORKLOGS`
     *  *  `WORK_ON_ISSUES`
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getAllPermissionSchemes
     * Request URI: /rest/api/3/permissionscheme
     */
    getAllPermissionSchemes(params: Params$getAllPermissionSchemes, option?: RequestOption): Promise<Response$getAllPermissionSchemes$Status$200["application/json"]>;
    /**
     * Create permission scheme
     * Creates a new permission scheme. You can create a permission scheme with or without defining a set of permission grants.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createPermissionScheme
     * Request URI: /rest/api/3/permissionscheme
     */
    createPermissionScheme(params: Params$createPermissionScheme, option?: RequestOption): Promise<Response$createPermissionScheme$Status$201["application/json"]>;
    /**
     * Get permission scheme
     * Returns a permission scheme.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getPermissionScheme
     * Request URI: /rest/api/3/permissionscheme/{schemeId}
     */
    getPermissionScheme(params: Params$getPermissionScheme, option?: RequestOption): Promise<Response$getPermissionScheme$Status$200["application/json"]>;
    /**
     * Update permission scheme
     * Updates a permission scheme. Below are some important things to note when using this resource:
     *
     *  *  If a permissions list is present in the request, then it is set in the permission scheme, overwriting *all existing* grants.
     *  *  If you want to update only the name and description, then do not send a permissions list in the request.
     *  *  Sending an empty list will remove all permission grants from the permission scheme.
     *
     * If you want to add or delete a permission grant instead of updating the whole list, see [Create permission grant](#api-rest-api-3-permissionscheme-schemeId-permission-post) or [Delete permission scheme entity](#api-rest-api-3-permissionscheme-schemeId-permission-permissionId-delete).
     *
     * See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updatePermissionScheme
     * Request URI: /rest/api/3/permissionscheme/{schemeId}
     */
    updatePermissionScheme(params: Params$updatePermissionScheme, option?: RequestOption): Promise<Response$updatePermissionScheme$Status$200["application/json"]>;
    /**
     * Delete permission scheme
     * Deletes a permission scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deletePermissionScheme
     * Request URI: /rest/api/3/permissionscheme/{schemeId}
     */
    deletePermissionScheme(params: Params$deletePermissionScheme, option?: RequestOption): Promise<void>;
    /**
     * Get permission scheme grants
     * Returns all permission grants for a permission scheme.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getPermissionSchemeGrants
     * Request URI: /rest/api/3/permissionscheme/{schemeId}/permission
     */
    getPermissionSchemeGrants(params: Params$getPermissionSchemeGrants, option?: RequestOption): Promise<Response$getPermissionSchemeGrants$Status$200["application/json"]>;
    /**
     * Create permission grant
     * Creates a permission grant in a permission scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createPermissionGrant
     * Request URI: /rest/api/3/permissionscheme/{schemeId}/permission
     */
    createPermissionGrant(params: Params$createPermissionGrant, option?: RequestOption): Promise<Response$createPermissionGrant$Status$201["application/json"]>;
    /**
     * Get permission scheme grant
     * Returns a permission grant.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getPermissionSchemeGrant
     * Request URI: /rest/api/3/permissionscheme/{schemeId}/permission/{permissionId}
     */
    getPermissionSchemeGrant(params: Params$getPermissionSchemeGrant, option?: RequestOption): Promise<Response$getPermissionSchemeGrant$Status$200["application/json"]>;
    /**
     * Delete permission scheme grant
     * Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deletePermissionSchemeEntity
     * Request URI: /rest/api/3/permissionscheme/{schemeId}/permission/{permissionId}
     */
    deletePermissionSchemeEntity(params: Params$deletePermissionSchemeEntity, option?: RequestOption): Promise<void>;
    /**
     * Get priorities
     * Returns the list of all issue priorities.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getPriorities
     * Request URI: /rest/api/3/priority
     */
    getPriorities(option?: RequestOption): Promise<Response$getPriorities$Status$200["application/json"]>;
    /**
     * Get priority
     * Returns an issue priority.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getPriority
     * Request URI: /rest/api/3/priority/{id}
     */
    getPriority(params: Params$getPriority, option?: RequestOption): Promise<Response$getPriority$Status$200["application/json"]>;
    /**
     * @deprecated
     * Get all projects
     * Returns all projects visible to the user. Deprecated, use [ Get projects paginated](#api-rest-api-3-project-search-get) that supports search and pagination.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Projects are returned only where the user has *Browse Projects* or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getAllProjects
     * Request URI: /rest/api/3/project
     */
    getAllProjects(params: Params$getAllProjects, option?: RequestOption): Promise<Response$getAllProjects$Status$200["application/json"]>;
    /**
     * Create project
     * Creates a project based on a project type template, as shown in the following table:
     *
     * | Project Type Key | Project Template Key |
     * |--|--|
     * | `business` | `com.atlassian.jira-core-project-templates:jira-core-simplified-content-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval`, `com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking`, `com.atlassian.jira-core-project-templates:jira-core-simplified-process-control`, `com.atlassian.jira-core-project-templates:jira-core-simplified-procurement`, `com.atlassian.jira-core-project-templates:jira-core-simplified-project-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment`, `com.atlassian.jira-core-project-templates:jira-core-simplified-task-tracking` |
     * | `service_desk` | `com.atlassian.servicedesk:simplified-it-service-management`, `com.atlassian.servicedesk:simplified-general-service-desk`, `com.atlassian.servicedesk:simplified-internal-service-desk`, `com.atlassian.servicedesk:simplified-external-service-desk`, `com.atlassian.servicedesk:simplified-hr-service-desk`, `com.atlassian.servicedesk:simplified-facilities-service-desk`, `com.atlassian.servicedesk:simplified-legal-service-desk` |
     * | `software` | `com.pyxis.greenhopper.jira:gh-simplified-agility-kanban`, `com.pyxis.greenhopper.jira:gh-simplified-agility-scrum`, `com.pyxis.greenhopper.jira:gh-simplified-basic`, `com.pyxis.greenhopper.jira:gh-simplified-kanban-classic`, `com.pyxis.greenhopper.jira:gh-simplified-scrum-classic` |
     * The project types are available according to the installed Jira features as follows:
     *
     *  *  Jira Core, the default, enables `business` projects.
     *  *  Jira Service Management enables `service_desk` projects.
     *  *  Jira Software enables `software` projects.
     *
     * To determine which features are installed, go to **Jira settings** > **Apps** > **Manage apps** and review the System Apps list. To add Jira Software or Jira Service Management into a JIRA instance, use **Jira settings** > **Apps** > **Finding new apps**. For more information, see [ Managing add-ons](https://confluence.atlassian.com/x/S31NLg).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createProject
     * Request URI: /rest/api/3/project
     */
    createProject(params: Params$createProject, option?: RequestOption): Promise<Response$createProject$Status$201["application/json"]>;
    /**
     * Get recent projects
     * Returns a list of up to 20 projects recently viewed by the user that are still visible to the user.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Projects are returned only where the user has one of:
     *
     *  *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getRecent
     * Request URI: /rest/api/3/project/recent
     */
    getRecent(params: Params$getRecent, option?: RequestOption): Promise<Response$getRecent$Status$200["application/json"]>;
    /**
     * Get projects paginated
     * Returns a [paginated](#pagination) list of projects visible to the user.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Projects are returned only where the user has one of:
     *
     *  *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: searchProjects
     * Request URI: /rest/api/3/project/search
     */
    searchProjects(params: Params$searchProjects, option?: RequestOption): Promise<Response$searchProjects$Status$200["application/json"]>;
    /**
     * Get all project types
     * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAllProjectTypes
     * Request URI: /rest/api/3/project/type
     */
    getAllProjectTypes(option?: RequestOption): Promise<Response$getAllProjectTypes$Status$200["application/json"]>;
    /**
     * Get licensed project types
     * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
     * operationId: getAllAccessibleProjectTypes
     * Request URI: /rest/api/3/project/type/accessible
     */
    getAllAccessibleProjectTypes(option?: RequestOption): Promise<Response$getAllAccessibleProjectTypes$Status$200["application/json"]>;
    /**
     * Get project type by key
     * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getProjectTypeByKey
     * Request URI: /rest/api/3/project/type/{projectTypeKey}
     */
    getProjectTypeByKey(params: Params$getProjectTypeByKey, option?: RequestOption): Promise<Response$getProjectTypeByKey$Status$200["application/json"]>;
    /**
     * Get accessible project type by key
     * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getAccessibleProjectTypeByKey
     * Request URI: /rest/api/3/project/type/{projectTypeKey}/accessible
     */
    getAccessibleProjectTypeByKey(params: Params$getAccessibleProjectTypeByKey, option?: RequestOption): Promise<Response$getAccessibleProjectTypeByKey$Status$200["application/json"]>;
    /**
     * Get project
     * Returns the [project details](https://confluence.atlassian.com/x/ahLpNw) for a project.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProject
     * Request URI: /rest/api/3/project/{projectIdOrKey}
     */
    getProject(params: Params$getProject, option?: RequestOption): Promise<Response$getProject$Status$200["application/json"]>;
    /**
     * Update project
     * Updates the [project details](https://confluence.atlassian.com/x/ahLpNw) of a project.
     *
     * All parameters are optional in the body of the request.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateProject
     * Request URI: /rest/api/3/project/{projectIdOrKey}
     */
    updateProject(params: Params$updateProject, option?: RequestOption): Promise<Response$updateProject$Status$200["application/json"]>;
    /**
     * Delete project
     * Deletes a project.
     *
     * You can't delete a project if it's archived. To delete an archived project, restore the project and then delete it. To restore a project, use the Jira UI.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteProject
     * Request URI: /rest/api/3/project/{projectIdOrKey}
     */
    deleteProject(params: Params$deleteProject, option?: RequestOption): Promise<void>;
    /**
     * Archive project
     * Archives a project. You can't delete a project if it's archived. To delete an archived project, restore the project and then delete it. To restore a project, use the Jira UI.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: archiveProject
     * Request URI: /rest/api/3/project/{projectIdOrKey}/archive
     */
    archiveProject(params: Params$archiveProject, option?: RequestOption): Promise<Response$archiveProject$Status$204["application/json"]>;
    /**
     * Set project avatar
     * Sets the avatar displayed for a project.
     *
     * Use [Load project avatar](#api-rest-api-3-project-projectIdOrKey-avatar2-post) to store avatars against the project, before using this operation to set the displayed avatar.
     *
     * **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: updateProjectAvatar
     * Request URI: /rest/api/3/project/{projectIdOrKey}/avatar
     */
    updateProjectAvatar(params: Params$updateProjectAvatar, option?: RequestOption): Promise<Response$updateProjectAvatar$Status$204["application/json"]>;
    /**
     * Delete project avatar
     * Deletes a custom avatar from a project. Note that system avatars cannot be deleted.
     *
     * **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: deleteProjectAvatar
     * Request URI: /rest/api/3/project/{projectIdOrKey}/avatar/{id}
     */
    deleteProjectAvatar(params: Params$deleteProjectAvatar, option?: RequestOption): Promise<void>;
    /**
     * Load project avatar
     * Loads an avatar for a project.
     *
     * Specify the avatar's local file location in the body of the request. Also, include the following headers:
     *
     *  *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
     *  *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
     *
     * For example:
     * `curl --request POST `
     *
     * `--user email@example.com:<api_token> `
     *
     * `--header 'X-Atlassian-Token: no-check' `
     *
     * `--header 'Content-Type: image/< image_type>' `
     *
     * `--data-binary "<@/path/to/file/with/your/avatar>" `
     *
     * `--url 'https://your-domain.atlassian.net/rest/api/3/project/{projectIdOrKey}/avatar2'`
     *
     * The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
     *
     * The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
     *
     * After creating the avatar use [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
     *
     * **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: createProjectAvatar
     * Request URI: /rest/api/3/project/{projectIdOrKey}/avatar2
     */
    createProjectAvatar(params: Params$createProjectAvatar, option?: RequestOption): Promise<Response$createProjectAvatar$Status$201["application/json"]>;
    /**
     * Get all project avatars
     * Returns all project avatars, grouped by system and custom avatars.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getAllProjectAvatars
     * Request URI: /rest/api/3/project/{projectIdOrKey}/avatars
     */
    getAllProjectAvatars(params: Params$getAllProjectAvatars, option?: RequestOption): Promise<Response$getAllProjectAvatars$Status$200["application/json"]>;
    /**
     * Get project components paginated
     * Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectComponentsPaginated
     * Request URI: /rest/api/3/project/{projectIdOrKey}/component
     */
    getProjectComponentsPaginated(params: Params$getProjectComponentsPaginated, option?: RequestOption): Promise<Response$getProjectComponentsPaginated$Status$200["application/json"]>;
    /**
     * Get project components
     * Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectComponents
     * Request URI: /rest/api/3/project/{projectIdOrKey}/components
     */
    getProjectComponents(params: Params$getProjectComponents, option?: RequestOption): Promise<Response$getProjectComponents$Status$200["application/json"]>;
    /**
     * Delete project asynchronously
     * Deletes a project asynchronously.
     *
     * This operation is:
     *
     *  *  transactional, that is, if part of the delete fails the project is not deleted.
     *  *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteProjectAsynchronously
     * Request URI: /rest/api/3/project/{projectIdOrKey}/delete
     */
    deleteProjectAsynchronously(params: Params$deleteProjectAsynchronously, option?: RequestOption): Promise<void>;
    /**
     * Get project features
     * Returns the list of features for a project.
     * operationId: getFeaturesForProject
     * Request URI: /rest/api/3/project/{projectIdOrKey}/features
     */
    getFeaturesForProject(params: Params$getFeaturesForProject, option?: RequestOption): Promise<Response$getFeaturesForProject$Status$200["application/json"]>;
    /**
     * Set project feature state
     * Sets the state of a project feature.
     * operationId: toggleFeatureForProject
     * Request URI: /rest/api/3/project/{projectIdOrKey}/features/{featureKey}
     */
    toggleFeatureForProject(params: Params$toggleFeatureForProject, option?: RequestOption): Promise<Response$toggleFeatureForProject$Status$200["application/json"]>;
    /**
     * Get project property keys
     * Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectPropertyKeys
     * Request URI: /rest/api/3/project/{projectIdOrKey}/properties
     */
    getProjectPropertyKeys(params: Params$getProjectPropertyKeys, option?: RequestOption): Promise<Response$getProjectPropertyKeys$Status$200["application/json"]>;
    /**
     * Get project property
     * Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
     * operationId: getProjectProperty
     * Request URI: /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey}
     */
    getProjectProperty(params: Params$getProjectProperty, option?: RequestOption): Promise<Response$getProjectProperty$Status$200["application/json"]>;
    /**
     * Set project property
     * Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
     * operationId: setProjectProperty
     * Request URI: /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey}
     */
    setProjectProperty(params: Params$setProjectProperty, option?: RequestOption): Promise<(Response$setProjectProperty$Status$200 | Response$setProjectProperty$Status$201)["application/json"]>;
    /**
     * Delete project property
     * Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
     * operationId: deleteProjectProperty
     * Request URI: /rest/api/3/project/{projectIdOrKey}/properties/{propertyKey}
     */
    deleteProjectProperty(params: Params$deleteProjectProperty, option?: RequestOption): Promise<void>;
    /**
     * Restore deleted project
     * Restores a project from the Jira recycle bin.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: restore
     * Request URI: /rest/api/3/project/{projectIdOrKey}/restore
     */
    restore(params: Params$restore, option?: RequestOption): Promise<Response$restore$Status$200["application/json"]>;
    /**
     * Get project roles for project
     * Returns a list of [project roles](https://confluence.atlassian.com/x/3odKLg) for the project returning the name and self URL for each role.
     *
     * Note that all project roles are shared with all projects in Jira Cloud. See [Get all project roles](#api-rest-api-3-role-get) for more information.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for any project on the site or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getProjectRoles
     * Request URI: /rest/api/3/project/{projectIdOrKey}/role
     */
    getProjectRoles(params: Params$getProjectRoles, option?: RequestOption): Promise<Response$getProjectRoles$Status$200["application/json"]>;
    /**
     * Get project role for project
     * Returns a project role's details and actors associated with the project. The list of actors is sorted by display name.
     *
     * To check whether a user belongs to a role based on their group memberships, use [Get user](#api-rest-api-3-user-get) with the `groups` expand parameter selected. Then check whether the user keys and groups match with the actors returned for the project.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getProjectRole
     * Request URI: /rest/api/3/project/{projectIdOrKey}/role/{id}
     */
    getProjectRole(params: Params$getProjectRole, option?: RequestOption): Promise<Response$getProjectRole$Status$200["application/json"]>;
    /**
     * Set actors for project role
     * Sets the actors for a project role for a project, replacing all existing actors.
     *
     * To add actors to the project without overwriting the existing list, use [Add actors to project role](#api-rest-api-3-project-projectIdOrKey-role-id-post).
     *
     * **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setActors
     * Request URI: /rest/api/3/project/{projectIdOrKey}/role/{id}
     */
    setActors(params: Params$setActors, option?: RequestOption): Promise<Response$setActors$Status$200["application/json"]>;
    /**
     * Add actors to project role
     * Adds actors to a project role for the project.
     *
     * To replace all actors for the project, use [Set actors for project role](#api-rest-api-3-project-projectIdOrKey-role-id-put).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addActorUsers
     * Request URI: /rest/api/3/project/{projectIdOrKey}/role/{id}
     */
    addActorUsers(params: Params$addActorUsers, option?: RequestOption): Promise<Response$addActorUsers$Status$200["application/json"]>;
    /**
     * Delete actors from project role
     * Deletes actors from a project role for the project.
     *
     * To remove default actors from the project role, use [Delete default actors from project role](#api-rest-api-3-role-id-actors-delete).
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteActor
     * Request URI: /rest/api/3/project/{projectIdOrKey}/role/{id}
     */
    deleteActor(params: Params$deleteActor, option?: RequestOption): Promise<void>;
    /**
     * Get project role details
     * Returns all [project roles](https://confluence.atlassian.com/x/3odKLg) and the details for each role. Note that the list of project roles is common to all projects.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectRoleDetails
     * Request URI: /rest/api/3/project/{projectIdOrKey}/roledetails
     */
    getProjectRoleDetails(params: Params$getProjectRoleDetails, option?: RequestOption): Promise<Response$getProjectRoleDetails$Status$200["application/json"]>;
    /**
     * Get all statuses for project
     * Returns the valid statuses for a project. The statuses are grouped by issue type, as each project has a set of valid issue types and each issue type has a set of valid statuses.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getAllStatuses
     * Request URI: /rest/api/3/project/{projectIdOrKey}/statuses
     */
    getAllStatuses(params: Params$getAllStatuses, option?: RequestOption): Promise<Response$getAllStatuses$Status$200["application/json"]>;
    /**
     * @deprecated
     * Update project type
     * Deprecated, this feature is no longer supported and no alternatives are available, see [Convert project to a different template or type](https://confluence.atlassian.com/x/yEKeOQ). Updates a [project type](https://confluence.atlassian.com/x/GwiiLQ). The project type can be updated for classic projects only, project type cannot be updated for next-gen projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateProjectType
     * Request URI: /rest/api/3/project/{projectIdOrKey}/type/{newProjectTypeKey}
     */
    updateProjectType(params: Params$updateProjectType, option?: RequestOption): Promise<Response$updateProjectType$Status$200["application/json"]>;
    /**
     * Get project versions paginated
     * Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectVersionsPaginated
     * Request URI: /rest/api/3/project/{projectIdOrKey}/version
     */
    getProjectVersionsPaginated(params: Params$getProjectVersionsPaginated, option?: RequestOption): Promise<Response$getProjectVersionsPaginated$Status$200["application/json"]>;
    /**
     * Get project versions
     * Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectVersions
     * Request URI: /rest/api/3/project/{projectIdOrKey}/versions
     */
    getProjectVersions(params: Params$getProjectVersions, option?: RequestOption): Promise<Response$getProjectVersions$Status$200["application/json"]>;
    /**
     * Get project's sender email
     * Returns the [project's sender email address](https://confluence.atlassian.com/x/dolKLg).
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getProjectEmail
     * Request URI: /rest/api/3/project/{projectId}/email
     */
    getProjectEmail(params: Params$getProjectEmail, option?: RequestOption): Promise<Response$getProjectEmail$Status$200["application/json"]>;
    /**
     * Set project's sender email
     * Sets the [project's sender email address](https://confluence.atlassian.com/x/dolKLg).
     *
     * If `emailAddress` is an empty string, the default email address is restored.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: updateProjectEmail
     * Request URI: /rest/api/3/project/{projectId}/email
     */
    updateProjectEmail(params: Params$updateProjectEmail, option?: RequestOption): Promise<Response$updateProjectEmail$Status$204["application/json"]>;
    /**
     * @deprecated
     * Get project issue type hierarchy
     * Get the issue type hierarchy for a next-gen project.
     *
     * The issue type hierarchy for a project consists of:
     *
     *  *  *Epic* at level 1 (optional).
     *  *  One or more issue types at level 0 such as *Story*, *Task*, or *Bug*. Where the issue type *Epic* is defined, these issue types are used to break down the content of an epic.
     *  *  *Subtask* at level -1 (optional). This issue type enables level 0 issue types to be broken down into components. Issues based on a level -1 issue type must have a parent issue.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
     * operationId: getHierarchy
     * Request URI: /rest/api/3/project/{projectId}/hierarchy
     */
    getHierarchy(params: Params$getHierarchy, option?: RequestOption): Promise<Response$getHierarchy$Status$200["application/json"]>;
    /**
     * Get project issue security scheme
     * Returns the [issue security scheme](https://confluence.atlassian.com/x/J4lKLg) associated with the project.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or the *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: getProjectIssueSecurityScheme
     * Request URI: /rest/api/3/project/{projectKeyOrId}/issuesecuritylevelscheme
     */
    getProjectIssueSecurityScheme(params: Params$getProjectIssueSecurityScheme, option?: RequestOption): Promise<Response$getProjectIssueSecurityScheme$Status$200["application/json"]>;
    /**
     * Get project notification scheme
     * Gets a [notification scheme](https://confluence.atlassian.com/x/8YdKLg) associated with the project. See the [Get notification scheme](#api-rest-api-3-notificationscheme-id-get) resource for more information about notification schemes.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: getNotificationSchemeForProject
     * Request URI: /rest/api/3/project/{projectKeyOrId}/notificationscheme
     */
    getNotificationSchemeForProject(params: Params$getNotificationSchemeForProject, option?: RequestOption): Promise<Response$getNotificationSchemeForProject$Status$200["application/json"]>;
    /**
     * Get assigned permission scheme
     * Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
     * operationId: getAssignedPermissionScheme
     * Request URI: /rest/api/3/project/{projectKeyOrId}/permissionscheme
     */
    getAssignedPermissionScheme(params: Params$getAssignedPermissionScheme, option?: RequestOption): Promise<Response$getAssignedPermissionScheme$Status$200["application/json"]>;
    /**
     * Assign permission scheme
     * Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
     * operationId: assignPermissionScheme
     * Request URI: /rest/api/3/project/{projectKeyOrId}/permissionscheme
     */
    assignPermissionScheme(params: Params$assignPermissionScheme, option?: RequestOption): Promise<Response$assignPermissionScheme$Status$200["application/json"]>;
    /**
     * Get project issue security levels
     * Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
     * operationId: getSecurityLevelsForProject
     * Request URI: /rest/api/3/project/{projectKeyOrId}/securitylevel
     */
    getSecurityLevelsForProject(params: Params$getSecurityLevelsForProject, option?: RequestOption): Promise<Response$getSecurityLevelsForProject$Status$200["application/json"]>;
    /**
     * Get all project categories
     * Returns all project categories.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getAllProjectCategories
     * Request URI: /rest/api/3/projectCategory
     */
    getAllProjectCategories(option?: RequestOption): Promise<Response$getAllProjectCategories$Status$200["application/json"]>;
    /**
     * Create project category
     * Creates a project category.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createProjectCategory
     * Request URI: /rest/api/3/projectCategory
     */
    createProjectCategory(params: Params$createProjectCategory, option?: RequestOption): Promise<Response$createProjectCategory$Status$201["application/json"]>;
    /**
     * Get project category by ID
     * Returns a project category.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getProjectCategoryById
     * Request URI: /rest/api/3/projectCategory/{id}
     */
    getProjectCategoryById(params: Params$getProjectCategoryById, option?: RequestOption): Promise<Response$getProjectCategoryById$Status$200["application/json"]>;
    /**
     * Update project category
     * Updates a project category.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateProjectCategory
     * Request URI: /rest/api/3/projectCategory/{id}
     */
    updateProjectCategory(params: Params$updateProjectCategory, option?: RequestOption): Promise<Response$updateProjectCategory$Status$200["application/json"]>;
    /**
     * Delete project category
     * Deletes a project category.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeProjectCategory
     * Request URI: /rest/api/3/projectCategory/{id}
     */
    removeProjectCategory(params: Params$removeProjectCategory, option?: RequestOption): Promise<void>;
    /**
     * Validate project key
     * Validates a project key by confirming the key is a valid string and not in use.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: validateProjectKey
     * Request URI: /rest/api/3/projectvalidate/key
     */
    validateProjectKey(params: Params$validateProjectKey, option?: RequestOption): Promise<Response$validateProjectKey$Status$200["application/json"]>;
    /**
     * Get valid project key
     * Validates a project key and, if the key is invalid or in use, generates a valid random string for the project key.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getValidProjectKey
     * Request URI: /rest/api/3/projectvalidate/validProjectKey
     */
    getValidProjectKey(params: Params$getValidProjectKey, option?: RequestOption): Promise<Response$getValidProjectKey$Status$200["application/json"]>;
    /**
     * Get valid project name
     * Checks that a project name isn't in use. If the name isn't in use, the passed string is returned. If the name is in use, this operation attempts to generate a valid project name based on the one supplied, usually by adding a sequence number. If a valid project name cannot be generated, a 404 response is returned.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getValidProjectName
     * Request URI: /rest/api/3/projectvalidate/validProjectName
     */
    getValidProjectName(params: Params$getValidProjectName, option?: RequestOption): Promise<Response$getValidProjectName$Status$200["application/json"]>;
    /**
     * Get resolutions
     * Returns a list of all issue resolution values.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getResolutions
     * Request URI: /rest/api/3/resolution
     */
    getResolutions(option?: RequestOption): Promise<Response$getResolutions$Status$200["application/json"]>;
    /**
     * Get resolution
     * Returns an issue resolution value.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getResolution
     * Request URI: /rest/api/3/resolution/{id}
     */
    getResolution(params: Params$getResolution, option?: RequestOption): Promise<Response$getResolution$Status$200["application/json"]>;
    /**
     * Get all project roles
     * Gets a list of all project roles, complete with project role details and default actors.
     *
     * ### About project roles ###
     *
     * [Project roles](https://confluence.atlassian.com/x/3odKLg) are a flexible way to to associate users and groups with projects. In Jira Cloud, the list of project roles is shared globally with all projects, but each project can have a different set of actors associated with it (unlike groups, which have the same membership throughout all Jira applications).
     *
     * Project roles are used in [permission schemes](#api-rest-api-3-permissionscheme-get), [email notification schemes](#api-rest-api-3-notificationscheme-get), [issue security levels](#api-rest-api-3-issuesecurityschemes-get), [comment visibility](#api-rest-api-3-comment-list-post), and workflow conditions.
     *
     * #### Members and actors ####
     *
     * In the Jira REST API, a member of a project role is called an *actor*. An *actor* is a group or user associated with a project role.
     *
     * Actors may be set as [default members](https://confluence.atlassian.com/x/3odKLg#Managingprojectroles-Specifying'defaultmembers'foraprojectrole) of the project role or set at the project level:
     *
     *  *  Default actors: Users and groups that are assigned to the project role for all newly created projects. The default actors can be removed at the project level later if desired.
     *  *  Actors: Users and groups that are associated with a project role for a project, which may differ from the default actors. This enables you to assign a user to different roles in different projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllProjectRoles
     * Request URI: /rest/api/3/role
     */
    getAllProjectRoles(option?: RequestOption): Promise<Response$getAllProjectRoles$Status$200["application/json"]>;
    /**
     * Create project role
     * Creates a new project role with no [default actors](#api-rest-api-3-resolution-get). You can use the [Add default actors to project role](#api-rest-api-3-role-id-actors-post) operation to add default actors to the project role after creating it.
     *
     * *Note that although a new project role is available to all projects upon creation, any default actors that are associated with the project role are not added to projects that existed prior to the role being created.*<
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createProjectRole
     * Request URI: /rest/api/3/role
     */
    createProjectRole(params: Params$createProjectRole, option?: RequestOption): Promise<Response$createProjectRole$Status$200["application/json"]>;
    /**
     * Get project role by ID
     * Gets the project role details and the default actors associated with the role. The list of default actors is sorted by display name.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getProjectRoleById
     * Request URI: /rest/api/3/role/{id}
     */
    getProjectRoleById(params: Params$getProjectRoleById, option?: RequestOption): Promise<Response$getProjectRoleById$Status$200["application/json"]>;
    /**
     * Fully update project role
     * Updates the project role's name and description. You must include both a name and a description in the request.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: fullyUpdateProjectRole
     * Request URI: /rest/api/3/role/{id}
     */
    fullyUpdateProjectRole(params: Params$fullyUpdateProjectRole, option?: RequestOption): Promise<Response$fullyUpdateProjectRole$Status$200["application/json"]>;
    /**
     * Partial update project role
     * Updates either the project role's name or its description.
     *
     * You cannot update both the name and description at the same time using this operation. If you send a request with a name and a description only the name is updated.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: partialUpdateProjectRole
     * Request URI: /rest/api/3/role/{id}
     */
    partialUpdateProjectRole(params: Params$partialUpdateProjectRole, option?: RequestOption): Promise<Response$partialUpdateProjectRole$Status$200["application/json"]>;
    /**
     * Delete project role
     * Deletes a project role. You must specify a replacement project role if you wish to delete a project role that is in use.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteProjectRole
     * Request URI: /rest/api/3/role/{id}
     */
    deleteProjectRole(params: Params$deleteProjectRole, option?: RequestOption): Promise<void>;
    /**
     * Get default actors for project role
     * Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getProjectRoleActorsForRole
     * Request URI: /rest/api/3/role/{id}/actors
     */
    getProjectRoleActorsForRole(params: Params$getProjectRoleActorsForRole, option?: RequestOption): Promise<Response$getProjectRoleActorsForRole$Status$200["application/json"]>;
    /**
     * Add default actors to project role
     * Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.
     *
     * Changing a project role's default actors does not affect project role members for projects already created.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addProjectRoleActorsToRole
     * Request URI: /rest/api/3/role/{id}/actors
     */
    addProjectRoleActorsToRole(params: Params$addProjectRoleActorsToRole, option?: RequestOption): Promise<Response$addProjectRoleActorsToRole$Status$200["application/json"]>;
    /**
     * Delete default actors from project role
     * Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.
     *
     * Changing a project role's default actors does not affect project role members for projects already created.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteProjectRoleActorsFromRole
     * Request URI: /rest/api/3/role/{id}/actors
     */
    deleteProjectRoleActorsFromRole(params: Params$deleteProjectRoleActorsFromRole, option?: RequestOption): Promise<Response$deleteProjectRoleActorsFromRole$Status$200["application/json"]>;
    /**
     * Get screens
     * Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getScreens
     * Request URI: /rest/api/3/screens
     */
    getScreens(params: Params$getScreens, option?: RequestOption): Promise<Response$getScreens$Status$200["application/json"]>;
    /**
     * Create screen
     * Creates a screen with a default field tab.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createScreen
     * Request URI: /rest/api/3/screens
     */
    createScreen(params: Params$createScreen, option?: RequestOption): Promise<Response$createScreen$Status$201["application/json"]>;
    /**
     * Add field to default screen
     * Adds a field to the default tab of the default screen.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addFieldToDefaultScreen
     * Request URI: /rest/api/3/screens/addToDefault/{fieldId}
     */
    addFieldToDefaultScreen(params: Params$addFieldToDefaultScreen, option?: RequestOption): Promise<Response$addFieldToDefaultScreen$Status$200["application/json"]>;
    /**
     * Update screen
     * Updates a screen. Only screens used in classic projects can be updated.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateScreen
     * Request URI: /rest/api/3/screens/{screenId}
     */
    updateScreen(params: Params$updateScreen, option?: RequestOption): Promise<Response$updateScreen$Status$200["application/json"]>;
    /**
     * Delete screen
     * Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.
     *
     * Only screens used in classic projects can be deleted.
     * operationId: deleteScreen
     * Request URI: /rest/api/3/screens/{screenId}
     */
    deleteScreen(params: Params$deleteScreen, option?: RequestOption): Promise<void>;
    /**
     * Get available screen fields
     * Returns the fields that can be added to a tab on a screen.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAvailableScreenFields
     * Request URI: /rest/api/3/screens/{screenId}/availableFields
     */
    getAvailableScreenFields(params: Params$getAvailableScreenFields, option?: RequestOption): Promise<Response$getAvailableScreenFields$Status$200["application/json"]>;
    /**
     * Get all screen tabs
     * Returns the list of tabs for a screen.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
     * operationId: getAllScreenTabs
     * Request URI: /rest/api/3/screens/{screenId}/tabs
     */
    getAllScreenTabs(params: Params$getAllScreenTabs, option?: RequestOption): Promise<Response$getAllScreenTabs$Status$200["application/json"]>;
    /**
     * Create screen tab
     * Creates a tab for a screen.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addScreenTab
     * Request URI: /rest/api/3/screens/{screenId}/tabs
     */
    addScreenTab(params: Params$addScreenTab, option?: RequestOption): Promise<Response$addScreenTab$Status$200["application/json"]>;
    /**
     * Update screen tab
     * Updates the name of a screen tab.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: renameScreenTab
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}
     */
    renameScreenTab(params: Params$renameScreenTab, option?: RequestOption): Promise<Response$renameScreenTab$Status$200["application/json"]>;
    /**
     * Delete screen tab
     * Deletes a screen tab.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteScreenTab
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}
     */
    deleteScreenTab(params: Params$deleteScreenTab, option?: RequestOption): Promise<void>;
    /**
     * Get all screen tab fields
     * Returns all fields for a screen tab.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
     * operationId: getAllScreenTabFields
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}/fields
     */
    getAllScreenTabFields(params: Params$getAllScreenTabFields, option?: RequestOption): Promise<Response$getAllScreenTabFields$Status$200["application/json"]>;
    /**
     * Add screen tab field
     * Adds a field to a screen tab.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: addScreenTabField
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}/fields
     */
    addScreenTabField(params: Params$addScreenTabField, option?: RequestOption): Promise<Response$addScreenTabField$Status$200["application/json"]>;
    /**
     * Remove screen tab field
     * Removes a field from a screen tab.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: removeScreenTabField
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}/fields/{id}
     */
    removeScreenTabField(params: Params$removeScreenTabField, option?: RequestOption): Promise<void>;
    /**
     * Move screen tab field
     * Moves a screen tab field.
     *
     * If `after` and `position` are provided in the request, `position` is ignored.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: moveScreenTabField
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}/fields/{id}/move
     */
    moveScreenTabField(params: Params$moveScreenTabField, option?: RequestOption): Promise<Response$moveScreenTabField$Status$204["application/json"]>;
    /**
     * Move screen tab
     * Moves a screen tab.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: moveScreenTab
     * Request URI: /rest/api/3/screens/{screenId}/tabs/{tabId}/move/{pos}
     */
    moveScreenTab(params: Params$moveScreenTab, option?: RequestOption): Promise<Response$moveScreenTab$Status$204["application/json"]>;
    /**
     * Get screen schemes
     * Returns a [paginated](#pagination) list of screen schemes.
     *
     * Only screen schemes used in classic projects are returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getScreenSchemes
     * Request URI: /rest/api/3/screenscheme
     */
    getScreenSchemes(params: Params$getScreenSchemes, option?: RequestOption): Promise<Response$getScreenSchemes$Status$200["application/json"]>;
    /**
     * Create screen scheme
     * Creates a screen scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createScreenScheme
     * Request URI: /rest/api/3/screenscheme
     */
    createScreenScheme(params: Params$createScreenScheme, option?: RequestOption): Promise<Response$createScreenScheme$Status$201["application/json"]>;
    /**
     * Update screen scheme
     * Updates a screen scheme. Only screen schemes used in classic projects can be updated.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateScreenScheme
     * Request URI: /rest/api/3/screenscheme/{screenSchemeId}
     */
    updateScreenScheme(params: Params$updateScreenScheme, option?: RequestOption): Promise<Response$updateScreenScheme$Status$204["application/json"]>;
    /**
     * Delete screen scheme
     * Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.
     *
     * Only screens schemes used in classic projects can be deleted.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteScreenScheme
     * Request URI: /rest/api/3/screenscheme/{screenSchemeId}
     */
    deleteScreenScheme(params: Params$deleteScreenScheme, option?: RequestOption): Promise<void>;
    /**
     * Search for issues using JQL (GET)
     * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).
     *
     * If the JQL query expression is too large to be encoded as a query parameter, use the [POST](#api-rest-api-3-search-post) version of this resource.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Issues are included in the response where the user has:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: searchForIssuesUsingJql
     * Request URI: /rest/api/3/search
     */
    searchForIssuesUsingJql(params: Params$searchForIssuesUsingJql, option?: RequestOption): Promise<Response$searchForIssuesUsingJql$Status$200["application/json"]>;
    /**
     * Search for issues using JQL (POST)
     * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).
     *
     * There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** Issues are included in the response where the user has:
     *
     *  *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
     *  *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
     * operationId: searchForIssuesUsingJqlPost
     * Request URI: /rest/api/3/search
     */
    searchForIssuesUsingJqlPost(params: Params$searchForIssuesUsingJqlPost, option?: RequestOption): Promise<Response$searchForIssuesUsingJqlPost$Status$200["application/json"]>;
    /**
     * Get issue security level
     * Returns details of an issue security level.
     *
     * Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getIssueSecurityLevel
     * Request URI: /rest/api/3/securitylevel/{id}
     */
    getIssueSecurityLevel(params: Params$getIssueSecurityLevel, option?: RequestOption): Promise<Response$getIssueSecurityLevel$Status$200["application/json"]>;
    /**
     * Get Jira instance info
     * Returns information about the Jira instance.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getServerInfo
     * Request URI: /rest/api/3/serverInfo
     */
    getServerInfo(option?: RequestOption): Promise<Response$getServerInfo$Status$200["application/json"]>;
    /**
     * Get issue navigator default columns
     * Returns the default issue navigator columns.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getIssueNavigatorDefaultColumns
     * Request URI: /rest/api/3/settings/columns
     */
    getIssueNavigatorDefaultColumns(option?: RequestOption): Promise<Response$getIssueNavigatorDefaultColumns$Status$200["application/json"]>;
    /**
     * Set issue navigator default columns
     * Sets the default issue navigator columns.
     *
     * The `columns` parameter accepts a navigable field value and is expressed as HTML form data. To specify multiple columns, pass multiple `columns` parameters. For example, in curl:
     *
     * `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/settings/columns`
     *
     * If no column details are sent, then all default columns are removed.
     *
     * A navigable field is one that can be used as a column on the issue navigator. Find details of navigable issue columns using [Get fields](#api-rest-api-3-field-get).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setIssueNavigatorDefaultColumns
     * Request URI: /rest/api/3/settings/columns
     */
    setIssueNavigatorDefaultColumns<RequestContentType extends RequestContentType$setIssueNavigatorDefaultColumns>(params: Params$setIssueNavigatorDefaultColumns<RequestContentType>, option?: RequestOption): Promise<Response$setIssueNavigatorDefaultColumns$Status$200["application/json"]>;
    /**
     * Get all statuses
     * Returns a list of all statuses associated with workflows.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getStatuses
     * Request URI: /rest/api/3/status
     */
    getStatuses(option?: RequestOption): Promise<Response$getStatuses$Status$200["application/json"]>;
    /**
     * Get status
     * Returns a status. The status must be associated with a workflow to be returned.
     *
     * If a name is used on more than one status, only the status found first is returned. Therefore, identifying the status by its ID may be preferable.
     *
     * This operation can be accessed anonymously.
     *
     * [Permissions](#permissions) required: None.
     * operationId: getStatus
     * Request URI: /rest/api/3/status/{idOrName}
     */
    getStatus(params: Params$getStatus, option?: RequestOption): Promise<Response$getStatus$Status$200["application/json"]>;
    /**
     * Get all status categories
     * Returns a list of all status categories.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getStatusCategories
     * Request URI: /rest/api/3/statuscategory
     */
    getStatusCategories(option?: RequestOption): Promise<Response$getStatusCategories$Status$200["application/json"]>;
    /**
     * Get status category
     * Returns a status category. Status categories provided a mechanism for categorizing [statuses](#api-rest-api-3-status-idOrName-get).
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getStatusCategory
     * Request URI: /rest/api/3/statuscategory/{idOrKey}
     */
    getStatusCategory(params: Params$getStatusCategory, option?: RequestOption): Promise<Response$getStatusCategory$Status$200["application/json"]>;
    /**
     * Get task
     * Returns the status of a [long-running asynchronous task](#async).
     *
     * When a task has finished, this operation returns the JSON blob applicable to the task. See the documentation of the operation that created the task for details. Task details are not permanently retained. As of September 2019, details are retained for 14 days although this period may change without notice.
     *
     * **[Permissions](#permissions) required:** either of:
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  Creator of the task.
     * operationId: getTask
     * Request URI: /rest/api/3/task/{taskId}
     */
    getTask(params: Params$getTask, option?: RequestOption): Promise<Response$getTask$Status$200["application/json"]>;
    /**
     * Cancel task
     * Cancels a task.
     *
     * **[Permissions](#permissions) required:** either of:
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *  *  Creator of the task.
     * operationId: cancelTask
     * Request URI: /rest/api/3/task/{taskId}/cancel
     */
    cancelTask(params: Params$cancelTask, option?: RequestOption): Promise<Response$cancelTask$Status$202["application/json"]>;
    /**
     * Get avatars
     * Returns the system and custom avatars for a project or issue type.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  for custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
     *  *  for custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
     *  *  for system avatars, none.
     * operationId: getAvatars
     * Request URI: /rest/api/3/universal_avatar/type/{type}/owner/{entityId}
     */
    getAvatars(params: Params$getAvatars, option?: RequestOption): Promise<Response$getAvatars$Status$200["application/json"]>;
    /**
     * Load avatar
     * Loads a custom avatar for a project or issue type.
     *
     * Specify the avatar's local file location in the body of the request. Also, include the following headers:
     *
     *  *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
     *  *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
     *
     * For example:
     * `curl --request POST `
     *
     * `--user email@example.com:<api_token> `
     *
     * `--header 'X-Atlassian-Token: no-check' `
     *
     * `--header 'Content-Type: image/< image_type>' `
     *
     * `--data-binary "<@/path/to/file/with/your/avatar>" `
     *
     * `--url 'https://your-domain.atlassian.net/rest/api/3/universal_avatar/type/{type}/owner/{entityId}'`
     *
     * The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
     *
     * The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
     *
     * After creating the avatar use:
     *
     *  *  [Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
     *  *  [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: storeAvatar
     * Request URI: /rest/api/3/universal_avatar/type/{type}/owner/{entityId}
     */
    storeAvatar(params: Params$storeAvatar, option?: RequestOption): Promise<Response$storeAvatar$Status$201["application/json"]>;
    /**
     * Delete avatar
     * Deletes an avatar from a project or issue type.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteAvatar
     * Request URI: /rest/api/3/universal_avatar/type/{type}/owner/{owningObjectId}/avatar/{id}
     */
    deleteAvatar(params: Params$deleteAvatar, option?: RequestOption): Promise<void>;
    /**
     * Get avatar image by type
     * Returns the default project or issue type avatar image.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: getAvatarImageByType
     * Request URI: /rest/api/3/universal_avatar/view/type/{type}
     */
    getAvatarImageByType<ResponseContentType extends ResponseContentType$getAvatarImageByType>(params: Params$getAvatarImageByType<ResponseContentType>, option?: RequestOption): Promise<Response$getAvatarImageByType$Status$200[ResponseContentType]>;
    /**
     * Get avatar image by ID
     * Returns a project or issue type avatar image by ID.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  For system avatars, none.
     *  *  For custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
     *  *  For custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
     * operationId: getAvatarImageByID
     * Request URI: /rest/api/3/universal_avatar/view/type/{type}/avatar/{id}
     */
    getAvatarImageByID<ResponseContentType extends ResponseContentType$getAvatarImageByID>(params: Params$getAvatarImageByID<ResponseContentType>, option?: RequestOption): Promise<Response$getAvatarImageByID$Status$200[ResponseContentType]>;
    /**
     * Get avatar image by owner
     * Returns the avatar image for a project or issue type.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  For system avatars, none.
     *  *  For custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
     *  *  For custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
     * operationId: getAvatarImageByOwner
     * Request URI: /rest/api/3/universal_avatar/view/type/{type}/owner/{entityId}
     */
    getAvatarImageByOwner<ResponseContentType extends ResponseContentType$getAvatarImageByOwner>(params: Params$getAvatarImageByOwner<ResponseContentType>, option?: RequestOption): Promise<Response$getAvatarImageByOwner$Status$200[ResponseContentType]>;
    /**
     * Get user
     * Returns a user.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getUser
     * Request URI: /rest/api/3/user
     */
    getUser(params: Params$getUser, option?: RequestOption): Promise<Response$getUser$Status$200["application/json"]>;
    /**
     * Create user
     * Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.
     *
     * If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createUser
     * Request URI: /rest/api/3/user
     */
    createUser(params: Params$createUser, option?: RequestOption): Promise<Response$createUser$Status$201["application/json"]>;
    /**
     * Delete user
     * Deletes a user.
     *
     * **[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
     * operationId: removeUser
     * Request URI: /rest/api/3/user
     */
    removeUser(params: Params$removeUser, option?: RequestOption): Promise<void>;
    /**
     * Find users assignable to projects
     * Returns a list of users who can be assigned issues in one or more projects. The list may be restricted to users whose attributes match a string.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned issues in the projects. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned issues in the projects, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** None.
     * operationId: findBulkAssignableUsers
     * Request URI: /rest/api/3/user/assignable/multiProjectSearch
     */
    findBulkAssignableUsers(params: Params$findBulkAssignableUsers, option?: RequestOption): Promise<Response$findBulkAssignableUsers$Status$200["application/json"]>;
    /**
     * Find users assignable to issues
     * Returns a list of users that can be assigned to an issue. Use this operation to find the list of users who can be assigned to:
     *
     *  *  a new issue, by providing the `projectKeyOrId`.
     *  *  an updated issue, by providing the `issueKey`.
     *  *  to an issue during a transition (workflow action), by providing the `issueKey` and the transition id in `actionDescriptorId`. You can obtain the IDs of an issue's valid transitions using the `transitions` option in the `expand` parameter of [ Get issue](#api-rest-api-3-issue-issueIdOrKey-get).
     *
     * In all these cases, you can pass an account ID to determine if a user can be assigned to an issue. The user is returned in the response if they can be assigned to the issue or issue transition.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned the issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned the issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: findAssignableUsers
     * Request URI: /rest/api/3/user/assignable/search
     */
    findAssignableUsers(params: Params$findAssignableUsers, option?: RequestOption): Promise<Response$findAssignableUsers$Status$200["application/json"]>;
    /**
     * Bulk get users
     * Returns a [paginated](#pagination) list of the users specified by one or more account IDs.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: bulkGetUsers
     * Request URI: /rest/api/3/user/bulk
     */
    bulkGetUsers(params: Params$bulkGetUsers, option?: RequestOption): Promise<Response$bulkGetUsers$Status$200["application/json"]>;
    /**
     * Get account IDs for users
     * Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: bulkGetUsersMigration
     * Request URI: /rest/api/3/user/bulk/migration
     */
    bulkGetUsersMigration(params: Params$bulkGetUsersMigration, option?: RequestOption): Promise<Response$bulkGetUsersMigration$Status$200["application/json"]>;
    /**
     * Get user default columns
     * Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
     *  *  Permission to access Jira, to get the calling user's column details.
     * operationId: getUserDefaultColumns
     * Request URI: /rest/api/3/user/columns
     */
    getUserDefaultColumns(params: Params$getUserDefaultColumns, option?: RequestOption): Promise<Response$getUserDefaultColumns$Status$200["application/json"]>;
    /**
     * Set user default columns
     * Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.
     *
     * The parameters for this resource are expressed as HTML form data. For example, in curl:
     *
     * `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
     *  *  Permission to access Jira, to set the calling user's columns.
     * operationId: setUserColumns
     * Request URI: /rest/api/3/user/columns
     */
    setUserColumns<RequestContentType extends RequestContentType$setUserColumns>(params: Params$setUserColumns<RequestContentType>, option?: RequestOption): Promise<Response$setUserColumns$Status$200["application/json"]>;
    /**
     * Reset user default columns
     * Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
     *  *  Permission to access Jira, to set the calling user's columns.
     * operationId: resetUserColumns
     * Request URI: /rest/api/3/user/columns
     */
    resetUserColumns(params: Params$resetUserColumns, option?: RequestOption): Promise<void>;
    /**
     * Get user email
     * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
     * operationId: getUserEmail
     * Request URI: /rest/api/3/user/email
     */
    getUserEmail(params: Params$getUserEmail, option?: RequestOption): Promise<Response$getUserEmail$Status$200["application/json"]>;
    /**
     * Get user email bulk
     * Returns a user's email address. This API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603).
     * operationId: getUserEmailBulk
     * Request URI: /rest/api/3/user/email/bulk
     */
    getUserEmailBulk(params: Params$getUserEmailBulk, option?: RequestOption): Promise<Response$getUserEmailBulk$Status$200["application/json"]>;
    /**
     * Get user groups
     * Returns the groups to which a user belongs.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getUserGroups
     * Request URI: /rest/api/3/user/groups
     */
    getUserGroups(params: Params$getUserGroups, option?: RequestOption): Promise<Response$getUserGroups$Status$200["application/json"]>;
    /**
     * Find users with permissions
     * Returns a list of users who fulfill these criteria:
     *
     *  *  their user attributes match a search string.
     *  *  they have a set of permissions for a project or issue.
     *
     * If no search string is provided, a list of all users with the permissions is returned.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission for the project or issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission for the project or issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get users for any project.
     *  *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project, to get users for that project.
     * operationId: findUsersWithAllPermissions
     * Request URI: /rest/api/3/user/permission/search
     */
    findUsersWithAllPermissions(params: Params$findUsersWithAllPermissions, option?: RequestOption): Promise<Response$findUsersWithAllPermissions$Status$200["application/json"]>;
    /**
     * Find users for picker
     * Returns a list of users whose attributes match the query term. The returned object includes the `html` field where the matched query term is highlighted with the HTML strong tag. A list of account IDs can be provided to exclude users from the results.
     *
     * This operation takes the users in the range defined by `maxResults`, up to the thousandth user, and then returns only the users from that range that match the query term. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the query term, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return search results for an exact name match only.
     * operationId: findUsersForPicker
     * Request URI: /rest/api/3/user/picker
     */
    findUsersForPicker(params: Params$findUsersForPicker, option?: RequestOption): Promise<Response$findUsersForPicker$Status$200["application/json"]>;
    /**
     * Get user property keys
     * Returns the keys of all properties for a user.
     *
     * Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to access the property keys on any user.
     *  *  Access to Jira, to access the calling user's property keys.
     * operationId: getUserPropertyKeys
     * Request URI: /rest/api/3/user/properties
     */
    getUserPropertyKeys(params: Params$getUserPropertyKeys, option?: RequestOption): Promise<Response$getUserPropertyKeys$Status$200["application/json"]>;
    /**
     * Get user property
     * Returns the value of a user's property. If no property key is provided [Get user property keys](#api-rest-api-3-user-properties-get) is called.
     *
     * Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get a property from any user.
     *  *  Access to Jira, to get a property from the calling user's record.
     * operationId: getUserProperty
     * Request URI: /rest/api/3/user/properties/{propertyKey}
     */
    getUserProperty(params: Params$getUserProperty, option?: RequestOption): Promise<Response$getUserProperty$Status$200["application/json"]>;
    /**
     * Set user property
     * Sets the value of a user's property. Use this resource to store custom data against a user.
     *
     * Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set a property on any user.
     *  *  Access to Jira, to set a property on the calling user's record.
     * operationId: setUserProperty
     * Request URI: /rest/api/3/user/properties/{propertyKey}
     */
    setUserProperty(params: Params$setUserProperty, option?: RequestOption): Promise<(Response$setUserProperty$Status$200 | Response$setUserProperty$Status$201)["application/json"]>;
    /**
     * Delete user property
     * Deletes a property from a user.
     *
     * Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
     *
     * **[Permissions](#permissions) required:**
     *
     *  *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to delete a property from any user.
     *  *  Access to Jira, to delete a property from the calling user's record.
     * operationId: deleteUserProperty
     * Request URI: /rest/api/3/user/properties/{propertyKey}
     */
    deleteUserProperty(params: Params$deleteUserProperty, option?: RequestOption): Promise<void>;
    /**
     * Find users
     * Returns a list of users that match the search string and property.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and property. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and property, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls or calls by users without the required permission return empty search results.
     * operationId: findUsers
     * Request URI: /rest/api/3/user/search
     */
    findUsers(params: Params$findUsers, option?: RequestOption): Promise<Response$findUsers$Status$200["application/json"]>;
    /**
     * Find users by query
     * Finds users with a structured query and returns a [paginated](#pagination) list of user details.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *
     * The query statements are:
     *
     *  *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
     *  *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
     *  *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value.
     *
     * The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
     *
     * `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
     * operationId: findUsersByQuery
     * Request URI: /rest/api/3/user/search/query
     */
    findUsersByQuery(params: Params$findUsersByQuery, option?: RequestOption): Promise<Response$findUsersByQuery$Status$200["application/json"]>;
    /**
     * Find user keys by query
     * Finds users with a structured query and returns a [paginated](#pagination) list of user keys.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     *
     * The query statements are:
     *
     *  *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
     *  *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
     *  *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
     *  *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value.
     *
     * The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
     *
     * `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
     * operationId: findUserKeysByQuery
     * Request URI: /rest/api/3/user/search/query/key
     */
    findUserKeysByQuery(params: Params$findUserKeysByQuery, option?: RequestOption): Promise<Response$findUserKeysByQuery$Status$200["application/json"]>;
    /**
     * Find users with browse permission
     * Returns a list of users who fulfill these criteria:
     *
     *  *  their user attributes match a search string.
     *  *  they have permission to browse issues.
     *
     * Use this resource to find users who can browse:
     *
     *  *  an issue, by providing the `issueKey`.
     *  *  any issue in a project, by providing the `projectKey`.
     *
     * This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission to browse issues. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission to browse issues, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return empty search results.
     * operationId: findUsersWithBrowsePermission
     * Request URI: /rest/api/3/user/viewissue/search
     */
    findUsersWithBrowsePermission(params: Params$findUsersWithBrowsePermission, option?: RequestOption): Promise<Response$findUsersWithBrowsePermission$Status$200["application/json"]>;
    /**
     * Get all users default
     * Returns a list of all (active and inactive) users.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllUsersDefault
     * Request URI: /rest/api/3/users
     */
    getAllUsersDefault(params: Params$getAllUsersDefault, option?: RequestOption): Promise<Response$getAllUsersDefault$Status$200["application/json"]>;
    /**
     * Get all users
     * Returns a list of all (active and inactive) users.
     *
     * **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllUsers
     * Request URI: /rest/api/3/users/search
     */
    getAllUsers(params: Params$getAllUsers, option?: RequestOption): Promise<Response$getAllUsers$Status$200["application/json"]>;
    /**
     * Create version
     * Creates a project version.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
     * operationId: createVersion
     * Request URI: /rest/api/3/version
     */
    createVersion(params: Params$createVersion, option?: RequestOption): Promise<Response$createVersion$Status$201["application/json"]>;
    /**
     * Get version
     * Returns a project version.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
     * operationId: getVersion
     * Request URI: /rest/api/3/version/{id}
     */
    getVersion(params: Params$getVersion, option?: RequestOption): Promise<Response$getVersion$Status$200["application/json"]>;
    /**
     * Update version
     * Updates a project version.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
     * operationId: updateVersion
     * Request URI: /rest/api/3/version/{id}
     */
    updateVersion(params: Params$updateVersion, option?: RequestOption): Promise<Response$updateVersion$Status$200["application/json"]>;
    /**
     * @deprecated
     * Delete version
     * Deletes a project version.
     *
     * Deprecated, use [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) that supports swapping version values in custom fields, in addition to the swapping for `fixVersion` and `affectedVersion` provided in this resource.
     *
     * Alternative versions can be provided to update issues that use the deleted version in `fixVersion` or `affectedVersion`. If alternatives are not provided, occurrences of `fixVersion` and `affectedVersion` that contain the deleted version are cleared.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
     * operationId: deleteVersion
     * Request URI: /rest/api/3/version/{id}
     */
    deleteVersion(params: Params$deleteVersion, option?: RequestOption): Promise<void>;
    /**
     * Merge versions
     * Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.
     *
     * Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
     * operationId: mergeVersions
     * Request URI: /rest/api/3/version/{id}/mergeto/{moveIssuesTo}
     */
    mergeVersions(params: Params$mergeVersions, option?: RequestOption): Promise<Response$mergeVersions$Status$204["application/json"]>;
    /**
     * Move version
     * Modifies the version's sequence within the project, which affects the display order of the versions in Jira.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
     * operationId: moveVersion
     * Request URI: /rest/api/3/version/{id}/move
     */
    moveVersion(params: Params$moveVersion, option?: RequestOption): Promise<Response$moveVersion$Status$200["application/json"]>;
    /**
     * Get version's related issues count
     * Returns the following counts for a version:
     *
     *  *  Number of issues where the `fixVersion` is set to the version.
     *  *  Number of issues where the `affectedVersion` is set to the version.
     *  *  Number of issues where a version custom field is set to the version.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
     * operationId: getVersionRelatedIssues
     * Request URI: /rest/api/3/version/{id}/relatedIssueCounts
     */
    getVersionRelatedIssues(params: Params$getVersionRelatedIssues, option?: RequestOption): Promise<Response$getVersionRelatedIssues$Status$200["application/json"]>;
    /**
     * Delete and replace version
     * Deletes a project version.
     *
     * Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
     * operationId: deleteAndReplaceVersion
     * Request URI: /rest/api/3/version/{id}/removeAndSwap
     */
    deleteAndReplaceVersion(params: Params$deleteAndReplaceVersion, option?: RequestOption): Promise<Response$deleteAndReplaceVersion$Status$204["application/json"]>;
    /**
     * Get version's unresolved issues count
     * Returns counts of the issues and unresolved issues for the project version.
     *
     * This operation can be accessed anonymously.
     *
     * **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
     * operationId: getVersionUnresolvedIssues
     * Request URI: /rest/api/3/version/{id}/unresolvedIssueCount
     */
    getVersionUnresolvedIssues(params: Params$getVersionUnresolvedIssues, option?: RequestOption): Promise<Response$getVersionUnresolvedIssues$Status$200["application/json"]>;
    /**
     * Get dynamic webhooks for app
     * Returns a [paginated](#pagination) list of the webhooks registered by the calling app.
     *
     * **[Permissions](#permissions) required:** Only [Connect](https://developer.atlassian.com/cloud/jira/platform/#connect-apps) and [OAuth 2.0](https://developer.atlassian.com/cloud/jira/platform/oauth-2-3lo-apps) apps can use this operation.
     * operationId: getDynamicWebhooksForApp
     * Request URI: /rest/api/3/webhook
     */
    getDynamicWebhooksForApp(params: Params$getDynamicWebhooksForApp, option?: RequestOption): Promise<Response$getDynamicWebhooksForApp$Status$200["application/json"]>;
    /**
     * Register dynamic webhooks
     * Registers webhooks.
     *
     * **[Permissions](#permissions) required:** Only [Connect](https://developer.atlassian.com/cloud/jira/platform/#connect-apps) and [OAuth 2.0](https://developer.atlassian.com/cloud/jira/platform/oauth-2-3lo-apps) apps can use this operation.
     * operationId: registerDynamicWebhooks
     * Request URI: /rest/api/3/webhook
     */
    registerDynamicWebhooks(params: Params$registerDynamicWebhooks, option?: RequestOption): Promise<Response$registerDynamicWebhooks$Status$200["application/json"]>;
    /**
     * Delete webhooks by ID
     * Removes webhooks by ID. Only webhooks registered by the calling app are removed. If webhooks created by other apps are specified, they are ignored.
     *
     * **[Permissions](#permissions) required:** Only [Connect](https://developer.atlassian.com/cloud/jira/platform/#connect-apps) and [OAuth 2.0](https://developer.atlassian.com/cloud/jira/platform/oauth-2-3lo-apps) apps can use this operation.
     * operationId: deleteWebhookById
     * Request URI: /rest/api/3/webhook
     */
    deleteWebhookById(params: Params$deleteWebhookById, option?: RequestOption): Promise<void>;
    /**
     * Get failed webhooks
     * Returns webhooks that have recently failed to be delivered to the requesting app after the maximum number of retries.
     *
     * After 72 hours the failure may no longer be returned by this operation.
     *
     * The oldest failure is returned first.
     *
     * This method uses a cursor-based pagination. To request the next page use the failure time of the last webhook on the list as the `failedAfter` value or use the URL provided in `next`.
     *
     * **[Permissions](#permissions) required:** Only [Connect apps](https://developer.atlassian.com/cloud/jira/platform/index/#connect-apps) can use this operation.
     * operationId: getFailedWebhooks
     * Request URI: /rest/api/3/webhook/failed
     */
    getFailedWebhooks(params: Params$getFailedWebhooks, option?: RequestOption): Promise<Response$getFailedWebhooks$Status$200["application/json"]>;
    /**
     * Extend webhook life
     * Webhooks registered through the REST API expire after 30 days. Call this resource periodically to keep them alive.
     *
     * Unrecognized webhook IDs (those that are not found or belong to other apps) are ignored.
     *
     * **[Permissions](#permissions) required:** Only [Connect](https://developer.atlassian.com/cloud/jira/platform/#connect-apps) and [OAuth 2.0](https://developer.atlassian.com/cloud/jira/platform/oauth-2-3lo-apps) apps can use this operation.
     * operationId: refreshWebhooks
     * Request URI: /rest/api/3/webhook/refresh
     */
    refreshWebhooks(params: Params$refreshWebhooks, option?: RequestOption): Promise<Response$refreshWebhooks$Status$200["application/json"]>;
    /**
     * @deprecated
     * Get all workflows
     * Returns all workflows in Jira or a workflow. Deprecated, use [Get workflows paginated](#api-rest-api-3-workflow-search-get).
     *
     * If the `workflowName` parameter is specified, the workflow is returned as an object (not in an array). Otherwise, an array of workflow objects is returned.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllWorkflows
     * Request URI: /rest/api/3/workflow
     */
    getAllWorkflows(params: Params$getAllWorkflows, option?: RequestOption): Promise<Response$getAllWorkflows$Status$200["application/json"]>;
    /**
     * Create workflow
     * Creates a workflow. You can define transition rules using the shapes detailed in the following sections. If no transitional rules are specified the default system transition rules are used.
     *
     * #### Conditions ####
     *
     * Conditions enable workflow rules that govern whether a transition can execute.
     *
     * ##### Always false condition #####
     *
     * A condition that always fails.
     *
     *     {
     *        "type": "AlwaysFalseCondition"
     *      }
     *
     * ##### Block transition until approval #####
     *
     * A condition that blocks issue transition if there is a pending approval.
     *
     *     {
     *        "type": "BlockInProgressApprovalCondition"
     *      }
     *
     * ##### Compare number custom field condition #####
     *
     * A condition that allows transition if a comparison between a number custom field and a value is true.
     *
     *     {
     *        "type": "CompareNumberCFCondition",
     *        "configuration": {
     *          "comparator": "=",
     *          "fieldId": "customfield_10029",
     *          "fieldValue": 2
     *        }
     *      }
     *
     *  *  `comparator` One of the supported comparator: `=`, `>`, and `<`.
     *  *  `fieldId` The custom numeric field ID. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:float`
     *      *  `com.pyxis.greenhopper.jira:jsw-story-points`
     *  *  `fieldValue` The value for comparison.
     *
     * ##### Hide from user condition #####
     *
     * A condition that hides a transition from users. The transition can only be triggered from a workflow function or REST API operation.
     *
     *     {
     *        "type": "RemoteOnlyCondition"
     *      }
     *
     * ##### Only assignee condition #####
     *
     * A condition that allows only the assignee to execute a transition.
     *
     *     {
     *        "type": "AllowOnlyAssignee"
     *      }
     *
     * ##### Only Bamboo notifications workflow condition #####
     *
     * A condition that makes the transition available only to Bamboo build notifications.
     *
     *     {
     *        "type": "OnlyBambooNotificationsCondition"
     *      }
     *
     * ##### Only reporter condition #####
     *
     * A condition that allows only the reporter to execute a transition.
     *
     *     {
     *        "type": "AllowOnlyReporter"
     *      }
     *
     * ##### Permission condition #####
     *
     * A condition that allows only users with a permission to execute a transition.
     *
     *     {
     *        "type": "PermissionCondition",
     *        "configuration": {
     *            "permissionKey": "BROWSE_PROJECTS"
     *        }
     *      }
     *
     *  *  `permissionKey` The permission required to perform the transition. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
     *
     * ##### Previous status condition #####
     *
     * A condition that allows a transition based on whether an issue has or has not transitioned through a status.
     *
     *     {
     *        "type": "PreviousStatusCondition",
     *        "configuration": {
     *          "ignoreLoopTransitions": true,
     *          "includeCurrentStatus": true,
     *          "mostRecentStatusOnly": true,
     *          "reverseCondition": true,
     *          "previousStatus": {
     *            "id": "5"
     *          }
     *        }
     *      }
     *
     * By default this condition allows the transition if the status, as defined by its ID in the `previousStatus` object, matches any previous issue status, unless:
     *
     *  *  `ignoreLoopTransitions` is `true`, then loop transitions (from and to the same status) are ignored.
     *  *  `includeCurrentStatus` is `true`, then the current issue status is also checked.
     *  *  `mostRecentStatusOnly` is `true`, then only the issue's preceding status (the one immediately before the current status) is checked.
     *  *  `reverseCondition` is `true`, then the status must not be present.
     *
     * ##### Separation of duties condition #####
     *
     * A condition that prevents a user to perform the transition, if the user has already performed a transition on the issue.
     *
     *     {
     *        "type": "SeparationOfDutiesCondition",
     *        "configuration": {
     *          "fromStatus": {
     *            "id": "5"
     *          },
     *          "toStatus": {
     *            "id": "6"
     *          }
     *        }
     *      }
     *
     *  *  `fromStatus` OPTIONAL. An object containing the ID of the source status of the transition that is blocked. If omitted any transition to `toStatus` is blocked.
     *  *  `toStatus` An object containing the ID of the target status of the transition that is blocked.
     *
     * ##### Subtask blocking condition #####
     *
     * A condition that blocks transition on a parent issue if any of its subtasks are in any of one or more statuses.
     *
     *     {
     *        "type": "SubTaskBlockingCondition",
     *        "configuration": {
     *          "statuses": [
     *            {
     *              "id": "1"
     *            },
     *            {
     *              "id": "3"
     *            }
     *          ]
     *        }
     *      }
     *
     *  *  `statuses` A list of objects containing status IDs.
     *
     * ##### User is in any group condition #####
     *
     * A condition that allows users belonging to any group from a list of groups to execute a transition.
     *
     *     {
     *        "type": "UserInAnyGroupCondition",
     *        "configuration": {
     *          "groups": [
     *            "administrators",
     *            "atlassian-addons-admin"
     *          ]
     *        }
     *      }
     *
     *  *  `groups` A list of group names.
     *
     * ##### User is in any project role condition #####
     *
     * A condition that allows only users with at least one project roles from a list of project roles to execute a transition.
     *
     *     {
     *        "type": "InAnyProjectRoleCondition",
     *        "configuration": {
     *          "projectRoles": [
     *            {
     *              "id": "10002"
     *            },
     *            {
     *              "id": "10003"
     *            },
     *            {
     *              "id": "10012"
     *            },
     *            {
     *              "id": "10013"
     *            }
     *          ]
     *        }
     *      }
     *
     *  *  `projectRoles` A list of objects containing project role IDs.
     *
     * ##### User is in custom field condition #####
     *
     * A condition that allows only users listed in a given custom field to execute the transition.
     *
     *     {
     *        "type": "UserIsInCustomFieldCondition",
     *        "configuration": {
     *          "allowUserInField": false,
     *          "fieldId": "customfield_10010"
     *        }
     *      }
     *
     *  *  `allowUserInField` If `true` only a user who is listed in `fieldId` can perform the transition, otherwise, only a user who is not listed in `fieldId` can perform the transition.
     *  *  `fieldId` The ID of the field containing the list of users.
     *
     * ##### User is in group condition #####
     *
     * A condition that allows users belonging to a group to execute a transition.
     *
     *     {
     *        "type": "UserInGroupCondition",
     *        "configuration": {
     *          "group": "administrators"
     *        }
     *      }
     *
     *  *  `group` The name of the group.
     *
     * ##### User is in group custom field condition #####
     *
     * A condition that allows users belonging to a group specified in a custom field to execute a transition.
     *
     *     {
     *        "type": "InGroupCFCondition",
     *        "configuration": {
     *          "fieldId": "customfield_10012"
     *        }
     *      }
     *
     *  *  `fieldId` The ID of the field. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:grouppicker`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:select`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:multiselect`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`
     *      *  `com.pyxis.greenhopper.jira:gh-epic-status`
     *
     * ##### User is in project role condition #####
     *
     * A condition that allows users with a project role to execute a transition.
     *
     *     {
     *        "type": "InProjectRoleCondition",
     *        "configuration": {
     *          "projectRole": {
     *            "id": "10002"
     *          }
     *        }
     *      }
     *
     *  *  `projectRole` An object containing the ID of a project role.
     *
     * ##### Value field condition #####
     *
     * A conditions that allows a transition to execute if the value of a field is equal to a constant value or simply set.
     *
     *     {
     *        "type": "ValueFieldCondition",
     *        "configuration": {
     *          "fieldId": "assignee",
     *          "fieldValue": "qm:6e1ecee6-8e64-4db6-8c85-916bb3275f51:54b56885-2bd2-4381-8239-78263442520f",
     *          "comparisonType": "NUMBER",
     *          "comparator": "="
     *        }
     *      }
     *
     *  *  `fieldId` The ID of a field used in the comparison.
     *  *  `fieldValue` The expected value of the field.
     *  *  `comparisonType` The type of the comparison. Allowed values: `STRING`, `NUMBER`, `DATE`, `DATE_WITHOUT_TIME`, or `OPTIONID`.
     *  *  `comparator` One of the supported comparator: `>`, `>=`, `=`, `<=`, `<`, `!=`.
     *
     * **Notes:**
     *
     *  *  If you choose the comparison type `STRING`, only `=` and `!=` are valid options.
     *  *  You may leave `fieldValue` empty when comparison type is `!=` to indicate that a value is required in the field.
     *  *  For date fields without time format values as `yyyy-MM-dd`, and for those with time as `yyyy-MM-dd HH:mm`. For example, for July 16 2021 use `2021-07-16`, for 8:05 AM use `2021-07-16 08:05`, and for 4 PM: `2021-07-16 16:00`.
     *
     * #### Validators ####
     *
     * Validators check that any input made to the transition is valid before the transition is performed.
     *
     * ##### Date field validator #####
     *
     * A validator that compares two dates.
     *
     *     {
     *        "type": "DateFieldValidator",
     *        "configuration": {
     *            "comparator": ">",
     *            "date1": "updated",
     *            "date2": "created",
     *            "expression": "1d",
     *            "includeTime": true
     *          }
     *      }
     *
     *  *  `comparator` One of the supported comparator: `>`, `>=`, `=`, `<=`, `<`, or `!=`.
     *  *  `date1` The date field to validate. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
     *      *  `duedate`
     *      *  `created`
     *      *  `updated`
     *      *  `Resolved`
     *  *  `date2` The second date field. Required, if `expression` is not passed. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
     *      *  `duedate`
     *      *  `created`
     *      *  `updated`
     *      *  `Resolved`
     *  *  `expression` An expression specifying an offset. Required, if `date2` is not passed. Offsets are built with a number, with `-` as prefix for the past, and one of these time units: `d` for day, `w` for week, `m` for month, or `y` for year. For example, -2d means two days into the past and 1w means one week into the future. The `now` keyword enables a comparison with the current date.
     *  *  `includeTime` If `true`, then the time part of the data is included for the comparison. If the field doesn't have a time part, 00:00:00 is used.
     *
     * ##### Windows date validator #####
     *
     * A validator that checks that a date falls on or after a reference date and before or on the reference date plus a number of days.
     *
     *     {
     *        "type": "WindowsDateValidator",
     *        "configuration": {
     *            "date1": "customfield_10009",
     *            "date2": "created",
     *            "windowsDays": 5
     *          }
     *      }
     *
     *  *  `date1` The date field to validate. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
     *      *  `duedate`
     *      *  `created`
     *      *  `updated`
     *      *  `Resolved`
     *  *  `date2` The reference date. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
     *      *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
     *      *  `duedate`
     *      *  `created`
     *      *  `updated`
     *      *  `Resolved`
     *  *  `windowsDays` A positive integer indicating a number of days.
     *
     * ##### Field required validator #####
     *
     * A validator that checks fields are not empty. By default, if a field is not included in the current context it's ignored and not validated.
     *
     *     {
     *          "type": "FieldRequiredValidator",
     *          "configuration": {
     *              "ignoreContext": true,
     *              "errorMessage": "Hey",
     *              "fieldIds": [
     *                  "versions",
     *                  "customfield_10037",
     *                  "customfield_10003"
     *              ]
     *          }
     *      }
     *
     *  *  `ignoreContext` If `true`, then the context is ignored and all the fields are validated.
     *  *  `errorMessage` OPTIONAL. The error message displayed when one or more fields are empty. A default error message is shown if an error message is not provided.
     *  *  `fieldIds` The list of fields to validate.
     *
     * ##### Field changed validator #####
     *
     * A validator that checks that a field value is changed. However, this validation can be ignored for users from a list of groups.
     *
     *     {
     *          "type": "FieldChangedValidator",
     *          "configuration": {
     *              "fieldId": "comment",
     *              "errorMessage": "Hey",
     *              "exemptedGroups": [
     *                  "administrators",
     *                  "atlassian-addons-admin"
     *              ]
     *          }
     *      }
     *
     *  *  `fieldId` The ID of a field.
     *  *  `errorMessage` OPTIONAL. The error message displayed if the field is not changed. A default error message is shown if the error message is not provided.
     *  *  `exemptedGroups` OPTIONAL. The list of groups.
     *
     * ##### Field has single value validator #####
     *
     * A validator that checks that a multi-select field has only one value. Optionally, the validation can ignore values copied from subtasks.
     *
     *     {
     *          "type": "FieldHasSingleValueValidator",
     *          "configuration": {
     *              "fieldId": "attachment,
     *              "excludeSubtasks": true
     *          }
     *      }
     *
     *  *  `fieldId` The ID of a field.
     *  *  `excludeSubtasks` If `true`, then values copied from subtasks are ignored.
     *
     * ##### Parent status validator #####
     *
     * A validator that checks the status of the parent issue of a subtask. Ìf the issue is not a subtask, no validation is performed.
     *
     *     {
     *          "type": "ParentStatusValidator",
     *          "configuration": {
     *              "parentStatuses": [
     *                  {
     *                    "id":"1"
     *                  },
     *                  {
     *                    "id":"2"
     *                  }
     *              ]
     *          }
     *      }
     *
     *  *  `parentStatus` The list of required parent issue statuses.
     *
     * ##### Permission validator #####
     *
     * A validator that checks the user has a permission.
     *
     *     {
     *        "type": "PermissionValidator",
     *        "configuration": {
     *            "permissionKey": "ADMINISTER_PROJECTS"
     *        }
     *      }
     *
     *  *  `permissionKey` The permission required to perform the transition. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
     *
     * ##### Previous status validator #####
     *
     * A validator that checks if the issue has held a status.
     *
     *     {
     *        "type": "PreviousStatusValidator",
     *        "configuration": {
     *            "mostRecentStatusOnly": false,
     *            "previousStatus": {
     *                "id": "15"
     *            }
     *        }
     *      }
     *
     *  *  `mostRecentStatusOnly` If `true`, then only the issue's preceding status (the one immediately before the current status) is checked.
     *  *  `previousStatus` An object containing the ID of an issue status.
     *
     * ##### Regular expression validator #####
     *
     * A validator that checks the content of a field against a regular expression.
     *
     *     {
     *        "type": "RegexpFieldValidator",
     *        "configuration": {
     *            "regExp": "[0-9]",
     *            "fieldId": "customfield_10029"
     *        }
     *      }
     *
     *  *  `regExp`A regular expression.
     *  *  `fieldId` The ID of a field. Allowed field types:
     *
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:select`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:multiselect`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:textarea`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:textfield`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:url`
     *      *  `com.atlassian.jira.plugin.system.customfieldtypes:float`
     *      *  `com.pyxis.greenhopper.jira:jsw-story-points`
     *      *  `com.pyxis.greenhopper.jira:gh-epic-status`
     *      *  `description`
     *      *  `summary`
     *
     * ##### User permission validator #####
     *
     * A validator that checks if a user has a permission. Obsolete. You may encounter this validator when getting transition rules and can pass it when updating or creating rules, for example, when you want to duplicate the rules from a workflow on a new workflow.
     *
     *     {
     *          "type": "UserPermissionValidator",
     *          "configuration": {
     *              "permissionKey": "BROWSE_PROJECTS",
     *              "nullAllowed": false,
     *              "username": "TestUser"
     *          }
     *      }
     *
     *  *  `permissionKey` The permission to be validated. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
     *  *  `nullAllowed` If `true`, allows the transition when `username` is empty.
     *  *  `username` The username to validate against the `permissionKey`.
     *
     * #### Post functions ####
     *
     * Post functions carry out any additional processing required after a Jira workflow transition is executed.
     *
     * ##### Fire issue event function #####
     *
     * A post function that fires an event that is processed by the listeners.
     *
     *     {
     *        "type": "FireIssueEventFunction",
     *        "configuration": {
     *          "event": {
     *            "id":"1"
     *          }
     *        }
     *      }
     *
     * **Note:** If provided, this post function overrides the default `FireIssueEventFunction`. Can be included once in a transition.
     *
     *  *  `event` An object containing the ID of the issue event.
     *
     * ##### Update issue status #####
     *
     * A post function that sets issue status to the linked status of the destination workflow status.
     *
     *     {
     *        "type": "UpdateIssueStatusFunction"
     *      }
     *
     * **Note:** This post function is a default function in global and directed transitions. It can only be added to the initial transition and can only be added once.
     *
     * ##### Create comment #####
     *
     * A post function that adds a comment entered during the transition to an issue.
     *
     *     {
     *        "type": "CreateCommentFunction"
     *      }
     *
     * **Note:** This post function is a default function in global and directed transitions. It can only be added to the initial transition and can only be added once.
     *
     * ##### Store issue #####
     *
     * A post function that stores updates to an issue.
     *
     *     {
     *        "type": "IssueStoreFunction"
     *      }
     *
     * **Note:** This post function can only be added to the initial transition and can only be added once.
     *
     * ##### Assign to current user function #####
     *
     * A post function that assigns the issue to the current user if the current user has the `ASSIGNABLE_USER` permission.
     *
     *     {
     *          "type": "AssignToCurrentUserFunction"
     *      }
     *
     * **Note:** This post function can be included once in a transition.
     *
     * ##### Assign to lead function #####
     *
     * A post function that assigns the issue to the project or component lead developer.
     *
     *     {
     *          "type": "AssignToLeadFunction"
     *      }
     *
     * **Note:** This post function can be included once in a transition.
     *
     * ##### Assign to reporter function #####
     *
     * A post function that assigns the issue to the reporter.
     *
     *     {
     *          "type": "AssignToReporterFunction"
     *      }
     *
     * **Note:** This post function can be included once in a transition.
     *
     * ##### Clear field value function #####
     *
     * A post function that clears the value from a field.
     *
     *     {
     *        "type": "ClearFieldValuePostFunction",
     *        "configuration": {
     *          "fieldId": "assignee"
     *        }
     *      }
     *
     *  *  `fieldId` The ID of the field.
     *
     * ##### Copy value from other field function #####
     *
     * A post function that copies the value of one field to another, either within an issue or from parent to subtask.
     *
     *     {
     *        "type": "CopyValueFromOtherFieldPostFunction",
     *        "configuration": {
     *          "sourceFieldId": "assignee",
     *          "destinationFieldId": "creator",
     *          "copyType": "same"
     *        }
     *      }
     *
     *  *  `sourceFieldId` The ID of the source field.
     *  *  `destinationFieldId` The ID of the destination field.
     *  *  `copyType` Use `same` to copy the value from a field inside the issue, or `parent` to copy the value from the parent issue.
     *
     * ##### Create Crucible review workflow function #####
     *
     * A post function that creates a Crucible review for all unreviewed code for the issue.
     *
     *     {
     *          "type": "CreateCrucibleReviewWorkflowFunction"
     *      }
     *
     * **Note:** This post function can be included once in a transition.
     *
     * ##### Set issue security level based on user's project role function #####
     *
     * A post function that sets the issue's security level if the current user has a project role.
     *
     *     {
     *        "type": "SetIssueSecurityFromRoleFunction",
     *        "configuration": {
     *          "projectRole": {
     *              "id":"10002"
     *          },
     *          "issueSecurityLevel": {
     *              "id":"10000"
     *          }
     *        }
     *      }
     *
     *  *  `projectRole` An object containing the ID of the project role.
     *  *  `issueSecurityLevel` OPTIONAL. The object containing the ID of the security level. If not passed, then the security level is set to `none`.
     *
     * ##### Trigger a webhook function #####
     *
     * A post function that triggers a webhook.
     *
     *     {
     *        "type": "TriggerWebhookFunction",
     *        "configuration": {
     *          "webhook": {
     *            "id": "1"
     *          }
     *        }
     *      }
     *
     *  *  `webhook` An object containing the ID of the webhook listener to trigger.
     *
     * ##### Update issue custom field function #####
     *
     * A post function that updates the content of an issue custom field.
     *
     *     {
     *        "type": "UpdateIssueCustomFieldPostFunction",
     *        "configuration": {
     *          "mode": "append",
     *          "fieldId": "customfield_10003",
     *          "fieldValue": "yikes"
     *        }
     *      }
     *
     *  *  `mode` Use `replace` to override the field content with `fieldValue` or `append` to add `fieldValue` to the end of the field content.
     *  *  `fieldId` The ID of the field.
     *  *  `fieldValue` The update content.
     *
     * ##### Update issue field function #####
     *
     * A post function that updates a simple issue field.
     *
     *     {
     *        "type": "UpdateIssueFieldFunction",
     *        "configuration": {
     *          "fieldId": "assignee",
     *          "fieldValue": "5f0c277e70b8a90025a00776"
     *        }
     *      }
     *
     *  *  `fieldId` The ID of the field. Allowed field types:
     *
     *      *  `assignee`
     *      *  `description`
     *      *  `environment`
     *      *  `priority`
     *      *  `resolution`
     *      *  `summary`
     *      *  `timeoriginalestimate`
     *      *  `timeestimate`
     *      *  `timespent`
     *  *  `fieldValue` The update value.
     *  *  If the `fieldId` is `assignee`, the `fieldValue` should be one of these values:
     *
     *      *  an account ID.
     *      *  `automatic`.
     *      *  a blank string, which sets the value to `unassigned`.
     *
     * #### Connect rules ####
     *
     * Connect rules are conditions, validators, and post functions of a transition that are registered by Connect apps. To create a rule registered by the app, the app must be enabled and the rule's module must exist.
     *
     *     {
     *        "type": "appKey__moduleKey",
     *        "configuration": {
     *          "value":"{\"isValid\":\"true\"}"
     *        }
     *      }
     *
     *  *  `type` A Connect rule key in a form of `appKey__moduleKey`.
     *  *  `value` The stringified JSON configuration of a Connect rule.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createWorkflow
     * Request URI: /rest/api/3/workflow
     */
    createWorkflow(params: Params$createWorkflow, option?: RequestOption): Promise<Response$createWorkflow$Status$201["application/json"]>;
    /**
     * Get workflow transition rule configurations
     * Returns a [paginated](#pagination) list of workflows with transition rules. The workflows can be filtered to return only those containing workflow transition rules:
     *
     *  *  of one or more transition rule types, such as [workflow post functions](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-post-function/).
     *  *  matching one or more transition rule keys.
     *
     * Only workflows containing transition rules created by the calling Connect app are returned. However, if a workflow is returned all transition rules that match the filters are returned for that workflow.
     *
     * Due to server-side optimizations, workflows with an empty list of rules may be returned; these workflows can be ignored.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can use this operation.
     * operationId: getWorkflowTransitionRuleConfigurations
     * Request URI: /rest/api/3/workflow/rule/config
     */
    getWorkflowTransitionRuleConfigurations(params: Params$getWorkflowTransitionRuleConfigurations, option?: RequestOption): Promise<Response$getWorkflowTransitionRuleConfigurations$Status$200["application/json"]>;
    /**
     * Update workflow transition rule configurations
     * Updates configuration of workflow transition rules. The following rule types are supported:
     *
     *  *  [post functions](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-post-function/)
     *  *  [conditions](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-condition/)
     *  *  [validators](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-validator/)
     *
     * Only rules created by the calling Connect app can be updated.
     *
     * To assist with app migration, this operation can be used to:
     *
     *  *  Disable a rule.
     *  *  Add a `tag`. Use this to filter rules in the [Get workflow transition rule configurations](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-rules/#api-rest-api-3-workflow-rule-config-get).
     *
     * Rules are enabled if the `disabled` parameter is not provided.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can use this operation.
     * operationId: updateWorkflowTransitionRuleConfigurations
     * Request URI: /rest/api/3/workflow/rule/config
     */
    updateWorkflowTransitionRuleConfigurations(params: Params$updateWorkflowTransitionRuleConfigurations, option?: RequestOption): Promise<Response$updateWorkflowTransitionRuleConfigurations$Status$200["application/json"]>;
    /**
     * Delete workflow transition rule configurations
     * Deletes workflow transition rules from one or more workflows. These rule types are supported:
     *
     *  *  [post functions](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-post-function/)
     *  *  [conditions](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-condition/)
     *  *  [validators](https://developer.atlassian.com/cloud/jira/platform/modules/workflow-validator/)
     *
     * Only rules created by the calling Connect app can be deleted.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can use this operation.
     * operationId: deleteWorkflowTransitionRuleConfigurations
     * Request URI: /rest/api/3/workflow/rule/config/delete
     */
    deleteWorkflowTransitionRuleConfigurations(params: Params$deleteWorkflowTransitionRuleConfigurations, option?: RequestOption): Promise<Response$deleteWorkflowTransitionRuleConfigurations$Status$200["application/json"]>;
    /**
     * Get workflows paginated
     * Returns a [paginated](#pagination) list of published classic workflows. When workflow names are specified, details of those workflows are returned. Otherwise, all published classic workflows are returned.
     *
     * This operation does not return next-gen workflows.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowsPaginated
     * Request URI: /rest/api/3/workflow/search
     */
    getWorkflowsPaginated(params: Params$getWorkflowsPaginated, option?: RequestOption): Promise<Response$getWorkflowsPaginated$Status$200["application/json"]>;
    /**
     * Get workflow transition properties
     * Returns the properties on a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowTransitionProperties
     * Request URI: /rest/api/3/workflow/transitions/{transitionId}/properties
     */
    getWorkflowTransitionProperties(params: Params$getWorkflowTransitionProperties, option?: RequestOption): Promise<Response$getWorkflowTransitionProperties$Status$200["application/json"]>;
    /**
     * Update workflow transition property
     * Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateWorkflowTransitionProperty
     * Request URI: /rest/api/3/workflow/transitions/{transitionId}/properties
     */
    updateWorkflowTransitionProperty(params: Params$updateWorkflowTransitionProperty, option?: RequestOption): Promise<Response$updateWorkflowTransitionProperty$Status$200["application/json"]>;
    /**
     * Create workflow transition property
     * Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createWorkflowTransitionProperty
     * Request URI: /rest/api/3/workflow/transitions/{transitionId}/properties
     */
    createWorkflowTransitionProperty(params: Params$createWorkflowTransitionProperty, option?: RequestOption): Promise<Response$createWorkflowTransitionProperty$Status$200["application/json"]>;
    /**
     * Delete workflow transition property
     * Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteWorkflowTransitionProperty
     * Request URI: /rest/api/3/workflow/transitions/{transitionId}/properties
     */
    deleteWorkflowTransitionProperty(params: Params$deleteWorkflowTransitionProperty, option?: RequestOption): Promise<void>;
    /**
     * Delete inactive workflow
     * Deletes a workflow.
     *
     * The workflow cannot be deleted if it is:
     *
     *  *  an active workflow.
     *  *  a system workflow.
     *  *  associated with any workflow scheme.
     *  *  associated with any draft workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteInactiveWorkflow
     * Request URI: /rest/api/3/workflow/{entityId}
     */
    deleteInactiveWorkflow(params: Params$deleteInactiveWorkflow, option?: RequestOption): Promise<void>;
    /**
     * Get all workflow schemes
     * Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getAllWorkflowSchemes
     * Request URI: /rest/api/3/workflowscheme
     */
    getAllWorkflowSchemes(params: Params$getAllWorkflowSchemes, option?: RequestOption): Promise<Response$getAllWorkflowSchemes$Status$200["application/json"]>;
    /**
     * Create workflow scheme
     * Creates a workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createWorkflowScheme
     * Request URI: /rest/api/3/workflowscheme
     */
    createWorkflowScheme(params: Params$createWorkflowScheme, option?: RequestOption): Promise<Response$createWorkflowScheme$Status$201["application/json"]>;
    /**
     * Get workflow scheme project associations
     * Returns a list of the workflow schemes associated with a list of projects. Each returned workflow scheme includes a list of the requested projects associated with it. Any team-managed or non-existent projects in the request are ignored and no errors are returned.
     *
     * If the project is associated with the `Default Workflow Scheme` no ID is returned. This is because the way the `Default Workflow Scheme` is stored means it has no ID.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowSchemeProjectAssociations
     * Request URI: /rest/api/3/workflowscheme/project
     */
    getWorkflowSchemeProjectAssociations(params: Params$getWorkflowSchemeProjectAssociations, option?: RequestOption): Promise<Response$getWorkflowSchemeProjectAssociations$Status$200["application/json"]>;
    /**
     * Assign workflow scheme to project
     * Assigns a workflow scheme to a project. This operation is performed only when there are no issues in the project.
     *
     * Workflow schemes can only be assigned to classic projects.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: assignSchemeToProject
     * Request URI: /rest/api/3/workflowscheme/project
     */
    assignSchemeToProject(params: Params$assignSchemeToProject, option?: RequestOption): Promise<Response$assignSchemeToProject$Status$204["application/json"]>;
    /**
     * Get workflow scheme
     * Returns a workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowScheme
     * Request URI: /rest/api/3/workflowscheme/{id}
     */
    getWorkflowScheme(params: Params$getWorkflowScheme, option?: RequestOption): Promise<Response$getWorkflowScheme$Status$200["application/json"]>;
    /**
     * Update workflow scheme
     * Updates a workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateWorkflowScheme
     * Request URI: /rest/api/3/workflowscheme/{id}
     */
    updateWorkflowScheme(params: Params$updateWorkflowScheme, option?: RequestOption): Promise<Response$updateWorkflowScheme$Status$200["application/json"]>;
    /**
     * Delete workflow scheme
     * Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteWorkflowScheme
     * Request URI: /rest/api/3/workflowscheme/{id}
     */
    deleteWorkflowScheme(params: Params$deleteWorkflowScheme, option?: RequestOption): Promise<void>;
    /**
     * Create draft workflow scheme
     * Create a draft workflow scheme from an active workflow scheme, by copying the active workflow scheme. Note that an active workflow scheme can only have one draft workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: createWorkflowSchemeDraftFromParent
     * Request URI: /rest/api/3/workflowscheme/{id}/createdraft
     */
    createWorkflowSchemeDraftFromParent(params: Params$createWorkflowSchemeDraftFromParent, option?: RequestOption): Promise<Response$createWorkflowSchemeDraftFromParent$Status$201["application/json"]>;
    /**
     * Get default workflow
     * Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getDefaultWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/default
     */
    getDefaultWorkflow(params: Params$getDefaultWorkflow, option?: RequestOption): Promise<Response$getDefaultWorkflow$Status$200["application/json"]>;
    /**
     * Update default workflow
     * Sets the default workflow for a workflow scheme.
     *
     * Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateDefaultWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/default
     */
    updateDefaultWorkflow(params: Params$updateDefaultWorkflow, option?: RequestOption): Promise<Response$updateDefaultWorkflow$Status$200["application/json"]>;
    /**
     * Delete default workflow
     * Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).
     *
     * Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteDefaultWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/default
     */
    deleteDefaultWorkflow(params: Params$deleteDefaultWorkflow, option?: RequestOption): Promise<Response$deleteDefaultWorkflow$Status$200["application/json"]>;
    /**
     * Get draft workflow scheme
     * Returns the draft workflow scheme for an active workflow scheme. Draft workflow schemes allow changes to be made to the active workflow schemes: When an active workflow scheme is updated, a draft copy is created. The draft is modified, then the changes in the draft are copied back to the active workflow scheme. See [Configuring workflow schemes](https://confluence.atlassian.com/x/tohKLg) for more information.
     * Note that:
     *
     *  *  Only active workflow schemes can have draft workflow schemes.
     *  *  An active workflow scheme can only have one draft workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowSchemeDraft
     * Request URI: /rest/api/3/workflowscheme/{id}/draft
     */
    getWorkflowSchemeDraft(params: Params$getWorkflowSchemeDraft, option?: RequestOption): Promise<Response$getWorkflowSchemeDraft$Status$200["application/json"]>;
    /**
     * Update draft workflow scheme
     * Updates a draft workflow scheme. If a draft workflow scheme does not exist for the active workflow scheme, then a draft is created. Note that an active workflow scheme can only have one draft workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateWorkflowSchemeDraft
     * Request URI: /rest/api/3/workflowscheme/{id}/draft
     */
    updateWorkflowSchemeDraft(params: Params$updateWorkflowSchemeDraft, option?: RequestOption): Promise<Response$updateWorkflowSchemeDraft$Status$200["application/json"]>;
    /**
     * Delete draft workflow scheme
     * Deletes a draft workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteWorkflowSchemeDraft
     * Request URI: /rest/api/3/workflowscheme/{id}/draft
     */
    deleteWorkflowSchemeDraft(params: Params$deleteWorkflowSchemeDraft, option?: RequestOption): Promise<void>;
    /**
     * Get draft default workflow
     * Returns the default workflow for a workflow scheme's draft. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getDraftDefaultWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/default
     */
    getDraftDefaultWorkflow(params: Params$getDraftDefaultWorkflow, option?: RequestOption): Promise<Response$getDraftDefaultWorkflow$Status$200["application/json"]>;
    /**
     * Update draft default workflow
     * Sets the default workflow for a workflow scheme's draft.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateDraftDefaultWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/default
     */
    updateDraftDefaultWorkflow(params: Params$updateDraftDefaultWorkflow, option?: RequestOption): Promise<Response$updateDraftDefaultWorkflow$Status$200["application/json"]>;
    /**
     * Delete draft default workflow
     * Resets the default workflow for a workflow scheme's draft. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteDraftDefaultWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/default
     */
    deleteDraftDefaultWorkflow(params: Params$deleteDraftDefaultWorkflow, option?: RequestOption): Promise<Response$deleteDraftDefaultWorkflow$Status$200["application/json"]>;
    /**
     * Get workflow for issue type in draft workflow scheme
     * Returns the issue type-workflow mapping for an issue type in a workflow scheme's draft.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowSchemeDraftIssueType
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType}
     */
    getWorkflowSchemeDraftIssueType(params: Params$getWorkflowSchemeDraftIssueType, option?: RequestOption): Promise<Response$getWorkflowSchemeDraftIssueType$Status$200["application/json"]>;
    /**
     * Set workflow for issue type in draft workflow scheme
     * Sets the workflow for an issue type in a workflow scheme's draft.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setWorkflowSchemeDraftIssueType
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType}
     */
    setWorkflowSchemeDraftIssueType(params: Params$setWorkflowSchemeDraftIssueType, option?: RequestOption): Promise<Response$setWorkflowSchemeDraftIssueType$Status$200["application/json"]>;
    /**
     * Delete workflow for issue type in draft workflow scheme
     * Deletes the issue type-workflow mapping for an issue type in a workflow scheme's draft.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteWorkflowSchemeDraftIssueType
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/issuetype/{issueType}
     */
    deleteWorkflowSchemeDraftIssueType(params: Params$deleteWorkflowSchemeDraftIssueType, option?: RequestOption): Promise<Response$deleteWorkflowSchemeDraftIssueType$Status$200["application/json"]>;
    /**
     * Publish draft workflow scheme
     * Publishes a draft workflow scheme.
     *
     * Where the draft workflow includes new workflow statuses for an issue type, mappings are provided to update issues with the original workflow status to the new workflow status.
     *
     * This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain updates.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: publishDraftWorkflowScheme
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/publish
     */
    publishDraftWorkflowScheme(params: Params$publishDraftWorkflowScheme, option?: RequestOption): Promise<void>;
    /**
     * Get issue types for workflows in draft workflow scheme
     * Returns the workflow-issue type mappings for a workflow scheme's draft.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getDraftWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/workflow
     */
    getDraftWorkflow(params: Params$getDraftWorkflow, option?: RequestOption): Promise<Response$getDraftWorkflow$Status$200["application/json"]>;
    /**
     * Set issue types for workflow in workflow scheme
     * Sets the issue types for a workflow in a workflow scheme's draft. The workflow can also be set as the default workflow for the draft workflow scheme. Unmapped issues types are mapped to the default workflow.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateDraftWorkflowMapping
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/workflow
     */
    updateDraftWorkflowMapping(params: Params$updateDraftWorkflowMapping, option?: RequestOption): Promise<Response$updateDraftWorkflowMapping$Status$200["application/json"]>;
    /**
     * Delete issue types for workflow in draft workflow scheme
     * Deletes the workflow-issue type mapping for a workflow in a workflow scheme's draft.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteDraftWorkflowMapping
     * Request URI: /rest/api/3/workflowscheme/{id}/draft/workflow
     */
    deleteDraftWorkflowMapping(params: Params$deleteDraftWorkflowMapping, option?: RequestOption): Promise<void>;
    /**
     * Get workflow for issue type in workflow scheme
     * Returns the issue type-workflow mapping for an issue type in a workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflowSchemeIssueType
     * Request URI: /rest/api/3/workflowscheme/{id}/issuetype/{issueType}
     */
    getWorkflowSchemeIssueType(params: Params$getWorkflowSchemeIssueType, option?: RequestOption): Promise<Response$getWorkflowSchemeIssueType$Status$200["application/json"]>;
    /**
     * Set workflow for issue type in workflow scheme
     * Sets the workflow for an issue type in a workflow scheme.
     *
     * Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: setWorkflowSchemeIssueType
     * Request URI: /rest/api/3/workflowscheme/{id}/issuetype/{issueType}
     */
    setWorkflowSchemeIssueType(params: Params$setWorkflowSchemeIssueType, option?: RequestOption): Promise<Response$setWorkflowSchemeIssueType$Status$200["application/json"]>;
    /**
     * Delete workflow for issue type in workflow scheme
     * Deletes the issue type-workflow mapping for an issue type in a workflow scheme.
     *
     * Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteWorkflowSchemeIssueType
     * Request URI: /rest/api/3/workflowscheme/{id}/issuetype/{issueType}
     */
    deleteWorkflowSchemeIssueType(params: Params$deleteWorkflowSchemeIssueType, option?: RequestOption): Promise<Response$deleteWorkflowSchemeIssueType$Status$200["application/json"]>;
    /**
     * Get issue types for workflows in workflow scheme
     * Returns the workflow-issue type mappings for a workflow scheme.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: getWorkflow
     * Request URI: /rest/api/3/workflowscheme/{id}/workflow
     */
    getWorkflow(params: Params$getWorkflow, option?: RequestOption): Promise<Response$getWorkflow$Status$200["application/json"]>;
    /**
     * Set issue types for workflow in workflow scheme
     * Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.
     *
     * Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: updateWorkflowMapping
     * Request URI: /rest/api/3/workflowscheme/{id}/workflow
     */
    updateWorkflowMapping(params: Params$updateWorkflowMapping, option?: RequestOption): Promise<Response$updateWorkflowMapping$Status$200["application/json"]>;
    /**
     * Delete issue types for workflow in workflow scheme
     * Deletes the workflow-issue type mapping for a workflow in a workflow scheme.
     *
     * Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.
     *
     * **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     * operationId: deleteWorkflowMapping
     * Request URI: /rest/api/3/workflowscheme/{id}/workflow
     */
    deleteWorkflowMapping(params: Params$deleteWorkflowMapping, option?: RequestOption): Promise<void>;
    /**
     * Get IDs of deleted worklogs
     * Returns a list of IDs and delete timestamps for worklogs deleted after a date and time.
     *
     * This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
     *
     * This resource does not return worklogs deleted during the minute preceding the request.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira.
     * operationId: getIdsOfWorklogsDeletedSince
     * Request URI: /rest/api/3/worklog/deleted
     */
    getIdsOfWorklogsDeletedSince(params: Params$getIdsOfWorklogsDeletedSince, option?: RequestOption): Promise<Response$getIdsOfWorklogsDeletedSince$Status$200["application/json"]>;
    /**
     * Get worklogs
     * Returns worklog details for a list of worklog IDs.
     *
     * The returned list of worklogs is limited to 1000 items.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
     *
     *  *  the worklog is set as *Viewable by All Users*.
     *  *  the user is a member of a project role or group with permission to view the worklog.
     * operationId: getWorklogsForIds
     * Request URI: /rest/api/3/worklog/list
     */
    getWorklogsForIds(params: Params$getWorklogsForIds, option?: RequestOption): Promise<Response$getWorklogsForIds$Status$200["application/json"]>;
    /**
     * Get IDs of updated worklogs
     * Returns a list of IDs and update timestamps for worklogs updated after a date and time.
     *
     * This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
     *
     * This resource does not return worklogs updated during the minute preceding the request.
     *
     * **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
     *
     *  *  the worklog is set as *Viewable by All Users*.
     *  *  the user is a member of a project role or group with permission to view the worklog.
     * operationId: getIdsOfWorklogsModifiedSince
     * Request URI: /rest/api/3/worklog/updated
     */
    getIdsOfWorklogsModifiedSince(params: Params$getIdsOfWorklogsModifiedSince, option?: RequestOption): Promise<Response$getIdsOfWorklogsModifiedSince$Status$200["application/json"]>;
    /**
     * Get app properties
     * Gets all the properties of an app.
     *
     * **[Permissions](#permissions) required:** Only a Connect app whose key matches `addonKey` can make this request.
     * operationId: AddonPropertiesResource.getAddonProperties_get
     * Request URI: /rest/atlassian-connect/1/addons/{addonKey}/properties
     */
    AddonPropertiesResource$getAddonProperties_get(params: Params$AddonPropertiesResource$getAddonProperties_get, option?: RequestOption): Promise<Response$AddonPropertiesResource$getAddonProperties_get$Status$200["application/json"]>;
    /**
     * Get app property
     * Returns the key and value of an app's property.
     *
     * **[Permissions](#permissions) required:** Only a Connect app whose key matches `addonKey` can make this request.
     * operationId: AddonPropertiesResource.getAddonProperty_get
     * Request URI: /rest/atlassian-connect/1/addons/{addonKey}/properties/{propertyKey}
     */
    AddonPropertiesResource$getAddonProperty_get(params: Params$AddonPropertiesResource$getAddonProperty_get, option?: RequestOption): Promise<Response$AddonPropertiesResource$getAddonProperty_get$Status$200["application/json"]>;
    /**
     * Set app property
     * Sets the value of an app's property. Use this resource to store custom data for your app.
     *
     * The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
     *
     * **[Permissions](#permissions) required:** Only a Connect app whose key matches `addonKey` can make this request.
     * operationId: AddonPropertiesResource.putAddonProperty_put
     * Request URI: /rest/atlassian-connect/1/addons/{addonKey}/properties/{propertyKey}
     */
    AddonPropertiesResource$putAddonProperty_put(params: Params$AddonPropertiesResource$putAddonProperty_put, option?: RequestOption): Promise<(Response$AddonPropertiesResource$putAddonProperty_put$Status$200 | Response$AddonPropertiesResource$putAddonProperty_put$Status$201)["application/json"]>;
    /**
     * Delete app property
     * Deletes an app's property.
     *
     * **[Permissions](#permissions) required:** Only a Connect app whose key matches `addonKey` can make this request.
     * operationId: AddonPropertiesResource.deleteAddonProperty_delete
     * Request URI: /rest/atlassian-connect/1/addons/{addonKey}/properties/{propertyKey}
     */
    AddonPropertiesResource$deleteAddonProperty_delete(params: Params$AddonPropertiesResource$deleteAddonProperty_delete, option?: RequestOption): Promise<void>;
    /**
     * Get modules
     * Returns all modules registered dynamically by the calling app.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can make this request.
     * operationId: DynamicModulesResource.getModules_get
     * Request URI: /rest/atlassian-connect/1/app/module/dynamic
     */
    DynamicModulesResource$getModules_get(option?: RequestOption): Promise<Response$DynamicModulesResource$getModules_get$Status$200["application/json"]>;
    /**
     * Register modules
     * Registers a list of modules.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can make this request.
     * operationId: DynamicModulesResource.registerModules_post
     * Request URI: /rest/atlassian-connect/1/app/module/dynamic
     */
    DynamicModulesResource$registerModules_post(params: Params$DynamicModulesResource$registerModules_post, option?: RequestOption): Promise<void>;
    /**
     * Remove modules
     * Remove all or a list of modules registered by the calling app.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can make this request.
     * operationId: DynamicModulesResource.removeModules_delete
     * Request URI: /rest/atlassian-connect/1/app/module/dynamic
     */
    DynamicModulesResource$removeModules_delete(params: Params$DynamicModulesResource$removeModules_delete, option?: RequestOption): Promise<void>;
    /**
     * Bulk update custom field value
     * Updates the value of a custom field added by Connect apps on one or more issues.
     * The values of up to 200 custom fields can be updated.
     *
     * **[Permissions](#permissions) required:** Only Connect apps can make this request.
     * operationId: AppIssueFieldValueUpdateResource.updateIssueFields_put
     * Request URI: /rest/atlassian-connect/1/migration/field
     */
    AppIssueFieldValueUpdateResource$updateIssueFields_put(params: Params$AppIssueFieldValueUpdateResource$updateIssueFields_put, option?: RequestOption): Promise<Response$AppIssueFieldValueUpdateResource$updateIssueFields_put$Status$200["application/json"]>;
    /**
     * Bulk update entity properties
     * Updates the values of multiple entity properties for an object, up to 50 updates per request. This operation is for use by Connect apps during app migration.
     * operationId: MigrationResource.updateEntityPropertiesValue_put
     * Request URI: /rest/atlassian-connect/1/migration/properties/{entityType}
     */
    MigrationResource$updateEntityPropertiesValue_put(params: Params$MigrationResource$updateEntityPropertiesValue_put, option?: RequestOption): Promise<void>;
    /**
     * Get workflow transition rule configurations
     * Returns configurations for workflow transition rules migrated from server to cloud and owned by the calling Connect app.
     * operationId: MigrationResource.workflowRuleSearch_post
     * Request URI: /rest/atlassian-connect/1/migration/workflow/rule/search
     */
    MigrationResource$workflowRuleSearch_post(params: Params$MigrationResource$workflowRuleSearch_post, option?: RequestOption): Promise<Response$MigrationResource$workflowRuleSearch_post$Status$200["application/json"]>;
}
